/* Generated automatically by the program `gencodes'
   from the machine description file `md'.  */

#ifndef GCC_INSN_CODES_H
#define GCC_INSN_CODES_H

enum insn_code {
  CODE_FOR_nothing = 0,
  CODE_FOR_ccmpqi = 1,
  CODE_FOR_ccmphi = 2,
  CODE_FOR_ccmpsi = 3,
  CODE_FOR_ccmpdi = 4,
  CODE_FOR_x86_sahf_1 = 51,
  CODE_FOR_x86_stc = 67,
  CODE_FOR_pushflsi2 = 84,
  CODE_FOR_pushfldi2 = 85,
  CODE_FOR_popflsi1 = 86,
  CODE_FOR_popfldi1 = 87,
  CODE_FOR_swapsi = 111,
  CODE_FOR_swapdi = 112,
  CODE_FOR_insvhi_1 = 132,
  CODE_FOR_insvsi_1 = 133,
  CODE_FOR_insvdi_1 = 134,
  CODE_FOR_push2_di = 163,
  CODE_FOR_pop2_di = 164,
  CODE_FOR_pushp_di = 165,
  CODE_FOR_popp_di = 166,
  CODE_FOR_push2p_di = 167,
  CODE_FOR_pop2p_di = 168,
  CODE_FOR_zero_extendditi2 = 178,
  CODE_FOR_zero_extendqidi2 = 180,
  CODE_FOR_zero_extendhidi2 = 181,
  CODE_FOR_zero_extendqisi2_and = 182,
  CODE_FOR_zero_extendhisi2_and = 183,
  CODE_FOR_zero_extendqihi2_and = 186,
  CODE_FOR_extendsidi2_1 = 189,
  CODE_FOR_extendditi2 = 190,
  CODE_FOR_extendqidi2 = 191,
  CODE_FOR_extendhidi2 = 192,
  CODE_FOR_extendhisi2 = 193,
  CODE_FOR_extendqisi2 = 195,
  CODE_FOR_extendqihi2 = 197,
  CODE_FOR_extendbfsf2_1 = 207,
  CODE_FOR_truncdfsf2 = 210,
  CODE_FOR_truncxfsf2 = 211,
  CODE_FOR_truncxfdf2 = 212,
  CODE_FOR_truncsfbf2 = 215,
  CODE_FOR_fix_trunchfsi2 = 216,
  CODE_FOR_fixuns_trunchfsi2 = 217,
  CODE_FOR_fix_trunchfdi2 = 218,
  CODE_FOR_fixuns_trunchfdi2 = 219,
  CODE_FOR_fixuns_truncsfdi2 = 220,
  CODE_FOR_fixuns_truncdfdi2 = 221,
  CODE_FOR_fixuns_truncsfsi2_avx512f = 222,
  CODE_FOR_fixuns_truncdfsi2_avx512f = 223,
  CODE_FOR_fix_truncsfsi_sse = 229,
  CODE_FOR_fix_truncsfdi_sse = 230,
  CODE_FOR_fix_truncdfsi_sse = 231,
  CODE_FOR_fix_truncdfdi_sse = 232,
  CODE_FOR_fix_trunchi_i387_fisttp = 233,
  CODE_FOR_fix_truncsi_i387_fisttp = 234,
  CODE_FOR_fix_truncdi_i387_fisttp = 235,
  CODE_FOR_fix_truncdi_i387 = 239,
  CODE_FOR_fix_trunchi_i387 = 240,
  CODE_FOR_fix_truncsi_i387 = 241,
  CODE_FOR_x86_fnstcw_1 = 242,
  CODE_FOR_floathisf2 = 243,
  CODE_FOR_floathidf2 = 244,
  CODE_FOR_floathixf2 = 245,
  CODE_FOR_floatsixf2 = 246,
  CODE_FOR_floatdixf2 = 247,
  CODE_FOR_floatsihf2 = 252,
  CODE_FOR_floatunssihf2 = 253,
  CODE_FOR_floatdihf2 = 254,
  CODE_FOR_floatunsdihf2 = 255,
  CODE_FOR_floatdisf2_i387_with_xmm = 258,
  CODE_FOR_floatdidf2_i387_with_xmm = 259,
  CODE_FOR_floatdixf2_i387_with_xmm = 260,
  CODE_FOR_floatunssisf2_i387_with_xmm = 265,
  CODE_FOR_floatunssidf2_i387_with_xmm = 266,
  CODE_FOR_floatunssixf2_i387_with_xmm = 267,
  CODE_FOR_addsi_1_zext = 300,
  CODE_FOR_addvqi4_1 = 350,
  CODE_FOR_addvhi4_1 = 351,
  CODE_FOR_addvsi4_1 = 352,
  CODE_FOR_addvdi4_1 = 353,
  CODE_FOR_subvqi4_1 = 433,
  CODE_FOR_subvhi4_1 = 434,
  CODE_FOR_subvsi4_1 = 435,
  CODE_FOR_subvdi4_1 = 436,
  CODE_FOR_addqi3_carry = 457,
  CODE_FOR_addhi3_carry = 458,
  CODE_FOR_addsi3_carry = 459,
  CODE_FOR_adddi3_carry = 460,
  CODE_FOR_addcarrysi = 499,
  CODE_FOR_addcarrydi = 500,
  CODE_FOR_subqi3_carry = 503,
  CODE_FOR_subhi3_carry = 504,
  CODE_FOR_subsi3_carry = 505,
  CODE_FOR_subdi3_carry = 506,
  CODE_FOR_subsi3_carry_ccc = 545,
  CODE_FOR_subdi3_carry_ccc = 546,
  CODE_FOR_subsi3_carry_ccgz = 549,
  CODE_FOR_subdi3_carry_ccgz = 550,
  CODE_FOR_subborrowsi = 551,
  CODE_FOR_subborrowdi = 552,
  CODE_FOR_addqi3_cc_overflow_1 = 566,
  CODE_FOR_addhi3_cc_overflow_1 = 567,
  CODE_FOR_addsi3_cc_overflow_1 = 568,
  CODE_FOR_adddi3_cc_overflow_1 = 569,
  CODE_FOR_smulsi3_highpart = 655,
  CODE_FOR_umulsi3_highpart = 656,
  CODE_FOR_smuldi3_highpart = 657,
  CODE_FOR_umuldi3_highpart = 658,
  CODE_FOR_divmodsi4_1 = 667,
  CODE_FOR_divmoddi4_1 = 668,
  CODE_FOR_udivmodsi4_1 = 669,
  CODE_FOR_udivmoddi4_1 = 670,
  CODE_FOR_divmodsi4_zext_1 = 671,
  CODE_FOR_udivmodsi4_zext_1 = 672,
  CODE_FOR_divmodsi4_zext_2 = 673,
  CODE_FOR_udivmodsi4_zext_2 = 674,
  CODE_FOR_divmodhiqi3_nf = 706,
  CODE_FOR_divmodhiqi3 = 707,
  CODE_FOR_udivmodhiqi3_nf = 708,
  CODE_FOR_udivmodhiqi3 = 709,
  CODE_FOR_ashldi3_doubleword = 1088,
  CODE_FOR_ashlti3_doubleword = 1089,
  CODE_FOR_x86_64_shld_nf = 1094,
  CODE_FOR_x86_64_shld = 1095,
  CODE_FOR_x86_64_shld_ndd_nf = 1096,
  CODE_FOR_x86_64_shld_ndd = 1097,
  CODE_FOR_x86_64_shld_1_nf = 1098,
  CODE_FOR_x86_64_shld_1 = 1099,
  CODE_FOR_x86_64_shld_ndd_1_nf = 1100,
  CODE_FOR_x86_64_shld_ndd_1 = 1101,
  CODE_FOR_x86_shld_nf = 1106,
  CODE_FOR_x86_shld = 1107,
  CODE_FOR_x86_shld_ndd_nf = 1108,
  CODE_FOR_x86_shld_ndd = 1109,
  CODE_FOR_x86_shld_1_nf = 1110,
  CODE_FOR_x86_shld_1 = 1111,
  CODE_FOR_x86_shld_ndd_1_nf = 1112,
  CODE_FOR_x86_shld_ndd_1 = 1113,
  CODE_FOR_lshrdi3_doubleword = 1162,
  CODE_FOR_ashrdi3_doubleword = 1163,
  CODE_FOR_lshrti3_doubleword = 1164,
  CODE_FOR_ashrti3_doubleword = 1165,
  CODE_FOR_lshrdi3_doubleword_lowpart_nf = 1166,
  CODE_FOR_ashrdi3_doubleword_lowpart_nf = 1167,
  CODE_FOR_lshrti3_doubleword_lowpart_nf = 1168,
  CODE_FOR_ashrti3_doubleword_lowpart_nf = 1169,
  CODE_FOR_lshrdi3_doubleword_lowpart = 1170,
  CODE_FOR_ashrdi3_doubleword_lowpart = 1171,
  CODE_FOR_lshrti3_doubleword_lowpart = 1172,
  CODE_FOR_ashrti3_doubleword_lowpart = 1173,
  CODE_FOR_x86_64_shrd_nf = 1174,
  CODE_FOR_x86_64_shrd = 1175,
  CODE_FOR_x86_64_shrd_ndd_nf = 1176,
  CODE_FOR_x86_64_shrd_ndd = 1177,
  CODE_FOR_x86_64_shrd_1_nf = 1178,
  CODE_FOR_x86_64_shrd_1 = 1179,
  CODE_FOR_x86_64_shrd_ndd_1_nf = 1180,
  CODE_FOR_x86_64_shrd_ndd_1 = 1181,
  CODE_FOR_x86_shrd_nf = 1186,
  CODE_FOR_x86_shrd = 1187,
  CODE_FOR_x86_shrd_ndd_nf = 1188,
  CODE_FOR_x86_shrd_ndd = 1189,
  CODE_FOR_x86_shrd_1_nf = 1190,
  CODE_FOR_x86_shrd_1 = 1191,
  CODE_FOR_x86_shrd_ndd_1_nf = 1192,
  CODE_FOR_x86_shrd_ndd_1 = 1193,
  CODE_FOR_ashrsi3_cvt_nf = 1198,
  CODE_FOR_ashrsi3_cvt = 1199,
  CODE_FOR_ashrdi3_cvt_nf = 1200,
  CODE_FOR_ashrdi3_cvt = 1201,
  CODE_FOR_ix86_rotldi3_doubleword = 1364,
  CODE_FOR_ix86_rotlti3_doubleword = 1365,
  CODE_FOR_ix86_rotrdi3_doubleword = 1366,
  CODE_FOR_ix86_rotrti3_doubleword = 1367,
  CODE_FOR_rotl32di2_doubleword = 1368,
  CODE_FOR_rotr32di2_doubleword = 1369,
  CODE_FOR_rotl64ti2_doubleword = 1370,
  CODE_FOR_rotr64ti2_doubleword = 1371,
  CODE_FOR_rcrsi2 = 1417,
  CODE_FOR_rcrdi2 = 1418,
  CODE_FOR_lshrsi3_carry = 1419,
  CODE_FOR_ashrsi3_carry = 1420,
  CODE_FOR_lshrdi3_carry = 1421,
  CODE_FOR_ashrdi3_carry = 1422,
  CODE_FOR_setcc_sf_sse = 1487,
  CODE_FOR_setcc_df_sse = 1488,
  CODE_FOR_setcc_hf_mask = 1489,
  CODE_FOR_jump = 1491,
  CODE_FOR_blockage = 1518,
  CODE_FOR_prologue_use = 1520,
  CODE_FOR_simple_return_internal = 1521,
  CODE_FOR_interrupt_return = 1522,
  CODE_FOR_simple_return_internal_long = 1523,
  CODE_FOR_simple_return_pop_internal = 1524,
  CODE_FOR_nop = 1527,
  CODE_FOR_nops = 1528,
  CODE_FOR_max_skip_align = 1529,
  CODE_FOR_set_got_rex64 = 1532,
  CODE_FOR_set_rip_rex64 = 1533,
  CODE_FOR_set_got_offset_rex64 = 1534,
  CODE_FOR_eh_return_internal = 1535,
  CODE_FOR_split_stack_return = 1538,
  CODE_FOR_ffssi2_no_cmove = 1539,
  CODE_FOR_ctzsi2 = 1546,
  CODE_FOR_ctzdi2 = 1547,
  CODE_FOR_bsr_rex64 = 1556,
  CODE_FOR_bsr_rex64_1 = 1557,
  CODE_FOR_bsr_rex64_1_zext = 1558,
  CODE_FOR_bsr = 1559,
  CODE_FOR_bsr_1 = 1560,
  CODE_FOR_bsr_zext_1 = 1561,
  CODE_FOR_clzsi2_lzcnt_nf = 1566,
  CODE_FOR_clzdi2_lzcnt_nf = 1567,
  CODE_FOR_clzsi2_lzcnt = 1568,
  CODE_FOR_clzdi2_lzcnt = 1569,
  CODE_FOR_tzcnt_si_nf = 1580,
  CODE_FOR_lzcnt_si_nf = 1581,
  CODE_FOR_tzcnt_di_nf = 1582,
  CODE_FOR_lzcnt_di_nf = 1583,
  CODE_FOR_tzcnt_si = 1584,
  CODE_FOR_lzcnt_si = 1585,
  CODE_FOR_tzcnt_di = 1586,
  CODE_FOR_lzcnt_di = 1587,
  CODE_FOR_tzcnt_hi_nf = 1596,
  CODE_FOR_tzcnt_hi = 1597,
  CODE_FOR_lzcnt_hi_nf = 1598,
  CODE_FOR_lzcnt_hi = 1599,
  CODE_FOR_bmi_bextr_si = 1600,
  CODE_FOR_bmi_bextr_di = 1601,
  CODE_FOR_bmi2_pdep_si3 = 1634,
  CODE_FOR_bmi2_pdep_di3 = 1635,
  CODE_FOR_bmi2_pext_si3 = 1636,
  CODE_FOR_bmi2_pext_di3 = 1637,
  CODE_FOR_tbm_bextri_si = 1638,
  CODE_FOR_tbm_bextri_di = 1639,
  CODE_FOR_popcountsi2_nf = 1658,
  CODE_FOR_popcountdi2_nf = 1659,
  CODE_FOR_popcountsi2 = 1660,
  CODE_FOR_popcountdi2 = 1661,
  CODE_FOR_popcounthi2_nf = 1672,
  CODE_FOR_popcounthi2 = 1673,
  CODE_FOR_bswaphisi2_lowpart = 1680,
  CODE_FOR_parityhi2_cmp = 1681,
  CODE_FOR_parityqi2_cmp = 1682,
  CODE_FOR_rcphf2 = 1715,
  CODE_FOR_truncxfsf2_i387_noop_unspec = 1740,
  CODE_FOR_truncxfdf2_i387_noop_unspec = 1741,
  CODE_FOR_sqrtxf2 = 1742,
  CODE_FOR_rsqrthf2 = 1744,
  CODE_FOR_sqrthf2 = 1745,
  CODE_FOR_x86_fnstsw_1 = 1748,
  CODE_FOR_fpremxf4_i387 = 1749,
  CODE_FOR_fprem1xf4_i387 = 1750,
  CODE_FOR_sinxf2 = 1751,
  CODE_FOR_cosxf2 = 1752,
  CODE_FOR_sincosxf3 = 1753,
  CODE_FOR_fptanxf4_i387 = 1754,
  CODE_FOR_atan2xf3 = 1755,
  CODE_FOR_fyl2xxf3_i387 = 1756,
  CODE_FOR_fyl2xp1xf3_i387 = 1757,
  CODE_FOR_fxtractxf3_i387 = 1758,
  CODE_FOR_fscalexf4_i387 = 1760,
  CODE_FOR_avx512f_scalefsf2 = 1761,
  CODE_FOR_avx512f_scalefdf2 = 1762,
  CODE_FOR_sse4_1_roundhf2 = 1763,
  CODE_FOR_sse4_1_roundsf2 = 1764,
  CODE_FOR_sse4_1_rounddf2 = 1765,
  CODE_FOR_rintxf2 = 1766,
  CODE_FOR_lrintxfdi2 = 1767,
  CODE_FOR_lrintxfhi2 = 1768,
  CODE_FOR_lrintxfsi2 = 1769,
  CODE_FOR_frndintxf2_roundeven = 1770,
  CODE_FOR_frndintxf2_floor = 1771,
  CODE_FOR_frndintxf2_ceil = 1772,
  CODE_FOR_frndintxf2_trunc = 1773,
  CODE_FOR_frndintxf2_roundeven_i387 = 1774,
  CODE_FOR_frndintxf2_floor_i387 = 1775,
  CODE_FOR_frndintxf2_ceil_i387 = 1776,
  CODE_FOR_frndintxf2_trunc_i387 = 1777,
  CODE_FOR_fistdi2_floor = 1784,
  CODE_FOR_fistdi2_ceil = 1785,
  CODE_FOR_fisthi2_floor = 1786,
  CODE_FOR_fisthi2_ceil = 1787,
  CODE_FOR_fistsi2_floor = 1788,
  CODE_FOR_fistsi2_ceil = 1789,
  CODE_FOR_fxamsf2_i387 = 1790,
  CODE_FOR_fxamdf2_i387 = 1791,
  CODE_FOR_fxamxf2_i387 = 1792,
  CODE_FOR_movmsk_df = 1793,
  CODE_FOR_cld = 1794,
  CODE_FOR_movhf_mask = 1843,
  CODE_FOR_smaxsf3 = 1849,
  CODE_FOR_sminsf3 = 1850,
  CODE_FOR_smaxdf3 = 1851,
  CODE_FOR_smindf3 = 1852,
  CODE_FOR_smaxhf3 = 1853,
  CODE_FOR_sminhf3 = 1854,
  CODE_FOR_pro_epilogue_adjust_stack_add_si = 1907,
  CODE_FOR_pro_epilogue_adjust_stack_add_di = 1908,
  CODE_FOR_pro_epilogue_adjust_stack_add_noccsi = 1909,
  CODE_FOR_pro_epilogue_adjust_stack_add_noccdi = 1910,
  CODE_FOR_pro_epilogue_adjust_stack_sub_si = 1911,
  CODE_FOR_pro_epilogue_adjust_stack_sub_di = 1912,
  CODE_FOR_allocate_stack_worker_probe_si = 1913,
  CODE_FOR_allocate_stack_worker_probe_di = 1914,
  CODE_FOR_probe_stack_1 = 1915,
  CODE_FOR_adjust_stack_and_probe_si = 1916,
  CODE_FOR_adjust_stack_and_probe_di = 1917,
  CODE_FOR_probe_stack_range_si = 1918,
  CODE_FOR_probe_stack_range_di = 1919,
  CODE_FOR_stack_protect_set_1_si_si = 1920,
  CODE_FOR_stack_protect_set_1_di_si = 1921,
  CODE_FOR_stack_protect_set_1_si_di = 1922,
  CODE_FOR_stack_protect_set_1_di_di = 1923,
  CODE_FOR_stack_protect_test_1_si = 1936,
  CODE_FOR_stack_protect_test_1_di = 1937,
  CODE_FOR_trap = 1938,
  CODE_FOR_ud2 = 1939,
  CODE_FOR_prefetchi = 1942,
  CODE_FOR_sse4_2_crc32qi = 1944,
  CODE_FOR_sse4_2_crc32hi = 1945,
  CODE_FOR_sse4_2_crc32si = 1946,
  CODE_FOR_sse4_2_crc32di = 1947,
  CODE_FOR_rdpmc = 1948,
  CODE_FOR_rdpmc_rex64 = 1949,
  CODE_FOR_rdtsc = 1950,
  CODE_FOR_rdtsc_rex64 = 1951,
  CODE_FOR_rdtscp = 1952,
  CODE_FOR_rdtscp_rex64 = 1953,
  CODE_FOR_fxsave = 1954,
  CODE_FOR_fxsave64 = 1955,
  CODE_FOR_fxrstor = 1956,
  CODE_FOR_fxrstor64 = 1957,
  CODE_FOR_xsave = 1958,
  CODE_FOR_xsaveopt = 1959,
  CODE_FOR_xsavec = 1960,
  CODE_FOR_xsaves = 1961,
  CODE_FOR_xsave_rex64 = 1962,
  CODE_FOR_xsaveopt_rex64 = 1963,
  CODE_FOR_xsavec_rex64 = 1964,
  CODE_FOR_xsaves_rex64 = 1965,
  CODE_FOR_xsave64 = 1966,
  CODE_FOR_xsaveopt64 = 1967,
  CODE_FOR_xsavec64 = 1968,
  CODE_FOR_xsaves64 = 1969,
  CODE_FOR_xrstor = 1970,
  CODE_FOR_xrstors = 1971,
  CODE_FOR_xrstor_rex64 = 1972,
  CODE_FOR_xrstors_rex64 = 1973,
  CODE_FOR_xrstor64 = 1974,
  CODE_FOR_xrstors64 = 1975,
  CODE_FOR_xsetbv = 1976,
  CODE_FOR_xsetbv_rex64 = 1977,
  CODE_FOR_xgetbv = 1978,
  CODE_FOR_xgetbv_rex64 = 1979,
  CODE_FOR_fnstenv = 1980,
  CODE_FOR_fldenv = 1981,
  CODE_FOR_fnstsw = 1982,
  CODE_FOR_fnclex = 1983,
  CODE_FOR_lwp_llwpcbsi = 1984,
  CODE_FOR_lwp_llwpcbdi = 1985,
  CODE_FOR_lwp_slwpcbsi = 1986,
  CODE_FOR_lwp_slwpcbdi = 1987,
  CODE_FOR_lwp_lwpvalsi = 1988,
  CODE_FOR_lwp_lwpvaldi = 1989,
  CODE_FOR_lwp_lwpinssi = 1990,
  CODE_FOR_lwp_lwpinsdi = 1991,
  CODE_FOR_rdfsbasesi = 1992,
  CODE_FOR_rdgsbasesi = 1993,
  CODE_FOR_rdfsbasedi = 1994,
  CODE_FOR_rdgsbasedi = 1995,
  CODE_FOR_wrfsbasesi = 1996,
  CODE_FOR_wrgsbasesi = 1997,
  CODE_FOR_wrfsbasedi = 1998,
  CODE_FOR_wrgsbasedi = 1999,
  CODE_FOR_ptwritesi = 2000,
  CODE_FOR_ptwritedi = 2001,
  CODE_FOR_rdrandhi = 2002,
  CODE_FOR_rdrandsi = 2003,
  CODE_FOR_rdranddi = 2004,
  CODE_FOR_rdseedhi = 2005,
  CODE_FOR_rdseedsi = 2006,
  CODE_FOR_rdseeddi = 2007,
  CODE_FOR_rdsspsi = 2009,
  CODE_FOR_rdsspdi = 2010,
  CODE_FOR_incsspsi = 2011,
  CODE_FOR_incsspdi = 2012,
  CODE_FOR_saveprevssp = 2013,
  CODE_FOR_rstorssp = 2014,
  CODE_FOR_wrsssi = 2015,
  CODE_FOR_wrssdi = 2016,
  CODE_FOR_wrusssi = 2017,
  CODE_FOR_wrussdi = 2018,
  CODE_FOR_setssbsy = 2019,
  CODE_FOR_clrssbsy = 2020,
  CODE_FOR_nop_endbr = 2021,
  CODE_FOR_xbegin_1 = 2022,
  CODE_FOR_xend = 2023,
  CODE_FOR_xabort = 2024,
  CODE_FOR_xtest_1 = 2025,
  CODE_FOR_clwb = 2026,
  CODE_FOR_clflushopt = 2027,
  CODE_FOR_mwaitx = 2028,
  CODE_FOR_monitorx_si = 2029,
  CODE_FOR_monitorx_di = 2030,
  CODE_FOR_clzero_si = 2031,
  CODE_FOR_clzero_di = 2032,
  CODE_FOR_rdpid = 2035,
  CODE_FOR_rdpid_rex64 = 2036,
  CODE_FOR_wbinvd = 2037,
  CODE_FOR_wbnoinvd = 2038,
  CODE_FOR_movdirisi = 2039,
  CODE_FOR_movdiridi = 2040,
  CODE_FOR_movdir64b_si = 2041,
  CODE_FOR_movdir64b_di = 2042,
  CODE_FOR_xsusldtrk = 2043,
  CODE_FOR_xresldtrk = 2044,
  CODE_FOR_enqcmd_si = 2045,
  CODE_FOR_enqcmds_si = 2046,
  CODE_FOR_enqcmd_di = 2047,
  CODE_FOR_enqcmds_di = 2048,
  CODE_FOR_clui = 2049,
  CODE_FOR_stui = 2050,
  CODE_FOR_testui = 2051,
  CODE_FOR_senduipi = 2052,
  CODE_FOR_umwait = 2053,
  CODE_FOR_umwait_rex64 = 2054,
  CODE_FOR_umonitor_si = 2055,
  CODE_FOR_umonitor_di = 2056,
  CODE_FOR_tpause = 2057,
  CODE_FOR_tpause_rex64 = 2058,
  CODE_FOR_cldemote = 2059,
  CODE_FOR_speculation_barrier = 2060,
  CODE_FOR_serialize = 2061,
  CODE_FOR_patchable_area = 2062,
  CODE_FOR_hreset = 2063,
  CODE_FOR_urdmsr = 2064,
  CODE_FOR_uwrmsr = 2065,
  CODE_FOR_ldtilecfg = 2066,
  CODE_FOR_sttilecfg = 2067,
  CODE_FOR_movrsqi = 2068,
  CODE_FOR_movrshi = 2069,
  CODE_FOR_movrssi = 2070,
  CODE_FOR_movrsdi = 2071,
  CODE_FOR_sse_movntq = 2104,
  CODE_FOR_mmx_ieee_maxv2sf3 = 2113,
  CODE_FOR_mmx_ieee_minv2sf3 = 2114,
  CODE_FOR_mmx_rcpv2sf2 = 2115,
  CODE_FOR_mmx_rcpit1v2sf3 = 2116,
  CODE_FOR_mmx_rcpit2v2sf3 = 2117,
  CODE_FOR_mmx_rsqrtv2sf2 = 2118,
  CODE_FOR_mmx_rsqit1v2sf3 = 2119,
  CODE_FOR_mmx_hsubv2sf3 = 2122,
  CODE_FOR_mmx_gtv2sf3 = 2126,
  CODE_FOR_mmx_gev2sf3 = 2127,
  CODE_FOR_sse4_1_insertps_v2sf = 2128,
  CODE_FOR_sse4_1_insertps_v2si = 2129,
  CODE_FOR_mmx_blendvps = 2131,
  CODE_FOR_andv2sf3 = 2133,
  CODE_FOR_iorv2sf3 = 2134,
  CODE_FOR_xorv2sf3 = 2135,
  CODE_FOR_mmx_fix_truncv2sfv2si2 = 2136,
  CODE_FOR_mmx_floatv2siv2sf2 = 2137,
  CODE_FOR_mmx_pf2iw = 2138,
  CODE_FOR_mmx_pi2fw = 2139,
  CODE_FOR_mmx_pswapdv2sf2 = 2140,
  CODE_FOR_andv2bf3 = 2167,
  CODE_FOR_iorv2bf3 = 2168,
  CODE_FOR_xorv2bf3 = 2169,
  CODE_FOR_andv4bf3 = 2170,
  CODE_FOR_iorv4bf3 = 2171,
  CODE_FOR_xorv4bf3 = 2172,
  CODE_FOR_andv2hf3 = 2173,
  CODE_FOR_iorv2hf3 = 2174,
  CODE_FOR_xorv2hf3 = 2175,
  CODE_FOR_andv4hf3 = 2176,
  CODE_FOR_iorv4hf3 = 2177,
  CODE_FOR_xorv4hf3 = 2178,
  CODE_FOR_negv2qi2 = 2179,
  CODE_FOR_addv4qi3 = 2188,
  CODE_FOR_subv4qi3 = 2189,
  CODE_FOR_addv2hi3 = 2190,
  CODE_FOR_subv2hi3 = 2191,
  CODE_FOR_addv2qi3 = 2192,
  CODE_FOR_subv2qi3 = 2193,
  CODE_FOR_ssaddv4qi3 = 2202,
  CODE_FOR_usaddv4qi3 = 2203,
  CODE_FOR_sssubv4qi3 = 2204,
  CODE_FOR_ussubv4qi3 = 2205,
  CODE_FOR_ssaddv2qi3 = 2206,
  CODE_FOR_usaddv2qi3 = 2207,
  CODE_FOR_sssubv2qi3 = 2208,
  CODE_FOR_ussubv2qi3 = 2209,
  CODE_FOR_ssaddv2hi3 = 2210,
  CODE_FOR_usaddv2hi3 = 2211,
  CODE_FOR_sssubv2hi3 = 2212,
  CODE_FOR_ussubv2hi3 = 2213,
  CODE_FOR_mulv2si3 = 2214,
  CODE_FOR_mulv2hi3 = 2216,
  CODE_FOR_smulv2hi3_highpart = 2219,
  CODE_FOR_umulv2hi3_highpart = 2220,
  CODE_FOR_smaxv8qi3 = 2224,
  CODE_FOR_sminv8qi3 = 2225,
  CODE_FOR_smaxv2si3 = 2226,
  CODE_FOR_sminv2si3 = 2227,
  CODE_FOR_smaxv4qi3 = 2230,
  CODE_FOR_sminv4qi3 = 2231,
  CODE_FOR_smaxv2qi3 = 2232,
  CODE_FOR_sminv2qi3 = 2233,
  CODE_FOR_smaxv2hi3 = 2234,
  CODE_FOR_sminv2hi3 = 2235,
  CODE_FOR_umaxv4hi3 = 2236,
  CODE_FOR_uminv4hi3 = 2237,
  CODE_FOR_umaxv2si3 = 2238,
  CODE_FOR_uminv2si3 = 2239,
  CODE_FOR_umaxv4qi3 = 2242,
  CODE_FOR_uminv4qi3 = 2243,
  CODE_FOR_umaxv2qi3 = 2244,
  CODE_FOR_uminv2qi3 = 2245,
  CODE_FOR_umaxv2hi3 = 2246,
  CODE_FOR_uminv2hi3 = 2247,
  CODE_FOR_ssse3_absv8qi2 = 2248,
  CODE_FOR_ssse3_absv4hi2 = 2249,
  CODE_FOR_ssse3_absv2si2 = 2250,
  CODE_FOR_absv4qi2 = 2251,
  CODE_FOR_absv2qi2 = 2252,
  CODE_FOR_absv2hi2 = 2253,
  CODE_FOR_mmx_ashrv4hi3 = 2254,
  CODE_FOR_mmx_ashrv2si3 = 2255,
  CODE_FOR_mmx_ashlv4hi3 = 2258,
  CODE_FOR_mmx_lshrv4hi3 = 2259,
  CODE_FOR_mmx_ashlv2si3 = 2260,
  CODE_FOR_mmx_lshrv2si3 = 2261,
  CODE_FOR_mmx_ashlv1di3 = 2262,
  CODE_FOR_mmx_lshrv1di3 = 2263,
  CODE_FOR_mmx_ashlv1si3 = 2264,
  CODE_FOR_mmx_lshrv1si3 = 2265,
  CODE_FOR_ashlv2hi3 = 2266,
  CODE_FOR_lshrv2hi3 = 2267,
  CODE_FOR_ashrv2hi3 = 2268,
  CODE_FOR_ashlv2qi3 = 2270,
  CODE_FOR_lshrv2qi3 = 2271,
  CODE_FOR_ashrv2qi3 = 2272,
  CODE_FOR_mmx_gtv8qi3 = 2279,
  CODE_FOR_mmx_gtv4hi3 = 2280,
  CODE_FOR_mmx_gtv2si3 = 2281,
  CODE_FOR_mmx_pblendvb_v8qi = 2297,
  CODE_FOR_mmx_pblendvb_v4qi = 2301,
  CODE_FOR_mmx_pblendvb_v2qi = 2302,
  CODE_FOR_mmx_pblendvb_v2hi = 2303,
  CODE_FOR_mmx_ppermv64 = 2319,
  CODE_FOR_mmx_ppermv32 = 2320,
  CODE_FOR_one_cmplv4qi2 = 2321,
  CODE_FOR_one_cmplv2qi2 = 2322,
  CODE_FOR_one_cmplv2hi2 = 2323,
  CODE_FOR_mmx_andnotv8qi3 = 2324,
  CODE_FOR_mmx_andnotv4hi3 = 2325,
  CODE_FOR_mmx_andnotv2si3 = 2326,
  CODE_FOR_mmx_packsswb = 2348,
  CODE_FOR_mmx_packuswb = 2349,
  CODE_FOR_mmx_packssdw = 2350,
  CODE_FOR_mmx_packusdw = 2351,
  CODE_FOR_mmx_punpckhbw = 2352,
  CODE_FOR_mmx_punpckhbw_low = 2353,
  CODE_FOR_mmx_punpcklbw = 2354,
  CODE_FOR_mmx_punpcklbw_low = 2355,
  CODE_FOR_mmx_punpckhwd = 2356,
  CODE_FOR_mmx_punpcklwd = 2357,
  CODE_FOR_mmx_punpckhdq = 2358,
  CODE_FOR_mmx_punpckldq = 2359,
  CODE_FOR_sse4_1_sign_extendv4qiv4hi2 = 2360,
  CODE_FOR_sse4_1_zero_extendv4qiv4hi2 = 2361,
  CODE_FOR_sse4_1_sign_extendv2hiv2si2 = 2362,
  CODE_FOR_sse4_1_zero_extendv2hiv2si2 = 2363,
  CODE_FOR_sse4_1_sign_extendv2qiv2si2 = 2364,
  CODE_FOR_sse4_1_zero_extendv2qiv2si2 = 2365,
  CODE_FOR_sse4_1_sign_extendv2qiv2hi2 = 2366,
  CODE_FOR_sse4_1_zero_extendv2qiv2hi2 = 2367,
  CODE_FOR_avx512vl_truncv4hiv4qi2 = 2368,
  CODE_FOR_avx512vl_truncv2hiv2qi2 = 2369,
  CODE_FOR_avx512vl_truncv2siv2qi2 = 2370,
  CODE_FOR_avx512vl_truncv2siv2hi2 = 2371,
  CODE_FOR_mmx_pshufbv8qi3 = 2386,
  CODE_FOR_mmx_pshufbv4qi3 = 2387,
  CODE_FOR_mmx_pshufwv4hf_1 = 2388,
  CODE_FOR_mmx_pshufwv4bf_1 = 2389,
  CODE_FOR_mmx_pshufwv4hi_1 = 2390,
  CODE_FOR_mmx_pswapdv2si2 = 2398,
  CODE_FOR_uavgv4qi3_ceil = 2436,
  CODE_FOR_uavgv2qi3_ceil = 2437,
  CODE_FOR_uavgv2hi3_ceil = 2438,
  CODE_FOR_mmx_pmovmskb = 2440,
  CODE_FOR_popcountv8qi2 = 2445,
  CODE_FOR_popcountv4qi2 = 2446,
  CODE_FOR_popcountv2qi2 = 2447,
  CODE_FOR_popcountv4hi2 = 2448,
  CODE_FOR_popcountv2hi2 = 2449,
  CODE_FOR_popcountv2si2 = 2450,
  CODE_FOR_movv64qi_internal = 2451,
  CODE_FOR_movv32qi_internal = 2452,
  CODE_FOR_movv16qi_internal = 2453,
  CODE_FOR_movv32hi_internal = 2454,
  CODE_FOR_movv16hi_internal = 2455,
  CODE_FOR_movv8hi_internal = 2456,
  CODE_FOR_movv16si_internal = 2457,
  CODE_FOR_movv8si_internal = 2458,
  CODE_FOR_movv4si_internal = 2459,
  CODE_FOR_movv8di_internal = 2460,
  CODE_FOR_movv4di_internal = 2461,
  CODE_FOR_movv2di_internal = 2462,
  CODE_FOR_movv4ti_internal = 2463,
  CODE_FOR_movv2ti_internal = 2464,
  CODE_FOR_movv1ti_internal = 2465,
  CODE_FOR_movv32hf_internal = 2466,
  CODE_FOR_movv16hf_internal = 2467,
  CODE_FOR_movv8hf_internal = 2468,
  CODE_FOR_movv32bf_internal = 2469,
  CODE_FOR_movv16bf_internal = 2470,
  CODE_FOR_movv8bf_internal = 2471,
  CODE_FOR_movv16sf_internal = 2472,
  CODE_FOR_movv8sf_internal = 2473,
  CODE_FOR_movv4sf_internal = 2474,
  CODE_FOR_movv8df_internal = 2475,
  CODE_FOR_movv4df_internal = 2476,
  CODE_FOR_movv2df_internal = 2477,
  CODE_FOR_avx512f_movhf_mask = 2559,
  CODE_FOR_avx512f_movsf_mask = 2560,
  CODE_FOR_avx512f_movdf_mask = 2561,
  CODE_FOR_avx512f_storehf_mask = 2565,
  CODE_FOR_avx512f_storesf_mask = 2566,
  CODE_FOR_avx512f_storedf_mask = 2567,
  CODE_FOR_avx512f_blendmv16si = 2568,
  CODE_FOR_avx512vl_blendmv8si = 2569,
  CODE_FOR_avx512vl_blendmv4si = 2570,
  CODE_FOR_avx512f_blendmv8di = 2571,
  CODE_FOR_avx512vl_blendmv4di = 2572,
  CODE_FOR_avx512vl_blendmv2di = 2573,
  CODE_FOR_avx512f_blendmv16sf = 2574,
  CODE_FOR_avx512vl_blendmv8sf = 2575,
  CODE_FOR_avx512vl_blendmv4sf = 2576,
  CODE_FOR_avx512f_blendmv8df = 2577,
  CODE_FOR_avx512vl_blendmv4df = 2578,
  CODE_FOR_avx512vl_blendmv2df = 2579,
  CODE_FOR_avx512bw_blendmv64qi = 2580,
  CODE_FOR_avx512vl_blendmv16qi = 2581,
  CODE_FOR_avx512vl_blendmv32qi = 2582,
  CODE_FOR_avx512bw_blendmv32hi = 2583,
  CODE_FOR_avx512vl_blendmv16hi = 2584,
  CODE_FOR_avx512vl_blendmv8hi = 2585,
  CODE_FOR_avx512bw_blendmv32hf = 2586,
  CODE_FOR_avx512vl_blendmv16hf = 2587,
  CODE_FOR_avx512fp16_blendmv8hf = 2588,
  CODE_FOR_avx512bw_blendmv32bf = 2589,
  CODE_FOR_avx512vl_blendmv16bf = 2590,
  CODE_FOR_avx512vl_blendmv8bf = 2591,
  CODE_FOR_movdi_to_sse = 2620,
  CODE_FOR_avx_lddqu256 = 2621,
  CODE_FOR_sse3_lddqu = 2622,
  CODE_FOR_sse2_movntisi = 2623,
  CODE_FOR_sse2_movntidi = 2624,
  CODE_FOR_avx512f_movntv16sf = 2625,
  CODE_FOR_avx_movntv8sf = 2626,
  CODE_FOR_sse_movntv4sf = 2627,
  CODE_FOR_avx512f_movntv8df = 2628,
  CODE_FOR_avx_movntv4df = 2629,
  CODE_FOR_sse2_movntv2df = 2630,
  CODE_FOR_avx512f_movntv8di = 2631,
  CODE_FOR_avx_movntv4di = 2632,
  CODE_FOR_sse2_movntv2di = 2633,
  CODE_FOR_kandqi = 2634,
  CODE_FOR_kiorqi = 2635,
  CODE_FOR_kxorqi = 2636,
  CODE_FOR_kandhi = 2637,
  CODE_FOR_kiorhi = 2638,
  CODE_FOR_kxorhi = 2639,
  CODE_FOR_kandsi = 2640,
  CODE_FOR_kiorsi = 2641,
  CODE_FOR_kxorsi = 2642,
  CODE_FOR_kanddi = 2643,
  CODE_FOR_kiordi = 2644,
  CODE_FOR_kxordi = 2645,
  CODE_FOR_kandnqi = 2646,
  CODE_FOR_kandnhi = 2647,
  CODE_FOR_kandnsi = 2648,
  CODE_FOR_kandndi = 2649,
  CODE_FOR_kxnorqi = 2650,
  CODE_FOR_kxnorhi = 2651,
  CODE_FOR_kxnorsi = 2652,
  CODE_FOR_kxnordi = 2653,
  CODE_FOR_knotqi = 2654,
  CODE_FOR_knothi = 2655,
  CODE_FOR_knotsi = 2656,
  CODE_FOR_knotdi = 2657,
  CODE_FOR_kaddqi = 2659,
  CODE_FOR_kaddhi = 2660,
  CODE_FOR_kaddsi = 2661,
  CODE_FOR_kadddi = 2662,
  CODE_FOR_kashiftqi = 2663,
  CODE_FOR_klshiftrtqi = 2664,
  CODE_FOR_kashifthi = 2665,
  CODE_FOR_klshiftrthi = 2666,
  CODE_FOR_kashiftsi = 2667,
  CODE_FOR_klshiftrtsi = 2668,
  CODE_FOR_kashiftdi = 2669,
  CODE_FOR_klshiftrtdi = 2670,
  CODE_FOR_ktestqi = 2672,
  CODE_FOR_ktesthi = 2673,
  CODE_FOR_ktestsi = 2674,
  CODE_FOR_ktestdi = 2675,
  CODE_FOR_kortestqi_ccc = 2680,
  CODE_FOR_kortesthi_ccc = 2681,
  CODE_FOR_kortestsi_ccc = 2682,
  CODE_FOR_kortestdi_ccc = 2683,
  CODE_FOR_kortestqi_ccz = 2684,
  CODE_FOR_kortesthi_ccz = 2685,
  CODE_FOR_kortestsi_ccz = 2686,
  CODE_FOR_kortestdi_ccz = 2687,
  CODE_FOR_kunpckhi = 2712,
  CODE_FOR_kunpcksi = 2713,
  CODE_FOR_kunpckdi = 2714,
  CODE_FOR_avx512fp16_vmaddv8hf3 = 2823,
  CODE_FOR_avx512fp16_vmaddv8hf3_round = 2824,
  CODE_FOR_avx512fp16_vmaddv8hf3_mask = 2825,
  CODE_FOR_avx512fp16_vmaddv8hf3_mask_round = 2826,
  CODE_FOR_avx512fp16_vmsubv8hf3 = 2827,
  CODE_FOR_avx512fp16_vmsubv8hf3_round = 2828,
  CODE_FOR_avx512fp16_vmsubv8hf3_mask = 2829,
  CODE_FOR_avx512fp16_vmsubv8hf3_mask_round = 2830,
  CODE_FOR_sse_vmaddv4sf3 = 2831,
  CODE_FOR_sse_vmaddv4sf3_round = 2832,
  CODE_FOR_sse_vmaddv4sf3_mask = 2833,
  CODE_FOR_sse_vmaddv4sf3_mask_round = 2834,
  CODE_FOR_sse_vmsubv4sf3 = 2835,
  CODE_FOR_sse_vmsubv4sf3_round = 2836,
  CODE_FOR_sse_vmsubv4sf3_mask = 2837,
  CODE_FOR_sse_vmsubv4sf3_mask_round = 2838,
  CODE_FOR_sse2_vmaddv2df3 = 2839,
  CODE_FOR_sse2_vmaddv2df3_round = 2840,
  CODE_FOR_sse2_vmaddv2df3_mask = 2841,
  CODE_FOR_sse2_vmaddv2df3_mask_round = 2842,
  CODE_FOR_sse2_vmsubv2df3 = 2843,
  CODE_FOR_sse2_vmsubv2df3_round = 2844,
  CODE_FOR_sse2_vmsubv2df3_mask = 2845,
  CODE_FOR_sse2_vmsubv2df3_mask_round = 2846,
  CODE_FOR_avx512fp16_vmmulv8hf3 = 2889,
  CODE_FOR_avx512fp16_vmmulv8hf3_round = 2890,
  CODE_FOR_avx512fp16_vmmulv8hf3_mask = 2891,
  CODE_FOR_avx512fp16_vmmulv8hf3_mask_round = 2892,
  CODE_FOR_avx512fp16_vmdivv8hf3 = 2893,
  CODE_FOR_avx512fp16_vmdivv8hf3_round = 2894,
  CODE_FOR_avx512fp16_vmdivv8hf3_mask = 2895,
  CODE_FOR_avx512fp16_vmdivv8hf3_mask_round = 2896,
  CODE_FOR_sse_vmmulv4sf3 = 2897,
  CODE_FOR_sse_vmmulv4sf3_round = 2898,
  CODE_FOR_sse_vmmulv4sf3_mask = 2899,
  CODE_FOR_sse_vmmulv4sf3_mask_round = 2900,
  CODE_FOR_sse_vmdivv4sf3 = 2901,
  CODE_FOR_sse_vmdivv4sf3_round = 2902,
  CODE_FOR_sse_vmdivv4sf3_mask = 2903,
  CODE_FOR_sse_vmdivv4sf3_mask_round = 2904,
  CODE_FOR_sse2_vmmulv2df3 = 2905,
  CODE_FOR_sse2_vmmulv2df3_round = 2906,
  CODE_FOR_sse2_vmmulv2df3_mask = 2907,
  CODE_FOR_sse2_vmmulv2df3_mask_round = 2908,
  CODE_FOR_sse2_vmdivv2df3 = 2909,
  CODE_FOR_sse2_vmdivv2df3_round = 2910,
  CODE_FOR_sse2_vmdivv2df3_mask = 2911,
  CODE_FOR_sse2_vmdivv2df3_mask_round = 2912,
  CODE_FOR_avx512fp16_divv32hf3 = 2913,
  CODE_FOR_avx512fp16_divv32hf3_round = 2914,
  CODE_FOR_avx512fp16_divv32hf3_mask = 2915,
  CODE_FOR_avx512fp16_divv32hf3_mask_round = 2916,
  CODE_FOR_avx512fp16_divv16hf3 = 2917,
   CODE_FOR_avx512fp16_divv16hf3_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_divv16hf3_mask = 2918,
   CODE_FOR_avx512fp16_divv16hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_divv8hf3 = 2919,
   CODE_FOR_avx512fp16_divv8hf3_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_divv8hf3_mask = 2920,
   CODE_FOR_avx512fp16_divv8hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_divv16sf3 = 2921,
  CODE_FOR_avx512f_divv16sf3_round = 2922,
  CODE_FOR_avx512f_divv16sf3_mask = 2923,
  CODE_FOR_avx512f_divv16sf3_mask_round = 2924,
  CODE_FOR_avx_divv8sf3 = 2925,
   CODE_FOR_avx_divv8sf3_round = CODE_FOR_nothing,
  CODE_FOR_avx_divv8sf3_mask = 2926,
   CODE_FOR_avx_divv8sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_sse_divv4sf3 = 2927,
   CODE_FOR_sse_divv4sf3_round = CODE_FOR_nothing,
  CODE_FOR_sse_divv4sf3_mask = 2928,
   CODE_FOR_sse_divv4sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_divv8df3 = 2929,
  CODE_FOR_avx512f_divv8df3_round = 2930,
  CODE_FOR_avx512f_divv8df3_mask = 2931,
  CODE_FOR_avx512f_divv8df3_mask_round = 2932,
  CODE_FOR_avx_divv4df3 = 2933,
   CODE_FOR_avx_divv4df3_round = CODE_FOR_nothing,
  CODE_FOR_avx_divv4df3_mask = 2934,
   CODE_FOR_avx_divv4df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_sse2_divv2df3 = 2935,
   CODE_FOR_sse2_divv2df3_round = CODE_FOR_nothing,
  CODE_FOR_sse2_divv2df3_mask = 2936,
   CODE_FOR_sse2_divv2df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx_rcpv8sf2 = 2937,
  CODE_FOR_sse_rcpv4sf2 = 2938,
  CODE_FOR_sse_vmrcpv4sf2 = 2939,
  CODE_FOR_avx512fp16_rcpv32hf2 = 2941,
  CODE_FOR_avx512fp16_rcpv32hf2_mask = 2942,
  CODE_FOR_avx512fp16_rcpv16hf2 = 2943,
  CODE_FOR_avx512fp16_rcpv16hf2_mask = 2944,
  CODE_FOR_avx512fp16_rcpv8hf2 = 2945,
  CODE_FOR_avx512fp16_rcpv8hf2_mask = 2946,
  CODE_FOR_avx512fp16_vmrcpv8hf2 = 2947,
  CODE_FOR_avx512fp16_vmrcpv8hf2_mask = 2948,
  CODE_FOR_rcp14v16sf_mask = 2951,
  CODE_FOR_rcp14v8sf_mask = 2953,
  CODE_FOR_rcp14v4sf_mask = 2955,
  CODE_FOR_rcp14v8df_mask = 2957,
  CODE_FOR_rcp14v4df_mask = 2959,
  CODE_FOR_rcp14v2df_mask = 2961,
  CODE_FOR_srcp14v4sf = 2962,
  CODE_FOR_srcp14v2df = 2963,
  CODE_FOR_srcp14v4sf_mask = 2964,
  CODE_FOR_srcp14v2df_mask = 2965,
  CODE_FOR_avx512fp16_sqrtv32hf2 = 2966,
  CODE_FOR_avx512fp16_sqrtv32hf2_round = 2967,
  CODE_FOR_avx512fp16_sqrtv32hf2_mask = 2968,
  CODE_FOR_avx512fp16_sqrtv32hf2_mask_round = 2969,
  CODE_FOR_avx512fp16_sqrtv16hf2 = 2970,
   CODE_FOR_avx512fp16_sqrtv16hf2_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_sqrtv16hf2_mask = 2971,
   CODE_FOR_avx512fp16_sqrtv16hf2_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_sqrtv8hf2 = 2972,
   CODE_FOR_avx512fp16_sqrtv8hf2_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_sqrtv8hf2_mask = 2973,
   CODE_FOR_avx512fp16_sqrtv8hf2_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_sqrtv16sf2 = 2974,
  CODE_FOR_avx512f_sqrtv16sf2_round = 2975,
  CODE_FOR_avx512f_sqrtv16sf2_mask = 2976,
  CODE_FOR_avx512f_sqrtv16sf2_mask_round = 2977,
  CODE_FOR_avx_sqrtv8sf2 = 2978,
   CODE_FOR_avx_sqrtv8sf2_round = CODE_FOR_nothing,
  CODE_FOR_avx_sqrtv8sf2_mask = 2979,
   CODE_FOR_avx_sqrtv8sf2_mask_round = CODE_FOR_nothing,
  CODE_FOR_sse_sqrtv4sf2 = 2980,
   CODE_FOR_sse_sqrtv4sf2_round = CODE_FOR_nothing,
  CODE_FOR_sse_sqrtv4sf2_mask = 2981,
   CODE_FOR_sse_sqrtv4sf2_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_sqrtv8df2 = 2982,
  CODE_FOR_avx512f_sqrtv8df2_round = 2983,
  CODE_FOR_avx512f_sqrtv8df2_mask = 2984,
  CODE_FOR_avx512f_sqrtv8df2_mask_round = 2985,
  CODE_FOR_avx_sqrtv4df2 = 2986,
   CODE_FOR_avx_sqrtv4df2_round = CODE_FOR_nothing,
  CODE_FOR_avx_sqrtv4df2_mask = 2987,
   CODE_FOR_avx_sqrtv4df2_mask_round = CODE_FOR_nothing,
  CODE_FOR_sse2_sqrtv2df2 = 2988,
   CODE_FOR_sse2_sqrtv2df2_round = CODE_FOR_nothing,
  CODE_FOR_sse2_sqrtv2df2_mask = 2989,
   CODE_FOR_sse2_sqrtv2df2_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_vmsqrtv8hf2 = 2990,
  CODE_FOR_avx512fp16_vmsqrtv8hf2_round = 2991,
  CODE_FOR_avx512fp16_vmsqrtv8hf2_mask = 2992,
  CODE_FOR_avx512fp16_vmsqrtv8hf2_mask_round = 2993,
  CODE_FOR_sse_vmsqrtv4sf2 = 2994,
  CODE_FOR_sse_vmsqrtv4sf2_round = 2995,
  CODE_FOR_sse_vmsqrtv4sf2_mask = 2996,
  CODE_FOR_sse_vmsqrtv4sf2_mask_round = 2997,
  CODE_FOR_sse2_vmsqrtv2df2 = 2998,
  CODE_FOR_sse2_vmsqrtv2df2_round = 2999,
  CODE_FOR_sse2_vmsqrtv2df2_mask = 3000,
  CODE_FOR_sse2_vmsqrtv2df2_mask_round = 3001,
  CODE_FOR_avx_rsqrtv8sf2 = 3014,
  CODE_FOR_sse_rsqrtv4sf2 = 3015,
  CODE_FOR_avx512fp16_rsqrtv32hf2 = 3016,
  CODE_FOR_avx512fp16_rsqrtv32hf2_mask = 3017,
  CODE_FOR_avx512fp16_rsqrtv16hf2 = 3018,
  CODE_FOR_avx512fp16_rsqrtv16hf2_mask = 3019,
  CODE_FOR_avx512fp16_rsqrtv8hf2 = 3020,
  CODE_FOR_avx512fp16_rsqrtv8hf2_mask = 3021,
  CODE_FOR_rsqrt14v16sf_mask = 3023,
  CODE_FOR_rsqrt14v8sf_mask = 3025,
  CODE_FOR_rsqrt14v4sf_mask = 3027,
  CODE_FOR_rsqrt14v8df_mask = 3029,
  CODE_FOR_rsqrt14v4df_mask = 3031,
  CODE_FOR_rsqrt14v2df_mask = 3033,
  CODE_FOR_rsqrt14v4sf = 3034,
  CODE_FOR_rsqrt14v2df = 3035,
  CODE_FOR_rsqrt14_v4sf_mask = 3036,
  CODE_FOR_rsqrt14_v2df_mask = 3037,
  CODE_FOR_sse_vmrsqrtv4sf2 = 3038,
  CODE_FOR_avx512fp16_vmrsqrtv8hf2 = 3040,
  CODE_FOR_avx512fp16_vmrsqrtv8hf2_mask = 3041,
  CODE_FOR_ieee_maxv32hf3 = 3113,
  CODE_FOR_ieee_maxv32hf3_round = 3114,
  CODE_FOR_ieee_maxv32hf3_mask = 3115,
  CODE_FOR_ieee_maxv32hf3_mask_round = 3116,
  CODE_FOR_ieee_minv32hf3 = 3117,
  CODE_FOR_ieee_minv32hf3_round = 3118,
  CODE_FOR_ieee_minv32hf3_mask = 3119,
  CODE_FOR_ieee_minv32hf3_mask_round = 3120,
  CODE_FOR_ieee_maxv16hf3 = 3121,
   CODE_FOR_ieee_maxv16hf3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv16hf3_mask = 3122,
   CODE_FOR_ieee_maxv16hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv16hf3 = 3123,
   CODE_FOR_ieee_minv16hf3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv16hf3_mask = 3124,
   CODE_FOR_ieee_minv16hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv8hf3 = 3125,
   CODE_FOR_ieee_maxv8hf3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv8hf3_mask = 3126,
   CODE_FOR_ieee_maxv8hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv8hf3 = 3127,
   CODE_FOR_ieee_minv8hf3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv8hf3_mask = 3128,
   CODE_FOR_ieee_minv8hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv16sf3 = 3129,
  CODE_FOR_ieee_maxv16sf3_round = 3130,
  CODE_FOR_ieee_maxv16sf3_mask = 3131,
  CODE_FOR_ieee_maxv16sf3_mask_round = 3132,
  CODE_FOR_ieee_minv16sf3 = 3133,
  CODE_FOR_ieee_minv16sf3_round = 3134,
  CODE_FOR_ieee_minv16sf3_mask = 3135,
  CODE_FOR_ieee_minv16sf3_mask_round = 3136,
  CODE_FOR_ieee_maxv8sf3 = 3137,
   CODE_FOR_ieee_maxv8sf3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv8sf3_mask = 3138,
   CODE_FOR_ieee_maxv8sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv8sf3 = 3139,
   CODE_FOR_ieee_minv8sf3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv8sf3_mask = 3140,
   CODE_FOR_ieee_minv8sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv4sf3 = 3141,
   CODE_FOR_ieee_maxv4sf3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv4sf3_mask = 3142,
   CODE_FOR_ieee_maxv4sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv4sf3 = 3143,
   CODE_FOR_ieee_minv4sf3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv4sf3_mask = 3144,
   CODE_FOR_ieee_minv4sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv8df3 = 3145,
  CODE_FOR_ieee_maxv8df3_round = 3146,
  CODE_FOR_ieee_maxv8df3_mask = 3147,
  CODE_FOR_ieee_maxv8df3_mask_round = 3148,
  CODE_FOR_ieee_minv8df3 = 3149,
  CODE_FOR_ieee_minv8df3_round = 3150,
  CODE_FOR_ieee_minv8df3_mask = 3151,
  CODE_FOR_ieee_minv8df3_mask_round = 3152,
  CODE_FOR_ieee_maxv4df3 = 3153,
   CODE_FOR_ieee_maxv4df3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv4df3_mask = 3154,
   CODE_FOR_ieee_maxv4df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv4df3 = 3155,
   CODE_FOR_ieee_minv4df3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv4df3_mask = 3156,
   CODE_FOR_ieee_minv4df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv2df3 = 3157,
   CODE_FOR_ieee_maxv2df3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_maxv2df3_mask = 3158,
   CODE_FOR_ieee_maxv2df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv2df3 = 3159,
   CODE_FOR_ieee_minv2df3_round = CODE_FOR_nothing,
  CODE_FOR_ieee_minv2df3_mask = 3160,
   CODE_FOR_ieee_minv2df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_ieee_vmmaxv8hf3 = 3191,
  CODE_FOR_avx512fp16_ieee_vmmaxv8hf3_mask = 3192,
  CODE_FOR_avx512fp16_ieee_vmmaxv8hf3_round = 3193,
  CODE_FOR_avx512fp16_ieee_vmmaxv8hf3_mask_round = 3194,
  CODE_FOR_avx512fp16_ieee_vmminv8hf3 = 3195,
  CODE_FOR_avx512fp16_ieee_vmminv8hf3_mask = 3196,
  CODE_FOR_avx512fp16_ieee_vmminv8hf3_round = 3197,
  CODE_FOR_avx512fp16_ieee_vmminv8hf3_mask_round = 3198,
  CODE_FOR_sse_ieee_vmmaxv4sf3 = 3199,
  CODE_FOR_sse_ieee_vmmaxv4sf3_mask = 3200,
  CODE_FOR_sse_ieee_vmmaxv4sf3_round = 3201,
  CODE_FOR_sse_ieee_vmmaxv4sf3_mask_round = 3202,
  CODE_FOR_sse_ieee_vmminv4sf3 = 3203,
  CODE_FOR_sse_ieee_vmminv4sf3_mask = 3204,
  CODE_FOR_sse_ieee_vmminv4sf3_round = 3205,
  CODE_FOR_sse_ieee_vmminv4sf3_mask_round = 3206,
  CODE_FOR_sse2_ieee_vmmaxv2df3 = 3207,
  CODE_FOR_sse2_ieee_vmmaxv2df3_mask = 3208,
  CODE_FOR_sse2_ieee_vmmaxv2df3_round = 3209,
  CODE_FOR_sse2_ieee_vmmaxv2df3_mask_round = 3210,
  CODE_FOR_sse2_ieee_vmminv2df3 = 3211,
  CODE_FOR_sse2_ieee_vmminv2df3_mask = 3212,
  CODE_FOR_sse2_ieee_vmminv2df3_round = 3213,
  CODE_FOR_sse2_ieee_vmminv2df3_mask_round = 3214,
  CODE_FOR_vec_addsubv8sf3 = 3215,
  CODE_FOR_vec_addsubv4sf3 = 3216,
  CODE_FOR_vec_addsubv4df3 = 3217,
  CODE_FOR_vec_addsubv2df3 = 3218,
  CODE_FOR_avx_haddv4df3 = 3219,
  CODE_FOR_avx_hsubv4df3 = 3220,
  CODE_FOR_sse3_hsubv2df3 = 3222,
  CODE_FOR_avx_haddv8sf3 = 3225,
  CODE_FOR_avx_hsubv8sf3 = 3226,
  CODE_FOR_sse3_haddv4sf3 = 3227,
  CODE_FOR_sse3_hsubv4sf3 = 3228,
  CODE_FOR_reducepv32hf_mask = 3231,
  CODE_FOR_reducepv32hf_mask_round = 3232,
  CODE_FOR_reducepv16hf_mask = 3235,
  CODE_FOR_reducepv16hf_mask_round = 3236,
  CODE_FOR_reducepv8hf_mask = 3239,
  CODE_FOR_reducepv8hf_mask_round = 3240,
  CODE_FOR_reducepv16sf_mask = 3243,
  CODE_FOR_reducepv16sf_mask_round = 3244,
  CODE_FOR_reducepv8sf_mask = 3247,
  CODE_FOR_reducepv8sf_mask_round = 3248,
  CODE_FOR_reducepv4sf_mask = 3251,
  CODE_FOR_reducepv4sf_mask_round = 3252,
  CODE_FOR_reducepv8df_mask = 3255,
  CODE_FOR_reducepv8df_mask_round = 3256,
  CODE_FOR_reducepv4df_mask = 3259,
  CODE_FOR_reducepv4df_mask_round = 3260,
  CODE_FOR_reducepv2df_mask = 3263,
  CODE_FOR_reducepv2df_mask_round = 3264,
  CODE_FOR_reducesv8hf = 3265,
  CODE_FOR_reducesv8hf_mask = 3266,
  CODE_FOR_reducesv8hf_round = 3267,
  CODE_FOR_reducesv8hf_mask_round = 3268,
  CODE_FOR_reducesv4sf = 3269,
  CODE_FOR_reducesv4sf_mask = 3270,
  CODE_FOR_reducesv4sf_round = 3271,
  CODE_FOR_reducesv4sf_mask_round = 3272,
  CODE_FOR_reducesv2df = 3273,
  CODE_FOR_reducesv2df_mask = 3274,
  CODE_FOR_reducesv2df_round = 3275,
  CODE_FOR_reducesv2df_mask_round = 3276,
  CODE_FOR_avx_cmpv8sf3 = 3277,
  CODE_FOR_avx_cmpv4sf3 = 3278,
  CODE_FOR_avx_cmpv4df3 = 3279,
  CODE_FOR_avx_cmpv2df3 = 3280,
  CODE_FOR_avx_vmcmpv4sf3 = 3309,
  CODE_FOR_avx_vmcmpv2df3 = 3310,
  CODE_FOR_avx_maskcmpv8sf3 = 3315,
  CODE_FOR_sse_maskcmpv4sf3 = 3316,
  CODE_FOR_avx_maskcmpv4df3 = 3317,
  CODE_FOR_sse2_maskcmpv2df3 = 3318,
  CODE_FOR_sse_vmmaskcmpv4sf3 = 3319,
  CODE_FOR_sse2_vmmaskcmpv2df3 = 3320,
  CODE_FOR_avx512f_cmpv16si3 = 3321,
  CODE_FOR_avx512f_cmpv16si3_round = 3322,
  CODE_FOR_avx512f_cmpv16si3_mask = 3323,
  CODE_FOR_avx512f_cmpv16si3_mask_round = 3324,
  CODE_FOR_avx512vl_cmpv8si3 = 3325,
   CODE_FOR_avx512vl_cmpv8si3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv8si3_mask = 3326,
   CODE_FOR_avx512vl_cmpv8si3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv4si3 = 3327,
   CODE_FOR_avx512vl_cmpv4si3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv4si3_mask = 3328,
   CODE_FOR_avx512vl_cmpv4si3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_cmpv8di3 = 3329,
  CODE_FOR_avx512f_cmpv8di3_round = 3330,
  CODE_FOR_avx512f_cmpv8di3_mask = 3331,
  CODE_FOR_avx512f_cmpv8di3_mask_round = 3332,
  CODE_FOR_avx512vl_cmpv4di3 = 3333,
   CODE_FOR_avx512vl_cmpv4di3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv4di3_mask = 3334,
   CODE_FOR_avx512vl_cmpv4di3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv2di3 = 3335,
   CODE_FOR_avx512vl_cmpv2di3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv2di3_mask = 3336,
   CODE_FOR_avx512vl_cmpv2di3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_cmpv32hf3 = 3337,
  CODE_FOR_avx512bw_cmpv32hf3_round = 3338,
  CODE_FOR_avx512bw_cmpv32hf3_mask = 3339,
  CODE_FOR_avx512bw_cmpv32hf3_mask_round = 3340,
  CODE_FOR_avx512vl_cmpv16hf3 = 3341,
   CODE_FOR_avx512vl_cmpv16hf3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv16hf3_mask = 3342,
   CODE_FOR_avx512vl_cmpv16hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_cmpv8hf3 = 3343,
   CODE_FOR_avx512fp16_cmpv8hf3_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_cmpv8hf3_mask = 3344,
   CODE_FOR_avx512fp16_cmpv8hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_cmpv16sf3 = 3345,
  CODE_FOR_avx512f_cmpv16sf3_round = 3346,
  CODE_FOR_avx512f_cmpv16sf3_mask = 3347,
  CODE_FOR_avx512f_cmpv16sf3_mask_round = 3348,
  CODE_FOR_avx512vl_cmpv8sf3 = 3349,
   CODE_FOR_avx512vl_cmpv8sf3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv8sf3_mask = 3350,
   CODE_FOR_avx512vl_cmpv8sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv4sf3 = 3351,
   CODE_FOR_avx512vl_cmpv4sf3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv4sf3_mask = 3352,
   CODE_FOR_avx512vl_cmpv4sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_cmpv8df3 = 3353,
  CODE_FOR_avx512f_cmpv8df3_round = 3354,
  CODE_FOR_avx512f_cmpv8df3_mask = 3355,
  CODE_FOR_avx512f_cmpv8df3_mask_round = 3356,
  CODE_FOR_avx512vl_cmpv4df3 = 3357,
   CODE_FOR_avx512vl_cmpv4df3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv4df3_mask = 3358,
   CODE_FOR_avx512vl_cmpv4df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv2df3 = 3359,
   CODE_FOR_avx512vl_cmpv2df3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_cmpv2df3_mask = 3360,
   CODE_FOR_avx512vl_cmpv2df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_cmpv64qi3 = 3481,
  CODE_FOR_avx512bw_cmpv64qi3_mask = 3482,
  CODE_FOR_avx512vl_cmpv16qi3 = 3483,
  CODE_FOR_avx512vl_cmpv16qi3_mask = 3484,
  CODE_FOR_avx512vl_cmpv32qi3 = 3485,
  CODE_FOR_avx512vl_cmpv32qi3_mask = 3486,
  CODE_FOR_avx512bw_cmpv32hi3 = 3487,
  CODE_FOR_avx512bw_cmpv32hi3_mask = 3488,
  CODE_FOR_avx512vl_cmpv16hi3 = 3489,
  CODE_FOR_avx512vl_cmpv16hi3_mask = 3490,
  CODE_FOR_avx512vl_cmpv8hi3 = 3491,
  CODE_FOR_avx512vl_cmpv8hi3_mask = 3492,
  CODE_FOR_avx512bw_ucmpv64qi3 = 3589,
  CODE_FOR_avx512bw_ucmpv64qi3_mask = 3590,
  CODE_FOR_avx512vl_ucmpv16qi3 = 3591,
  CODE_FOR_avx512vl_ucmpv16qi3_mask = 3592,
  CODE_FOR_avx512vl_ucmpv32qi3 = 3593,
  CODE_FOR_avx512vl_ucmpv32qi3_mask = 3594,
  CODE_FOR_avx512bw_ucmpv32hi3 = 3595,
  CODE_FOR_avx512bw_ucmpv32hi3_mask = 3596,
  CODE_FOR_avx512vl_ucmpv16hi3 = 3597,
  CODE_FOR_avx512vl_ucmpv16hi3_mask = 3598,
  CODE_FOR_avx512vl_ucmpv8hi3 = 3599,
  CODE_FOR_avx512vl_ucmpv8hi3_mask = 3600,
  CODE_FOR_avx512f_ucmpv16si3 = 3661,
  CODE_FOR_avx512f_ucmpv16si3_mask = 3662,
  CODE_FOR_avx512vl_ucmpv8si3 = 3663,
  CODE_FOR_avx512vl_ucmpv8si3_mask = 3664,
  CODE_FOR_avx512vl_ucmpv4si3 = 3665,
  CODE_FOR_avx512vl_ucmpv4si3_mask = 3666,
  CODE_FOR_avx512f_ucmpv8di3 = 3667,
  CODE_FOR_avx512f_ucmpv8di3_mask = 3668,
  CODE_FOR_avx512vl_ucmpv4di3 = 3669,
  CODE_FOR_avx512vl_ucmpv4di3_mask = 3670,
  CODE_FOR_avx512vl_ucmpv2di3 = 3671,
  CODE_FOR_avx512vl_ucmpv2di3_mask = 3672,
  CODE_FOR_avx512f_vmcmpv8hf3 = 3727,
  CODE_FOR_avx512f_vmcmpv8hf3_round = 3728,
  CODE_FOR_avx512f_vmcmpv4sf3 = 3729,
  CODE_FOR_avx512f_vmcmpv4sf3_round = 3730,
  CODE_FOR_avx512f_vmcmpv2df3 = 3731,
  CODE_FOR_avx512f_vmcmpv2df3_round = 3732,
  CODE_FOR_avx512f_vmcmpv8hf3_mask = 3733,
  CODE_FOR_avx512f_vmcmpv8hf3_mask_round = 3734,
  CODE_FOR_avx512f_vmcmpv4sf3_mask = 3735,
  CODE_FOR_avx512f_vmcmpv4sf3_mask_round = 3736,
  CODE_FOR_avx512f_vmcmpv2df3_mask = 3737,
  CODE_FOR_avx512f_vmcmpv2df3_mask_round = 3738,
  CODE_FOR_avx10_2_comxhf = 3739,
  CODE_FOR_avx10_2_comxhf_round = 3740,
  CODE_FOR_avx10_2_ucomxhf = 3741,
  CODE_FOR_avx10_2_ucomxhf_round = 3742,
  CODE_FOR_avx10_2_comxsf = 3743,
  CODE_FOR_avx10_2_comxsf_round = 3744,
  CODE_FOR_avx10_2_ucomxsf = 3745,
  CODE_FOR_avx10_2_ucomxsf_round = 3746,
  CODE_FOR_avx10_2_comxdf = 3747,
  CODE_FOR_avx10_2_comxdf_round = 3748,
  CODE_FOR_avx10_2_ucomxdf = 3749,
  CODE_FOR_avx10_2_ucomxdf_round = 3750,
  CODE_FOR_avx512fp16_comi = 3751,
  CODE_FOR_avx512fp16_comi_round = 3752,
  CODE_FOR_avx512fp16_ucomi = 3753,
  CODE_FOR_avx512fp16_ucomi_round = 3754,
  CODE_FOR_sse_comi = 3755,
  CODE_FOR_sse_comi_round = 3756,
  CODE_FOR_sse_ucomi = 3757,
  CODE_FOR_sse_ucomi_round = 3758,
  CODE_FOR_sse2_comi = 3759,
  CODE_FOR_sse2_comi_round = 3760,
  CODE_FOR_sse2_ucomi = 3761,
  CODE_FOR_sse2_ucomi_round = 3762,
  CODE_FOR_avx10_2_comisbf16_v8bf = 3763,
  CODE_FOR_avx512bf16_andnotv16bf3 = 3764,
   CODE_FOR_avx512bf16_andnotv16bf3_mask = CODE_FOR_nothing,
  CODE_FOR_avx512bf16_andnotv8bf3 = 3765,
   CODE_FOR_avx512bf16_andnotv8bf3_mask = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_andnotv16hf3 = 3766,
   CODE_FOR_avx512fp16_andnotv16hf3_mask = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_andnotv8hf3 = 3767,
   CODE_FOR_avx512fp16_andnotv8hf3_mask = CODE_FOR_nothing,
  CODE_FOR_avx_andnotv8sf3 = 3768,
  CODE_FOR_avx_andnotv8sf3_mask = 3769,
  CODE_FOR_sse_andnotv4sf3 = 3770,
  CODE_FOR_sse_andnotv4sf3_mask = 3771,
  CODE_FOR_avx_andnotv4df3 = 3772,
  CODE_FOR_avx_andnotv4df3_mask = 3773,
  CODE_FOR_sse2_andnotv2df3 = 3774,
  CODE_FOR_sse2_andnotv2df3_mask = 3775,
  CODE_FOR_avx512bf16_andnotv32bf3 = 3776,
   CODE_FOR_avx512bf16_andnotv32bf3_mask = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_andnotv32hf3 = 3777,
   CODE_FOR_avx512fp16_andnotv32hf3_mask = CODE_FOR_nothing,
  CODE_FOR_avx512f_andnotv16sf3 = 3778,
  CODE_FOR_avx512f_andnotv16sf3_mask = 3779,
  CODE_FOR_avx512f_andnotv8df3 = 3780,
  CODE_FOR_avx512f_andnotv8df3_mask = 3781,
  CODE_FOR_andbf3 = 3854,
  CODE_FOR_iorbf3 = 3855,
  CODE_FOR_xorbf3 = 3856,
  CODE_FOR_andhf3 = 3857,
  CODE_FOR_iorhf3 = 3858,
  CODE_FOR_xorhf3 = 3859,
  CODE_FOR_andsf3 = 3860,
  CODE_FOR_iorsf3 = 3861,
  CODE_FOR_xorsf3 = 3862,
  CODE_FOR_anddf3 = 3863,
  CODE_FOR_iordf3 = 3864,
  CODE_FOR_xordf3 = 3865,
  CODE_FOR_fma_fmadd_v32hf_maskz_1 = 3876,
  CODE_FOR_fma_fmadd_v32hf_maskz_1_round = 3878,
  CODE_FOR_fma_fmadd_v16hf_maskz_1 = 3880,
   CODE_FOR_fma_fmadd_v16hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmadd_v8hf_maskz_1 = 3882,
   CODE_FOR_fma_fmadd_v8hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmadd_v16sf_maskz_1 = 3886,
  CODE_FOR_fma_fmadd_v16sf_maskz_1_round = 3888,
  CODE_FOR_fma_fmadd_v8sf_maskz_1 = 3890,
   CODE_FOR_fma_fmadd_v8sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmadd_v4sf_maskz_1 = 3892,
   CODE_FOR_fma_fmadd_v4sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmadd_v8df_maskz_1 = 3895,
  CODE_FOR_fma_fmadd_v8df_maskz_1_round = 3897,
  CODE_FOR_fma_fmadd_v4df_maskz_1 = 3899,
   CODE_FOR_fma_fmadd_v4df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmadd_v2df_maskz_1 = 3901,
   CODE_FOR_fma_fmadd_v2df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_fmadd_v32hf_mask = 3902,
  CODE_FOR_avx512bw_fmadd_v32hf_mask_round = 3903,
  CODE_FOR_avx512vl_fmadd_v16hf_mask = 3904,
   CODE_FOR_avx512vl_fmadd_v16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_fmadd_v8hf_mask = 3905,
   CODE_FOR_avx512fp16_fmadd_v8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_fmadd_v16sf_mask = 3906,
  CODE_FOR_avx512f_fmadd_v16sf_mask_round = 3907,
  CODE_FOR_avx512vl_fmadd_v8sf_mask = 3908,
   CODE_FOR_avx512vl_fmadd_v8sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fmadd_v4sf_mask = 3909,
   CODE_FOR_avx512vl_fmadd_v4sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_fmadd_v8df_mask = 3910,
  CODE_FOR_avx512f_fmadd_v8df_mask_round = 3911,
  CODE_FOR_avx512vl_fmadd_v4df_mask = 3912,
   CODE_FOR_avx512vl_fmadd_v4df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fmadd_v2df_mask = 3913,
   CODE_FOR_avx512vl_fmadd_v2df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_fmadd_v32hf_mask3 = 3914,
  CODE_FOR_avx512bw_fmadd_v32hf_mask3_round = 3915,
  CODE_FOR_avx512vl_fmadd_v16hf_mask3 = 3916,
  CODE_FOR_avx512vl_fmadd_v16hf_mask3_round = 3917,
  CODE_FOR_avx512fp16_fmadd_v8hf_mask3 = 3918,
  CODE_FOR_avx512fp16_fmadd_v8hf_mask3_round = 3919,
  CODE_FOR_avx512f_fmadd_v16sf_mask3 = 3920,
  CODE_FOR_avx512f_fmadd_v16sf_mask3_round = 3921,
  CODE_FOR_avx512vl_fmadd_v8sf_mask3 = 3922,
  CODE_FOR_avx512vl_fmadd_v8sf_mask3_round = 3923,
  CODE_FOR_avx512vl_fmadd_v4sf_mask3 = 3924,
  CODE_FOR_avx512vl_fmadd_v4sf_mask3_round = 3925,
  CODE_FOR_avx512f_fmadd_v8df_mask3 = 3926,
  CODE_FOR_avx512f_fmadd_v8df_mask3_round = 3927,
  CODE_FOR_avx512vl_fmadd_v4df_mask3 = 3928,
  CODE_FOR_avx512vl_fmadd_v4df_mask3_round = 3929,
  CODE_FOR_avx512vl_fmadd_v2df_mask3 = 3930,
  CODE_FOR_avx512vl_fmadd_v2df_mask3_round = 3931,
  CODE_FOR_fma_fmsub_v32hf_maskz_1 = 3939,
  CODE_FOR_fma_fmsub_v32hf_maskz_1_round = 3941,
  CODE_FOR_fma_fmsub_v16hf_maskz_1 = 3943,
   CODE_FOR_fma_fmsub_v16hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmsub_v8hf_maskz_1 = 3945,
   CODE_FOR_fma_fmsub_v8hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmsub_v16sf_maskz_1 = 3949,
  CODE_FOR_fma_fmsub_v16sf_maskz_1_round = 3951,
  CODE_FOR_fma_fmsub_v8sf_maskz_1 = 3953,
   CODE_FOR_fma_fmsub_v8sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmsub_v4sf_maskz_1 = 3955,
   CODE_FOR_fma_fmsub_v4sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmsub_v8df_maskz_1 = 3958,
  CODE_FOR_fma_fmsub_v8df_maskz_1_round = 3960,
  CODE_FOR_fma_fmsub_v4df_maskz_1 = 3962,
   CODE_FOR_fma_fmsub_v4df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmsub_v2df_maskz_1 = 3964,
   CODE_FOR_fma_fmsub_v2df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_fmsub_v32hf_mask = 3965,
  CODE_FOR_avx512bw_fmsub_v32hf_mask_round = 3966,
  CODE_FOR_avx512vl_fmsub_v16hf_mask = 3967,
  CODE_FOR_avx512vl_fmsub_v16hf_mask_round = 3968,
  CODE_FOR_avx512fp16_fmsub_v8hf_mask = 3969,
  CODE_FOR_avx512fp16_fmsub_v8hf_mask_round = 3970,
  CODE_FOR_avx512f_fmsub_v16sf_mask = 3971,
  CODE_FOR_avx512f_fmsub_v16sf_mask_round = 3972,
  CODE_FOR_avx512vl_fmsub_v8sf_mask = 3973,
  CODE_FOR_avx512vl_fmsub_v8sf_mask_round = 3974,
  CODE_FOR_avx512vl_fmsub_v4sf_mask = 3975,
  CODE_FOR_avx512vl_fmsub_v4sf_mask_round = 3976,
  CODE_FOR_avx512f_fmsub_v8df_mask = 3977,
  CODE_FOR_avx512f_fmsub_v8df_mask_round = 3978,
  CODE_FOR_avx512vl_fmsub_v4df_mask = 3979,
  CODE_FOR_avx512vl_fmsub_v4df_mask_round = 3980,
  CODE_FOR_avx512vl_fmsub_v2df_mask = 3981,
  CODE_FOR_avx512vl_fmsub_v2df_mask_round = 3982,
  CODE_FOR_avx512bw_fmsub_v32hf_mask3 = 3983,
  CODE_FOR_avx512bw_fmsub_v32hf_mask3_round = 3984,
  CODE_FOR_avx512vl_fmsub_v16hf_mask3 = 3985,
   CODE_FOR_avx512vl_fmsub_v16hf_mask3_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_fmsub_v8hf_mask3 = 3986,
   CODE_FOR_avx512fp16_fmsub_v8hf_mask3_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_fmsub_v16sf_mask3 = 3987,
  CODE_FOR_avx512f_fmsub_v16sf_mask3_round = 3988,
  CODE_FOR_avx512vl_fmsub_v8sf_mask3 = 3989,
   CODE_FOR_avx512vl_fmsub_v8sf_mask3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fmsub_v4sf_mask3 = 3990,
   CODE_FOR_avx512vl_fmsub_v4sf_mask3_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_fmsub_v8df_mask3 = 3991,
  CODE_FOR_avx512f_fmsub_v8df_mask3_round = 3992,
  CODE_FOR_avx512vl_fmsub_v4df_mask3 = 3993,
   CODE_FOR_avx512vl_fmsub_v4df_mask3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fmsub_v2df_mask3 = 3994,
   CODE_FOR_avx512vl_fmsub_v2df_mask3_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmadd_v32hf_maskz_1 = 4002,
  CODE_FOR_fma_fnmadd_v32hf_maskz_1_round = 4004,
  CODE_FOR_fma_fnmadd_v16hf_maskz_1 = 4006,
   CODE_FOR_fma_fnmadd_v16hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmadd_v8hf_maskz_1 = 4008,
   CODE_FOR_fma_fnmadd_v8hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmadd_v16sf_maskz_1 = 4012,
  CODE_FOR_fma_fnmadd_v16sf_maskz_1_round = 4014,
  CODE_FOR_fma_fnmadd_v8sf_maskz_1 = 4016,
   CODE_FOR_fma_fnmadd_v8sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmadd_v4sf_maskz_1 = 4018,
   CODE_FOR_fma_fnmadd_v4sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmadd_v8df_maskz_1 = 4021,
  CODE_FOR_fma_fnmadd_v8df_maskz_1_round = 4023,
  CODE_FOR_fma_fnmadd_v4df_maskz_1 = 4025,
   CODE_FOR_fma_fnmadd_v4df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmadd_v2df_maskz_1 = 4027,
   CODE_FOR_fma_fnmadd_v2df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_fnmadd_v32hf_mask = 4028,
  CODE_FOR_avx512bw_fnmadd_v32hf_mask_round = 4029,
  CODE_FOR_avx512vl_fnmadd_v16hf_mask = 4030,
   CODE_FOR_avx512vl_fnmadd_v16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_fnmadd_v8hf_mask = 4031,
   CODE_FOR_avx512fp16_fnmadd_v8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_fnmadd_v16sf_mask = 4032,
  CODE_FOR_avx512f_fnmadd_v16sf_mask_round = 4033,
  CODE_FOR_avx512vl_fnmadd_v8sf_mask = 4034,
   CODE_FOR_avx512vl_fnmadd_v8sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fnmadd_v4sf_mask = 4035,
   CODE_FOR_avx512vl_fnmadd_v4sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_fnmadd_v8df_mask = 4036,
  CODE_FOR_avx512f_fnmadd_v8df_mask_round = 4037,
  CODE_FOR_avx512vl_fnmadd_v4df_mask = 4038,
   CODE_FOR_avx512vl_fnmadd_v4df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fnmadd_v2df_mask = 4039,
   CODE_FOR_avx512vl_fnmadd_v2df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_fnmadd_v32hf_mask3 = 4040,
  CODE_FOR_avx512bw_fnmadd_v32hf_mask3_round = 4041,
  CODE_FOR_avx512vl_fnmadd_v16hf_mask3 = 4042,
   CODE_FOR_avx512vl_fnmadd_v16hf_mask3_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_fnmadd_v8hf_mask3 = 4043,
   CODE_FOR_avx512fp16_fnmadd_v8hf_mask3_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_fnmadd_v16sf_mask3 = 4044,
  CODE_FOR_avx512f_fnmadd_v16sf_mask3_round = 4045,
  CODE_FOR_avx512vl_fnmadd_v8sf_mask3 = 4046,
   CODE_FOR_avx512vl_fnmadd_v8sf_mask3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fnmadd_v4sf_mask3 = 4047,
   CODE_FOR_avx512vl_fnmadd_v4sf_mask3_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_fnmadd_v8df_mask3 = 4048,
  CODE_FOR_avx512f_fnmadd_v8df_mask3_round = 4049,
  CODE_FOR_avx512vl_fnmadd_v4df_mask3 = 4050,
   CODE_FOR_avx512vl_fnmadd_v4df_mask3_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fnmadd_v2df_mask3 = 4051,
   CODE_FOR_avx512vl_fnmadd_v2df_mask3_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmsub_v32hf_maskz_1 = 4073,
  CODE_FOR_fma_fnmsub_v32hf_maskz_1_round = 4075,
  CODE_FOR_fma_fnmsub_v16hf_maskz_1 = 4077,
   CODE_FOR_fma_fnmsub_v16hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmsub_v8hf_maskz_1 = 4079,
   CODE_FOR_fma_fnmsub_v8hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmsub_v16sf_maskz_1 = 4083,
  CODE_FOR_fma_fnmsub_v16sf_maskz_1_round = 4085,
  CODE_FOR_fma_fnmsub_v8sf_maskz_1 = 4087,
   CODE_FOR_fma_fnmsub_v8sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmsub_v4sf_maskz_1 = 4089,
   CODE_FOR_fma_fnmsub_v4sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmsub_v8df_maskz_1 = 4092,
  CODE_FOR_fma_fnmsub_v8df_maskz_1_round = 4094,
  CODE_FOR_fma_fnmsub_v4df_maskz_1 = 4096,
   CODE_FOR_fma_fnmsub_v4df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fnmsub_v2df_maskz_1 = 4098,
   CODE_FOR_fma_fnmsub_v2df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_fnmsub_v32hf_mask = 4099,
  CODE_FOR_avx512bw_fnmsub_v32hf_mask_round = 4100,
  CODE_FOR_avx512vl_fnmsub_v16hf_mask = 4101,
   CODE_FOR_avx512vl_fnmsub_v16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_fnmsub_v8hf_mask = 4102,
   CODE_FOR_avx512fp16_fnmsub_v8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_fnmsub_v16sf_mask = 4103,
  CODE_FOR_avx512f_fnmsub_v16sf_mask_round = 4104,
  CODE_FOR_avx512vl_fnmsub_v8sf_mask = 4105,
   CODE_FOR_avx512vl_fnmsub_v8sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fnmsub_v4sf_mask = 4106,
   CODE_FOR_avx512vl_fnmsub_v4sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512f_fnmsub_v8df_mask = 4107,
  CODE_FOR_avx512f_fnmsub_v8df_mask_round = 4108,
  CODE_FOR_avx512vl_fnmsub_v4df_mask = 4109,
   CODE_FOR_avx512vl_fnmsub_v4df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fnmsub_v2df_mask = 4110,
   CODE_FOR_avx512vl_fnmsub_v2df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_fnmsub_v32hf_mask3 = 4111,
  CODE_FOR_avx512bw_fnmsub_v32hf_mask3_round = 4112,
  CODE_FOR_avx512vl_fnmsub_v16hf_mask3 = 4113,
  CODE_FOR_avx512vl_fnmsub_v16hf_mask3_round = 4114,
  CODE_FOR_avx512fp16_fnmsub_v8hf_mask3 = 4115,
  CODE_FOR_avx512fp16_fnmsub_v8hf_mask3_round = 4116,
  CODE_FOR_avx512f_fnmsub_v16sf_mask3 = 4117,
  CODE_FOR_avx512f_fnmsub_v16sf_mask3_round = 4118,
  CODE_FOR_avx512vl_fnmsub_v8sf_mask3 = 4119,
  CODE_FOR_avx512vl_fnmsub_v8sf_mask3_round = 4120,
  CODE_FOR_avx512vl_fnmsub_v4sf_mask3 = 4121,
  CODE_FOR_avx512vl_fnmsub_v4sf_mask3_round = 4122,
  CODE_FOR_avx512f_fnmsub_v8df_mask3 = 4123,
  CODE_FOR_avx512f_fnmsub_v8df_mask3_round = 4124,
  CODE_FOR_avx512vl_fnmsub_v4df_mask3 = 4125,
  CODE_FOR_avx512vl_fnmsub_v4df_mask3_round = 4126,
  CODE_FOR_avx512vl_fnmsub_v2df_mask3 = 4127,
  CODE_FOR_avx512vl_fnmsub_v2df_mask3_round = 4128,
  CODE_FOR_fma_fmaddsub_v32hf_maskz_1 = 4134,
  CODE_FOR_fma_fmaddsub_v32hf_maskz_1_round = 4136,
  CODE_FOR_fma_fmaddsub_v16hf_maskz_1 = 4138,
   CODE_FOR_fma_fmaddsub_v16hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmaddsub_v8hf_maskz_1 = 4140,
   CODE_FOR_fma_fmaddsub_v8hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmaddsub_v16sf_maskz_1 = 4142,
  CODE_FOR_fma_fmaddsub_v16sf_maskz_1_round = 4144,
  CODE_FOR_fma_fmaddsub_v8sf_maskz_1 = 4146,
   CODE_FOR_fma_fmaddsub_v8sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmaddsub_v4sf_maskz_1 = 4148,
   CODE_FOR_fma_fmaddsub_v4sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmaddsub_v8df_maskz_1 = 4150,
  CODE_FOR_fma_fmaddsub_v8df_maskz_1_round = 4152,
  CODE_FOR_fma_fmaddsub_v4df_maskz_1 = 4154,
   CODE_FOR_fma_fmaddsub_v4df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmaddsub_v2df_maskz_1 = 4156,
   CODE_FOR_fma_fmaddsub_v2df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_fmaddsub_v32hf_mask = 4157,
  CODE_FOR_avx512bw_fmaddsub_v32hf_mask_round = 4158,
  CODE_FOR_avx512vl_fmaddsub_v16hf_mask = 4159,
  CODE_FOR_avx512vl_fmaddsub_v16hf_mask_round = 4160,
  CODE_FOR_avx512fp16_fmaddsub_v8hf_mask = 4161,
  CODE_FOR_avx512fp16_fmaddsub_v8hf_mask_round = 4162,
  CODE_FOR_avx512f_fmaddsub_v16sf_mask = 4163,
  CODE_FOR_avx512f_fmaddsub_v16sf_mask_round = 4164,
  CODE_FOR_avx512vl_fmaddsub_v8sf_mask = 4165,
  CODE_FOR_avx512vl_fmaddsub_v8sf_mask_round = 4166,
  CODE_FOR_avx512vl_fmaddsub_v4sf_mask = 4167,
  CODE_FOR_avx512vl_fmaddsub_v4sf_mask_round = 4168,
  CODE_FOR_avx512f_fmaddsub_v8df_mask = 4169,
  CODE_FOR_avx512f_fmaddsub_v8df_mask_round = 4170,
  CODE_FOR_avx512vl_fmaddsub_v4df_mask = 4171,
  CODE_FOR_avx512vl_fmaddsub_v4df_mask_round = 4172,
  CODE_FOR_avx512vl_fmaddsub_v2df_mask = 4173,
  CODE_FOR_avx512vl_fmaddsub_v2df_mask_round = 4174,
  CODE_FOR_avx512bw_fmaddsub_v32hf_mask3 = 4175,
  CODE_FOR_avx512bw_fmaddsub_v32hf_mask3_round = 4176,
  CODE_FOR_avx512vl_fmaddsub_v16hf_mask3 = 4177,
  CODE_FOR_avx512vl_fmaddsub_v16hf_mask3_round = 4178,
  CODE_FOR_avx512fp16_fmaddsub_v8hf_mask3 = 4179,
  CODE_FOR_avx512fp16_fmaddsub_v8hf_mask3_round = 4180,
  CODE_FOR_avx512f_fmaddsub_v16sf_mask3 = 4181,
  CODE_FOR_avx512f_fmaddsub_v16sf_mask3_round = 4182,
  CODE_FOR_avx512vl_fmaddsub_v8sf_mask3 = 4183,
  CODE_FOR_avx512vl_fmaddsub_v8sf_mask3_round = 4184,
  CODE_FOR_avx512vl_fmaddsub_v4sf_mask3 = 4185,
  CODE_FOR_avx512vl_fmaddsub_v4sf_mask3_round = 4186,
  CODE_FOR_avx512f_fmaddsub_v8df_mask3 = 4187,
  CODE_FOR_avx512f_fmaddsub_v8df_mask3_round = 4188,
  CODE_FOR_avx512vl_fmaddsub_v4df_mask3 = 4189,
  CODE_FOR_avx512vl_fmaddsub_v4df_mask3_round = 4190,
  CODE_FOR_avx512vl_fmaddsub_v2df_mask3 = 4191,
  CODE_FOR_avx512vl_fmaddsub_v2df_mask3_round = 4192,
  CODE_FOR_fma_fmsubadd_v32hf_maskz_1 = 4198,
  CODE_FOR_fma_fmsubadd_v32hf_maskz_1_round = 4200,
  CODE_FOR_fma_fmsubadd_v16hf_maskz_1 = 4202,
   CODE_FOR_fma_fmsubadd_v16hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmsubadd_v8hf_maskz_1 = 4204,
   CODE_FOR_fma_fmsubadd_v8hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmsubadd_v16sf_maskz_1 = 4206,
  CODE_FOR_fma_fmsubadd_v16sf_maskz_1_round = 4208,
  CODE_FOR_fma_fmsubadd_v8sf_maskz_1 = 4210,
   CODE_FOR_fma_fmsubadd_v8sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmsubadd_v4sf_maskz_1 = 4212,
   CODE_FOR_fma_fmsubadd_v4sf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmsubadd_v8df_maskz_1 = 4214,
  CODE_FOR_fma_fmsubadd_v8df_maskz_1_round = 4216,
  CODE_FOR_fma_fmsubadd_v4df_maskz_1 = 4218,
   CODE_FOR_fma_fmsubadd_v4df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmsubadd_v2df_maskz_1 = 4220,
   CODE_FOR_fma_fmsubadd_v2df_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_fmsubadd_v32hf_mask = 4221,
  CODE_FOR_avx512bw_fmsubadd_v32hf_mask_round = 4222,
  CODE_FOR_avx512vl_fmsubadd_v16hf_mask = 4223,
  CODE_FOR_avx512vl_fmsubadd_v16hf_mask_round = 4224,
  CODE_FOR_avx512fp16_fmsubadd_v8hf_mask = 4225,
  CODE_FOR_avx512fp16_fmsubadd_v8hf_mask_round = 4226,
  CODE_FOR_avx512f_fmsubadd_v16sf_mask = 4227,
  CODE_FOR_avx512f_fmsubadd_v16sf_mask_round = 4228,
  CODE_FOR_avx512vl_fmsubadd_v8sf_mask = 4229,
  CODE_FOR_avx512vl_fmsubadd_v8sf_mask_round = 4230,
  CODE_FOR_avx512vl_fmsubadd_v4sf_mask = 4231,
  CODE_FOR_avx512vl_fmsubadd_v4sf_mask_round = 4232,
  CODE_FOR_avx512f_fmsubadd_v8df_mask = 4233,
  CODE_FOR_avx512f_fmsubadd_v8df_mask_round = 4234,
  CODE_FOR_avx512vl_fmsubadd_v4df_mask = 4235,
  CODE_FOR_avx512vl_fmsubadd_v4df_mask_round = 4236,
  CODE_FOR_avx512vl_fmsubadd_v2df_mask = 4237,
  CODE_FOR_avx512vl_fmsubadd_v2df_mask_round = 4238,
  CODE_FOR_avx512bw_fmsubadd_v32hf_mask3 = 4239,
  CODE_FOR_avx512bw_fmsubadd_v32hf_mask3_round = 4240,
  CODE_FOR_avx512vl_fmsubadd_v16hf_mask3 = 4241,
  CODE_FOR_avx512vl_fmsubadd_v16hf_mask3_round = 4242,
  CODE_FOR_avx512fp16_fmsubadd_v8hf_mask3 = 4243,
  CODE_FOR_avx512fp16_fmsubadd_v8hf_mask3_round = 4244,
  CODE_FOR_avx512f_fmsubadd_v16sf_mask3 = 4245,
  CODE_FOR_avx512f_fmsubadd_v16sf_mask3_round = 4246,
  CODE_FOR_avx512vl_fmsubadd_v8sf_mask3 = 4247,
  CODE_FOR_avx512vl_fmsubadd_v8sf_mask3_round = 4248,
  CODE_FOR_avx512vl_fmsubadd_v4sf_mask3 = 4249,
  CODE_FOR_avx512vl_fmsubadd_v4sf_mask3_round = 4250,
  CODE_FOR_avx512f_fmsubadd_v8df_mask3 = 4251,
  CODE_FOR_avx512f_fmsubadd_v8df_mask3_round = 4252,
  CODE_FOR_avx512vl_fmsubadd_v4df_mask3 = 4253,
  CODE_FOR_avx512vl_fmsubadd_v4df_mask3_round = 4254,
  CODE_FOR_avx512vl_fmsubadd_v2df_mask3 = 4255,
  CODE_FOR_avx512vl_fmsubadd_v2df_mask3_round = 4256,
  CODE_FOR_avx512f_vmfmadd_v8hf_mask = 4281,
  CODE_FOR_avx512f_vmfmadd_v8hf_mask_round = 4282,
  CODE_FOR_avx512f_vmfmadd_v4sf_mask = 4283,
  CODE_FOR_avx512f_vmfmadd_v4sf_mask_round = 4284,
  CODE_FOR_avx512f_vmfmadd_v2df_mask = 4285,
  CODE_FOR_avx512f_vmfmadd_v2df_mask_round = 4286,
  CODE_FOR_avx512f_vmfmadd_v8hf_mask3 = 4287,
  CODE_FOR_avx512f_vmfmadd_v8hf_mask3_round = 4288,
  CODE_FOR_avx512f_vmfmadd_v4sf_mask3 = 4289,
  CODE_FOR_avx512f_vmfmadd_v4sf_mask3_round = 4290,
  CODE_FOR_avx512f_vmfmadd_v2df_mask3 = 4291,
  CODE_FOR_avx512f_vmfmadd_v2df_mask3_round = 4292,
  CODE_FOR_avx512f_vmfmadd_v8hf_maskz_1 = 4293,
  CODE_FOR_avx512f_vmfmadd_v8hf_maskz_1_round = 4294,
  CODE_FOR_avx512f_vmfmadd_v4sf_maskz_1 = 4295,
  CODE_FOR_avx512f_vmfmadd_v4sf_maskz_1_round = 4296,
  CODE_FOR_avx512f_vmfmadd_v2df_maskz_1 = 4297,
  CODE_FOR_avx512f_vmfmadd_v2df_maskz_1_round = 4298,
  CODE_FOR_avx512f_vmfmsub_v8hf_mask3 = 4305,
  CODE_FOR_avx512f_vmfmsub_v8hf_mask3_round = 4306,
  CODE_FOR_avx512f_vmfmsub_v4sf_mask3 = 4307,
  CODE_FOR_avx512f_vmfmsub_v4sf_mask3_round = 4308,
  CODE_FOR_avx512f_vmfmsub_v2df_mask3 = 4309,
  CODE_FOR_avx512f_vmfmsub_v2df_mask3_round = 4310,
  CODE_FOR_avx512f_vmfnmadd_v8hf_mask = 4317,
  CODE_FOR_avx512f_vmfnmadd_v8hf_mask_round = 4318,
  CODE_FOR_avx512f_vmfnmadd_v4sf_mask = 4319,
  CODE_FOR_avx512f_vmfnmadd_v4sf_mask_round = 4320,
  CODE_FOR_avx512f_vmfnmadd_v2df_mask = 4321,
  CODE_FOR_avx512f_vmfnmadd_v2df_mask_round = 4322,
  CODE_FOR_avx512f_vmfnmadd_v8hf_mask3 = 4323,
  CODE_FOR_avx512f_vmfnmadd_v8hf_mask3_round = 4324,
  CODE_FOR_avx512f_vmfnmadd_v4sf_mask3 = 4325,
  CODE_FOR_avx512f_vmfnmadd_v4sf_mask3_round = 4326,
  CODE_FOR_avx512f_vmfnmadd_v2df_mask3 = 4327,
  CODE_FOR_avx512f_vmfnmadd_v2df_mask3_round = 4328,
  CODE_FOR_avx512f_vmfnmadd_v8hf_maskz_1 = 4329,
  CODE_FOR_avx512f_vmfnmadd_v8hf_maskz_1_round = 4330,
  CODE_FOR_avx512f_vmfnmadd_v4sf_maskz_1 = 4331,
  CODE_FOR_avx512f_vmfnmadd_v4sf_maskz_1_round = 4332,
  CODE_FOR_avx512f_vmfnmadd_v2df_maskz_1 = 4333,
  CODE_FOR_avx512f_vmfnmadd_v2df_maskz_1_round = 4334,
  CODE_FOR_fma_fmaddc_v32hf = 4361,
  CODE_FOR_fma_fmaddc_v32hf_round = 4362,
  CODE_FOR_fma_fmaddc_v32hf_maskz_1 = 4363,
  CODE_FOR_fma_fmaddc_v32hf_maskz_1_round = 4364,
  CODE_FOR_fma_fcmaddc_v32hf = 4365,
  CODE_FOR_fma_fcmaddc_v32hf_round = 4366,
  CODE_FOR_fma_fcmaddc_v32hf_maskz_1 = 4367,
  CODE_FOR_fma_fcmaddc_v32hf_maskz_1_round = 4368,
  CODE_FOR_fma_fmaddc_v16hf = 4369,
   CODE_FOR_fma_fmaddc_v16hf_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmaddc_v16hf_maskz_1 = 4370,
   CODE_FOR_fma_fmaddc_v16hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fcmaddc_v16hf = 4371,
   CODE_FOR_fma_fcmaddc_v16hf_round = CODE_FOR_nothing,
  CODE_FOR_fma_fcmaddc_v16hf_maskz_1 = 4372,
   CODE_FOR_fma_fcmaddc_v16hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmaddc_v8hf = 4373,
   CODE_FOR_fma_fmaddc_v8hf_round = CODE_FOR_nothing,
  CODE_FOR_fma_fmaddc_v8hf_maskz_1 = 4374,
   CODE_FOR_fma_fmaddc_v8hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_fcmaddc_v8hf = 4375,
   CODE_FOR_fma_fcmaddc_v8hf_round = CODE_FOR_nothing,
  CODE_FOR_fma_fcmaddc_v8hf_maskz_1 = 4376,
   CODE_FOR_fma_fcmaddc_v8hf_maskz_1_round = CODE_FOR_nothing,
  CODE_FOR_fma_v32hf_fadd_fmul = 4377,
  CODE_FOR_fma_v16hf_fadd_fmul = 4378,
  CODE_FOR_fma_v8hf_fadd_fmul = 4379,
  CODE_FOR_fma_v32hf_fadd_fcmul = 4380,
  CODE_FOR_fma_v16hf_fadd_fcmul = 4381,
  CODE_FOR_fma_v8hf_fadd_fcmul = 4382,
  CODE_FOR_fma_fmaddc_v32hf_fma_zero = 4383,
  CODE_FOR_fma_fcmaddc_v32hf_fma_zero = 4384,
  CODE_FOR_fma_fmaddc_v16hf_fma_zero = 4385,
  CODE_FOR_fma_fcmaddc_v16hf_fma_zero = 4386,
  CODE_FOR_fma_fmaddc_v8hf_fma_zero = 4387,
  CODE_FOR_fma_fcmaddc_v8hf_fma_zero = 4388,
  CODE_FOR_fma_fmaddc_v16sf_pair = 4389,
  CODE_FOR_fma_fcmaddc_v16sf_pair = 4390,
  CODE_FOR_fma_fmaddc_v8sf_pair = 4391,
  CODE_FOR_fma_fcmaddc_v8sf_pair = 4392,
  CODE_FOR_fma_fmaddc_v4sf_pair = 4393,
  CODE_FOR_fma_fcmaddc_v4sf_pair = 4394,
  CODE_FOR_fma_v32hf_fmaddc_bcst = 4395,
  CODE_FOR_fma_v16hf_fmaddc_bcst = 4396,
  CODE_FOR_fma_v8hf_fmaddc_bcst = 4397,
  CODE_FOR_fma_v32hf_fcmaddc_bcst = 4398,
  CODE_FOR_fma_v16hf_fcmaddc_bcst = 4399,
  CODE_FOR_fma_v8hf_fcmaddc_bcst = 4400,
  CODE_FOR_avx512bw_fmaddc_v32hf_mask = 4401,
  CODE_FOR_avx512bw_fmaddc_v32hf_mask_round = 4402,
  CODE_FOR_avx512bw_fcmaddc_v32hf_mask = 4403,
  CODE_FOR_avx512bw_fcmaddc_v32hf_mask_round = 4404,
  CODE_FOR_avx512vl_fmaddc_v16hf_mask = 4405,
   CODE_FOR_avx512vl_fmaddc_v16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fcmaddc_v16hf_mask = 4406,
   CODE_FOR_avx512vl_fcmaddc_v16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_fmaddc_v8hf_mask = 4407,
   CODE_FOR_avx512fp16_fmaddc_v8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_fcmaddc_v8hf_mask = 4408,
   CODE_FOR_avx512fp16_fcmaddc_v8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512bw_fmulc_v32hf = 4409,
  CODE_FOR_avx512bw_fmulc_v32hf_mask = 4410,
  CODE_FOR_avx512bw_fmulc_v32hf_round = 4411,
  CODE_FOR_avx512bw_fmulc_v32hf_mask_round = 4412,
  CODE_FOR_avx512bw_fcmulc_v32hf = 4413,
  CODE_FOR_avx512bw_fcmulc_v32hf_mask = 4414,
  CODE_FOR_avx512bw_fcmulc_v32hf_round = 4415,
  CODE_FOR_avx512bw_fcmulc_v32hf_mask_round = 4416,
  CODE_FOR_avx512vl_fmulc_v16hf = 4417,
  CODE_FOR_avx512vl_fmulc_v16hf_mask = 4418,
   CODE_FOR_avx512vl_fmulc_v16hf_round = CODE_FOR_nothing,
   CODE_FOR_avx512vl_fmulc_v16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512vl_fcmulc_v16hf = 4419,
  CODE_FOR_avx512vl_fcmulc_v16hf_mask = 4420,
   CODE_FOR_avx512vl_fcmulc_v16hf_round = CODE_FOR_nothing,
   CODE_FOR_avx512vl_fcmulc_v16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_fmulc_v8hf = 4421,
  CODE_FOR_avx512fp16_fmulc_v8hf_mask = 4422,
   CODE_FOR_avx512fp16_fmulc_v8hf_round = CODE_FOR_nothing,
   CODE_FOR_avx512fp16_fmulc_v8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_fcmulc_v8hf = 4423,
  CODE_FOR_avx512fp16_fcmulc_v8hf_mask = 4424,
   CODE_FOR_avx512fp16_fcmulc_v8hf_round = CODE_FOR_nothing,
   CODE_FOR_avx512fp16_fcmulc_v8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_fma_fmaddcsh_v8hf = 4425,
  CODE_FOR_avx512fp16_fma_fmaddcsh_v8hf_maskz = 4426,
  CODE_FOR_avx512fp16_fma_fmaddcsh_v8hf_round = 4427,
  CODE_FOR_avx512fp16_fma_fmaddcsh_v8hf_maskz_round = 4428,
  CODE_FOR_avx512fp16_fma_fcmaddcsh_v8hf = 4429,
  CODE_FOR_avx512fp16_fma_fcmaddcsh_v8hf_maskz = 4430,
  CODE_FOR_avx512fp16_fma_fcmaddcsh_v8hf_round = 4431,
  CODE_FOR_avx512fp16_fma_fcmaddcsh_v8hf_maskz_round = 4432,
  CODE_FOR_avx512fp16_fmaddcsh_v8hf_mask = 4433,
  CODE_FOR_avx512fp16_fmaddcsh_v8hf_mask_round = 4434,
  CODE_FOR_avx512fp16_fcmaddcsh_v8hf_mask = 4435,
  CODE_FOR_avx512fp16_fcmaddcsh_v8hf_mask_round = 4436,
  CODE_FOR_avx512fp16_fmulcsh_v8hf = 4437,
  CODE_FOR_avx512fp16_fmulcsh_v8hf_round = 4438,
  CODE_FOR_avx512fp16_fmulcsh_v8hf_mask = 4439,
  CODE_FOR_avx512fp16_fmulcsh_v8hf_mask_round = 4440,
  CODE_FOR_avx512fp16_fcmulcsh_v8hf = 4441,
  CODE_FOR_avx512fp16_fcmulcsh_v8hf_round = 4442,
  CODE_FOR_avx512fp16_fcmulcsh_v8hf_mask = 4443,
  CODE_FOR_avx512fp16_fcmulcsh_v8hf_mask_round = 4444,
  CODE_FOR_avx512fp16_vcvtph2uw_v32hi = 4445,
  CODE_FOR_avx512fp16_vcvtph2uw_v32hi_round = 4446,
  CODE_FOR_avx512fp16_vcvtph2uw_v32hi_mask = 4447,
  CODE_FOR_avx512fp16_vcvtph2uw_v32hi_mask_round = 4448,
  CODE_FOR_avx512fp16_vcvtph2w_v32hi = 4449,
  CODE_FOR_avx512fp16_vcvtph2w_v32hi_round = 4450,
  CODE_FOR_avx512fp16_vcvtph2w_v32hi_mask = 4451,
  CODE_FOR_avx512fp16_vcvtph2w_v32hi_mask_round = 4452,
  CODE_FOR_avx512fp16_vcvtph2udq_v16si = 4453,
  CODE_FOR_avx512fp16_vcvtph2udq_v16si_round = 4454,
  CODE_FOR_avx512fp16_vcvtph2udq_v16si_mask = 4455,
  CODE_FOR_avx512fp16_vcvtph2udq_v16si_mask_round = 4456,
  CODE_FOR_avx512fp16_vcvtph2dq_v16si = 4457,
  CODE_FOR_avx512fp16_vcvtph2dq_v16si_round = 4458,
  CODE_FOR_avx512fp16_vcvtph2dq_v16si_mask = 4459,
  CODE_FOR_avx512fp16_vcvtph2dq_v16si_mask_round = 4460,
  CODE_FOR_avx512fp16_vcvtph2uqq_v8di = 4461,
  CODE_FOR_avx512fp16_vcvtph2uqq_v8di_round = 4462,
  CODE_FOR_avx512fp16_vcvtph2uqq_v8di_mask = 4463,
  CODE_FOR_avx512fp16_vcvtph2uqq_v8di_mask_round = 4464,
  CODE_FOR_avx512fp16_vcvtph2qq_v8di = 4465,
  CODE_FOR_avx512fp16_vcvtph2qq_v8di_round = 4466,
  CODE_FOR_avx512fp16_vcvtph2qq_v8di_mask = 4467,
  CODE_FOR_avx512fp16_vcvtph2qq_v8di_mask_round = 4468,
  CODE_FOR_avx512fp16_vcvtph2uw_v16hi = 4469,
  CODE_FOR_avx512fp16_vcvtph2uw_v16hi_round = 4470,
  CODE_FOR_avx512fp16_vcvtph2uw_v16hi_mask = 4471,
  CODE_FOR_avx512fp16_vcvtph2uw_v16hi_mask_round = 4472,
  CODE_FOR_avx512fp16_vcvtph2w_v16hi = 4473,
  CODE_FOR_avx512fp16_vcvtph2w_v16hi_round = 4474,
  CODE_FOR_avx512fp16_vcvtph2w_v16hi_mask = 4475,
  CODE_FOR_avx512fp16_vcvtph2w_v16hi_mask_round = 4476,
  CODE_FOR_avx512fp16_vcvtph2udq_v8si = 4477,
  CODE_FOR_avx512fp16_vcvtph2udq_v8si_round = 4478,
  CODE_FOR_avx512fp16_vcvtph2udq_v8si_mask = 4479,
  CODE_FOR_avx512fp16_vcvtph2udq_v8si_mask_round = 4480,
  CODE_FOR_avx512fp16_vcvtph2dq_v8si = 4481,
  CODE_FOR_avx512fp16_vcvtph2dq_v8si_round = 4482,
  CODE_FOR_avx512fp16_vcvtph2dq_v8si_mask = 4483,
  CODE_FOR_avx512fp16_vcvtph2dq_v8si_mask_round = 4484,
  CODE_FOR_avx512fp16_vcvtph2uqq_v4di = 4485,
  CODE_FOR_avx512fp16_vcvtph2uqq_v4di_round = 4486,
  CODE_FOR_avx512fp16_vcvtph2uqq_v4di_mask = 4487,
  CODE_FOR_avx512fp16_vcvtph2uqq_v4di_mask_round = 4488,
  CODE_FOR_avx512fp16_vcvtph2qq_v4di = 4489,
  CODE_FOR_avx512fp16_vcvtph2qq_v4di_round = 4490,
  CODE_FOR_avx512fp16_vcvtph2qq_v4di_mask = 4491,
  CODE_FOR_avx512fp16_vcvtph2qq_v4di_mask_round = 4492,
  CODE_FOR_avx512fp16_vcvtph2uw_v8hi = 4493,
  CODE_FOR_avx512fp16_vcvtph2uw_v8hi_round = 4494,
  CODE_FOR_avx512fp16_vcvtph2uw_v8hi_mask = 4495,
  CODE_FOR_avx512fp16_vcvtph2uw_v8hi_mask_round = 4496,
  CODE_FOR_avx512fp16_vcvtph2w_v8hi = 4497,
  CODE_FOR_avx512fp16_vcvtph2w_v8hi_round = 4498,
  CODE_FOR_avx512fp16_vcvtph2w_v8hi_mask = 4499,
  CODE_FOR_avx512fp16_vcvtph2w_v8hi_mask_round = 4500,
  CODE_FOR_avx512fp16_vcvtph2udq_v4si = 4501,
  CODE_FOR_avx512fp16_vcvtph2udq_v4si_round = 4502,
  CODE_FOR_avx512fp16_vcvtph2udq_v4si_mask = 4503,
  CODE_FOR_avx512fp16_vcvtph2udq_v4si_mask_round = 4504,
  CODE_FOR_avx512fp16_vcvtph2dq_v4si = 4505,
  CODE_FOR_avx512fp16_vcvtph2dq_v4si_round = 4506,
  CODE_FOR_avx512fp16_vcvtph2dq_v4si_mask = 4507,
  CODE_FOR_avx512fp16_vcvtph2dq_v4si_mask_round = 4508,
  CODE_FOR_avx512fp16_vcvtph2uqq_v2di = 4509,
  CODE_FOR_avx512fp16_vcvtph2uqq_v2di_round = 4510,
  CODE_FOR_avx512fp16_vcvtph2uqq_v2di_mask = 4511,
  CODE_FOR_avx512fp16_vcvtph2uqq_v2di_mask_round = 4512,
  CODE_FOR_avx512fp16_vcvtph2qq_v2di = 4513,
  CODE_FOR_avx512fp16_vcvtph2qq_v2di_round = 4514,
  CODE_FOR_avx512fp16_vcvtph2qq_v2di_mask = 4515,
  CODE_FOR_avx512fp16_vcvtph2qq_v2di_mask_round = 4516,
  CODE_FOR_avx512fp16_vcvtw2ph_v8hi = 4517,
  CODE_FOR_avx512fp16_vcvtw2ph_v8hi_round = 4518,
  CODE_FOR_avx512fp16_vcvtw2ph_v8hi_mask = 4519,
  CODE_FOR_avx512fp16_vcvtw2ph_v8hi_mask_round = 4520,
  CODE_FOR_avx512fp16_vcvtuw2ph_v8hi = 4521,
  CODE_FOR_avx512fp16_vcvtuw2ph_v8hi_round = 4522,
  CODE_FOR_avx512fp16_vcvtuw2ph_v8hi_mask = 4523,
  CODE_FOR_avx512fp16_vcvtuw2ph_v8hi_mask_round = 4524,
  CODE_FOR_avx512fp16_vcvtw2ph_v16hi = 4525,
  CODE_FOR_avx512fp16_vcvtw2ph_v16hi_round = 4526,
  CODE_FOR_avx512fp16_vcvtw2ph_v16hi_mask = 4527,
  CODE_FOR_avx512fp16_vcvtw2ph_v16hi_mask_round = 4528,
  CODE_FOR_avx512fp16_vcvtuw2ph_v16hi = 4529,
  CODE_FOR_avx512fp16_vcvtuw2ph_v16hi_round = 4530,
  CODE_FOR_avx512fp16_vcvtuw2ph_v16hi_mask = 4531,
  CODE_FOR_avx512fp16_vcvtuw2ph_v16hi_mask_round = 4532,
  CODE_FOR_avx512fp16_vcvtw2ph_v32hi = 4533,
  CODE_FOR_avx512fp16_vcvtw2ph_v32hi_round = 4534,
  CODE_FOR_avx512fp16_vcvtw2ph_v32hi_mask = 4535,
  CODE_FOR_avx512fp16_vcvtw2ph_v32hi_mask_round = 4536,
  CODE_FOR_avx512fp16_vcvtuw2ph_v32hi = 4537,
  CODE_FOR_avx512fp16_vcvtuw2ph_v32hi_round = 4538,
  CODE_FOR_avx512fp16_vcvtuw2ph_v32hi_mask = 4539,
  CODE_FOR_avx512fp16_vcvtuw2ph_v32hi_mask_round = 4540,
  CODE_FOR_avx512fp16_vcvtdq2ph_v8si = 4541,
  CODE_FOR_avx512fp16_vcvtdq2ph_v8si_round = 4542,
  CODE_FOR_avx512fp16_vcvtdq2ph_v8si_mask = 4543,
  CODE_FOR_avx512fp16_vcvtdq2ph_v8si_mask_round = 4544,
  CODE_FOR_avx512fp16_vcvtudq2ph_v8si = 4545,
  CODE_FOR_avx512fp16_vcvtudq2ph_v8si_round = 4546,
  CODE_FOR_avx512fp16_vcvtudq2ph_v8si_mask = 4547,
  CODE_FOR_avx512fp16_vcvtudq2ph_v8si_mask_round = 4548,
  CODE_FOR_avx512fp16_vcvtdq2ph_v16si = 4549,
  CODE_FOR_avx512fp16_vcvtdq2ph_v16si_round = 4550,
  CODE_FOR_avx512fp16_vcvtdq2ph_v16si_mask = 4551,
  CODE_FOR_avx512fp16_vcvtdq2ph_v16si_mask_round = 4552,
  CODE_FOR_avx512fp16_vcvtudq2ph_v16si = 4553,
  CODE_FOR_avx512fp16_vcvtudq2ph_v16si_round = 4554,
  CODE_FOR_avx512fp16_vcvtudq2ph_v16si_mask = 4555,
  CODE_FOR_avx512fp16_vcvtudq2ph_v16si_mask_round = 4556,
  CODE_FOR_avx512fp16_vcvtqq2ph_v8di = 4557,
  CODE_FOR_avx512fp16_vcvtqq2ph_v8di_round = 4558,
  CODE_FOR_avx512fp16_vcvtqq2ph_v8di_mask = 4559,
  CODE_FOR_avx512fp16_vcvtqq2ph_v8di_mask_round = 4560,
  CODE_FOR_avx512fp16_vcvtuqq2ph_v8di = 4561,
  CODE_FOR_avx512fp16_vcvtuqq2ph_v8di_round = 4562,
  CODE_FOR_avx512fp16_vcvtuqq2ph_v8di_mask = 4563,
  CODE_FOR_avx512fp16_vcvtuqq2ph_v8di_mask_round = 4564,
  CODE_FOR_avx512fp16_vcvtsh2usi = 4583,
  CODE_FOR_avx512fp16_vcvtsh2usi_round = 4584,
  CODE_FOR_avx512fp16_vcvtsh2si = 4585,
  CODE_FOR_avx512fp16_vcvtsh2si_round = 4586,
  CODE_FOR_avx512fp16_vcvtsh2usiq = 4587,
  CODE_FOR_avx512fp16_vcvtsh2usiq_round = 4588,
  CODE_FOR_avx512fp16_vcvtsh2siq = 4589,
  CODE_FOR_avx512fp16_vcvtsh2siq_round = 4590,
  CODE_FOR_avx512fp16_vcvtsh2usi_2 = 4591,
  CODE_FOR_avx512fp16_vcvtsh2si_2 = 4592,
  CODE_FOR_avx512fp16_vcvtsh2usiq_2 = 4593,
  CODE_FOR_avx512fp16_vcvtsh2siq_2 = 4594,
  CODE_FOR_avx512fp16_vcvtsi2sh = 4595,
  CODE_FOR_avx512fp16_vcvtsi2sh_round = 4596,
  CODE_FOR_avx512fp16_vcvtusi2sh = 4597,
  CODE_FOR_avx512fp16_vcvtusi2sh_round = 4598,
  CODE_FOR_avx512fp16_vcvtsi2shq = 4599,
  CODE_FOR_avx512fp16_vcvtsi2shq_round = 4600,
  CODE_FOR_avx512fp16_vcvtusi2shq = 4601,
  CODE_FOR_avx512fp16_vcvtusi2shq_round = 4602,
  CODE_FOR_unspec_avx512fp16_fix_truncv8hi2 = 4603,
  CODE_FOR_unspec_avx512fp16_fix_truncv8hi2_round = 4604,
  CODE_FOR_unspec_avx512fp16_fix_truncv8hi2_mask = 4605,
  CODE_FOR_unspec_avx512fp16_fix_truncv8hi2_mask_round = 4606,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8hi2 = 4607,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8hi2_round = 4608,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8hi2_mask = 4609,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8hi2_mask_round = 4610,
  CODE_FOR_unspec_avx512fp16_fix_truncv16hi2 = 4611,
  CODE_FOR_unspec_avx512fp16_fix_truncv16hi2_round = 4612,
  CODE_FOR_unspec_avx512fp16_fix_truncv16hi2_mask = 4613,
  CODE_FOR_unspec_avx512fp16_fix_truncv16hi2_mask_round = 4614,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv16hi2 = 4615,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv16hi2_round = 4616,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv16hi2_mask = 4617,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv16hi2_mask_round = 4618,
  CODE_FOR_unspec_avx512fp16_fix_truncv32hi2 = 4619,
  CODE_FOR_unspec_avx512fp16_fix_truncv32hi2_round = 4620,
  CODE_FOR_unspec_avx512fp16_fix_truncv32hi2_mask = 4621,
  CODE_FOR_unspec_avx512fp16_fix_truncv32hi2_mask_round = 4622,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv32hi2 = 4623,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv32hi2_round = 4624,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv32hi2_mask = 4625,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv32hi2_mask_round = 4626,
  CODE_FOR_unspec_avx512fp16_fix_truncv8si2 = 4627,
  CODE_FOR_unspec_avx512fp16_fix_truncv8si2_round = 4628,
  CODE_FOR_unspec_avx512fp16_fix_truncv8si2_mask = 4629,
  CODE_FOR_unspec_avx512fp16_fix_truncv8si2_mask_round = 4630,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8si2 = 4631,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8si2_round = 4632,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8si2_mask = 4633,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8si2_mask_round = 4634,
  CODE_FOR_unspec_avx512fp16_fix_truncv16si2 = 4635,
  CODE_FOR_unspec_avx512fp16_fix_truncv16si2_round = 4636,
  CODE_FOR_unspec_avx512fp16_fix_truncv16si2_mask = 4637,
  CODE_FOR_unspec_avx512fp16_fix_truncv16si2_mask_round = 4638,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv16si2 = 4639,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv16si2_round = 4640,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv16si2_mask = 4641,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv16si2_mask_round = 4642,
  CODE_FOR_unspec_avx512fp16_fix_truncv8di2 = 4643,
  CODE_FOR_unspec_avx512fp16_fix_truncv8di2_round = 4644,
  CODE_FOR_unspec_avx512fp16_fix_truncv8di2_mask = 4645,
  CODE_FOR_unspec_avx512fp16_fix_truncv8di2_mask_round = 4646,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8di2 = 4647,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8di2_round = 4648,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8di2_mask = 4649,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv8di2_mask_round = 4650,
  CODE_FOR_avx512fp16_fix_truncv8hi2 = 4651,
  CODE_FOR_avx512fp16_fix_truncv8hi2_round = 4652,
  CODE_FOR_avx512fp16_fix_truncv8hi2_mask = 4653,
  CODE_FOR_avx512fp16_fix_truncv8hi2_mask_round = 4654,
  CODE_FOR_avx512fp16_fixuns_truncv8hi2 = 4655,
  CODE_FOR_avx512fp16_fixuns_truncv8hi2_round = 4656,
  CODE_FOR_avx512fp16_fixuns_truncv8hi2_mask = 4657,
  CODE_FOR_avx512fp16_fixuns_truncv8hi2_mask_round = 4658,
  CODE_FOR_avx512fp16_fix_truncv16hi2 = 4659,
  CODE_FOR_avx512fp16_fix_truncv16hi2_round = 4660,
  CODE_FOR_avx512fp16_fix_truncv16hi2_mask = 4661,
  CODE_FOR_avx512fp16_fix_truncv16hi2_mask_round = 4662,
  CODE_FOR_avx512fp16_fixuns_truncv16hi2 = 4663,
  CODE_FOR_avx512fp16_fixuns_truncv16hi2_round = 4664,
  CODE_FOR_avx512fp16_fixuns_truncv16hi2_mask = 4665,
  CODE_FOR_avx512fp16_fixuns_truncv16hi2_mask_round = 4666,
  CODE_FOR_avx512fp16_fix_truncv32hi2 = 4667,
  CODE_FOR_avx512fp16_fix_truncv32hi2_round = 4668,
  CODE_FOR_avx512fp16_fix_truncv32hi2_mask = 4669,
  CODE_FOR_avx512fp16_fix_truncv32hi2_mask_round = 4670,
  CODE_FOR_avx512fp16_fixuns_truncv32hi2 = 4671,
  CODE_FOR_avx512fp16_fixuns_truncv32hi2_round = 4672,
  CODE_FOR_avx512fp16_fixuns_truncv32hi2_mask = 4673,
  CODE_FOR_avx512fp16_fixuns_truncv32hi2_mask_round = 4674,
  CODE_FOR_avx512fp16_fix_truncv8si2 = 4675,
  CODE_FOR_avx512fp16_fix_truncv8si2_round = 4676,
  CODE_FOR_avx512fp16_fix_truncv8si2_mask = 4677,
  CODE_FOR_avx512fp16_fix_truncv8si2_mask_round = 4678,
  CODE_FOR_avx512fp16_fixuns_truncv8si2 = 4679,
  CODE_FOR_avx512fp16_fixuns_truncv8si2_round = 4680,
  CODE_FOR_avx512fp16_fixuns_truncv8si2_mask = 4681,
  CODE_FOR_avx512fp16_fixuns_truncv8si2_mask_round = 4682,
  CODE_FOR_avx512fp16_fix_truncv16si2 = 4683,
  CODE_FOR_avx512fp16_fix_truncv16si2_round = 4684,
  CODE_FOR_avx512fp16_fix_truncv16si2_mask = 4685,
  CODE_FOR_avx512fp16_fix_truncv16si2_mask_round = 4686,
  CODE_FOR_avx512fp16_fixuns_truncv16si2 = 4687,
  CODE_FOR_avx512fp16_fixuns_truncv16si2_round = 4688,
  CODE_FOR_avx512fp16_fixuns_truncv16si2_mask = 4689,
  CODE_FOR_avx512fp16_fixuns_truncv16si2_mask_round = 4690,
  CODE_FOR_avx512fp16_fix_truncv8di2 = 4691,
  CODE_FOR_avx512fp16_fix_truncv8di2_round = 4692,
  CODE_FOR_avx512fp16_fix_truncv8di2_mask = 4693,
  CODE_FOR_avx512fp16_fix_truncv8di2_mask_round = 4694,
  CODE_FOR_avx512fp16_fixuns_truncv8di2 = 4695,
  CODE_FOR_avx512fp16_fixuns_truncv8di2_round = 4696,
  CODE_FOR_avx512fp16_fixuns_truncv8di2_mask = 4697,
  CODE_FOR_avx512fp16_fixuns_truncv8di2_mask_round = 4698,
  CODE_FOR_unspec_avx512fp16_fix_truncv4si2 = 4699,
  CODE_FOR_unspec_avx512fp16_fix_truncv4si2_mask = 4700,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv4si2 = 4701,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv4si2_mask = 4702,
  CODE_FOR_unspec_avx512fp16_fix_truncv4di2 = 4703,
  CODE_FOR_unspec_avx512fp16_fix_truncv4di2_mask = 4704,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv4di2 = 4705,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv4di2_mask = 4706,
  CODE_FOR_avx512fp16_fix_truncv4si2 = 4707,
  CODE_FOR_avx512fp16_fix_truncv4si2_mask = 4708,
  CODE_FOR_avx512fp16_fixuns_truncv4si2 = 4709,
  CODE_FOR_avx512fp16_fixuns_truncv4si2_mask = 4710,
  CODE_FOR_avx512fp16_fix_truncv4di2 = 4711,
  CODE_FOR_avx512fp16_fix_truncv4di2_mask = 4712,
  CODE_FOR_avx512fp16_fixuns_truncv4di2 = 4713,
  CODE_FOR_avx512fp16_fixuns_truncv4di2_mask = 4714,
  CODE_FOR_unspec_avx512fp16_fix_truncv2di2 = 4723,
  CODE_FOR_unspec_avx512fp16_fix_truncv2di2_mask = 4724,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv2di2 = 4725,
  CODE_FOR_unspec_avx512fp16_fixuns_truncv2di2_mask = 4726,
  CODE_FOR_avx512fp16_fix_truncv2di2 = 4727,
  CODE_FOR_avx512fp16_fix_truncv2di2_mask = 4728,
  CODE_FOR_avx512fp16_fixuns_truncv2di2 = 4729,
  CODE_FOR_avx512fp16_fixuns_truncv2di2_mask = 4730,
  CODE_FOR_unspec_avx512fp16_fix_truncsi2 = 4735,
  CODE_FOR_unspec_avx512fp16_fix_truncsi2_round = 4736,
  CODE_FOR_unspec_avx512fp16_fixuns_truncsi2 = 4737,
  CODE_FOR_unspec_avx512fp16_fixuns_truncsi2_round = 4738,
  CODE_FOR_unspec_avx512fp16_fix_truncdi2 = 4739,
  CODE_FOR_unspec_avx512fp16_fix_truncdi2_round = 4740,
  CODE_FOR_unspec_avx512fp16_fixuns_truncdi2 = 4741,
  CODE_FOR_unspec_avx512fp16_fixuns_truncdi2_round = 4742,
  CODE_FOR_avx512fp16_fix_truncsi2 = 4743,
  CODE_FOR_avx512fp16_fix_truncsi2_round = 4744,
  CODE_FOR_avx512fp16_fixuns_truncsi2 = 4745,
  CODE_FOR_avx512fp16_fixuns_truncsi2_round = 4746,
  CODE_FOR_avx512fp16_fix_truncdi2 = 4747,
  CODE_FOR_avx512fp16_fix_truncdi2_round = 4748,
  CODE_FOR_avx512fp16_fixuns_truncdi2 = 4749,
  CODE_FOR_avx512fp16_fixuns_truncdi2_round = 4750,
  CODE_FOR_avx512fp16_fix_truncsi2_mem = 4751,
  CODE_FOR_avx512fp16_fixuns_truncsi2_mem = 4752,
  CODE_FOR_avx512fp16_fix_truncdi2_mem = 4753,
  CODE_FOR_avx512fp16_fixuns_truncdi2_mem = 4754,
  CODE_FOR_avx512fp16_float_extend_phv8df2 = 4755,
  CODE_FOR_avx512fp16_float_extend_phv8df2_round = 4756,
  CODE_FOR_avx512fp16_float_extend_phv8df2_mask = 4757,
  CODE_FOR_avx512fp16_float_extend_phv8df2_mask_round = 4758,
  CODE_FOR_avx512fp16_float_extend_phv16sf2 = 4759,
  CODE_FOR_avx512fp16_float_extend_phv16sf2_round = 4760,
  CODE_FOR_avx512fp16_float_extend_phv16sf2_mask = 4761,
  CODE_FOR_avx512fp16_float_extend_phv16sf2_mask_round = 4762,
  CODE_FOR_avx512fp16_float_extend_phv8sf2 = 4763,
  CODE_FOR_avx512fp16_float_extend_phv8sf2_round = 4764,
  CODE_FOR_avx512fp16_float_extend_phv8sf2_mask = 4765,
  CODE_FOR_avx512fp16_float_extend_phv8sf2_mask_round = 4766,
  CODE_FOR_avx512fp16_float_extend_phv4df2 = 4767,
  CODE_FOR_avx512fp16_float_extend_phv4df2_mask = 4768,
  CODE_FOR_avx512fp16_float_extend_phv4sf2 = 4769,
  CODE_FOR_avx512fp16_float_extend_phv4sf2_mask = 4770,
  CODE_FOR_avx512fp16_float_extend_phv2df2 = 4775,
  CODE_FOR_avx512fp16_float_extend_phv2df2_mask = 4776,
  CODE_FOR_avx512fp16_vcvtpd2ph_v8df = 4779,
  CODE_FOR_avx512fp16_vcvtpd2ph_v8df_round = 4780,
  CODE_FOR_avx512fp16_vcvtpd2ph_v8df_mask = 4781,
  CODE_FOR_avx512fp16_vcvtpd2ph_v8df_mask_round = 4782,
  CODE_FOR_avx512fp16_vcvtps2ph_v16sf = 4783,
  CODE_FOR_avx512fp16_vcvtps2ph_v16sf_round = 4784,
  CODE_FOR_avx512fp16_vcvtps2ph_v16sf_mask = 4785,
  CODE_FOR_avx512fp16_vcvtps2ph_v16sf_mask_round = 4786,
  CODE_FOR_avx512fp16_vcvtps2ph_v8sf = 4787,
  CODE_FOR_avx512fp16_vcvtps2ph_v8sf_round = 4788,
  CODE_FOR_avx512fp16_vcvtps2ph_v8sf_mask = 4789,
  CODE_FOR_avx512fp16_vcvtps2ph_v8sf_mask_round = 4790,
  CODE_FOR_avx512fp16_vcvtsh2sd = 4800,
  CODE_FOR_avx512fp16_vcvtsh2sd_mask = 4801,
  CODE_FOR_avx512fp16_vcvtsh2sd_round = 4802,
  CODE_FOR_avx512fp16_vcvtsh2sd_mask_round = 4803,
  CODE_FOR_avx512fp16_vcvtsh2ss = 4804,
  CODE_FOR_avx512fp16_vcvtsh2ss_mask = 4805,
  CODE_FOR_avx512fp16_vcvtsh2ss_round = 4806,
  CODE_FOR_avx512fp16_vcvtsh2ss_mask_round = 4807,
  CODE_FOR_avx512fp16_vcvtsh2sd_mem = 4808,
  CODE_FOR_avx512fp16_vcvtsh2sd_mask_mem = 4809,
  CODE_FOR_avx512fp16_vcvtsh2ss_mem = 4810,
  CODE_FOR_avx512fp16_vcvtsh2ss_mask_mem = 4811,
  CODE_FOR_avx512fp16_vcvtsd2sh = 4812,
  CODE_FOR_avx512fp16_vcvtsd2sh_round = 4813,
  CODE_FOR_avx512fp16_vcvtsd2sh_mask = 4814,
  CODE_FOR_avx512fp16_vcvtsd2sh_mask_round = 4815,
  CODE_FOR_avx512fp16_vcvtss2sh = 4816,
  CODE_FOR_avx512fp16_vcvtss2sh_round = 4817,
  CODE_FOR_avx512fp16_vcvtss2sh_mask = 4818,
  CODE_FOR_avx512fp16_vcvtss2sh_mask_round = 4819,
  CODE_FOR_avx512fp16_vcvtss2sh_mem = 4820,
  CODE_FOR_avx512fp16_vcvtss2sh_mask_mem = 4821,
  CODE_FOR_avx512fp16_vcvtsd2sh_mem = 4822,
  CODE_FOR_avx512fp16_vcvtsd2sh_mask_mem = 4823,
  CODE_FOR_sse_cvtpi2ps = 4824,
  CODE_FOR_sse_cvtps2pi = 4825,
  CODE_FOR_unspec_sse_cvttps2pi = 4826,
  CODE_FOR_sse_cvttps2pi = 4827,
  CODE_FOR_sse_cvtsi2ss = 4828,
  CODE_FOR_sse_cvtsi2ss_round = 4829,
  CODE_FOR_sse_cvtsi2ssq = 4830,
  CODE_FOR_sse_cvtsi2ssq_round = 4831,
  CODE_FOR_sse_cvtss2si = 4832,
  CODE_FOR_sse_cvtss2si_round = 4833,
  CODE_FOR_sse_cvtss2siq = 4834,
  CODE_FOR_sse_cvtss2siq_round = 4835,
  CODE_FOR_sse_cvtss2si_2 = 4836,
  CODE_FOR_sse_cvtss2siq_2 = 4837,
  CODE_FOR_unspec_sse_cvttss2si = 4838,
  CODE_FOR_unspec_sse_cvttss2si_round = 4839,
  CODE_FOR_unspec_sse_cvttss2siq = 4840,
  CODE_FOR_unspec_sse_cvttss2siq_round = 4841,
  CODE_FOR_sse_cvttss2si = 4842,
  CODE_FOR_sse_cvttss2si_round = 4843,
  CODE_FOR_sse_cvttss2siq = 4844,
  CODE_FOR_sse_cvttss2siq_round = 4845,
  CODE_FOR_cvtusi2ss32 = 4846,
  CODE_FOR_cvtusi2ss32_round = 4847,
  CODE_FOR_cvtusi2sd32 = 4848,
   CODE_FOR_cvtusi2sd32_round = CODE_FOR_nothing,
  CODE_FOR_cvtusi2ss64 = 4849,
  CODE_FOR_cvtusi2ss64_round = 4850,
  CODE_FOR_cvtusi2sd64 = 4851,
  CODE_FOR_cvtusi2sd64_round = 4852,
  CODE_FOR_floatv16siv16sf2 = 4853,
  CODE_FOR_floatv16siv16sf2_round = 4854,
  CODE_FOR_floatv16siv16sf2_mask = 4855,
  CODE_FOR_floatv16siv16sf2_mask_round = 4856,
  CODE_FOR_floatv8siv8sf2 = 4857,
   CODE_FOR_floatv8siv8sf2_round = CODE_FOR_nothing,
  CODE_FOR_floatv8siv8sf2_mask = 4858,
   CODE_FOR_floatv8siv8sf2_mask_round = CODE_FOR_nothing,
  CODE_FOR_floatv4siv4sf2 = 4859,
   CODE_FOR_floatv4siv4sf2_round = CODE_FOR_nothing,
  CODE_FOR_floatv4siv4sf2_mask = 4860,
   CODE_FOR_floatv4siv4sf2_mask_round = CODE_FOR_nothing,
  CODE_FOR_floatunsv16siv16sf2_mask = 4863,
  CODE_FOR_floatunsv16siv16sf2_mask_round = 4864,
  CODE_FOR_floatunsv8siv8sf2_mask = 4867,
  CODE_FOR_floatunsv8siv8sf2_mask_round = 4868,
  CODE_FOR_floatunsv4siv4sf2_mask = 4871,
  CODE_FOR_floatunsv4siv4sf2_mask_round = 4872,
  CODE_FOR_avx_fix_notruncv8sfv8si = 4873,
  CODE_FOR_avx_fix_notruncv8sfv8si_mask = 4874,
  CODE_FOR_sse2_fix_notruncv4sfv4si = 4875,
  CODE_FOR_sse2_fix_notruncv4sfv4si_mask = 4876,
  CODE_FOR_avx512f_fix_notruncv16sfv16si = 4877,
  CODE_FOR_avx512f_fix_notruncv16sfv16si_round = 4878,
  CODE_FOR_avx512f_fix_notruncv16sfv16si_mask = 4879,
  CODE_FOR_avx512f_fix_notruncv16sfv16si_mask_round = 4880,
  CODE_FOR_avx512f_fixuns_notruncv16sfv16si_mask = 4883,
  CODE_FOR_avx512f_fixuns_notruncv16sfv16si_mask_round = 4884,
  CODE_FOR_avx512vl_fixuns_notruncv8sfv8si_mask = 4887,
  CODE_FOR_avx512vl_fixuns_notruncv8sfv8si_mask_round = 4888,
  CODE_FOR_avx512vl_fixuns_notruncv4sfv4si_mask = 4891,
  CODE_FOR_avx512vl_fixuns_notruncv4sfv4si_mask_round = 4892,
  CODE_FOR_avx512dq_cvtps2qqv8di_mask = 4895,
  CODE_FOR_avx512dq_cvtps2qqv8di_mask_round = 4896,
  CODE_FOR_avx512dq_cvtps2qqv4di_mask = 4898,
   CODE_FOR_avx512dq_cvtps2qqv4di_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512dq_cvtps2qqv2di_mask = 4900,
  CODE_FOR_avx512dq_cvtps2uqqv8di_mask = 4903,
  CODE_FOR_avx512dq_cvtps2uqqv8di_mask_round = 4904,
  CODE_FOR_avx512dq_cvtps2uqqv4di_mask = 4906,
   CODE_FOR_avx512dq_cvtps2uqqv4di_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512dq_cvtps2uqqv2di_mask = 4908,
  CODE_FOR_unspec_fix_truncv16sfv16si2 = 4909,
  CODE_FOR_unspec_fix_truncv16sfv16si2_round = 4910,
  CODE_FOR_unspec_fix_truncv16sfv16si2_mask = 4911,
  CODE_FOR_unspec_fix_truncv16sfv16si2_mask_round = 4912,
  CODE_FOR_unspec_fixuns_truncv16sfv16si2 = 4913,
  CODE_FOR_unspec_fixuns_truncv16sfv16si2_round = 4914,
  CODE_FOR_unspec_fixuns_truncv16sfv16si2_mask = 4915,
  CODE_FOR_unspec_fixuns_truncv16sfv16si2_mask_round = 4916,
  CODE_FOR_fix_truncv16sfv16si2 = 4917,
  CODE_FOR_fix_truncv16sfv16si2_round = 4918,
  CODE_FOR_fix_truncv16sfv16si2_mask = 4919,
  CODE_FOR_fix_truncv16sfv16si2_mask_round = 4920,
  CODE_FOR_fixuns_truncv16sfv16si2 = 4921,
  CODE_FOR_fixuns_truncv16sfv16si2_round = 4922,
  CODE_FOR_fixuns_truncv16sfv16si2_mask = 4923,
  CODE_FOR_fixuns_truncv16sfv16si2_mask_round = 4924,
  CODE_FOR_unspec_fix_truncv8sfv8si2 = 4925,
  CODE_FOR_unspec_fix_truncv8sfv8si2_mask = 4926,
  CODE_FOR_fix_truncv8sfv8si2 = 4927,
  CODE_FOR_fix_truncv8sfv8si2_mask = 4928,
  CODE_FOR_unspec_fix_truncv4sfv4si2 = 4929,
  CODE_FOR_unspec_fix_truncv4sfv4si2_mask = 4930,
  CODE_FOR_fix_truncv4sfv4si2 = 4931,
  CODE_FOR_fix_truncv4sfv4si2_mask = 4932,
  CODE_FOR_sse2_cvtpi2pd = 4933,
  CODE_FOR_floatunsv2siv2df2 = 4934,
  CODE_FOR_sse2_cvtpd2pi = 4935,
  CODE_FOR_unspec_sse2_cvttpd2pi = 4936,
  CODE_FOR_sse2_cvttpd2pi = 4937,
  CODE_FOR_unspec_fixuns_truncv2dfv2si2 = 4938,
  CODE_FOR_fixuns_truncv2dfv2si2 = 4939,
  CODE_FOR_sse2_cvtsi2sd = 4940,
  CODE_FOR_sse2_cvtsi2sdq = 4941,
  CODE_FOR_sse2_cvtsi2sdq_round = 4942,
  CODE_FOR_avx512f_vcvtss2usi = 4943,
  CODE_FOR_avx512f_vcvtss2usi_round = 4944,
  CODE_FOR_avx512f_vcvtss2usiq = 4945,
  CODE_FOR_avx512f_vcvtss2usiq_round = 4946,
  CODE_FOR_unspec_avx512f_vcvttss2usi = 4947,
  CODE_FOR_unspec_avx512f_vcvttss2usi_round = 4948,
  CODE_FOR_unspec_avx512f_vcvttss2usiq = 4949,
  CODE_FOR_unspec_avx512f_vcvttss2usiq_round = 4950,
  CODE_FOR_avx512f_vcvttss2usi = 4951,
  CODE_FOR_avx512f_vcvttss2usi_round = 4952,
  CODE_FOR_avx512f_vcvttss2usiq = 4953,
  CODE_FOR_avx512f_vcvttss2usiq_round = 4954,
  CODE_FOR_avx512f_vcvtsd2usi = 4955,
  CODE_FOR_avx512f_vcvtsd2usi_round = 4956,
  CODE_FOR_avx512f_vcvtsd2usiq = 4957,
  CODE_FOR_avx512f_vcvtsd2usiq_round = 4958,
  CODE_FOR_unspec_avx512f_vcvttsd2usi = 4959,
  CODE_FOR_unspec_avx512f_vcvttsd2usi_round = 4960,
  CODE_FOR_unspec_avx512f_vcvttsd2usiq = 4961,
  CODE_FOR_unspec_avx512f_vcvttsd2usiq_round = 4962,
  CODE_FOR_avx512f_vcvttsd2usi = 4963,
  CODE_FOR_avx512f_vcvttsd2usi_round = 4964,
  CODE_FOR_avx512f_vcvttsd2usiq = 4965,
  CODE_FOR_avx512f_vcvttsd2usiq_round = 4966,
  CODE_FOR_sse2_cvtsd2si = 4967,
  CODE_FOR_sse2_cvtsd2si_round = 4968,
  CODE_FOR_sse2_cvtsd2siq = 4969,
  CODE_FOR_sse2_cvtsd2siq_round = 4970,
  CODE_FOR_sse2_cvtsd2si_2 = 4971,
  CODE_FOR_sse2_cvtsd2siq_2 = 4972,
  CODE_FOR_unspec_sse2_cvttsd2si = 4973,
  CODE_FOR_unspec_sse2_cvttsd2si_round = 4974,
  CODE_FOR_unspec_sse2_cvttsd2siq = 4975,
  CODE_FOR_unspec_sse2_cvttsd2siq_round = 4976,
  CODE_FOR_sse2_cvttsd2si = 4977,
  CODE_FOR_sse2_cvttsd2si_round = 4978,
  CODE_FOR_sse2_cvttsd2siq = 4979,
  CODE_FOR_sse2_cvttsd2siq_round = 4980,
  CODE_FOR_floatv8siv8df2 = 4981,
  CODE_FOR_floatv8siv8df2_mask = 4982,
  CODE_FOR_floatv4siv4df2 = 4983,
  CODE_FOR_floatv4siv4df2_mask = 4984,
  CODE_FOR_floatv8div8df2 = 4985,
  CODE_FOR_floatv8div8df2_round = 4986,
  CODE_FOR_floatv8div8df2_mask = 4987,
  CODE_FOR_floatv8div8df2_mask_round = 4988,
  CODE_FOR_floatunsv8div8df2 = 4989,
  CODE_FOR_floatunsv8div8df2_round = 4990,
  CODE_FOR_floatunsv8div8df2_mask = 4991,
  CODE_FOR_floatunsv8div8df2_mask_round = 4992,
  CODE_FOR_floatv4div4df2 = 4993,
  CODE_FOR_floatv4div4df2_round = 4994,
  CODE_FOR_floatv4div4df2_mask = 4995,
  CODE_FOR_floatv4div4df2_mask_round = 4996,
  CODE_FOR_floatunsv4div4df2 = 4997,
  CODE_FOR_floatunsv4div4df2_round = 4998,
  CODE_FOR_floatunsv4div4df2_mask = 4999,
  CODE_FOR_floatunsv4div4df2_mask_round = 5000,
  CODE_FOR_floatv2div2df2 = 5001,
  CODE_FOR_floatv2div2df2_round = 5002,
  CODE_FOR_floatv2div2df2_mask = 5003,
  CODE_FOR_floatv2div2df2_mask_round = 5004,
  CODE_FOR_floatunsv2div2df2 = 5005,
  CODE_FOR_floatunsv2div2df2_round = 5006,
  CODE_FOR_floatunsv2div2df2_mask = 5007,
  CODE_FOR_floatunsv2div2df2_mask_round = 5008,
  CODE_FOR_floatv8div8sf2 = 5009,
  CODE_FOR_floatv8div8sf2_round = 5010,
  CODE_FOR_floatv8div8sf2_mask = 5011,
  CODE_FOR_floatv8div8sf2_mask_round = 5012,
  CODE_FOR_floatunsv8div8sf2 = 5013,
  CODE_FOR_floatunsv8div8sf2_round = 5014,
  CODE_FOR_floatunsv8div8sf2_mask = 5015,
  CODE_FOR_floatunsv8div8sf2_mask_round = 5016,
  CODE_FOR_floatv4div4sf2 = 5017,
   CODE_FOR_floatv4div4sf2_round = CODE_FOR_nothing,
  CODE_FOR_floatv4div4sf2_mask = 5018,
   CODE_FOR_floatv4div4sf2_mask_round = CODE_FOR_nothing,
  CODE_FOR_floatunsv4div4sf2 = 5019,
   CODE_FOR_floatunsv4div4sf2_round = CODE_FOR_nothing,
  CODE_FOR_floatunsv4div4sf2_mask = 5020,
   CODE_FOR_floatunsv4div4sf2_mask_round = CODE_FOR_nothing,
  CODE_FOR_floatunsv8siv8df2 = 5027,
  CODE_FOR_floatunsv8siv8df2_mask = 5028,
  CODE_FOR_floatunsv4siv4df2 = 5029,
  CODE_FOR_floatunsv4siv4df2_mask = 5030,
  CODE_FOR_floatunsv2siv2df2_mask = 5032,
  CODE_FOR_avx512f_cvtdq2pd512_2 = 5033,
  CODE_FOR_avx_cvtdq2pd256_2 = 5034,
  CODE_FOR_sse2_cvtdq2pd = 5035,
  CODE_FOR_sse2_cvtdq2pd_mask = 5036,
  CODE_FOR_avx512f_cvtpd2dq512 = 5037,
  CODE_FOR_avx512f_cvtpd2dq512_round = 5038,
  CODE_FOR_avx512f_cvtpd2dq512_mask = 5039,
  CODE_FOR_avx512f_cvtpd2dq512_mask_round = 5040,
  CODE_FOR_avx_cvtpd2dq256 = 5041,
  CODE_FOR_avx_cvtpd2dq256_mask = 5042,
  CODE_FOR_sse2_cvtpd2dq = 5044,
  CODE_FOR_sse2_cvtpd2dq_mask = 5045,
  CODE_FOR_fixuns_notruncv8dfv8si2 = 5047,
  CODE_FOR_fixuns_notruncv8dfv8si2_round = 5048,
  CODE_FOR_fixuns_notruncv8dfv8si2_mask = 5049,
  CODE_FOR_fixuns_notruncv8dfv8si2_mask_round = 5050,
  CODE_FOR_fixuns_notruncv4dfv4si2 = 5051,
  CODE_FOR_fixuns_notruncv4dfv4si2_round = 5052,
  CODE_FOR_fixuns_notruncv4dfv4si2_mask = 5053,
  CODE_FOR_fixuns_notruncv4dfv4si2_mask_round = 5054,
  CODE_FOR_fixuns_notruncv2dfv2si2 = 5055,
  CODE_FOR_fixuns_notruncv2dfv2si2_mask = 5056,
  CODE_FOR_unspec_fix_truncv8dfv8si2 = 5058,
  CODE_FOR_unspec_fix_truncv8dfv8si2_round = 5059,
  CODE_FOR_unspec_fix_truncv8dfv8si2_mask = 5060,
  CODE_FOR_unspec_fix_truncv8dfv8si2_mask_round = 5061,
  CODE_FOR_unspec_fixuns_truncv8dfv8si2 = 5062,
  CODE_FOR_unspec_fixuns_truncv8dfv8si2_round = 5063,
  CODE_FOR_unspec_fixuns_truncv8dfv8si2_mask = 5064,
  CODE_FOR_unspec_fixuns_truncv8dfv8si2_mask_round = 5065,
  CODE_FOR_fix_truncv8dfv8si2 = 5066,
  CODE_FOR_fix_truncv8dfv8si2_round = 5067,
  CODE_FOR_fix_truncv8dfv8si2_mask = 5068,
  CODE_FOR_fix_truncv8dfv8si2_mask_round = 5069,
  CODE_FOR_fixuns_truncv8dfv8si2 = 5070,
  CODE_FOR_fixuns_truncv8dfv8si2_round = 5071,
  CODE_FOR_fixuns_truncv8dfv8si2_mask = 5072,
  CODE_FOR_fixuns_truncv8dfv8si2_mask_round = 5073,
  CODE_FOR_unspec_fixuns_truncv2dfv2si2_mask = 5076,
  CODE_FOR_fixuns_truncv2dfv2si2_mask = 5077,
  CODE_FOR_unspec_fix_truncv4dfv4si2 = 5079,
  CODE_FOR_unspec_fix_truncv4dfv4si2_mask = 5080,
  CODE_FOR_fix_truncv4dfv4si2 = 5081,
  CODE_FOR_fix_truncv4dfv4si2_mask = 5082,
  CODE_FOR_unspec_fixuns_truncv4dfv4si2 = 5083,
  CODE_FOR_unspec_fixuns_truncv4dfv4si2_mask = 5084,
  CODE_FOR_fixuns_truncv4dfv4si2 = 5085,
  CODE_FOR_fixuns_truncv4dfv4si2_mask = 5086,
  CODE_FOR_unspec_fix_truncv8dfv8di2 = 5087,
  CODE_FOR_unspec_fix_truncv8dfv8di2_round = 5088,
  CODE_FOR_unspec_fix_truncv8dfv8di2_mask = 5089,
  CODE_FOR_unspec_fix_truncv8dfv8di2_mask_round = 5090,
  CODE_FOR_unspec_fixuns_truncv8dfv8di2 = 5091,
  CODE_FOR_unspec_fixuns_truncv8dfv8di2_round = 5092,
  CODE_FOR_unspec_fixuns_truncv8dfv8di2_mask = 5093,
  CODE_FOR_unspec_fixuns_truncv8dfv8di2_mask_round = 5094,
  CODE_FOR_unspec_fix_truncv4dfv4di2 = 5095,
   CODE_FOR_unspec_fix_truncv4dfv4di2_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fix_truncv4dfv4di2_mask = 5096,
   CODE_FOR_unspec_fix_truncv4dfv4di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fixuns_truncv4dfv4di2 = 5097,
   CODE_FOR_unspec_fixuns_truncv4dfv4di2_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fixuns_truncv4dfv4di2_mask = 5098,
   CODE_FOR_unspec_fixuns_truncv4dfv4di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fix_truncv2dfv2di2 = 5099,
   CODE_FOR_unspec_fix_truncv2dfv2di2_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fix_truncv2dfv2di2_mask = 5100,
   CODE_FOR_unspec_fix_truncv2dfv2di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fixuns_truncv2dfv2di2 = 5101,
   CODE_FOR_unspec_fixuns_truncv2dfv2di2_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fixuns_truncv2dfv2di2_mask = 5102,
   CODE_FOR_unspec_fixuns_truncv2dfv2di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_fix_truncv8dfv8di2 = 5103,
  CODE_FOR_fix_truncv8dfv8di2_round = 5104,
  CODE_FOR_fix_truncv8dfv8di2_mask = 5105,
  CODE_FOR_fix_truncv8dfv8di2_mask_round = 5106,
  CODE_FOR_fixuns_truncv8dfv8di2 = 5107,
  CODE_FOR_fixuns_truncv8dfv8di2_round = 5108,
  CODE_FOR_fixuns_truncv8dfv8di2_mask = 5109,
  CODE_FOR_fixuns_truncv8dfv8di2_mask_round = 5110,
  CODE_FOR_fix_truncv4dfv4di2 = 5111,
   CODE_FOR_fix_truncv4dfv4di2_round = CODE_FOR_nothing,
  CODE_FOR_fix_truncv4dfv4di2_mask = 5112,
   CODE_FOR_fix_truncv4dfv4di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_fixuns_truncv4dfv4di2 = 5113,
   CODE_FOR_fixuns_truncv4dfv4di2_round = CODE_FOR_nothing,
  CODE_FOR_fixuns_truncv4dfv4di2_mask = 5114,
   CODE_FOR_fixuns_truncv4dfv4di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_fix_truncv2dfv2di2 = 5115,
   CODE_FOR_fix_truncv2dfv2di2_round = CODE_FOR_nothing,
  CODE_FOR_fix_truncv2dfv2di2_mask = 5116,
   CODE_FOR_fix_truncv2dfv2di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_fixuns_truncv2dfv2di2 = 5117,
   CODE_FOR_fixuns_truncv2dfv2di2_round = CODE_FOR_nothing,
  CODE_FOR_fixuns_truncv2dfv2di2_mask = 5118,
   CODE_FOR_fixuns_truncv2dfv2di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_fix_notruncv8dfv8di2 = 5119,
  CODE_FOR_fix_notruncv8dfv8di2_round = 5120,
  CODE_FOR_fix_notruncv8dfv8di2_mask = 5121,
  CODE_FOR_fix_notruncv8dfv8di2_mask_round = 5122,
  CODE_FOR_fix_notruncv4dfv4di2 = 5123,
   CODE_FOR_fix_notruncv4dfv4di2_round = CODE_FOR_nothing,
  CODE_FOR_fix_notruncv4dfv4di2_mask = 5124,
   CODE_FOR_fix_notruncv4dfv4di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_fix_notruncv2dfv2di2 = 5125,
   CODE_FOR_fix_notruncv2dfv2di2_round = CODE_FOR_nothing,
  CODE_FOR_fix_notruncv2dfv2di2_mask = 5126,
   CODE_FOR_fix_notruncv2dfv2di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_fixuns_notruncv8dfv8di2 = 5127,
  CODE_FOR_fixuns_notruncv8dfv8di2_round = 5128,
  CODE_FOR_fixuns_notruncv8dfv8di2_mask = 5129,
  CODE_FOR_fixuns_notruncv8dfv8di2_mask_round = 5130,
  CODE_FOR_fixuns_notruncv4dfv4di2 = 5131,
   CODE_FOR_fixuns_notruncv4dfv4di2_round = CODE_FOR_nothing,
  CODE_FOR_fixuns_notruncv4dfv4di2_mask = 5132,
   CODE_FOR_fixuns_notruncv4dfv4di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_fixuns_notruncv2dfv2di2 = 5133,
   CODE_FOR_fixuns_notruncv2dfv2di2_round = CODE_FOR_nothing,
  CODE_FOR_fixuns_notruncv2dfv2di2_mask = 5134,
   CODE_FOR_fixuns_notruncv2dfv2di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fix_truncv8sfv8di2 = 5135,
  CODE_FOR_unspec_fix_truncv8sfv8di2_round = 5136,
  CODE_FOR_unspec_fix_truncv8sfv8di2_mask = 5137,
  CODE_FOR_unspec_fix_truncv8sfv8di2_mask_round = 5138,
  CODE_FOR_unspec_fixuns_truncv8sfv8di2 = 5139,
  CODE_FOR_unspec_fixuns_truncv8sfv8di2_round = 5140,
  CODE_FOR_unspec_fixuns_truncv8sfv8di2_mask = 5141,
  CODE_FOR_unspec_fixuns_truncv8sfv8di2_mask_round = 5142,
  CODE_FOR_unspec_fix_truncv4sfv4di2 = 5143,
   CODE_FOR_unspec_fix_truncv4sfv4di2_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fix_truncv4sfv4di2_mask = 5144,
   CODE_FOR_unspec_fix_truncv4sfv4di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fixuns_truncv4sfv4di2 = 5145,
   CODE_FOR_unspec_fixuns_truncv4sfv4di2_round = CODE_FOR_nothing,
  CODE_FOR_unspec_fixuns_truncv4sfv4di2_mask = 5146,
   CODE_FOR_unspec_fixuns_truncv4sfv4di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_fix_truncv8sfv8di2 = 5147,
  CODE_FOR_fix_truncv8sfv8di2_round = 5148,
  CODE_FOR_fix_truncv8sfv8di2_mask = 5149,
  CODE_FOR_fix_truncv8sfv8di2_mask_round = 5150,
  CODE_FOR_fixuns_truncv8sfv8di2 = 5151,
  CODE_FOR_fixuns_truncv8sfv8di2_round = 5152,
  CODE_FOR_fixuns_truncv8sfv8di2_mask = 5153,
  CODE_FOR_fixuns_truncv8sfv8di2_mask_round = 5154,
  CODE_FOR_fix_truncv4sfv4di2 = 5155,
   CODE_FOR_fix_truncv4sfv4di2_round = CODE_FOR_nothing,
  CODE_FOR_fix_truncv4sfv4di2_mask = 5156,
   CODE_FOR_fix_truncv4sfv4di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_fixuns_truncv4sfv4di2 = 5157,
   CODE_FOR_fixuns_truncv4sfv4di2_round = CODE_FOR_nothing,
  CODE_FOR_fixuns_truncv4sfv4di2_mask = 5158,
   CODE_FOR_fixuns_truncv4sfv4di2_mask_round = CODE_FOR_nothing,
  CODE_FOR_unspec_avx512dq_fix_truncv2sfv2di2 = 5159,
  CODE_FOR_unspec_avx512dq_fix_truncv2sfv2di2_mask = 5160,
  CODE_FOR_unspec_avx512dq_fixuns_truncv2sfv2di2 = 5161,
  CODE_FOR_unspec_avx512dq_fixuns_truncv2sfv2di2_mask = 5162,
  CODE_FOR_avx512dq_fix_truncv2sfv2di2 = 5163,
  CODE_FOR_avx512dq_fix_truncv2sfv2di2_mask = 5164,
  CODE_FOR_avx512dq_fixuns_truncv2sfv2di2 = 5165,
  CODE_FOR_avx512dq_fixuns_truncv2sfv2di2_mask = 5166,
  CODE_FOR_unspec_fixuns_truncv8sfv8si2_mask = 5168,
  CODE_FOR_unspec_fixuns_truncv4sfv4si2_mask = 5170,
  CODE_FOR_fixuns_truncv8sfv8si2_mask = 5172,
  CODE_FOR_fixuns_truncv4sfv4si2_mask = 5174,
  CODE_FOR_unspec_sse2_cvttpd2dq = 5175,
  CODE_FOR_unspec_sse2_cvttpd2dq_mask = 5176,
  CODE_FOR_sse2_cvttpd2dq = 5177,
  CODE_FOR_sse2_cvttpd2dq_mask = 5178,
  CODE_FOR_sse2_cvtsd2ss = 5180,
  CODE_FOR_sse2_cvtsd2ss_round = 5181,
  CODE_FOR_sse2_cvtsd2ss_mask = 5182,
  CODE_FOR_sse2_cvtsd2ss_mask_round = 5183,
  CODE_FOR_sse2_cvtss2sd = 5185,
  CODE_FOR_sse2_cvtss2sd_round = 5186,
  CODE_FOR_sse2_cvtss2sd_mask = 5187,
  CODE_FOR_sse2_cvtss2sd_mask_round = 5188,
  CODE_FOR_avx512f_cvtpd2ps512_mask = 5192,
  CODE_FOR_avx512f_cvtpd2ps512_mask_round = 5193,
  CODE_FOR_avx_cvtpd2ps256 = 5194,
  CODE_FOR_avx_cvtpd2ps256_mask = 5195,
  CODE_FOR_truncv2dfv2sf2 = 5197,
  CODE_FOR_avx512f_cvtps2pd512 = 5200,
  CODE_FOR_avx512f_cvtps2pd512_round = 5201,
  CODE_FOR_avx512f_cvtps2pd512_mask = 5202,
  CODE_FOR_avx512f_cvtps2pd512_mask_round = 5203,
  CODE_FOR_avx_cvtps2pd256 = 5204,
   CODE_FOR_avx_cvtps2pd256_round = CODE_FOR_nothing,
  CODE_FOR_avx_cvtps2pd256_mask = 5205,
   CODE_FOR_avx_cvtps2pd256_mask_round = CODE_FOR_nothing,
  CODE_FOR_vec_unpacks_lo_v16sf = 5207,
  CODE_FOR_avx512bw_cvtb2maskv64qi = 5208,
  CODE_FOR_avx512vl_cvtb2maskv16qi = 5209,
  CODE_FOR_avx512vl_cvtb2maskv32qi = 5210,
  CODE_FOR_avx512bw_cvtw2maskv32hi = 5211,
  CODE_FOR_avx512vl_cvtw2maskv16hi = 5212,
  CODE_FOR_avx512vl_cvtw2maskv8hi = 5213,
  CODE_FOR_avx512f_cvtd2maskv16si = 5214,
  CODE_FOR_avx512vl_cvtd2maskv8si = 5215,
  CODE_FOR_avx512vl_cvtd2maskv4si = 5216,
  CODE_FOR_avx512f_cvtq2maskv8di = 5217,
  CODE_FOR_avx512vl_cvtq2maskv4di = 5218,
  CODE_FOR_avx512vl_cvtq2maskv2di = 5219,
  CODE_FOR_sse2_cvtps2pd = 5250,
  CODE_FOR_sse2_cvtps2pd_mask = 5251,
  CODE_FOR_sse2_cvtps2pd_1 = 5252,
  CODE_FOR_sse2_cvtps2pd_mask_1 = 5253,
  CODE_FOR_sse_movhlps = 5254,
  CODE_FOR_sse_movlhps = 5255,
  CODE_FOR_sse_movlhps_v8hi = 5256,
  CODE_FOR_sse_movlhps_v8hf = 5257,
  CODE_FOR_sse_movlhps_v8bf = 5258,
  CODE_FOR_avx512f_unpckhps512_mask = 5260,
  CODE_FOR_avx_unpckhps256 = 5261,
  CODE_FOR_avx_unpckhps256_mask = 5262,
  CODE_FOR_vec_interleave_highv4sf = 5263,
  CODE_FOR_vec_interleave_highv4sf_mask = 5264,
  CODE_FOR_avx512f_unpcklps512_mask = 5266,
  CODE_FOR_avx_unpcklps256 = 5267,
  CODE_FOR_avx_unpcklps256_mask = 5268,
  CODE_FOR_unpcklps128_mask = 5269,
  CODE_FOR_vec_interleave_lowv4sf = 5270,
  CODE_FOR_avx_movshdup256 = 5271,
  CODE_FOR_avx_movshdup256_mask = 5272,
  CODE_FOR_sse3_movshdup = 5273,
  CODE_FOR_sse3_movshdup_mask = 5274,
  CODE_FOR_avx512f_movshdup512_mask = 5276,
  CODE_FOR_avx_movsldup256 = 5277,
  CODE_FOR_avx_movsldup256_mask = 5278,
  CODE_FOR_sse3_movsldup = 5279,
  CODE_FOR_sse3_movsldup_mask = 5280,
  CODE_FOR_avx512f_movsldup512_mask = 5282,
  CODE_FOR_avx_shufps256_1 = 5283,
  CODE_FOR_avx_shufps256_1_mask = 5284,
  CODE_FOR_sse_shufps_v4sf_mask = 5285,
  CODE_FOR_sse_shufps_v4si = 5286,
  CODE_FOR_sse_shufps_v4sf = 5287,
  CODE_FOR_sse_storehps = 5288,
  CODE_FOR_sse_loadhps = 5289,
  CODE_FOR_sse_storelps = 5290,
  CODE_FOR_sse_loadlps = 5291,
  CODE_FOR_sse_movss_v4si = 5292,
  CODE_FOR_sse_movss_v4sf = 5293,
  CODE_FOR_avx2_vec_dupv8sf = 5294,
  CODE_FOR_avx2_vec_dupv4sf = 5295,
  CODE_FOR_avx2_vec_dupv8sf_1 = 5296,
  CODE_FOR_avx512f_vec_dupv16sf_1 = 5297,
  CODE_FOR_avx512f_vec_dupv8df_1 = 5298,
  CODE_FOR_vec_setv4si_0 = 5310,
  CODE_FOR_vec_setv4sf_0 = 5311,
  CODE_FOR_vec_setv8hi_0 = 5312,
  CODE_FOR_vec_setv8hf_0 = 5313,
  CODE_FOR_vec_setv8bf_0 = 5314,
  CODE_FOR_vec_setv16hi_0 = 5318,
  CODE_FOR_vec_setv32hi_0 = 5319,
  CODE_FOR_vec_setv16hf_0 = 5320,
  CODE_FOR_vec_setv32hf_0 = 5321,
  CODE_FOR_vec_setv16bf_0 = 5322,
  CODE_FOR_vec_setv32bf_0 = 5323,
  CODE_FOR_vec_setv8si_0 = 5335,
  CODE_FOR_vec_setv8sf_0 = 5336,
  CODE_FOR_vec_setv16si_0 = 5337,
  CODE_FOR_vec_setv16sf_0 = 5338,
  CODE_FOR_sse4_1_insertps_v4si = 5343,
  CODE_FOR_sse4_1_insertps_v4sf = 5344,
  CODE_FOR_vec_setv2df_0 = 5345,
  CODE_FOR_avx512dq_vextractf64x2_1_mask = 5349,
  CODE_FOR_avx512dq_vextracti64x2_1_mask = 5350,
  CODE_FOR_avx512f_vextractf32x4_1_mask = 5353,
  CODE_FOR_avx512f_vextracti32x4_1_mask = 5354,
  CODE_FOR_vec_extract_lo_v8df_mask = 5357,
  CODE_FOR_vec_extract_lo_v8di_mask = 5358,
  CODE_FOR_vec_extract_lo_v8df = 5359,
  CODE_FOR_vec_extract_lo_v8di = 5360,
  CODE_FOR_vec_extract_hi_v8df_mask = 5361,
  CODE_FOR_vec_extract_hi_v8di_mask = 5362,
  CODE_FOR_vec_extract_hi_v8df = 5363,
  CODE_FOR_vec_extract_hi_v8di = 5364,
  CODE_FOR_vec_extract_hi_v16sf_mask = 5365,
  CODE_FOR_vec_extract_hi_v16si_mask = 5366,
  CODE_FOR_vec_extract_hi_v16sf = 5367,
  CODE_FOR_vec_extract_hi_v16si = 5368,
  CODE_FOR_vec_extract_lo_v16sf_mask = 5369,
  CODE_FOR_vec_extract_lo_v16si_mask = 5370,
  CODE_FOR_vec_extract_lo_v16sf = 5371,
  CODE_FOR_vec_extract_lo_v16si = 5372,
  CODE_FOR_vec_extract_lo_v4di_mask = 5373,
  CODE_FOR_vec_extract_lo_v4df_mask = 5374,
  CODE_FOR_vec_extract_lo_v4di = 5375,
  CODE_FOR_vec_extract_lo_v4df = 5376,
  CODE_FOR_vec_extract_hi_v4di_mask = 5377,
  CODE_FOR_vec_extract_hi_v4df_mask = 5378,
  CODE_FOR_vec_extract_hi_v4di = 5379,
  CODE_FOR_vec_extract_hi_v4df = 5380,
  CODE_FOR_vec_extract_lo_v8si_mask = 5381,
  CODE_FOR_vec_extract_lo_v8sf_mask = 5382,
  CODE_FOR_vec_extract_lo_v8si = 5383,
  CODE_FOR_vec_extract_lo_v8sf = 5384,
  CODE_FOR_vec_extract_hi_v8si_mask = 5385,
  CODE_FOR_vec_extract_hi_v8sf_mask = 5386,
  CODE_FOR_vec_extract_hi_v8si = 5387,
  CODE_FOR_vec_extract_hi_v8sf = 5388,
  CODE_FOR_vec_extract_lo_v32hi = 5389,
  CODE_FOR_vec_extract_lo_v32hf = 5390,
  CODE_FOR_vec_extract_lo_v32bf = 5391,
  CODE_FOR_vec_extract_hi_v32hi = 5392,
  CODE_FOR_vec_extract_hi_v32hf = 5393,
  CODE_FOR_vec_extract_hi_v32bf = 5394,
  CODE_FOR_vec_extract_lo_v16hi = 5395,
  CODE_FOR_vec_extract_lo_v16hf = 5396,
  CODE_FOR_vec_extract_lo_v16bf = 5397,
  CODE_FOR_vec_extract_hi_v16hi = 5398,
  CODE_FOR_vec_extract_hi_v16hf = 5399,
  CODE_FOR_vec_extract_hi_v16bf = 5400,
  CODE_FOR_vec_extract_lo_v64qi = 5401,
  CODE_FOR_vec_extract_hi_v64qi = 5402,
  CODE_FOR_vec_extract_lo_v32qi = 5403,
  CODE_FOR_vec_extract_hi_v32qi = 5404,
  CODE_FOR_avx512f_unpckhpd512_mask = 5414,
  CODE_FOR_avx_unpckhpd256 = 5415,
  CODE_FOR_avx_unpckhpd256_mask = 5416,
  CODE_FOR_avx512vl_unpckhpd128_mask = 5417,
  CODE_FOR_avx512f_movddup512 = 5419,
  CODE_FOR_avx512f_movddup512_mask = 5420,
  CODE_FOR_avx512f_unpcklpd512 = 5421,
  CODE_FOR_avx512f_unpcklpd512_mask = 5422,
  CODE_FOR_avx_movddup256 = 5423,
  CODE_FOR_avx_movddup256_mask = 5424,
  CODE_FOR_avx_unpcklpd256 = 5425,
  CODE_FOR_avx_unpcklpd256_mask = 5426,
  CODE_FOR_avx512vl_unpcklpd128_mask = 5427,
  CODE_FOR_avx512f_vmscalefv8hf = 5429,
  CODE_FOR_avx512f_vmscalefv8hf_round = 5430,
  CODE_FOR_avx512f_vmscalefv8hf_mask = 5431,
  CODE_FOR_avx512f_vmscalefv8hf_mask_round = 5432,
  CODE_FOR_avx512f_vmscalefv4sf = 5433,
  CODE_FOR_avx512f_vmscalefv4sf_round = 5434,
  CODE_FOR_avx512f_vmscalefv4sf_mask = 5435,
  CODE_FOR_avx512f_vmscalefv4sf_mask_round = 5436,
  CODE_FOR_avx512f_vmscalefv2df = 5437,
  CODE_FOR_avx512f_vmscalefv2df_round = 5438,
  CODE_FOR_avx512f_vmscalefv2df_mask = 5439,
  CODE_FOR_avx512f_vmscalefv2df_mask_round = 5440,
  CODE_FOR_avx512bw_scalefv32hf = 5441,
  CODE_FOR_avx512bw_scalefv32hf_round = 5442,
  CODE_FOR_avx512bw_scalefv32hf_mask = 5443,
  CODE_FOR_avx512bw_scalefv32hf_mask_round = 5444,
  CODE_FOR_avx512vl_scalefv16hf = 5445,
  CODE_FOR_avx512vl_scalefv16hf_round = 5446,
  CODE_FOR_avx512vl_scalefv16hf_mask = 5447,
  CODE_FOR_avx512vl_scalefv16hf_mask_round = 5448,
  CODE_FOR_avx512fp16_scalefv8hf = 5449,
  CODE_FOR_avx512fp16_scalefv8hf_round = 5450,
  CODE_FOR_avx512fp16_scalefv8hf_mask = 5451,
  CODE_FOR_avx512fp16_scalefv8hf_mask_round = 5452,
  CODE_FOR_avx512f_scalefv16sf = 5453,
  CODE_FOR_avx512f_scalefv16sf_round = 5454,
  CODE_FOR_avx512f_scalefv16sf_mask = 5455,
  CODE_FOR_avx512f_scalefv16sf_mask_round = 5456,
  CODE_FOR_avx512vl_scalefv8sf = 5457,
  CODE_FOR_avx512vl_scalefv8sf_round = 5458,
  CODE_FOR_avx512vl_scalefv8sf_mask = 5459,
  CODE_FOR_avx512vl_scalefv8sf_mask_round = 5460,
  CODE_FOR_avx512vl_scalefv4sf = 5461,
  CODE_FOR_avx512vl_scalefv4sf_round = 5462,
  CODE_FOR_avx512vl_scalefv4sf_mask = 5463,
  CODE_FOR_avx512vl_scalefv4sf_mask_round = 5464,
  CODE_FOR_avx512f_scalefv8df = 5465,
  CODE_FOR_avx512f_scalefv8df_round = 5466,
  CODE_FOR_avx512f_scalefv8df_mask = 5467,
  CODE_FOR_avx512f_scalefv8df_mask_round = 5468,
  CODE_FOR_avx512vl_scalefv4df = 5469,
  CODE_FOR_avx512vl_scalefv4df_round = 5470,
  CODE_FOR_avx512vl_scalefv4df_mask = 5471,
  CODE_FOR_avx512vl_scalefv4df_mask_round = 5472,
  CODE_FOR_avx512vl_scalefv2df = 5473,
  CODE_FOR_avx512vl_scalefv2df_round = 5474,
  CODE_FOR_avx512vl_scalefv2df_mask = 5475,
  CODE_FOR_avx512vl_scalefv2df_mask_round = 5476,
  CODE_FOR_avx512f_vternlogv16si = 5477,
  CODE_FOR_avx512f_vternlogv16si_maskz_1 = 5478,
  CODE_FOR_avx512vl_vternlogv8si = 5479,
  CODE_FOR_avx512vl_vternlogv8si_maskz_1 = 5480,
  CODE_FOR_avx512vl_vternlogv4si = 5481,
  CODE_FOR_avx512vl_vternlogv4si_maskz_1 = 5482,
  CODE_FOR_avx512f_vternlogv8di = 5483,
  CODE_FOR_avx512f_vternlogv8di_maskz_1 = 5484,
  CODE_FOR_avx512vl_vternlogv4di = 5485,
  CODE_FOR_avx512vl_vternlogv4di_maskz_1 = 5486,
  CODE_FOR_avx512vl_vternlogv2di = 5487,
  CODE_FOR_avx512vl_vternlogv2di_maskz_1 = 5488,
  CODE_FOR_avx512bw_getexpv32hf = 7055,
  CODE_FOR_avx512bw_getexpv32hf_round = 7056,
  CODE_FOR_avx512bw_getexpv32hf_mask = 7057,
  CODE_FOR_avx512bw_getexpv32hf_mask_round = 7058,
  CODE_FOR_avx512vl_getexpv16hf = 7059,
  CODE_FOR_avx512vl_getexpv16hf_round = 7060,
  CODE_FOR_avx512vl_getexpv16hf_mask = 7061,
  CODE_FOR_avx512vl_getexpv16hf_mask_round = 7062,
  CODE_FOR_avx512fp16_getexpv8hf = 7063,
  CODE_FOR_avx512fp16_getexpv8hf_round = 7064,
  CODE_FOR_avx512fp16_getexpv8hf_mask = 7065,
  CODE_FOR_avx512fp16_getexpv8hf_mask_round = 7066,
  CODE_FOR_avx512f_getexpv16sf = 7067,
  CODE_FOR_avx512f_getexpv16sf_round = 7068,
  CODE_FOR_avx512f_getexpv16sf_mask = 7069,
  CODE_FOR_avx512f_getexpv16sf_mask_round = 7070,
  CODE_FOR_avx512vl_getexpv8sf = 7071,
  CODE_FOR_avx512vl_getexpv8sf_round = 7072,
  CODE_FOR_avx512vl_getexpv8sf_mask = 7073,
  CODE_FOR_avx512vl_getexpv8sf_mask_round = 7074,
  CODE_FOR_avx512vl_getexpv4sf = 7075,
  CODE_FOR_avx512vl_getexpv4sf_round = 7076,
  CODE_FOR_avx512vl_getexpv4sf_mask = 7077,
  CODE_FOR_avx512vl_getexpv4sf_mask_round = 7078,
  CODE_FOR_avx512f_getexpv8df = 7079,
  CODE_FOR_avx512f_getexpv8df_round = 7080,
  CODE_FOR_avx512f_getexpv8df_mask = 7081,
  CODE_FOR_avx512f_getexpv8df_mask_round = 7082,
  CODE_FOR_avx512vl_getexpv4df = 7083,
  CODE_FOR_avx512vl_getexpv4df_round = 7084,
  CODE_FOR_avx512vl_getexpv4df_mask = 7085,
  CODE_FOR_avx512vl_getexpv4df_mask_round = 7086,
  CODE_FOR_avx512vl_getexpv2df = 7087,
  CODE_FOR_avx512vl_getexpv2df_round = 7088,
  CODE_FOR_avx512vl_getexpv2df_mask = 7089,
  CODE_FOR_avx512vl_getexpv2df_mask_round = 7090,
  CODE_FOR_avx512f_sgetexpv8hf = 7091,
  CODE_FOR_avx512f_sgetexpv8hf_mask = 7092,
  CODE_FOR_avx512f_sgetexpv8hf_round = 7093,
  CODE_FOR_avx512f_sgetexpv8hf_mask_round = 7094,
  CODE_FOR_avx512f_sgetexpv4sf = 7095,
  CODE_FOR_avx512f_sgetexpv4sf_mask = 7096,
  CODE_FOR_avx512f_sgetexpv4sf_round = 7097,
  CODE_FOR_avx512f_sgetexpv4sf_mask_round = 7098,
  CODE_FOR_avx512f_sgetexpv2df = 7099,
  CODE_FOR_avx512f_sgetexpv2df_mask = 7100,
  CODE_FOR_avx512f_sgetexpv2df_round = 7101,
  CODE_FOR_avx512f_sgetexpv2df_mask_round = 7102,
  CODE_FOR_avx512f_alignv16si_mask = 7104,
  CODE_FOR_avx512vl_alignv8si_mask = 7106,
  CODE_FOR_avx512vl_alignv4si_mask = 7108,
  CODE_FOR_avx512f_alignv8di_mask = 7110,
  CODE_FOR_avx512vl_alignv4di_mask = 7112,
  CODE_FOR_avx512vl_alignv2di_mask = 7114,
  CODE_FOR_avx512f_fixupimmv16sf = 7123,
  CODE_FOR_avx512f_fixupimmv16sf_round = 7124,
  CODE_FOR_avx512f_fixupimmv16sf_maskz_1 = 7125,
  CODE_FOR_avx512f_fixupimmv16sf_maskz_1_round = 7126,
  CODE_FOR_avx512vl_fixupimmv8sf = 7127,
  CODE_FOR_avx512vl_fixupimmv8sf_round = 7128,
  CODE_FOR_avx512vl_fixupimmv8sf_maskz_1 = 7129,
  CODE_FOR_avx512vl_fixupimmv8sf_maskz_1_round = 7130,
  CODE_FOR_avx512vl_fixupimmv4sf = 7131,
  CODE_FOR_avx512vl_fixupimmv4sf_round = 7132,
  CODE_FOR_avx512vl_fixupimmv4sf_maskz_1 = 7133,
  CODE_FOR_avx512vl_fixupimmv4sf_maskz_1_round = 7134,
  CODE_FOR_avx512f_fixupimmv8df = 7135,
  CODE_FOR_avx512f_fixupimmv8df_round = 7136,
  CODE_FOR_avx512f_fixupimmv8df_maskz_1 = 7137,
  CODE_FOR_avx512f_fixupimmv8df_maskz_1_round = 7138,
  CODE_FOR_avx512vl_fixupimmv4df = 7139,
  CODE_FOR_avx512vl_fixupimmv4df_round = 7140,
  CODE_FOR_avx512vl_fixupimmv4df_maskz_1 = 7141,
  CODE_FOR_avx512vl_fixupimmv4df_maskz_1_round = 7142,
  CODE_FOR_avx512vl_fixupimmv2df = 7143,
  CODE_FOR_avx512vl_fixupimmv2df_round = 7144,
  CODE_FOR_avx512vl_fixupimmv2df_maskz_1 = 7145,
  CODE_FOR_avx512vl_fixupimmv2df_maskz_1_round = 7146,
  CODE_FOR_avx512f_fixupimmv16sf_mask = 7147,
  CODE_FOR_avx512f_fixupimmv16sf_mask_round = 7148,
  CODE_FOR_avx512vl_fixupimmv8sf_mask = 7149,
  CODE_FOR_avx512vl_fixupimmv8sf_mask_round = 7150,
  CODE_FOR_avx512vl_fixupimmv4sf_mask = 7151,
  CODE_FOR_avx512vl_fixupimmv4sf_mask_round = 7152,
  CODE_FOR_avx512f_fixupimmv8df_mask = 7153,
  CODE_FOR_avx512f_fixupimmv8df_mask_round = 7154,
  CODE_FOR_avx512vl_fixupimmv4df_mask = 7155,
  CODE_FOR_avx512vl_fixupimmv4df_mask_round = 7156,
  CODE_FOR_avx512vl_fixupimmv2df_mask = 7157,
  CODE_FOR_avx512vl_fixupimmv2df_mask_round = 7158,
  CODE_FOR_avx512f_sfixupimmv4sf = 7159,
  CODE_FOR_avx512f_sfixupimmv4sf_round = 7160,
  CODE_FOR_avx512f_sfixupimmv4sf_maskz_1 = 7161,
  CODE_FOR_avx512f_sfixupimmv4sf_maskz_1_round = 7162,
  CODE_FOR_avx512f_sfixupimmv2df = 7163,
  CODE_FOR_avx512f_sfixupimmv2df_round = 7164,
  CODE_FOR_avx512f_sfixupimmv2df_maskz_1 = 7165,
  CODE_FOR_avx512f_sfixupimmv2df_maskz_1_round = 7166,
  CODE_FOR_avx512f_sfixupimmv4sf_mask = 7167,
  CODE_FOR_avx512f_sfixupimmv4sf_mask_round = 7168,
  CODE_FOR_avx512f_sfixupimmv2df_mask = 7169,
  CODE_FOR_avx512f_sfixupimmv2df_mask_round = 7170,
  CODE_FOR_avx512bw_rndscalev32hf = 7171,
  CODE_FOR_avx512bw_rndscalev32hf_round = 7172,
  CODE_FOR_avx512bw_rndscalev32hf_mask = 7173,
  CODE_FOR_avx512bw_rndscalev32hf_mask_round = 7174,
  CODE_FOR_avx512vl_rndscalev16hf = 7175,
  CODE_FOR_avx512vl_rndscalev16hf_round = 7176,
  CODE_FOR_avx512vl_rndscalev16hf_mask = 7177,
  CODE_FOR_avx512vl_rndscalev16hf_mask_round = 7178,
  CODE_FOR_avx512fp16_rndscalev8hf = 7179,
  CODE_FOR_avx512fp16_rndscalev8hf_round = 7180,
  CODE_FOR_avx512fp16_rndscalev8hf_mask = 7181,
  CODE_FOR_avx512fp16_rndscalev8hf_mask_round = 7182,
  CODE_FOR_avx512f_rndscalev16sf = 7183,
  CODE_FOR_avx512f_rndscalev16sf_round = 7184,
  CODE_FOR_avx512f_rndscalev16sf_mask = 7185,
  CODE_FOR_avx512f_rndscalev16sf_mask_round = 7186,
  CODE_FOR_avx512vl_rndscalev8sf = 7187,
  CODE_FOR_avx512vl_rndscalev8sf_round = 7188,
  CODE_FOR_avx512vl_rndscalev8sf_mask = 7189,
  CODE_FOR_avx512vl_rndscalev8sf_mask_round = 7190,
  CODE_FOR_avx512vl_rndscalev4sf = 7191,
  CODE_FOR_avx512vl_rndscalev4sf_round = 7192,
  CODE_FOR_avx512vl_rndscalev4sf_mask = 7193,
  CODE_FOR_avx512vl_rndscalev4sf_mask_round = 7194,
  CODE_FOR_avx512f_rndscalev8df = 7195,
  CODE_FOR_avx512f_rndscalev8df_round = 7196,
  CODE_FOR_avx512f_rndscalev8df_mask = 7197,
  CODE_FOR_avx512f_rndscalev8df_mask_round = 7198,
  CODE_FOR_avx512vl_rndscalev4df = 7199,
  CODE_FOR_avx512vl_rndscalev4df_round = 7200,
  CODE_FOR_avx512vl_rndscalev4df_mask = 7201,
  CODE_FOR_avx512vl_rndscalev4df_mask_round = 7202,
  CODE_FOR_avx512vl_rndscalev2df = 7203,
  CODE_FOR_avx512vl_rndscalev2df_round = 7204,
  CODE_FOR_avx512vl_rndscalev2df_mask = 7205,
  CODE_FOR_avx512vl_rndscalev2df_mask_round = 7206,
  CODE_FOR_avx512f_rndscalev8hf = 7207,
  CODE_FOR_avx512f_rndscalev8hf_mask = 7208,
  CODE_FOR_avx512f_rndscalev8hf_round = 7209,
  CODE_FOR_avx512f_rndscalev8hf_mask_round = 7210,
  CODE_FOR_avx512f_rndscalev4sf = 7211,
  CODE_FOR_avx512f_rndscalev4sf_mask = 7212,
  CODE_FOR_avx512f_rndscalev4sf_round = 7213,
  CODE_FOR_avx512f_rndscalev4sf_mask_round = 7214,
  CODE_FOR_avx512f_rndscalev2df = 7215,
  CODE_FOR_avx512f_rndscalev2df_mask = 7216,
  CODE_FOR_avx512f_rndscalev2df_round = 7217,
  CODE_FOR_avx512f_rndscalev2df_mask_round = 7218,
  CODE_FOR_avx512f_shufps512_1 = 7225,
  CODE_FOR_avx512f_shufps512_1_mask = 7226,
  CODE_FOR_avx512f_shufpd512_1 = 7227,
  CODE_FOR_avx512f_shufpd512_1_mask = 7228,
  CODE_FOR_avx_shufpd256_1 = 7229,
  CODE_FOR_avx_shufpd256_1_mask = 7230,
  CODE_FOR_sse2_shufpd_v2df_mask = 7231,
  CODE_FOR_avx2_interleave_highv4di = 7232,
  CODE_FOR_avx2_interleave_highv4di_mask = 7233,
  CODE_FOR_avx512f_interleave_highv8di_mask = 7235,
  CODE_FOR_vec_interleave_highv2di = 7236,
  CODE_FOR_vec_interleave_highv2di_mask = 7237,
  CODE_FOR_avx2_interleave_lowv4di = 7238,
  CODE_FOR_avx2_interleave_lowv4di_mask = 7239,
  CODE_FOR_avx512f_interleave_lowv8di_mask = 7241,
  CODE_FOR_vec_interleave_lowv2di = 7242,
  CODE_FOR_vec_interleave_lowv2di_mask = 7243,
  CODE_FOR_sse2_shufpd_v2di = 7244,
  CODE_FOR_sse2_shufpd_v2df = 7245,
  CODE_FOR_sse2_storehpd = 7246,
  CODE_FOR_sse2_storelpd = 7248,
  CODE_FOR_sse2_loadhpd = 7250,
  CODE_FOR_sse2_loadlpd = 7251,
  CODE_FOR_sse2_movsd_v2di = 7252,
  CODE_FOR_sse2_movsd_v2df = 7253,
  CODE_FOR_vec_dupv2df = 7254,
  CODE_FOR_vec_dupv2df_mask = 7255,
  CODE_FOR_vec_concatv2df = 7256,
  CODE_FOR_vec_setv8df_0 = 7257,
  CODE_FOR_vec_setv4df_0 = 7258,
  CODE_FOR_avx512f_ss_truncatev16siv16qi2_mask = 7276,
  CODE_FOR_avx512f_truncatev16siv16qi2_mask = 7277,
  CODE_FOR_avx512f_us_truncatev16siv16qi2_mask = 7278,
  CODE_FOR_avx512f_ss_truncatev16siv16hi2_mask = 7279,
  CODE_FOR_avx512f_truncatev16siv16hi2_mask = 7280,
  CODE_FOR_avx512f_us_truncatev16siv16hi2_mask = 7281,
  CODE_FOR_avx512f_ss_truncatev8div8si2_mask = 7282,
  CODE_FOR_avx512f_truncatev8div8si2_mask = 7283,
  CODE_FOR_avx512f_us_truncatev8div8si2_mask = 7284,
  CODE_FOR_avx512f_ss_truncatev8div8hi2_mask = 7285,
  CODE_FOR_avx512f_truncatev8div8hi2_mask = 7286,
  CODE_FOR_avx512f_us_truncatev8div8hi2_mask = 7287,
  CODE_FOR_avx512bw_ss_truncatev32hiv32qi2 = 7288,
  CODE_FOR_avx512bw_truncatev32hiv32qi2 = 7289,
  CODE_FOR_avx512bw_us_truncatev32hiv32qi2 = 7290,
  CODE_FOR_avx512bw_ss_truncatev32hiv32qi2_mask = 7292,
  CODE_FOR_avx512bw_truncatev32hiv32qi2_mask = 7293,
  CODE_FOR_avx512bw_us_truncatev32hiv32qi2_mask = 7294,
  CODE_FOR_avx512vl_ss_truncatev4div4si2_mask = 7306,
  CODE_FOR_avx512vl_truncatev4div4si2_mask = 7307,
  CODE_FOR_avx512vl_us_truncatev4div4si2_mask = 7308,
  CODE_FOR_avx512vl_ss_truncatev8siv8hi2_mask = 7309,
  CODE_FOR_avx512vl_truncatev8siv8hi2_mask = 7310,
  CODE_FOR_avx512vl_us_truncatev8siv8hi2_mask = 7311,
  CODE_FOR_avx512vl_ss_truncatev16hiv16qi2_mask = 7312,
  CODE_FOR_avx512vl_truncatev16hiv16qi2_mask = 7313,
  CODE_FOR_avx512vl_us_truncatev16hiv16qi2_mask = 7314,
  CODE_FOR_avx512vl_ss_truncatev4div4qi2 = 7315,
  CODE_FOR_avx512vl_truncatev4div4qi2 = 7316,
  CODE_FOR_avx512vl_us_truncatev4div4qi2 = 7317,
  CODE_FOR_avx512vl_ss_truncatev2div2qi2 = 7318,
  CODE_FOR_avx512vl_truncatev2div2qi2 = 7319,
  CODE_FOR_avx512vl_us_truncatev2div2qi2 = 7320,
  CODE_FOR_avx512vl_ss_truncatev8siv8qi2 = 7321,
  CODE_FOR_avx512vl_truncatev8siv8qi2 = 7322,
  CODE_FOR_avx512vl_us_truncatev8siv8qi2 = 7323,
  CODE_FOR_avx512vl_ss_truncatev4siv4qi2 = 7324,
  CODE_FOR_avx512vl_truncatev4siv4qi2 = 7325,
  CODE_FOR_avx512vl_us_truncatev4siv4qi2 = 7326,
  CODE_FOR_avx512vl_ss_truncatev8hiv8qi2 = 7327,
  CODE_FOR_avx512vl_truncatev8hiv8qi2 = 7328,
  CODE_FOR_avx512vl_us_truncatev8hiv8qi2 = 7329,
  CODE_FOR_avx512vl_ss_truncatev2div2qi2_mask = 7337,
  CODE_FOR_avx512vl_truncatev2div2qi2_mask = 7338,
  CODE_FOR_avx512vl_us_truncatev2div2qi2_mask = 7339,
  CODE_FOR_avx512vl_ss_truncatev2div2qi2_mask_store_1 = 7343,
  CODE_FOR_avx512vl_truncatev2div2qi2_mask_store_1 = 7344,
  CODE_FOR_avx512vl_us_truncatev2div2qi2_mask_store_1 = 7345,
  CODE_FOR_avx512vl_ss_truncatev4siv4qi2_mask = 7358,
  CODE_FOR_avx512vl_truncatev4siv4qi2_mask = 7359,
  CODE_FOR_avx512vl_us_truncatev4siv4qi2_mask = 7360,
  CODE_FOR_avx512vl_ss_truncatev4div4qi2_mask = 7361,
  CODE_FOR_avx512vl_truncatev4div4qi2_mask = 7362,
  CODE_FOR_avx512vl_us_truncatev4div4qi2_mask = 7363,
  CODE_FOR_avx512vl_ss_truncatev4siv4qi2_mask_store_1 = 7370,
  CODE_FOR_avx512vl_truncatev4siv4qi2_mask_store_1 = 7371,
  CODE_FOR_avx512vl_us_truncatev4siv4qi2_mask_store_1 = 7372,
  CODE_FOR_avx512vl_ss_truncatev4div4qi2_mask_store_1 = 7373,
  CODE_FOR_avx512vl_truncatev4div4qi2_mask_store_1 = 7374,
  CODE_FOR_avx512vl_us_truncatev4div4qi2_mask_store_1 = 7375,
  CODE_FOR_avx512vl_ss_truncatev8hiv8qi2_mask = 7388,
  CODE_FOR_avx512vl_truncatev8hiv8qi2_mask = 7389,
  CODE_FOR_avx512vl_us_truncatev8hiv8qi2_mask = 7390,
  CODE_FOR_avx512vl_ss_truncatev8siv8qi2_mask = 7391,
  CODE_FOR_avx512vl_truncatev8siv8qi2_mask = 7392,
  CODE_FOR_avx512vl_us_truncatev8siv8qi2_mask = 7393,
  CODE_FOR_avx512vl_ss_truncatev8hiv8qi2_mask_store_1 = 7400,
  CODE_FOR_avx512vl_truncatev8hiv8qi2_mask_store_1 = 7401,
  CODE_FOR_avx512vl_us_truncatev8hiv8qi2_mask_store_1 = 7402,
  CODE_FOR_avx512vl_ss_truncatev8siv8qi2_mask_store_1 = 7403,
  CODE_FOR_avx512vl_truncatev8siv8qi2_mask_store_1 = 7404,
  CODE_FOR_avx512vl_us_truncatev8siv8qi2_mask_store_1 = 7405,
  CODE_FOR_avx512vl_ss_truncatev4div4hi2 = 7406,
  CODE_FOR_avx512vl_truncatev4div4hi2 = 7407,
  CODE_FOR_avx512vl_us_truncatev4div4hi2 = 7408,
  CODE_FOR_avx512vl_ss_truncatev2div2hi2 = 7409,
  CODE_FOR_avx512vl_truncatev2div2hi2 = 7410,
  CODE_FOR_avx512vl_us_truncatev2div2hi2 = 7411,
  CODE_FOR_avx512vl_ss_truncatev4siv4hi2 = 7412,
  CODE_FOR_avx512vl_truncatev4siv4hi2 = 7413,
  CODE_FOR_avx512vl_us_truncatev4siv4hi2 = 7414,
  CODE_FOR_avx512vl_ss_truncatev4siv4hi2_mask = 7428,
  CODE_FOR_avx512vl_truncatev4siv4hi2_mask = 7429,
  CODE_FOR_avx512vl_us_truncatev4siv4hi2_mask = 7430,
  CODE_FOR_avx512vl_ss_truncatev4div4hi2_mask = 7431,
  CODE_FOR_avx512vl_truncatev4div4hi2_mask = 7432,
  CODE_FOR_avx512vl_us_truncatev4div4hi2_mask = 7433,
  CODE_FOR_avx512vl_ss_truncatev4siv4hi2_mask_store_1 = 7440,
  CODE_FOR_avx512vl_truncatev4siv4hi2_mask_store_1 = 7441,
  CODE_FOR_avx512vl_us_truncatev4siv4hi2_mask_store_1 = 7442,
  CODE_FOR_avx512vl_ss_truncatev4div4hi2_mask_store_1 = 7443,
  CODE_FOR_avx512vl_truncatev4div4hi2_mask_store_1 = 7444,
  CODE_FOR_avx512vl_us_truncatev4div4hi2_mask_store_1 = 7445,
  CODE_FOR_avx512vl_ss_truncatev2div2hi2_mask = 7452,
  CODE_FOR_avx512vl_truncatev2div2hi2_mask = 7453,
  CODE_FOR_avx512vl_us_truncatev2div2hi2_mask = 7454,
  CODE_FOR_avx512vl_ss_truncatev2div2hi2_mask_store_1 = 7458,
  CODE_FOR_avx512vl_truncatev2div2hi2_mask_store_1 = 7459,
  CODE_FOR_avx512vl_us_truncatev2div2hi2_mask_store_1 = 7460,
  CODE_FOR_avx512vl_ss_truncatev2div2si2 = 7461,
  CODE_FOR_avx512vl_truncatev2div2si2 = 7462,
  CODE_FOR_avx512vl_us_truncatev2div2si2 = 7463,
  CODE_FOR_avx512vl_ss_truncatev2div2si2_mask = 7471,
  CODE_FOR_avx512vl_truncatev2div2si2_mask = 7472,
  CODE_FOR_avx512vl_us_truncatev2div2si2_mask = 7473,
  CODE_FOR_avx512vl_ss_truncatev2div2si2_mask_store_1 = 7477,
  CODE_FOR_avx512vl_truncatev2div2si2_mask_store_1 = 7478,
  CODE_FOR_avx512vl_us_truncatev2div2si2_mask_store_1 = 7479,
  CODE_FOR_avx512f_ss_truncatev8div16qi2 = 7480,
  CODE_FOR_avx512f_truncatev8div16qi2 = 7481,
  CODE_FOR_avx512f_us_truncatev8div16qi2 = 7482,
  CODE_FOR_avx512f_ss_truncatev8div16qi2_mask = 7489,
  CODE_FOR_avx512f_truncatev8div16qi2_mask = 7490,
  CODE_FOR_avx512f_us_truncatev8div16qi2_mask = 7491,
  CODE_FOR_avx512f_ss_truncatev8div16qi2_mask_store_1 = 7495,
  CODE_FOR_avx512f_truncatev8div16qi2_mask_store_1 = 7496,
  CODE_FOR_avx512f_us_truncatev8div16qi2_mask_store_1 = 7497,
  CODE_FOR_avx512bw_pmaddwd512v32hi = 7624,
  CODE_FOR_avx512bw_pmaddwd512v32hi_mask = 7625,
  CODE_FOR_avx512bw_pmaddwd512v16hi = 7626,
  CODE_FOR_avx512bw_pmaddwd512v16hi_mask = 7627,
  CODE_FOR_avx512bw_pmaddwd512v8hi = 7628,
  CODE_FOR_avx512bw_pmaddwd512v8hi_mask = 7629,
  CODE_FOR_ashrv16hi3_mask = 7645,
  CODE_FOR_ashrv8hi3_mask = 7647,
  CODE_FOR_ashrv8si3_mask = 7649,
  CODE_FOR_ashrv4si3_mask = 7651,
  CODE_FOR_ashrv2di3_mask = 7653,
  CODE_FOR_ashrv16hi3 = 7654,
  CODE_FOR_ashrv8hi3 = 7655,
  CODE_FOR_ashrv8si3 = 7656,
  CODE_FOR_ashrv4si3 = 7657,
  CODE_FOR_ashrv32hi3_mask = 7663,
  CODE_FOR_ashrv4di3_mask = 7665,
  CODE_FOR_ashrv16si3_mask = 7667,
  CODE_FOR_ashrv8di3_mask = 7669,
  CODE_FOR_ashlv16hi3_mask = 7680,
  CODE_FOR_lshrv16hi3_mask = 7682,
  CODE_FOR_ashlv8hi3_mask = 7684,
  CODE_FOR_lshrv8hi3_mask = 7686,
  CODE_FOR_ashlv8si3_mask = 7688,
  CODE_FOR_lshrv8si3_mask = 7690,
  CODE_FOR_ashlv4si3_mask = 7692,
  CODE_FOR_lshrv4si3_mask = 7694,
  CODE_FOR_ashlv4di3_mask = 7696,
  CODE_FOR_lshrv4di3_mask = 7698,
  CODE_FOR_ashlv2di3_mask = 7700,
  CODE_FOR_lshrv2di3_mask = 7702,
  CODE_FOR_ashlv16hi3 = 7703,
  CODE_FOR_lshrv16hi3 = 7704,
  CODE_FOR_ashlv8hi3 = 7705,
  CODE_FOR_lshrv8hi3 = 7706,
  CODE_FOR_ashlv8si3 = 7707,
  CODE_FOR_lshrv8si3 = 7708,
  CODE_FOR_ashlv4si3 = 7709,
  CODE_FOR_lshrv4si3 = 7710,
  CODE_FOR_ashlv4di3 = 7711,
  CODE_FOR_lshrv4di3 = 7712,
  CODE_FOR_ashlv2di3 = 7713,
  CODE_FOR_lshrv2di3 = 7714,
  CODE_FOR_ashlv32hi3 = 7719,
  CODE_FOR_ashlv32hi3_mask = 7720,
  CODE_FOR_lshrv32hi3 = 7721,
  CODE_FOR_lshrv32hi3_mask = 7722,
  CODE_FOR_ashlv16si3 = 7723,
  CODE_FOR_ashlv16si3_mask = 7724,
  CODE_FOR_lshrv16si3 = 7725,
  CODE_FOR_lshrv16si3_mask = 7726,
  CODE_FOR_ashlv8di3 = 7727,
  CODE_FOR_ashlv8di3_mask = 7728,
  CODE_FOR_lshrv8di3 = 7729,
  CODE_FOR_lshrv8di3_mask = 7730,
  CODE_FOR_avx512bw_ashlv4ti3 = 7736,
  CODE_FOR_avx512bw_lshrv4ti3 = 7737,
  CODE_FOR_avx512bw_ashlv2ti3 = 7738,
  CODE_FOR_avx512bw_lshrv2ti3 = 7739,
  CODE_FOR_avx512bw_ashlv1ti3 = 7740,
  CODE_FOR_avx512bw_lshrv1ti3 = 7741,
  CODE_FOR_avx2_ashlv2ti3 = 7742,
  CODE_FOR_avx2_lshrv2ti3 = 7743,
  CODE_FOR_sse2_ashlv1ti3 = 7744,
  CODE_FOR_sse2_lshrv1ti3 = 7745,
  CODE_FOR_avx512f_rolvv16si = 7746,
  CODE_FOR_avx512f_rolvv16si_mask = 7747,
  CODE_FOR_avx512f_rorvv16si = 7748,
  CODE_FOR_avx512f_rorvv16si_mask = 7749,
  CODE_FOR_avx512vl_rolvv8si = 7750,
  CODE_FOR_avx512vl_rolvv8si_mask = 7751,
  CODE_FOR_avx512vl_rorvv8si = 7752,
  CODE_FOR_avx512vl_rorvv8si_mask = 7753,
  CODE_FOR_avx512vl_rolvv4si = 7754,
  CODE_FOR_avx512vl_rolvv4si_mask = 7755,
  CODE_FOR_avx512vl_rorvv4si = 7756,
  CODE_FOR_avx512vl_rorvv4si_mask = 7757,
  CODE_FOR_avx512f_rolvv8di = 7758,
  CODE_FOR_avx512f_rolvv8di_mask = 7759,
  CODE_FOR_avx512f_rorvv8di = 7760,
  CODE_FOR_avx512f_rorvv8di_mask = 7761,
  CODE_FOR_avx512vl_rolvv4di = 7762,
  CODE_FOR_avx512vl_rolvv4di_mask = 7763,
  CODE_FOR_avx512vl_rorvv4di = 7764,
  CODE_FOR_avx512vl_rorvv4di_mask = 7765,
  CODE_FOR_avx512vl_rolvv2di = 7766,
  CODE_FOR_avx512vl_rolvv2di_mask = 7767,
  CODE_FOR_avx512vl_rorvv2di = 7768,
  CODE_FOR_avx512vl_rorvv2di_mask = 7769,
  CODE_FOR_avx512f_rolv16si = 7770,
  CODE_FOR_avx512f_rolv16si_mask = 7771,
  CODE_FOR_avx512f_rorv16si = 7772,
  CODE_FOR_avx512f_rorv16si_mask = 7773,
  CODE_FOR_avx512vl_rolv8si = 7774,
  CODE_FOR_avx512vl_rolv8si_mask = 7775,
  CODE_FOR_avx512vl_rorv8si = 7776,
  CODE_FOR_avx512vl_rorv8si_mask = 7777,
  CODE_FOR_avx512vl_rolv4si = 7778,
  CODE_FOR_avx512vl_rolv4si_mask = 7779,
  CODE_FOR_avx512vl_rorv4si = 7780,
  CODE_FOR_avx512vl_rorv4si_mask = 7781,
  CODE_FOR_avx512f_rolv8di = 7782,
  CODE_FOR_avx512f_rolv8di_mask = 7783,
  CODE_FOR_avx512f_rorv8di = 7784,
  CODE_FOR_avx512f_rorv8di_mask = 7785,
  CODE_FOR_avx512vl_rolv4di = 7786,
  CODE_FOR_avx512vl_rolv4di_mask = 7787,
  CODE_FOR_avx512vl_rorv4di = 7788,
  CODE_FOR_avx512vl_rorv4di_mask = 7789,
  CODE_FOR_avx512vl_rolv2di = 7790,
  CODE_FOR_avx512vl_rolv2di_mask = 7791,
  CODE_FOR_avx512vl_rorv2di = 7792,
  CODE_FOR_avx512vl_rorv2di_mask = 7793,
  CODE_FOR_sse4_2_gtv2di3 = 7992,
  CODE_FOR_avx2_gtv32qi3 = 7993,
  CODE_FOR_avx2_gtv16hi3 = 7994,
  CODE_FOR_avx2_gtv8si3 = 7995,
  CODE_FOR_avx2_gtv4di3 = 7996,
  CODE_FOR_one_cmplv16si2_mask = 8001,
  CODE_FOR_one_cmplv8di2_mask = 8003,
   CODE_FOR_one_cmplv64qi2_mask = CODE_FOR_nothing,
   CODE_FOR_one_cmplv32qi2_mask = CODE_FOR_nothing,
   CODE_FOR_one_cmplv16qi2_mask = CODE_FOR_nothing,
   CODE_FOR_one_cmplv32hi2_mask = CODE_FOR_nothing,
   CODE_FOR_one_cmplv16hi2_mask = CODE_FOR_nothing,
   CODE_FOR_one_cmplv8hi2_mask = CODE_FOR_nothing,
  CODE_FOR_one_cmplv8si2_mask = 8011,
  CODE_FOR_one_cmplv4si2_mask = 8013,
  CODE_FOR_one_cmplv4di2_mask = 8015,
  CODE_FOR_one_cmplv2di2_mask = 8017,
  CODE_FOR_andv1ti3 = 8102,
  CODE_FOR_iorv1ti3 = 8103,
  CODE_FOR_xorv1ti3 = 8104,
  CODE_FOR_avx512bw_testmv64qi3 = 8153,
  CODE_FOR_avx512bw_testmv64qi3_mask = 8154,
  CODE_FOR_avx512vl_testmv32qi3 = 8155,
  CODE_FOR_avx512vl_testmv32qi3_mask = 8156,
  CODE_FOR_avx512vl_testmv16qi3 = 8157,
  CODE_FOR_avx512vl_testmv16qi3_mask = 8158,
  CODE_FOR_avx512bw_testmv32hi3 = 8159,
  CODE_FOR_avx512bw_testmv32hi3_mask = 8160,
  CODE_FOR_avx512vl_testmv16hi3 = 8161,
  CODE_FOR_avx512vl_testmv16hi3_mask = 8162,
  CODE_FOR_avx512vl_testmv8hi3 = 8163,
  CODE_FOR_avx512vl_testmv8hi3_mask = 8164,
  CODE_FOR_avx512f_testmv16si3 = 8165,
  CODE_FOR_avx512f_testmv16si3_mask = 8166,
  CODE_FOR_avx512vl_testmv8si3 = 8167,
  CODE_FOR_avx512vl_testmv8si3_mask = 8168,
  CODE_FOR_avx512vl_testmv4si3 = 8169,
  CODE_FOR_avx512vl_testmv4si3_mask = 8170,
  CODE_FOR_avx512f_testmv8di3 = 8171,
  CODE_FOR_avx512f_testmv8di3_mask = 8172,
  CODE_FOR_avx512vl_testmv4di3 = 8173,
  CODE_FOR_avx512vl_testmv4di3_mask = 8174,
  CODE_FOR_avx512vl_testmv2di3 = 8175,
  CODE_FOR_avx512vl_testmv2di3_mask = 8176,
  CODE_FOR_avx512bw_testnmv64qi3 = 8177,
  CODE_FOR_avx512bw_testnmv64qi3_mask = 8178,
  CODE_FOR_avx512vl_testnmv32qi3 = 8179,
  CODE_FOR_avx512vl_testnmv32qi3_mask = 8180,
  CODE_FOR_avx512vl_testnmv16qi3 = 8181,
  CODE_FOR_avx512vl_testnmv16qi3_mask = 8182,
  CODE_FOR_avx512bw_testnmv32hi3 = 8183,
  CODE_FOR_avx512bw_testnmv32hi3_mask = 8184,
  CODE_FOR_avx512vl_testnmv16hi3 = 8185,
  CODE_FOR_avx512vl_testnmv16hi3_mask = 8186,
  CODE_FOR_avx512vl_testnmv8hi3 = 8187,
  CODE_FOR_avx512vl_testnmv8hi3_mask = 8188,
  CODE_FOR_avx512f_testnmv16si3 = 8189,
  CODE_FOR_avx512f_testnmv16si3_mask = 8190,
  CODE_FOR_avx512vl_testnmv8si3 = 8191,
  CODE_FOR_avx512vl_testnmv8si3_mask = 8192,
  CODE_FOR_avx512vl_testnmv4si3 = 8193,
  CODE_FOR_avx512vl_testnmv4si3_mask = 8194,
  CODE_FOR_avx512f_testnmv8di3 = 8195,
  CODE_FOR_avx512f_testnmv8di3_mask = 8196,
  CODE_FOR_avx512vl_testnmv4di3 = 8197,
  CODE_FOR_avx512vl_testnmv4di3_mask = 8198,
  CODE_FOR_avx512vl_testnmv2di3 = 8199,
  CODE_FOR_avx512vl_testnmv2di3_mask = 8200,
  CODE_FOR_sse2_packsswb = 8345,
  CODE_FOR_sse2_packsswb_mask = 8346,
  CODE_FOR_avx2_packsswb = 8347,
  CODE_FOR_avx2_packsswb_mask = 8348,
  CODE_FOR_avx512bw_packsswb = 8349,
  CODE_FOR_avx512bw_packsswb_mask = 8350,
  CODE_FOR_sse2_packssdw = 8351,
  CODE_FOR_sse2_packssdw_mask = 8352,
  CODE_FOR_avx2_packssdw = 8353,
  CODE_FOR_avx2_packssdw_mask = 8354,
  CODE_FOR_avx512bw_packssdw = 8355,
  CODE_FOR_avx512bw_packssdw_mask = 8356,
  CODE_FOR_avx512bw_packuswb = 8357,
  CODE_FOR_avx512bw_packuswb_mask = 8358,
  CODE_FOR_avx2_packuswb = 8359,
  CODE_FOR_avx2_packuswb_mask = 8360,
  CODE_FOR_sse2_packuswb = 8361,
  CODE_FOR_sse2_packuswb_mask = 8362,
  CODE_FOR_avx512bw_interleave_highv64qi = 8363,
  CODE_FOR_avx512bw_interleave_highv64qi_mask = 8364,
  CODE_FOR_avx2_interleave_highv32qi = 8365,
  CODE_FOR_avx2_interleave_highv32qi_mask = 8366,
  CODE_FOR_vec_interleave_highv16qi = 8367,
  CODE_FOR_vec_interleave_highv16qi_mask = 8368,
  CODE_FOR_avx512bw_interleave_lowv64qi = 8369,
  CODE_FOR_avx512bw_interleave_lowv64qi_mask = 8370,
  CODE_FOR_avx2_interleave_lowv32qi = 8371,
  CODE_FOR_avx2_interleave_lowv32qi_mask = 8372,
  CODE_FOR_vec_interleave_lowv16qi = 8373,
  CODE_FOR_vec_interleave_lowv16qi_mask = 8374,
  CODE_FOR_avx512bw_interleave_highv32hi = 8375,
  CODE_FOR_avx512bw_interleave_highv32hi_mask = 8376,
  CODE_FOR_avx512bw_interleave_highv32hf = 8377,
  CODE_FOR_avx512bw_interleave_highv32hf_mask = 8378,
  CODE_FOR_avx512bw_interleave_highv32bf = 8379,
  CODE_FOR_avx512bw_interleave_highv32bf_mask = 8380,
  CODE_FOR_avx2_interleave_highv16hi = 8381,
  CODE_FOR_avx2_interleave_highv16hi_mask = 8382,
  CODE_FOR_avx2_interleave_highv16hf = 8383,
  CODE_FOR_avx2_interleave_highv16hf_mask = 8384,
  CODE_FOR_avx2_interleave_highv16bf = 8385,
  CODE_FOR_avx2_interleave_highv16bf_mask = 8386,
  CODE_FOR_vec_interleave_highv8hi = 8387,
  CODE_FOR_vec_interleave_highv8hi_mask = 8388,
  CODE_FOR_vec_interleave_highv8hf = 8389,
  CODE_FOR_vec_interleave_highv8hf_mask = 8390,
  CODE_FOR_vec_interleave_highv8bf = 8391,
  CODE_FOR_vec_interleave_highv8bf_mask = 8392,
  CODE_FOR_avx512bw_interleave_lowv32hi_mask = 8394,
  CODE_FOR_avx512bw_interleave_lowv32hf_mask = 8396,
  CODE_FOR_avx512bw_interleave_lowv32bf_mask = 8398,
  CODE_FOR_avx2_interleave_lowv16hi = 8399,
  CODE_FOR_avx2_interleave_lowv16hi_mask = 8400,
  CODE_FOR_avx2_interleave_lowv16hf = 8401,
  CODE_FOR_avx2_interleave_lowv16hf_mask = 8402,
  CODE_FOR_avx2_interleave_lowv16bf = 8403,
  CODE_FOR_avx2_interleave_lowv16bf_mask = 8404,
  CODE_FOR_vec_interleave_lowv8hi = 8405,
  CODE_FOR_vec_interleave_lowv8hi_mask = 8406,
  CODE_FOR_vec_interleave_lowv8hf = 8407,
  CODE_FOR_vec_interleave_lowv8hf_mask = 8408,
  CODE_FOR_vec_interleave_lowv8bf = 8409,
  CODE_FOR_vec_interleave_lowv8bf_mask = 8410,
  CODE_FOR_avx2_interleave_highv8si = 8411,
  CODE_FOR_avx2_interleave_highv8si_mask = 8412,
  CODE_FOR_avx512f_interleave_highv16si_mask = 8414,
  CODE_FOR_vec_interleave_highv4si = 8415,
  CODE_FOR_vec_interleave_highv4si_mask = 8416,
  CODE_FOR_avx2_interleave_lowv8si = 8417,
  CODE_FOR_avx2_interleave_lowv8si_mask = 8418,
  CODE_FOR_avx512f_interleave_lowv16si_mask = 8420,
  CODE_FOR_vec_interleave_lowv4si = 8421,
  CODE_FOR_vec_interleave_lowv4si_mask = 8422,
  CODE_FOR_sse4_1_pinsrb = 8423,
  CODE_FOR_sse2_pinsrw = 8424,
  CODE_FOR_sse2_pinsrph = 8425,
  CODE_FOR_sse2_pinsrbf = 8426,
  CODE_FOR_sse4_1_pinsrd = 8427,
  CODE_FOR_sse4_1_pinsrq = 8428,
  CODE_FOR_avx512dq_vinsertf64x2_1_mask = 8434,
  CODE_FOR_avx512dq_vinserti64x2_1_mask = 8436,
  CODE_FOR_avx512f_vinsertf32x4_1_mask = 8438,
  CODE_FOR_avx512f_vinserti32x4_1_mask = 8440,
  CODE_FOR_vec_set_lo_v16sf = 8441,
  CODE_FOR_vec_set_lo_v16sf_mask = 8442,
  CODE_FOR_vec_set_lo_v16si = 8443,
  CODE_FOR_vec_set_lo_v16si_mask = 8444,
  CODE_FOR_vec_set_hi_v16sf = 8445,
  CODE_FOR_vec_set_hi_v16sf_mask = 8446,
  CODE_FOR_vec_set_hi_v16si = 8447,
  CODE_FOR_vec_set_hi_v16si_mask = 8448,
  CODE_FOR_vec_set_lo_v8df = 8449,
  CODE_FOR_vec_set_lo_v8df_mask = 8450,
  CODE_FOR_vec_set_lo_v8di = 8451,
  CODE_FOR_vec_set_lo_v8di_mask = 8452,
  CODE_FOR_vec_set_hi_v8df = 8453,
  CODE_FOR_vec_set_hi_v8df_mask = 8454,
  CODE_FOR_vec_set_hi_v8di = 8455,
  CODE_FOR_vec_set_hi_v8di_mask = 8456,
  CODE_FOR_avx512dq_shuf_i64x2_1_mask = 8458,
  CODE_FOR_avx512dq_shuf_f64x2_1_mask = 8460,
  CODE_FOR_avx512f_shuf_f64x2_1 = 8461,
  CODE_FOR_avx512f_shuf_f64x2_1_mask = 8462,
  CODE_FOR_avx512f_shuf_i64x2_1 = 8463,
  CODE_FOR_avx512f_shuf_i64x2_1_mask = 8464,
  CODE_FOR_avx512vl_shuf_i32x4_1 = 8469,
  CODE_FOR_avx512vl_shuf_i32x4_1_mask = 8470,
  CODE_FOR_avx512vl_shuf_f32x4_1 = 8471,
  CODE_FOR_avx512vl_shuf_f32x4_1_mask = 8472,
  CODE_FOR_avx512f_shuf_f32x4_1 = 8473,
  CODE_FOR_avx512f_shuf_f32x4_1_mask = 8474,
  CODE_FOR_avx512f_shuf_i32x4_1 = 8475,
  CODE_FOR_avx512f_shuf_i32x4_1_mask = 8476,
  CODE_FOR_avx512f_pshufd_1 = 8481,
  CODE_FOR_avx512f_pshufd_1_mask = 8482,
  CODE_FOR_avx2_pshufd_1 = 8483,
  CODE_FOR_avx2_pshufd_1_mask = 8484,
  CODE_FOR_sse2_pshufd_1 = 8485,
  CODE_FOR_sse2_pshufd_1_mask = 8486,
  CODE_FOR_avx512bw_pshuflwv32hi_mask = 8488,
  CODE_FOR_avx2_pshuflw_1 = 8489,
  CODE_FOR_avx2_pshuflw_1_mask = 8490,
  CODE_FOR_sse2_pshuflw_1 = 8491,
  CODE_FOR_sse2_pshuflw_1_mask = 8492,
  CODE_FOR_avx512bw_pshufhwv32hi_mask = 8494,
  CODE_FOR_avx2_pshufhw_1 = 8495,
  CODE_FOR_avx2_pshufhw_1_mask = 8496,
  CODE_FOR_sse2_pshufhw_1 = 8497,
  CODE_FOR_sse2_pshufhw_1_mask = 8498,
  CODE_FOR_sse2_loadld = 8499,
  CODE_FOR_vec_concatv2di = 8533,
  CODE_FOR_vec_setv8di_0 = 8535,
  CODE_FOR_vec_setv4di_0 = 8536,
  CODE_FOR_avx_movmskps256 = 8552,
  CODE_FOR_sse_movmskps = 8553,
  CODE_FOR_avx_movmskpd256 = 8554,
  CODE_FOR_sse2_movmskpd = 8555,
  CODE_FOR_avx2_pmovmskb = 8600,
  CODE_FOR_sse2_pmovmskb = 8601,
  CODE_FOR_sse_ldmxcsr = 8625,
  CODE_FOR_sse_stmxcsr = 8626,
  CODE_FOR_sse2_clflush = 8627,
  CODE_FOR_sse3_mwait = 8628,
  CODE_FOR_sse3_monitor_si = 8629,
  CODE_FOR_sse3_monitor_di = 8630,
  CODE_FOR_avx2_phaddwv16hi3 = 8631,
  CODE_FOR_avx2_phaddswv16hi3 = 8632,
  CODE_FOR_avx2_phsubwv16hi3 = 8633,
  CODE_FOR_avx2_phsubswv16hi3 = 8634,
  CODE_FOR_ssse3_phaddwv8hi3 = 8635,
  CODE_FOR_ssse3_phaddswv8hi3 = 8636,
  CODE_FOR_ssse3_phsubwv8hi3 = 8637,
  CODE_FOR_ssse3_phsubswv8hi3 = 8638,
  CODE_FOR_ssse3_phaddwv4hi3 = 8639,
  CODE_FOR_ssse3_phaddswv4hi3 = 8640,
  CODE_FOR_ssse3_phsubwv4hi3 = 8641,
  CODE_FOR_ssse3_phsubswv4hi3 = 8642,
  CODE_FOR_avx2_phadddv8si3 = 8643,
  CODE_FOR_avx2_phsubdv8si3 = 8644,
  CODE_FOR_ssse3_phadddv4si3 = 8645,
  CODE_FOR_ssse3_phsubdv4si3 = 8646,
  CODE_FOR_ssse3_phadddv2si3 = 8647,
  CODE_FOR_ssse3_phsubdv2si3 = 8648,
  CODE_FOR_avx2_pmaddubsw256 = 8649,
  CODE_FOR_avx512bw_pmaddubsw512v8hi = 8650,
  CODE_FOR_avx512bw_pmaddubsw512v8hi_mask = 8651,
  CODE_FOR_avx512bw_pmaddubsw512v16hi = 8652,
  CODE_FOR_avx512bw_pmaddubsw512v16hi_mask = 8653,
  CODE_FOR_avx512bw_pmaddubsw512v32hi = 8654,
  CODE_FOR_avx512bw_pmaddubsw512v32hi_mask = 8655,
  CODE_FOR_avx512bw_umulhrswv32hi3 = 8656,
  CODE_FOR_avx512bw_umulhrswv32hi3_mask = 8657,
  CODE_FOR_ssse3_pmaddubsw128 = 8658,
  CODE_FOR_ssse3_pmaddubsw = 8659,
  CODE_FOR_avx512bw_pshufbv64qi3 = 8668,
  CODE_FOR_avx512bw_pshufbv64qi3_mask = 8669,
  CODE_FOR_avx2_pshufbv32qi3 = 8670,
  CODE_FOR_avx2_pshufbv32qi3_mask = 8671,
  CODE_FOR_ssse3_pshufbv16qi3 = 8672,
  CODE_FOR_ssse3_pshufbv16qi3_mask = 8673,
  CODE_FOR_avx2_psignv32qi3 = 8675,
  CODE_FOR_ssse3_psignv16qi3 = 8676,
  CODE_FOR_avx2_psignv16hi3 = 8677,
  CODE_FOR_ssse3_psignv8hi3 = 8678,
  CODE_FOR_avx2_psignv8si3 = 8679,
  CODE_FOR_ssse3_psignv4si3 = 8680,
  CODE_FOR_ssse3_psignv8qi3 = 8681,
  CODE_FOR_ssse3_psignv4hi3 = 8682,
  CODE_FOR_ssse3_psignv2si3 = 8683,
  CODE_FOR_avx512bw_palignrv64qi_mask = 8684,
  CODE_FOR_avx2_palignrv32qi_mask = 8685,
  CODE_FOR_ssse3_palignrv16qi_mask = 8686,
  CODE_FOR_avx512bw_palignrv4ti = 8687,
  CODE_FOR_avx2_palignrv2ti = 8688,
  CODE_FOR_ssse3_palignrv1ti = 8689,
  CODE_FOR_ssse3_palignrdi = 8690,
  CODE_FOR_absv16si2_mask = 8703,
  CODE_FOR_absv8si2_mask = 8704,
  CODE_FOR_absv4si2_mask = 8705,
  CODE_FOR_absv8di2_mask = 8706,
  CODE_FOR_absv4di2_mask = 8707,
  CODE_FOR_absv2di2_mask = 8708,
  CODE_FOR_absv64qi2_mask = 8709,
  CODE_FOR_absv16qi2_mask = 8710,
  CODE_FOR_absv32qi2_mask = 8711,
  CODE_FOR_absv32hi2_mask = 8712,
  CODE_FOR_absv16hi2_mask = 8713,
  CODE_FOR_absv8hi2_mask = 8714,
  CODE_FOR_sse4a_movntsf = 8715,
  CODE_FOR_sse4a_movntdf = 8716,
  CODE_FOR_sse4a_vmmovntv4sf = 8717,
  CODE_FOR_sse4a_vmmovntv2df = 8718,
  CODE_FOR_sse4a_extrqi = 8719,
  CODE_FOR_sse4a_extrq = 8720,
  CODE_FOR_sse4a_insertqi = 8721,
  CODE_FOR_sse4a_insertq = 8722,
  CODE_FOR_avx_blendps256 = 8723,
  CODE_FOR_sse4_1_blendps = 8724,
  CODE_FOR_avx_blendpd256 = 8725,
  CODE_FOR_sse4_1_blendpd = 8726,
  CODE_FOR_avx_blendvps256 = 8727,
  CODE_FOR_sse4_1_blendvps = 8728,
  CODE_FOR_avx_blendvpd256 = 8729,
  CODE_FOR_sse4_1_blendvpd = 8730,
  CODE_FOR_sse4_1_blendvss = 8731,
  CODE_FOR_sse4_1_blendvsd = 8732,
  CODE_FOR_avx_dpps256 = 8757,
  CODE_FOR_sse4_1_dpps = 8758,
  CODE_FOR_avx_dppd256 = 8759,
  CODE_FOR_sse4_1_dppd = 8760,
  CODE_FOR_avx512f_movntdqa = 8761,
  CODE_FOR_avx2_movntdqa = 8762,
  CODE_FOR_sse4_1_movntdqa = 8763,
  CODE_FOR_avx2_mpsadbw = 8764,
  CODE_FOR_sse4_1_mpsadbw = 8765,
  CODE_FOR_avx10_2_mpsadbw = 8766,
  CODE_FOR_avx10_2_mpsadbw_mask = 8767,
  CODE_FOR_avx2_mpsadbw_mask = 8769,
  CODE_FOR_sse4_1_mpsadbw_mask = 8771,
  CODE_FOR_avx512bw_packusdw = 8772,
  CODE_FOR_avx512bw_packusdw_mask = 8773,
  CODE_FOR_avx2_packusdw = 8774,
  CODE_FOR_avx2_packusdw_mask = 8775,
  CODE_FOR_sse4_1_packusdw = 8776,
  CODE_FOR_sse4_1_packusdw_mask = 8777,
  CODE_FOR_avx2_pblendvb = 8778,
  CODE_FOR_sse4_1_pblendvb = 8779,
  CODE_FOR_sse4_1_pblendw = 8788,
  CODE_FOR_sse4_1_pblendph = 8789,
  CODE_FOR_sse4_1_pblendbf = 8790,
  CODE_FOR_avx2_pblenddv8si = 8794,
  CODE_FOR_avx2_pblenddv4si = 8795,
  CODE_FOR_sse4_1_phminposuw = 8796,
  CODE_FOR_avx2_sign_extendv16qiv16hi2 = 8797,
  CODE_FOR_avx2_sign_extendv16qiv16hi2_mask = 8798,
  CODE_FOR_avx2_zero_extendv16qiv16hi2 = 8799,
  CODE_FOR_avx2_zero_extendv16qiv16hi2_mask = 8800,
  CODE_FOR_avx512bw_sign_extendv32qiv32hi2 = 8805,
  CODE_FOR_avx512bw_sign_extendv32qiv32hi2_mask = 8806,
  CODE_FOR_avx512bw_zero_extendv32qiv32hi2 = 8807,
  CODE_FOR_avx512bw_zero_extendv32qiv32hi2_mask = 8808,
  CODE_FOR_sse4_1_sign_extendv8qiv8hi2 = 8813,
  CODE_FOR_sse4_1_sign_extendv8qiv8hi2_mask = 8814,
  CODE_FOR_sse4_1_zero_extendv8qiv8hi2 = 8815,
  CODE_FOR_sse4_1_zero_extendv8qiv8hi2_mask = 8816,
  CODE_FOR_avx512f_sign_extendv16qiv16si2_mask = 8830,
  CODE_FOR_avx512f_zero_extendv16qiv16si2_mask = 8832,
  CODE_FOR_avx2_sign_extendv8qiv8si2 = 8833,
  CODE_FOR_avx2_sign_extendv8qiv8si2_mask = 8834,
  CODE_FOR_avx2_zero_extendv8qiv8si2 = 8835,
  CODE_FOR_avx2_zero_extendv8qiv8si2_mask = 8836,
  CODE_FOR_sse4_1_sign_extendv4qiv4si2 = 8845,
  CODE_FOR_sse4_1_sign_extendv4qiv4si2_mask = 8846,
  CODE_FOR_sse4_1_zero_extendv4qiv4si2 = 8847,
  CODE_FOR_sse4_1_zero_extendv4qiv4si2_mask = 8848,
  CODE_FOR_avx512f_sign_extendv16hiv16si2 = 8859,
  CODE_FOR_avx512f_sign_extendv16hiv16si2_mask = 8860,
  CODE_FOR_avx512f_zero_extendv16hiv16si2 = 8861,
  CODE_FOR_avx512f_zero_extendv16hiv16si2_mask = 8862,
  CODE_FOR_avx512f_zero_extendv16hiv16si2_1 = 8863,
  CODE_FOR_avx2_sign_extendv8hiv8si2 = 8867,
  CODE_FOR_avx2_sign_extendv8hiv8si2_mask = 8868,
  CODE_FOR_avx2_zero_extendv8hiv8si2 = 8869,
  CODE_FOR_avx2_zero_extendv8hiv8si2_mask = 8870,
  CODE_FOR_avx2_zero_extendv8hiv8si2_1 = 8871,
  CODE_FOR_sse4_1_sign_extendv4hiv4si2 = 8875,
  CODE_FOR_sse4_1_sign_extendv4hiv4si2_mask = 8876,
  CODE_FOR_sse4_1_zero_extendv4hiv4si2 = 8877,
  CODE_FOR_sse4_1_zero_extendv4hiv4si2_mask = 8878,
  CODE_FOR_avx512f_sign_extendv8qiv8di2 = 8891,
  CODE_FOR_avx512f_sign_extendv8qiv8di2_mask = 8892,
  CODE_FOR_avx512f_zero_extendv8qiv8di2 = 8893,
  CODE_FOR_avx512f_zero_extendv8qiv8di2_mask = 8894,
  CODE_FOR_avx2_sign_extendv4qiv4di2 = 8903,
  CODE_FOR_avx2_sign_extendv4qiv4di2_mask = 8904,
  CODE_FOR_avx2_zero_extendv4qiv4di2 = 8905,
  CODE_FOR_avx2_zero_extendv4qiv4di2_mask = 8906,
  CODE_FOR_sse4_1_sign_extendv2qiv2di2 = 8915,
  CODE_FOR_sse4_1_sign_extendv2qiv2di2_mask = 8916,
  CODE_FOR_sse4_1_zero_extendv2qiv2di2 = 8917,
  CODE_FOR_sse4_1_zero_extendv2qiv2di2_mask = 8918,
  CODE_FOR_avx512f_sign_extendv8hiv8di2 = 8926,
  CODE_FOR_avx512f_sign_extendv8hiv8di2_mask = 8927,
  CODE_FOR_avx512f_zero_extendv8hiv8di2 = 8928,
  CODE_FOR_avx512f_zero_extendv8hiv8di2_mask = 8929,
  CODE_FOR_avx2_sign_extendv4hiv4di2 = 8930,
  CODE_FOR_avx2_sign_extendv4hiv4di2_mask = 8931,
  CODE_FOR_avx2_zero_extendv4hiv4di2 = 8932,
  CODE_FOR_avx2_zero_extendv4hiv4di2_mask = 8933,
  CODE_FOR_sse4_1_sign_extendv2hiv2di2 = 8942,
  CODE_FOR_sse4_1_sign_extendv2hiv2di2_mask = 8943,
  CODE_FOR_sse4_1_zero_extendv2hiv2di2 = 8944,
  CODE_FOR_sse4_1_zero_extendv2hiv2di2_mask = 8945,
  CODE_FOR_avx512f_sign_extendv8siv8di2 = 8954,
  CODE_FOR_avx512f_sign_extendv8siv8di2_mask = 8955,
  CODE_FOR_avx512f_zero_extendv8siv8di2 = 8956,
  CODE_FOR_avx512f_zero_extendv8siv8di2_mask = 8957,
  CODE_FOR_avx2_sign_extendv4siv4di2 = 8960,
  CODE_FOR_avx2_sign_extendv4siv4di2_mask = 8961,
  CODE_FOR_avx2_zero_extendv4siv4di2 = 8962,
  CODE_FOR_avx2_zero_extendv4siv4di2_mask = 8963,
  CODE_FOR_sse4_1_sign_extendv2siv2di2 = 8966,
  CODE_FOR_sse4_1_sign_extendv2siv2di2_mask = 8967,
  CODE_FOR_sse4_1_zero_extendv2siv2di2 = 8968,
  CODE_FOR_sse4_1_zero_extendv2siv2di2_mask = 8969,
  CODE_FOR_avx_vtestps256 = 8980,
  CODE_FOR_avx_vtestps = 8981,
  CODE_FOR_avx_vtestpd256 = 8982,
  CODE_FOR_avx_vtestpd = 8983,
  CODE_FOR_ptesttf2 = 8998,
  CODE_FOR_avx_roundps256 = 9021,
  CODE_FOR_sse4_1_roundps = 9022,
  CODE_FOR_avx_roundpd256 = 9023,
  CODE_FOR_sse4_1_roundpd = 9024,
  CODE_FOR_sse4_1_roundsh = 9025,
  CODE_FOR_sse4_1_roundss = 9026,
  CODE_FOR_sse4_1_roundsd = 9027,
  CODE_FOR_sse4_2_pcmpestr = 9031,
  CODE_FOR_sse4_2_pcmpestri = 9032,
  CODE_FOR_sse4_2_pcmpestrm = 9033,
  CODE_FOR_sse4_2_pcmpestr_cconly = 9034,
  CODE_FOR_sse4_2_pcmpistr = 9035,
  CODE_FOR_sse4_2_pcmpistri = 9036,
  CODE_FOR_sse4_2_pcmpistrm = 9037,
  CODE_FOR_sse4_2_pcmpistr_cconly = 9038,
  CODE_FOR_xop_pmacsww = 9039,
  CODE_FOR_xop_pmacssww = 9040,
  CODE_FOR_xop_pmacsdd = 9041,
  CODE_FOR_xop_pmacssdd = 9042,
  CODE_FOR_xop_pmacsdql = 9043,
  CODE_FOR_xop_pmacssdql = 9044,
  CODE_FOR_xop_pmacsdqh = 9045,
  CODE_FOR_xop_pmacssdqh = 9046,
  CODE_FOR_xop_pmacswd = 9047,
  CODE_FOR_xop_pmacsswd = 9048,
  CODE_FOR_xop_pmadcswd = 9049,
  CODE_FOR_xop_pmadcsswd = 9050,
  CODE_FOR_xop_pcmov_v32qi256 = 9051,
  CODE_FOR_xop_pcmov_v16qi = 9052,
  CODE_FOR_xop_pcmov_v16hi256 = 9053,
  CODE_FOR_xop_pcmov_v8hi = 9054,
  CODE_FOR_xop_pcmov_v8si256 = 9055,
  CODE_FOR_xop_pcmov_v4si = 9056,
  CODE_FOR_xop_pcmov_v4di256 = 9057,
  CODE_FOR_xop_pcmov_v2di = 9058,
  CODE_FOR_xop_pcmov_v2ti256 = 9059,
  CODE_FOR_xop_pcmov_v1ti = 9060,
  CODE_FOR_xop_pcmov_v16hf256 = 9061,
  CODE_FOR_xop_pcmov_v8hf = 9062,
  CODE_FOR_xop_pcmov_v8sf256 = 9063,
  CODE_FOR_xop_pcmov_v4sf = 9064,
  CODE_FOR_xop_pcmov_v4df256 = 9065,
  CODE_FOR_xop_pcmov_v2df = 9066,
  CODE_FOR_xop_phaddbw = 9067,
  CODE_FOR_xop_phaddubw = 9068,
  CODE_FOR_xop_phaddbd = 9069,
  CODE_FOR_xop_phaddubd = 9070,
  CODE_FOR_xop_phaddbq = 9071,
  CODE_FOR_xop_phaddubq = 9072,
  CODE_FOR_xop_phaddwd = 9073,
  CODE_FOR_xop_phadduwd = 9074,
  CODE_FOR_xop_phaddwq = 9075,
  CODE_FOR_xop_phadduwq = 9076,
  CODE_FOR_xop_phadddq = 9077,
  CODE_FOR_xop_phaddudq = 9078,
  CODE_FOR_xop_phsubbw = 9079,
  CODE_FOR_xop_phsubwd = 9080,
  CODE_FOR_xop_phsubdq = 9081,
  CODE_FOR_xop_pperm = 9082,
  CODE_FOR_xop_pperm_pack_v2di_v4si = 9083,
  CODE_FOR_xop_pperm_pack_v4si_v8hi = 9084,
  CODE_FOR_xop_pperm_pack_v8hi_v16qi = 9085,
  CODE_FOR_xop_rotlv16qi3 = 9086,
  CODE_FOR_xop_rotlv8hi3 = 9087,
  CODE_FOR_xop_rotlv4si3 = 9088,
  CODE_FOR_xop_rotlv2di3 = 9089,
  CODE_FOR_xop_rotrv16qi3 = 9090,
  CODE_FOR_xop_rotrv8hi3 = 9091,
  CODE_FOR_xop_rotrv4si3 = 9092,
  CODE_FOR_xop_rotrv2di3 = 9093,
  CODE_FOR_xop_vrotlv16qi3 = 9094,
  CODE_FOR_xop_vrotlv8hi3 = 9095,
  CODE_FOR_xop_vrotlv4si3 = 9096,
  CODE_FOR_xop_vrotlv2di3 = 9097,
  CODE_FOR_xop_shav16qi3 = 9098,
  CODE_FOR_xop_shav8hi3 = 9099,
  CODE_FOR_xop_shav4si3 = 9100,
  CODE_FOR_xop_shav2di3 = 9101,
  CODE_FOR_xop_shlv16qi3 = 9102,
  CODE_FOR_xop_shlv8hi3 = 9103,
  CODE_FOR_xop_shlv4si3 = 9104,
  CODE_FOR_xop_shlv2di3 = 9105,
  CODE_FOR_xop_frczsf2 = 9107,
  CODE_FOR_xop_frczdf2 = 9108,
  CODE_FOR_xop_frczv4sf2 = 9109,
  CODE_FOR_xop_frczv2df2 = 9110,
  CODE_FOR_xop_frczv8sf2 = 9111,
  CODE_FOR_xop_frczv4df2 = 9112,
  CODE_FOR_xop_maskcmpv16qi3 = 9115,
  CODE_FOR_xop_maskcmpv8hi3 = 9116,
  CODE_FOR_xop_maskcmpv4si3 = 9117,
  CODE_FOR_xop_maskcmpv2di3 = 9118,
  CODE_FOR_xop_maskcmp_unsv16qi3 = 9119,
  CODE_FOR_xop_maskcmp_unsv8hi3 = 9120,
  CODE_FOR_xop_maskcmp_unsv4si3 = 9121,
  CODE_FOR_xop_maskcmp_unsv2di3 = 9122,
  CODE_FOR_xop_maskcmp_uns2v16qi3 = 9123,
  CODE_FOR_xop_maskcmp_uns2v8hi3 = 9124,
  CODE_FOR_xop_maskcmp_uns2v4si3 = 9125,
  CODE_FOR_xop_maskcmp_uns2v2di3 = 9126,
  CODE_FOR_xop_pcom_tfv16qi3 = 9127,
  CODE_FOR_xop_pcom_tfv8hi3 = 9128,
  CODE_FOR_xop_pcom_tfv4si3 = 9129,
  CODE_FOR_xop_pcom_tfv2di3 = 9130,
  CODE_FOR_xop_vpermil2v8sf3 = 9131,
  CODE_FOR_xop_vpermil2v4sf3 = 9132,
  CODE_FOR_xop_vpermil2v4df3 = 9133,
  CODE_FOR_xop_vpermil2v2df3 = 9134,
  CODE_FOR_aesenc = 9135,
  CODE_FOR_aesenclast = 9136,
  CODE_FOR_aesdec = 9137,
  CODE_FOR_aesdeclast = 9138,
  CODE_FOR_aesimc = 9139,
  CODE_FOR_aeskeygenassist = 9140,
  CODE_FOR_pclmulqdq = 9141,
  CODE_FOR_avx_vzeroupper_callee_abi = 9143,
  CODE_FOR_avx2_pbroadcastv16si = 9144,
  CODE_FOR_avx2_pbroadcastv8di = 9145,
  CODE_FOR_avx2_pbroadcastv64qi = 9146,
  CODE_FOR_avx2_pbroadcastv32qi = 9147,
  CODE_FOR_avx2_pbroadcastv16qi = 9148,
  CODE_FOR_avx2_pbroadcastv32hi = 9149,
  CODE_FOR_avx2_pbroadcastv16hi = 9150,
  CODE_FOR_avx2_pbroadcastv8hi = 9151,
  CODE_FOR_avx2_pbroadcastv8si = 9152,
  CODE_FOR_avx2_pbroadcastv4si = 9153,
  CODE_FOR_avx2_pbroadcastv4di = 9154,
  CODE_FOR_avx2_pbroadcastv2di = 9155,
  CODE_FOR_avx2_pbroadcastv32hf = 9156,
  CODE_FOR_avx2_pbroadcastv16hf = 9157,
  CODE_FOR_avx2_pbroadcastv8hf = 9158,
  CODE_FOR_avx2_pbroadcastv32bf = 9159,
  CODE_FOR_avx2_pbroadcastv16bf = 9160,
  CODE_FOR_avx2_pbroadcastv8bf = 9161,
  CODE_FOR_avx2_pbroadcastv32qi_1 = 9162,
  CODE_FOR_avx2_pbroadcastv16hi_1 = 9163,
  CODE_FOR_avx2_pbroadcastv8si_1 = 9164,
  CODE_FOR_avx2_pbroadcastv4di_1 = 9165,
  CODE_FOR_avx2_pbroadcastv16hf_1 = 9166,
  CODE_FOR_avx2_pbroadcastv16bf_1 = 9167,
  CODE_FOR_avx2_permvarv8si = 9168,
  CODE_FOR_avx2_permvarv8si_mask = 9169,
  CODE_FOR_avx2_permvarv8sf = 9170,
  CODE_FOR_avx2_permvarv8sf_mask = 9171,
  CODE_FOR_avx512f_permvarv16si = 9172,
  CODE_FOR_avx512f_permvarv16si_mask = 9173,
  CODE_FOR_avx512f_permvarv16sf = 9174,
  CODE_FOR_avx512f_permvarv16sf_mask = 9175,
  CODE_FOR_avx512f_permvarv8di = 9176,
  CODE_FOR_avx512f_permvarv8di_mask = 9177,
  CODE_FOR_avx512f_permvarv8df = 9178,
  CODE_FOR_avx512f_permvarv8df_mask = 9179,
  CODE_FOR_avx2_permvarv4di = 9180,
  CODE_FOR_avx2_permvarv4di_mask = 9181,
  CODE_FOR_avx2_permvarv4df = 9182,
  CODE_FOR_avx2_permvarv4df_mask = 9183,
  CODE_FOR_avx512bw_permvarv64qi = 9184,
  CODE_FOR_avx512bw_permvarv64qi_mask = 9185,
  CODE_FOR_avx512vl_permvarv16qi = 9186,
  CODE_FOR_avx512vl_permvarv16qi_mask = 9187,
  CODE_FOR_avx512vl_permvarv32qi = 9188,
  CODE_FOR_avx512vl_permvarv32qi_mask = 9189,
  CODE_FOR_avx512vl_permvarv8hi = 9190,
  CODE_FOR_avx512vl_permvarv8hi_mask = 9191,
  CODE_FOR_avx512vl_permvarv16hi = 9192,
  CODE_FOR_avx512vl_permvarv16hi_mask = 9193,
  CODE_FOR_avx512bw_permvarv32hi = 9194,
  CODE_FOR_avx512bw_permvarv32hi_mask = 9195,
  CODE_FOR_avx512fp16_permvarv8hf = 9196,
  CODE_FOR_avx512fp16_permvarv8hf_mask = 9197,
  CODE_FOR_avx512vl_permvarv16hf = 9198,
  CODE_FOR_avx512vl_permvarv16hf_mask = 9199,
  CODE_FOR_avx512bw_permvarv32hf = 9200,
  CODE_FOR_avx512bw_permvarv32hf_mask = 9201,
  CODE_FOR_avx512vl_permvarv8bf = 9202,
  CODE_FOR_avx512vl_permvarv8bf_mask = 9203,
  CODE_FOR_avx512vl_permvarv16bf = 9204,
  CODE_FOR_avx512vl_permvarv16bf_mask = 9205,
  CODE_FOR_avx512bw_permvarv32bf = 9206,
  CODE_FOR_avx512bw_permvarv32bf_mask = 9207,
  CODE_FOR_avx2_permv4di_1 = 9235,
  CODE_FOR_avx2_permv4di_1_mask = 9236,
  CODE_FOR_avx2_permv4df_1 = 9237,
  CODE_FOR_avx2_permv4df_1_mask = 9238,
  CODE_FOR_avx512f_permv8df_1 = 9239,
  CODE_FOR_avx512f_permv8df_1_mask = 9240,
  CODE_FOR_avx512f_permv8di_1 = 9241,
  CODE_FOR_avx512f_permv8di_1_mask = 9242,
  CODE_FOR_avx2_permv2ti = 9243,
  CODE_FOR_avx2_vec_dupv4df = 9244,
  CODE_FOR_avx512f_vec_dupv16si_1 = 9245,
  CODE_FOR_avx512f_vec_dupv8di_1 = 9246,
  CODE_FOR_avx512bw_vec_dupv32hi_1 = 9247,
  CODE_FOR_avx512bw_vec_dupv64qi_1 = 9248,
  CODE_FOR_avx512bw_vec_dupv32hf_1 = 9249,
  CODE_FOR_avx512bw_vec_dupv32bf_1 = 9250,
  CODE_FOR_avx512f_vec_dupv16si = 9251,
  CODE_FOR_avx512f_vec_dupv16si_mask = 9252,
  CODE_FOR_avx512vl_vec_dupv8si = 9253,
  CODE_FOR_avx512vl_vec_dupv8si_mask = 9254,
  CODE_FOR_avx512vl_vec_dupv4si = 9255,
  CODE_FOR_avx512vl_vec_dupv4si_mask = 9256,
  CODE_FOR_avx512f_vec_dupv8di = 9257,
  CODE_FOR_avx512f_vec_dupv8di_mask = 9258,
  CODE_FOR_avx512vl_vec_dupv4di = 9259,
  CODE_FOR_avx512vl_vec_dupv4di_mask = 9260,
  CODE_FOR_avx512vl_vec_dupv2di = 9261,
  CODE_FOR_avx512vl_vec_dupv2di_mask = 9262,
  CODE_FOR_avx512f_vec_dupv16sf = 9263,
  CODE_FOR_avx512f_vec_dupv16sf_mask = 9264,
  CODE_FOR_avx512vl_vec_dupv8sf = 9265,
  CODE_FOR_avx512vl_vec_dupv8sf_mask = 9266,
  CODE_FOR_avx512vl_vec_dupv4sf = 9267,
  CODE_FOR_avx512vl_vec_dupv4sf_mask = 9268,
  CODE_FOR_avx512f_vec_dupv8df = 9269,
  CODE_FOR_avx512f_vec_dupv8df_mask = 9270,
  CODE_FOR_avx512vl_vec_dupv4df = 9271,
  CODE_FOR_avx512vl_vec_dupv4df_mask = 9272,
  CODE_FOR_avx512vl_vec_dupv2df = 9273,
  CODE_FOR_avx512vl_vec_dupv2df_mask = 9274,
  CODE_FOR_avx512bw_vec_dupv64qi = 9275,
  CODE_FOR_avx512bw_vec_dupv64qi_mask = 9276,
  CODE_FOR_avx512vl_vec_dupv16qi = 9277,
  CODE_FOR_avx512vl_vec_dupv16qi_mask = 9278,
  CODE_FOR_avx512vl_vec_dupv32qi = 9279,
  CODE_FOR_avx512vl_vec_dupv32qi_mask = 9280,
  CODE_FOR_avx512bw_vec_dupv32hi = 9281,
  CODE_FOR_avx512bw_vec_dupv32hi_mask = 9282,
  CODE_FOR_avx512vl_vec_dupv16hi = 9283,
  CODE_FOR_avx512vl_vec_dupv16hi_mask = 9284,
  CODE_FOR_avx512vl_vec_dupv8hi = 9285,
  CODE_FOR_avx512vl_vec_dupv8hi_mask = 9286,
  CODE_FOR_avx512bw_vec_dupv32hf = 9287,
  CODE_FOR_avx512bw_vec_dupv32hf_mask = 9288,
  CODE_FOR_avx512vl_vec_dupv16hf = 9289,
  CODE_FOR_avx512vl_vec_dupv16hf_mask = 9290,
  CODE_FOR_avx512fp16_vec_dupv8hf = 9291,
  CODE_FOR_avx512fp16_vec_dupv8hf_mask = 9292,
  CODE_FOR_avx512bw_vec_dupv32bf = 9293,
  CODE_FOR_avx512bw_vec_dupv32bf_mask = 9294,
  CODE_FOR_avx512vl_vec_dupv16bf = 9295,
  CODE_FOR_avx512vl_vec_dupv16bf_mask = 9296,
  CODE_FOR_avx512vl_vec_dupv8bf = 9297,
  CODE_FOR_avx512vl_vec_dupv8bf_mask = 9298,
  CODE_FOR_avx512f_broadcastv16sf_mask = 9300,
  CODE_FOR_avx512f_broadcastv16si_mask = 9302,
  CODE_FOR_avx512f_broadcastv8df_mask = 9304,
  CODE_FOR_avx512f_broadcastv8di_mask = 9306,
  CODE_FOR_avx512bw_vec_dup_gprv64qi_mask = 9308,
  CODE_FOR_avx512vl_vec_dup_gprv16qi_mask = 9310,
  CODE_FOR_avx512vl_vec_dup_gprv32qi_mask = 9312,
  CODE_FOR_avx512bw_vec_dup_gprv32hi_mask = 9314,
  CODE_FOR_avx512vl_vec_dup_gprv16hi_mask = 9316,
  CODE_FOR_avx512vl_vec_dup_gprv8hi_mask = 9318,
  CODE_FOR_avx512bw_vec_dup_gprv32hf_mask = 9320,
  CODE_FOR_avx512vl_vec_dup_gprv16hf_mask = 9322,
  CODE_FOR_avx512fp16_vec_dup_gprv8hf_mask = 9324,
  CODE_FOR_avx512bw_vec_dup_gprv32bf_mask = 9326,
  CODE_FOR_avx512vl_vec_dup_gprv16bf_mask = 9328,
  CODE_FOR_avx512vl_vec_dup_gprv8bf_mask = 9330,
  CODE_FOR_avx512f_vec_dup_gprv16si_mask = 9332,
  CODE_FOR_avx512vl_vec_dup_gprv8si_mask = 9334,
  CODE_FOR_avx512vl_vec_dup_gprv4si_mask = 9336,
  CODE_FOR_avx512f_vec_dup_gprv8di_mask = 9338,
  CODE_FOR_avx512vl_vec_dup_gprv4di_mask = 9340,
  CODE_FOR_avx512vl_vec_dup_gprv2di_mask = 9342,
  CODE_FOR_avx512f_vec_dup_gprv16sf_mask = 9344,
  CODE_FOR_avx512vl_vec_dup_gprv8sf_mask = 9346,
  CODE_FOR_avx512vl_vec_dup_gprv4sf_mask = 9348,
  CODE_FOR_avx512f_vec_dup_gprv8df_mask = 9350,
  CODE_FOR_avx512vl_vec_dup_gprv4df_mask = 9352,
  CODE_FOR_avx512vl_vec_dup_gprv2df_mask = 9354,
  CODE_FOR_vec_dupv4sf = 9355,
  CODE_FOR_avx2_vbroadcasti128_v32qi = 9358,
  CODE_FOR_avx2_vbroadcasti128_v16hi = 9359,
  CODE_FOR_avx2_vbroadcasti128_v8si = 9360,
  CODE_FOR_avx2_vbroadcasti128_v4di = 9361,
  CODE_FOR_avx2_lddqu_inserti_to_bcasti = 9362,
  CODE_FOR_vec_dupv8si = 9373,
  CODE_FOR_vec_dupv8sf = 9374,
  CODE_FOR_vec_dupv4di = 9375,
  CODE_FOR_vec_dupv4df = 9376,
  CODE_FOR_avx_vbroadcastf128_v32qi = 9377,
  CODE_FOR_avx_vbroadcastf128_v16hi = 9378,
  CODE_FOR_avx_vbroadcastf128_v8si = 9379,
  CODE_FOR_avx_vbroadcastf128_v4di = 9380,
  CODE_FOR_avx_vbroadcastf128_v8sf = 9381,
  CODE_FOR_avx_vbroadcastf128_v4df = 9382,
  CODE_FOR_avx_vbroadcastf128_v16hf = 9383,
  CODE_FOR_avx_vbroadcastf128_v16bf = 9384,
  CODE_FOR_avx512dq_broadcastv16si_mask = 9394,
  CODE_FOR_avx512dq_broadcastv8si_mask = 9396,
  CODE_FOR_avx512dq_broadcastv4si_mask = 9398,
  CODE_FOR_avx512dq_broadcastv16sf_mask = 9400,
  CODE_FOR_avx512dq_broadcastv8sf_mask = 9402,
  CODE_FOR_avx512vl_broadcastv8si_mask_1 = 9404,
  CODE_FOR_avx512vl_broadcastv8sf_mask_1 = 9406,
  CODE_FOR_avx512dq_broadcastv16sf_mask_1 = 9408,
  CODE_FOR_avx512dq_broadcastv16si_mask_1 = 9410,
  CODE_FOR_avx512dq_broadcastv8di_mask_1 = 9412,
  CODE_FOR_avx512dq_broadcastv8df_mask_1 = 9414,
  CODE_FOR_avx512dq_broadcastv4di_mask_1 = 9416,
  CODE_FOR_avx512dq_broadcastv4df_mask_1 = 9418,
  CODE_FOR_avx512cd_maskb_vec_dupv8di = 9419,
  CODE_FOR_avx512cd_maskb_vec_dupv4di = 9420,
  CODE_FOR_avx512cd_maskb_vec_dupv2di = 9421,
  CODE_FOR_avx512cd_maskw_vec_dupv16si = 9422,
  CODE_FOR_avx512cd_maskw_vec_dupv8si = 9423,
  CODE_FOR_avx512cd_maskw_vec_dupv4si = 9424,
  CODE_FOR_avx512f_vpermilvarv16sf3 = 9425,
  CODE_FOR_avx512f_vpermilvarv16sf3_mask = 9426,
  CODE_FOR_avx_vpermilvarv8sf3 = 9427,
  CODE_FOR_avx_vpermilvarv8sf3_mask = 9428,
  CODE_FOR_avx_vpermilvarv4sf3 = 9429,
  CODE_FOR_avx_vpermilvarv4sf3_mask = 9430,
  CODE_FOR_avx512f_vpermilvarv8df3 = 9431,
  CODE_FOR_avx512f_vpermilvarv8df3_mask = 9432,
  CODE_FOR_avx_vpermilvarv4df3 = 9433,
  CODE_FOR_avx_vpermilvarv4df3_mask = 9434,
  CODE_FOR_avx_vpermilvarv2df3 = 9435,
  CODE_FOR_avx_vpermilvarv2df3_mask = 9436,
  CODE_FOR_avx512f_vpermt2varv16si3 = 9455,
  CODE_FOR_avx512f_vpermt2varv16si3_maskz_1 = 9456,
  CODE_FOR_avx512f_vpermt2varv16sf3 = 9457,
  CODE_FOR_avx512f_vpermt2varv16sf3_maskz_1 = 9458,
  CODE_FOR_avx512f_vpermt2varv8di3 = 9459,
  CODE_FOR_avx512f_vpermt2varv8di3_maskz_1 = 9460,
  CODE_FOR_avx512f_vpermt2varv8df3 = 9461,
  CODE_FOR_avx512f_vpermt2varv8df3_maskz_1 = 9462,
  CODE_FOR_avx512vl_vpermt2varv8si3 = 9463,
  CODE_FOR_avx512vl_vpermt2varv8si3_maskz_1 = 9464,
  CODE_FOR_avx512vl_vpermt2varv8sf3 = 9465,
  CODE_FOR_avx512vl_vpermt2varv8sf3_maskz_1 = 9466,
  CODE_FOR_avx512vl_vpermt2varv4di3 = 9467,
  CODE_FOR_avx512vl_vpermt2varv4di3_maskz_1 = 9468,
  CODE_FOR_avx512vl_vpermt2varv4df3 = 9469,
  CODE_FOR_avx512vl_vpermt2varv4df3_maskz_1 = 9470,
  CODE_FOR_avx512vl_vpermt2varv4si3 = 9471,
  CODE_FOR_avx512vl_vpermt2varv4si3_maskz_1 = 9472,
  CODE_FOR_avx512vl_vpermt2varv4sf3 = 9473,
  CODE_FOR_avx512vl_vpermt2varv4sf3_maskz_1 = 9474,
  CODE_FOR_avx512vl_vpermt2varv2di3 = 9475,
  CODE_FOR_avx512vl_vpermt2varv2di3_maskz_1 = 9476,
  CODE_FOR_avx512vl_vpermt2varv2df3 = 9477,
  CODE_FOR_avx512vl_vpermt2varv2df3_maskz_1 = 9478,
  CODE_FOR_avx512bw_vpermt2varv32hi3 = 9479,
  CODE_FOR_avx512bw_vpermt2varv32hi3_maskz_1 = 9480,
  CODE_FOR_avx512vl_vpermt2varv16hi3 = 9481,
  CODE_FOR_avx512vl_vpermt2varv16hi3_maskz_1 = 9482,
  CODE_FOR_avx512vl_vpermt2varv8hi3 = 9483,
  CODE_FOR_avx512vl_vpermt2varv8hi3_maskz_1 = 9484,
  CODE_FOR_avx512bw_vpermt2varv64qi3 = 9485,
  CODE_FOR_avx512bw_vpermt2varv64qi3_maskz_1 = 9486,
  CODE_FOR_avx512vl_vpermt2varv32qi3 = 9487,
  CODE_FOR_avx512vl_vpermt2varv32qi3_maskz_1 = 9488,
  CODE_FOR_avx512vl_vpermt2varv16qi3 = 9489,
  CODE_FOR_avx512vl_vpermt2varv16qi3_maskz_1 = 9490,
  CODE_FOR_avx512bw_vpermt2varv32hf3 = 9491,
  CODE_FOR_avx512bw_vpermt2varv32hf3_maskz_1 = 9492,
  CODE_FOR_avx512vl_vpermt2varv16hf3 = 9493,
  CODE_FOR_avx512vl_vpermt2varv16hf3_maskz_1 = 9494,
  CODE_FOR_avx512fp16_vpermt2varv8hf3 = 9495,
  CODE_FOR_avx512fp16_vpermt2varv8hf3_maskz_1 = 9496,
  CODE_FOR_avx512bw_vpermt2varv32bf3 = 9497,
  CODE_FOR_avx512bw_vpermt2varv32bf3_maskz_1 = 9498,
  CODE_FOR_avx512vl_vpermt2varv16bf3 = 9499,
  CODE_FOR_avx512vl_vpermt2varv16bf3_maskz_1 = 9500,
  CODE_FOR_avx512vl_vpermt2varv8bf3 = 9501,
  CODE_FOR_avx512vl_vpermt2varv8bf3_maskz_1 = 9502,
  CODE_FOR_avx512f_vpermt2varv16si3_mask = 9503,
  CODE_FOR_avx512f_vpermt2varv16sf3_mask = 9504,
  CODE_FOR_avx512f_vpermt2varv8di3_mask = 9505,
  CODE_FOR_avx512f_vpermt2varv8df3_mask = 9506,
  CODE_FOR_avx512vl_vpermt2varv8si3_mask = 9507,
  CODE_FOR_avx512vl_vpermt2varv8sf3_mask = 9508,
  CODE_FOR_avx512vl_vpermt2varv4di3_mask = 9509,
  CODE_FOR_avx512vl_vpermt2varv4df3_mask = 9510,
  CODE_FOR_avx512vl_vpermt2varv4si3_mask = 9511,
  CODE_FOR_avx512vl_vpermt2varv4sf3_mask = 9512,
  CODE_FOR_avx512vl_vpermt2varv2di3_mask = 9513,
  CODE_FOR_avx512vl_vpermt2varv2df3_mask = 9514,
  CODE_FOR_avx512bw_vpermt2varv32hi3_mask = 9515,
  CODE_FOR_avx512vl_vpermt2varv16hi3_mask = 9516,
  CODE_FOR_avx512vl_vpermt2varv8hi3_mask = 9517,
  CODE_FOR_avx512bw_vpermt2varv64qi3_mask = 9518,
  CODE_FOR_avx512vl_vpermt2varv32qi3_mask = 9519,
  CODE_FOR_avx512vl_vpermt2varv16qi3_mask = 9520,
  CODE_FOR_vec_set_lo_v4di = 9535,
  CODE_FOR_vec_set_lo_v4di_mask = 9536,
  CODE_FOR_vec_set_lo_v4df = 9537,
  CODE_FOR_vec_set_lo_v4df_mask = 9538,
  CODE_FOR_vec_set_hi_v4di = 9539,
  CODE_FOR_vec_set_hi_v4di_mask = 9540,
  CODE_FOR_vec_set_hi_v4df = 9541,
  CODE_FOR_vec_set_hi_v4df_mask = 9542,
  CODE_FOR_vec_set_lo_v8si = 9543,
  CODE_FOR_vec_set_lo_v8si_mask = 9544,
  CODE_FOR_vec_set_lo_v8sf = 9545,
  CODE_FOR_vec_set_lo_v8sf_mask = 9546,
  CODE_FOR_vec_set_hi_v8si = 9547,
  CODE_FOR_vec_set_hi_v8si_mask = 9548,
  CODE_FOR_vec_set_hi_v8sf = 9549,
  CODE_FOR_vec_set_hi_v8sf_mask = 9550,
  CODE_FOR_vec_set_lo_v16hi = 9551,
  CODE_FOR_vec_set_lo_v16hf = 9552,
  CODE_FOR_vec_set_lo_v16bf = 9553,
  CODE_FOR_vec_set_hi_v16hi = 9554,
  CODE_FOR_vec_set_hi_v16hf = 9555,
  CODE_FOR_vec_set_hi_v16bf = 9556,
  CODE_FOR_vec_set_lo_v32qi = 9557,
  CODE_FOR_vec_set_hi_v32qi = 9558,
  CODE_FOR_avx_maskloadps = 9559,
  CODE_FOR_avx_maskloadpd = 9560,
  CODE_FOR_avx2_maskloadq256 = 9561,
  CODE_FOR_avx2_maskloadq = 9562,
  CODE_FOR_avx_maskloadps256 = 9563,
  CODE_FOR_avx_maskloadpd256 = 9564,
  CODE_FOR_avx2_maskloadd256 = 9565,
  CODE_FOR_avx2_maskloadd = 9566,
  CODE_FOR_avx_maskstoreps = 9567,
  CODE_FOR_avx_maskstorepd = 9568,
  CODE_FOR_avx2_maskstoreq256 = 9569,
  CODE_FOR_avx2_maskstoreq = 9570,
  CODE_FOR_avx_maskstoreps256 = 9571,
  CODE_FOR_avx_maskstorepd256 = 9572,
  CODE_FOR_avx2_maskstored256 = 9573,
  CODE_FOR_avx2_maskstored = 9574,
  CODE_FOR_avx512f_storev16si_mask = 9575,
  CODE_FOR_avx512vl_storev8si_mask = 9576,
  CODE_FOR_avx512vl_storev4si_mask = 9577,
  CODE_FOR_avx512f_storev8di_mask = 9578,
  CODE_FOR_avx512vl_storev4di_mask = 9579,
  CODE_FOR_avx512vl_storev2di_mask = 9580,
  CODE_FOR_avx512f_storev16sf_mask = 9581,
  CODE_FOR_avx512vl_storev8sf_mask = 9582,
  CODE_FOR_avx512vl_storev4sf_mask = 9583,
  CODE_FOR_avx512f_storev8df_mask = 9584,
  CODE_FOR_avx512vl_storev4df_mask = 9585,
  CODE_FOR_avx512vl_storev2df_mask = 9586,
  CODE_FOR_avx512bw_storev64qi_mask = 9587,
  CODE_FOR_avx512vl_storev16qi_mask = 9588,
  CODE_FOR_avx512vl_storev32qi_mask = 9589,
  CODE_FOR_avx512bw_storev32hi_mask = 9590,
  CODE_FOR_avx512vl_storev16hi_mask = 9591,
  CODE_FOR_avx512vl_storev8hi_mask = 9592,
  CODE_FOR_avx512bw_storev32hf_mask = 9593,
  CODE_FOR_avx512vl_storev16hf_mask = 9594,
  CODE_FOR_avx512fp16_storev8hf_mask = 9595,
  CODE_FOR_avx512bw_storev32bf_mask = 9596,
  CODE_FOR_avx512vl_storev16bf_mask = 9597,
  CODE_FOR_avx512vl_storev8bf_mask = 9598,
  CODE_FOR_avx_si256_si = 9623,
  CODE_FOR_avx_ps256_ps = 9624,
  CODE_FOR_avx_pd256_pd = 9625,
  CODE_FOR_avx2_ashrvv4si = 9626,
  CODE_FOR_avx2_ashrvv4si_mask = 9627,
  CODE_FOR_avx2_ashrvv8si = 9628,
  CODE_FOR_avx2_ashrvv8si_mask = 9629,
  CODE_FOR_avx512f_ashrvv16si = 9630,
  CODE_FOR_avx512f_ashrvv16si_mask = 9631,
  CODE_FOR_avx2_ashrvv2di = 9632,
  CODE_FOR_avx2_ashrvv2di_mask = 9633,
  CODE_FOR_avx2_ashrvv4di = 9634,
  CODE_FOR_avx2_ashrvv4di_mask = 9635,
  CODE_FOR_avx512f_ashrvv8di = 9636,
  CODE_FOR_avx512f_ashrvv8di_mask = 9637,
  CODE_FOR_avx512vl_ashrvv8hi = 9638,
  CODE_FOR_avx512vl_ashrvv8hi_mask = 9639,
  CODE_FOR_avx512vl_ashrvv16hi = 9640,
  CODE_FOR_avx512vl_ashrvv16hi_mask = 9641,
  CODE_FOR_avx512bw_ashrvv32hi = 9642,
  CODE_FOR_avx512bw_ashrvv32hi_mask = 9643,
  CODE_FOR_avx512f_ashlvv16si = 9644,
  CODE_FOR_avx512f_ashlvv16si_mask = 9645,
  CODE_FOR_avx512f_lshrvv16si = 9646,
  CODE_FOR_avx512f_lshrvv16si_mask = 9647,
  CODE_FOR_avx2_ashlvv8si = 9648,
  CODE_FOR_avx2_ashlvv8si_mask = 9649,
  CODE_FOR_avx2_lshrvv8si = 9650,
  CODE_FOR_avx2_lshrvv8si_mask = 9651,
  CODE_FOR_avx2_ashlvv4si = 9652,
  CODE_FOR_avx2_ashlvv4si_mask = 9653,
  CODE_FOR_avx2_lshrvv4si = 9654,
  CODE_FOR_avx2_lshrvv4si_mask = 9655,
  CODE_FOR_avx512f_ashlvv8di = 9656,
  CODE_FOR_avx512f_ashlvv8di_mask = 9657,
  CODE_FOR_avx512f_lshrvv8di = 9658,
  CODE_FOR_avx512f_lshrvv8di_mask = 9659,
  CODE_FOR_avx2_ashlvv4di = 9660,
  CODE_FOR_avx2_ashlvv4di_mask = 9661,
  CODE_FOR_avx2_lshrvv4di = 9662,
  CODE_FOR_avx2_lshrvv4di_mask = 9663,
  CODE_FOR_avx2_ashlvv2di = 9664,
  CODE_FOR_avx2_ashlvv2di_mask = 9665,
  CODE_FOR_avx2_lshrvv2di = 9666,
  CODE_FOR_avx2_lshrvv2di_mask = 9667,
  CODE_FOR_avx512vl_ashlvv8hi = 9668,
  CODE_FOR_avx512vl_ashlvv8hi_mask = 9669,
  CODE_FOR_avx512vl_lshrvv8hi = 9670,
  CODE_FOR_avx512vl_lshrvv8hi_mask = 9671,
  CODE_FOR_avx512vl_ashlvv16hi = 9672,
  CODE_FOR_avx512vl_ashlvv16hi_mask = 9673,
  CODE_FOR_avx512vl_lshrvv16hi = 9674,
  CODE_FOR_avx512vl_lshrvv16hi_mask = 9675,
  CODE_FOR_avx512bw_ashlvv32hi = 9676,
  CODE_FOR_avx512bw_ashlvv32hi_mask = 9677,
  CODE_FOR_avx512bw_lshrvv32hi = 9678,
  CODE_FOR_avx512bw_lshrvv32hi_mask = 9679,
  CODE_FOR_avx_vec_concatv32qi = 9680,
  CODE_FOR_avx_vec_concatv16hi = 9681,
  CODE_FOR_avx_vec_concatv16hf = 9682,
  CODE_FOR_avx_vec_concatv16bf = 9683,
  CODE_FOR_avx_vec_concatv8si = 9684,
  CODE_FOR_avx_vec_concatv4di = 9685,
  CODE_FOR_avx_vec_concatv8sf = 9686,
  CODE_FOR_avx_vec_concatv4df = 9687,
  CODE_FOR_avx_vec_concatv64qi = 9688,
  CODE_FOR_avx_vec_concatv32hi = 9689,
  CODE_FOR_avx_vec_concatv32hf = 9690,
  CODE_FOR_avx_vec_concatv32bf = 9691,
  CODE_FOR_avx_vec_concatv16si = 9692,
  CODE_FOR_avx_vec_concatv8di = 9693,
  CODE_FOR_avx_vec_concatv16sf = 9694,
  CODE_FOR_avx_vec_concatv8df = 9695,
  CODE_FOR_vcvtph2ps = 9720,
  CODE_FOR_vcvtph2ps_mask = 9721,
  CODE_FOR_vcvtph2ps256 = 9724,
  CODE_FOR_vcvtph2ps256_mask = 9725,
  CODE_FOR_avx512f_vcvtph2ps512_mask = 9728,
  CODE_FOR_avx512f_vcvtph2ps512_mask_round = 9729,
  CODE_FOR_vcvtps2ph256 = 9733,
  CODE_FOR_vcvtps2ph256_mask = 9734,
  CODE_FOR_avx512f_vcvtps2ph512_mask = 9739,
  CODE_FOR_avx512f_vcvtps2ph512_mask_round = 9740,
  CODE_FOR_avx512f_compressv16si_mask = 9959,
  CODE_FOR_avx512f_compressv16sf_mask = 9960,
  CODE_FOR_avx512f_compressv8di_mask = 9961,
  CODE_FOR_avx512f_compressv8df_mask = 9962,
  CODE_FOR_avx512vl_compressv8si_mask = 9963,
  CODE_FOR_avx512vl_compressv8sf_mask = 9964,
  CODE_FOR_avx512vl_compressv4di_mask = 9965,
  CODE_FOR_avx512vl_compressv4df_mask = 9966,
  CODE_FOR_avx512vl_compressv4si_mask = 9967,
  CODE_FOR_avx512vl_compressv4sf_mask = 9968,
  CODE_FOR_avx512vl_compressv2di_mask = 9969,
  CODE_FOR_avx512vl_compressv2df_mask = 9970,
  CODE_FOR_compressv64qi_mask = 9971,
  CODE_FOR_compressv16qi_mask = 9972,
  CODE_FOR_compressv32qi_mask = 9973,
  CODE_FOR_compressv32hi_mask = 9974,
  CODE_FOR_compressv16hi_mask = 9975,
  CODE_FOR_compressv8hi_mask = 9976,
  CODE_FOR_avx512f_compressstorev16si_mask = 9977,
  CODE_FOR_avx512f_compressstorev16sf_mask = 9978,
  CODE_FOR_avx512f_compressstorev8di_mask = 9979,
  CODE_FOR_avx512f_compressstorev8df_mask = 9980,
  CODE_FOR_avx512vl_compressstorev8si_mask = 9981,
  CODE_FOR_avx512vl_compressstorev8sf_mask = 9982,
  CODE_FOR_avx512vl_compressstorev4di_mask = 9983,
  CODE_FOR_avx512vl_compressstorev4df_mask = 9984,
  CODE_FOR_avx512vl_compressstorev4si_mask = 9985,
  CODE_FOR_avx512vl_compressstorev4sf_mask = 9986,
  CODE_FOR_avx512vl_compressstorev2di_mask = 9987,
  CODE_FOR_avx512vl_compressstorev2df_mask = 9988,
  CODE_FOR_compressstorev64qi_mask = 9989,
  CODE_FOR_compressstorev16qi_mask = 9990,
  CODE_FOR_compressstorev32qi_mask = 9991,
  CODE_FOR_compressstorev32hi_mask = 9992,
  CODE_FOR_compressstorev16hi_mask = 9993,
  CODE_FOR_compressstorev8hi_mask = 9994,
  CODE_FOR_expandv16si_mask = 9995,
  CODE_FOR_expandv16sf_mask = 9996,
  CODE_FOR_expandv8di_mask = 9997,
  CODE_FOR_expandv8df_mask = 9998,
  CODE_FOR_expandv8si_mask = 9999,
  CODE_FOR_expandv8sf_mask = 10000,
  CODE_FOR_expandv4di_mask = 10001,
  CODE_FOR_expandv4df_mask = 10002,
  CODE_FOR_expandv4si_mask = 10003,
  CODE_FOR_expandv4sf_mask = 10004,
  CODE_FOR_expandv2di_mask = 10005,
  CODE_FOR_expandv2df_mask = 10006,
  CODE_FOR_expandv64qi_mask = 10007,
  CODE_FOR_expandv16qi_mask = 10008,
  CODE_FOR_expandv32qi_mask = 10009,
  CODE_FOR_expandv32hi_mask = 10010,
  CODE_FOR_expandv16hi_mask = 10011,
  CODE_FOR_expandv8hi_mask = 10012,
  CODE_FOR_avx512dq_rangepv16sf = 10031,
  CODE_FOR_avx512dq_rangepv16sf_round = 10032,
  CODE_FOR_avx512dq_rangepv16sf_mask = 10033,
  CODE_FOR_avx512dq_rangepv16sf_mask_round = 10034,
  CODE_FOR_avx512dq_rangepv8sf = 10035,
   CODE_FOR_avx512dq_rangepv8sf_round = CODE_FOR_nothing,
  CODE_FOR_avx512dq_rangepv8sf_mask = 10036,
   CODE_FOR_avx512dq_rangepv8sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512dq_rangepv4sf = 10037,
   CODE_FOR_avx512dq_rangepv4sf_round = CODE_FOR_nothing,
  CODE_FOR_avx512dq_rangepv4sf_mask = 10038,
   CODE_FOR_avx512dq_rangepv4sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512dq_rangepv8df = 10039,
  CODE_FOR_avx512dq_rangepv8df_round = 10040,
  CODE_FOR_avx512dq_rangepv8df_mask = 10041,
  CODE_FOR_avx512dq_rangepv8df_mask_round = 10042,
  CODE_FOR_avx512dq_rangepv4df = 10043,
   CODE_FOR_avx512dq_rangepv4df_round = CODE_FOR_nothing,
  CODE_FOR_avx512dq_rangepv4df_mask = 10044,
   CODE_FOR_avx512dq_rangepv4df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512dq_rangepv2df = 10045,
   CODE_FOR_avx512dq_rangepv2df_round = CODE_FOR_nothing,
  CODE_FOR_avx512dq_rangepv2df_mask = 10046,
   CODE_FOR_avx512dq_rangepv2df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512dq_rangesv4sf = 10047,
  CODE_FOR_avx512dq_rangesv4sf_mask = 10048,
  CODE_FOR_avx512dq_rangesv4sf_round = 10049,
  CODE_FOR_avx512dq_rangesv4sf_mask_round = 10050,
  CODE_FOR_avx512dq_rangesv2df = 10051,
  CODE_FOR_avx512dq_rangesv2df_mask = 10052,
  CODE_FOR_avx512dq_rangesv2df_round = 10053,
  CODE_FOR_avx512dq_rangesv2df_mask_round = 10054,
  CODE_FOR_avx512dq_fpclassv32hf = 10055,
  CODE_FOR_avx512dq_fpclassv32hf_mask = 10056,
  CODE_FOR_avx512dq_fpclassv16hf = 10057,
  CODE_FOR_avx512dq_fpclassv16hf_mask = 10058,
  CODE_FOR_avx512dq_fpclassv8hf = 10059,
  CODE_FOR_avx512dq_fpclassv8hf_mask = 10060,
  CODE_FOR_avx512dq_fpclassv16sf = 10061,
  CODE_FOR_avx512dq_fpclassv16sf_mask = 10062,
  CODE_FOR_avx512dq_fpclassv8sf = 10063,
  CODE_FOR_avx512dq_fpclassv8sf_mask = 10064,
  CODE_FOR_avx512dq_fpclassv4sf = 10065,
  CODE_FOR_avx512dq_fpclassv4sf_mask = 10066,
  CODE_FOR_avx512dq_fpclassv8df = 10067,
  CODE_FOR_avx512dq_fpclassv8df_mask = 10068,
  CODE_FOR_avx512dq_fpclassv4df = 10069,
  CODE_FOR_avx512dq_fpclassv4df_mask = 10070,
  CODE_FOR_avx512dq_fpclassv2df = 10071,
  CODE_FOR_avx512dq_fpclassv2df_mask = 10072,
  CODE_FOR_avx512dq_vmfpclassv8hf = 10073,
  CODE_FOR_avx512dq_vmfpclassv8hf_mask = 10074,
  CODE_FOR_avx512dq_vmfpclassv4sf = 10075,
  CODE_FOR_avx512dq_vmfpclassv4sf_mask = 10076,
  CODE_FOR_avx512dq_vmfpclassv2df = 10077,
  CODE_FOR_avx512dq_vmfpclassv2df_mask = 10078,
  CODE_FOR_avx512bw_getmantv32hf = 10079,
  CODE_FOR_avx512bw_getmantv32hf_round = 10080,
  CODE_FOR_avx512bw_getmantv32hf_mask = 10081,
  CODE_FOR_avx512bw_getmantv32hf_mask_round = 10082,
  CODE_FOR_avx512vl_getmantv16hf = 10083,
  CODE_FOR_avx512vl_getmantv16hf_round = 10084,
  CODE_FOR_avx512vl_getmantv16hf_mask = 10085,
  CODE_FOR_avx512vl_getmantv16hf_mask_round = 10086,
  CODE_FOR_avx512fp16_getmantv8hf = 10087,
  CODE_FOR_avx512fp16_getmantv8hf_round = 10088,
  CODE_FOR_avx512fp16_getmantv8hf_mask = 10089,
  CODE_FOR_avx512fp16_getmantv8hf_mask_round = 10090,
  CODE_FOR_avx512f_getmantv16sf = 10091,
  CODE_FOR_avx512f_getmantv16sf_round = 10092,
  CODE_FOR_avx512f_getmantv16sf_mask = 10093,
  CODE_FOR_avx512f_getmantv16sf_mask_round = 10094,
  CODE_FOR_avx512vl_getmantv8sf = 10095,
  CODE_FOR_avx512vl_getmantv8sf_round = 10096,
  CODE_FOR_avx512vl_getmantv8sf_mask = 10097,
  CODE_FOR_avx512vl_getmantv8sf_mask_round = 10098,
  CODE_FOR_avx512vl_getmantv4sf = 10099,
  CODE_FOR_avx512vl_getmantv4sf_round = 10100,
  CODE_FOR_avx512vl_getmantv4sf_mask = 10101,
  CODE_FOR_avx512vl_getmantv4sf_mask_round = 10102,
  CODE_FOR_avx512f_getmantv8df = 10103,
  CODE_FOR_avx512f_getmantv8df_round = 10104,
  CODE_FOR_avx512f_getmantv8df_mask = 10105,
  CODE_FOR_avx512f_getmantv8df_mask_round = 10106,
  CODE_FOR_avx512vl_getmantv4df = 10107,
  CODE_FOR_avx512vl_getmantv4df_round = 10108,
  CODE_FOR_avx512vl_getmantv4df_mask = 10109,
  CODE_FOR_avx512vl_getmantv4df_mask_round = 10110,
  CODE_FOR_avx512vl_getmantv2df = 10111,
  CODE_FOR_avx512vl_getmantv2df_round = 10112,
  CODE_FOR_avx512vl_getmantv2df_mask = 10113,
  CODE_FOR_avx512vl_getmantv2df_mask_round = 10114,
  CODE_FOR_avx512f_vgetmantv8hf = 10115,
  CODE_FOR_avx512f_vgetmantv8hf_mask = 10116,
  CODE_FOR_avx512f_vgetmantv8hf_round = 10117,
  CODE_FOR_avx512f_vgetmantv8hf_mask_round = 10118,
  CODE_FOR_avx512f_vgetmantv4sf = 10119,
  CODE_FOR_avx512f_vgetmantv4sf_mask = 10120,
  CODE_FOR_avx512f_vgetmantv4sf_round = 10121,
  CODE_FOR_avx512f_vgetmantv4sf_mask_round = 10122,
  CODE_FOR_avx512f_vgetmantv2df = 10123,
  CODE_FOR_avx512f_vgetmantv2df_mask = 10124,
  CODE_FOR_avx512f_vgetmantv2df_round = 10125,
  CODE_FOR_avx512f_vgetmantv2df_mask_round = 10126,
  CODE_FOR_avx512bw_dbpsadbwv8hi_mask = 10128,
  CODE_FOR_avx512bw_dbpsadbwv16hi_mask = 10130,
  CODE_FOR_avx512bw_dbpsadbwv32hi_mask = 10132,
  CODE_FOR_clzv16si2 = 10133,
  CODE_FOR_clzv16si2_mask = 10134,
  CODE_FOR_clzv8si2 = 10135,
  CODE_FOR_clzv8si2_mask = 10136,
  CODE_FOR_clzv4si2 = 10137,
  CODE_FOR_clzv4si2_mask = 10138,
  CODE_FOR_clzv8di2 = 10139,
  CODE_FOR_clzv8di2_mask = 10140,
  CODE_FOR_clzv4di2 = 10141,
  CODE_FOR_clzv4di2_mask = 10142,
  CODE_FOR_clzv2di2 = 10143,
  CODE_FOR_clzv2di2_mask = 10144,
  CODE_FOR_conflictv16si_mask = 10146,
  CODE_FOR_conflictv8si_mask = 10148,
  CODE_FOR_conflictv4si_mask = 10150,
  CODE_FOR_conflictv8di_mask = 10152,
  CODE_FOR_conflictv4di_mask = 10154,
  CODE_FOR_conflictv2di_mask = 10156,
  CODE_FOR_sha1msg1 = 10157,
  CODE_FOR_sha1msg2 = 10158,
  CODE_FOR_sha1nexte = 10159,
  CODE_FOR_sha1rnds4 = 10160,
  CODE_FOR_sha256msg1 = 10161,
  CODE_FOR_sha256msg2 = 10162,
  CODE_FOR_sha256rnds2 = 10163,
  CODE_FOR_vsm3msg1 = 10164,
  CODE_FOR_vsm3msg2 = 10165,
  CODE_FOR_vsm3rnds2 = 10166,
  CODE_FOR_vsha512msg1 = 10167,
  CODE_FOR_vsha512msg2 = 10168,
  CODE_FOR_vsha512rnds2 = 10169,
  CODE_FOR_vsm4key4_v16si = 10170,
  CODE_FOR_vsm4key4_v8si = 10171,
  CODE_FOR_vsm4key4_v4si = 10172,
  CODE_FOR_vsm4rnds4_v16si = 10173,
  CODE_FOR_vsm4rnds4_v8si = 10174,
  CODE_FOR_vsm4rnds4_v4si = 10175,
  CODE_FOR_avx512f_si512_si = 10176,
  CODE_FOR_avx512f_ps512_ps = 10177,
  CODE_FOR_avx512f_pd512_pd = 10178,
  CODE_FOR_avx512f_si512_256si = 10179,
  CODE_FOR_avx512f_ps512_256ps = 10180,
  CODE_FOR_avx512f_pd512_256pd = 10181,
  CODE_FOR_vpmadd52luqv8di = 10182,
  CODE_FOR_vpmadd52huqv8di = 10183,
  CODE_FOR_vpmadd52luqv4di = 10184,
  CODE_FOR_vpmadd52huqv4di = 10185,
  CODE_FOR_vpmadd52luqv2di = 10186,
  CODE_FOR_vpmadd52huqv2di = 10187,
  CODE_FOR_vpmadd52luqv8di_maskz_1 = 10188,
  CODE_FOR_vpmadd52huqv8di_maskz_1 = 10189,
  CODE_FOR_vpmadd52luqv4di_maskz_1 = 10190,
  CODE_FOR_vpmadd52huqv4di_maskz_1 = 10191,
  CODE_FOR_vpmadd52luqv2di_maskz_1 = 10192,
  CODE_FOR_vpmadd52huqv2di_maskz_1 = 10193,
  CODE_FOR_vpmadd52luqv8di_mask = 10194,
  CODE_FOR_vpmadd52huqv8di_mask = 10195,
  CODE_FOR_vpmadd52luqv4di_mask = 10196,
  CODE_FOR_vpmadd52huqv4di_mask = 10197,
  CODE_FOR_vpmadd52luqv2di_mask = 10198,
  CODE_FOR_vpmadd52huqv2di_mask = 10199,
  CODE_FOR_vpmultishiftqbv64qi = 10200,
  CODE_FOR_vpmultishiftqbv64qi_mask = 10201,
  CODE_FOR_vpmultishiftqbv16qi = 10202,
  CODE_FOR_vpmultishiftqbv16qi_mask = 10203,
  CODE_FOR_vpmultishiftqbv32qi = 10204,
  CODE_FOR_vpmultishiftqbv32qi_mask = 10205,
  CODE_FOR_vpopcountv16si = 10206,
  CODE_FOR_vpopcountv16si_mask = 10207,
  CODE_FOR_vpopcountv8si = 10208,
  CODE_FOR_vpopcountv8si_mask = 10209,
  CODE_FOR_vpopcountv4si = 10210,
  CODE_FOR_vpopcountv4si_mask = 10211,
  CODE_FOR_vpopcountv8di = 10212,
  CODE_FOR_vpopcountv8di_mask = 10213,
  CODE_FOR_vpopcountv4di = 10214,
  CODE_FOR_vpopcountv4di_mask = 10215,
  CODE_FOR_vpopcountv2di = 10216,
  CODE_FOR_vpopcountv2di_mask = 10217,
  CODE_FOR_vpopcountv64qi = 10226,
  CODE_FOR_vpopcountv64qi_mask = 10227,
  CODE_FOR_vpopcountv16qi = 10228,
  CODE_FOR_vpopcountv16qi_mask = 10229,
  CODE_FOR_vpopcountv32qi = 10230,
  CODE_FOR_vpopcountv32qi_mask = 10231,
  CODE_FOR_vpopcountv32hi = 10232,
  CODE_FOR_vpopcountv32hi_mask = 10233,
  CODE_FOR_vpopcountv16hi = 10234,
  CODE_FOR_vpopcountv16hi_mask = 10235,
  CODE_FOR_vpopcountv8hi = 10236,
  CODE_FOR_vpopcountv8hi_mask = 10237,
  CODE_FOR_vgf2p8affineinvqb_v64qi = 10238,
  CODE_FOR_vgf2p8affineinvqb_v64qi_mask = 10239,
  CODE_FOR_vgf2p8affineinvqb_v32qi = 10240,
  CODE_FOR_vgf2p8affineinvqb_v32qi_mask = 10241,
  CODE_FOR_vgf2p8affineinvqb_v16qi = 10242,
  CODE_FOR_vgf2p8affineinvqb_v16qi_mask = 10243,
  CODE_FOR_vgf2p8affineqb_v64qi = 10244,
  CODE_FOR_vgf2p8affineqb_v64qi_mask = 10245,
  CODE_FOR_vgf2p8affineqb_v32qi = 10246,
  CODE_FOR_vgf2p8affineqb_v32qi_mask = 10247,
  CODE_FOR_vgf2p8affineqb_v16qi = 10248,
  CODE_FOR_vgf2p8affineqb_v16qi_mask = 10249,
  CODE_FOR_vgf2p8mulb_v64qi = 10250,
  CODE_FOR_vgf2p8mulb_v64qi_mask = 10251,
  CODE_FOR_vgf2p8mulb_v32qi = 10252,
  CODE_FOR_vgf2p8mulb_v32qi_mask = 10253,
  CODE_FOR_vgf2p8mulb_v16qi = 10254,
  CODE_FOR_vgf2p8mulb_v16qi_mask = 10255,
  CODE_FOR_vpshrd_v32hi = 10256,
  CODE_FOR_vpshrd_v32hi_mask = 10257,
  CODE_FOR_vpshrd_v16si = 10258,
  CODE_FOR_vpshrd_v16si_mask = 10259,
  CODE_FOR_vpshrd_v8di = 10260,
  CODE_FOR_vpshrd_v8di_mask = 10261,
  CODE_FOR_vpshrd_v16hi = 10262,
  CODE_FOR_vpshrd_v16hi_mask = 10263,
  CODE_FOR_vpshrd_v8si = 10264,
  CODE_FOR_vpshrd_v8si_mask = 10265,
  CODE_FOR_vpshrd_v4di = 10266,
  CODE_FOR_vpshrd_v4di_mask = 10267,
  CODE_FOR_vpshrd_v8hi = 10268,
  CODE_FOR_vpshrd_v8hi_mask = 10269,
  CODE_FOR_vpshrd_v4si = 10270,
  CODE_FOR_vpshrd_v4si_mask = 10271,
  CODE_FOR_vpshrd_v2di = 10272,
  CODE_FOR_vpshrd_v2di_mask = 10273,
  CODE_FOR_vpshld_v32hi = 10274,
  CODE_FOR_vpshld_v32hi_mask = 10275,
  CODE_FOR_vpshld_v16si = 10276,
  CODE_FOR_vpshld_v16si_mask = 10277,
  CODE_FOR_vpshld_v8di = 10278,
  CODE_FOR_vpshld_v8di_mask = 10279,
  CODE_FOR_vpshld_v16hi = 10280,
  CODE_FOR_vpshld_v16hi_mask = 10281,
  CODE_FOR_vpshld_v8si = 10282,
  CODE_FOR_vpshld_v8si_mask = 10283,
  CODE_FOR_vpshld_v4di = 10284,
  CODE_FOR_vpshld_v4di_mask = 10285,
  CODE_FOR_vpshld_v8hi = 10286,
  CODE_FOR_vpshld_v8hi_mask = 10287,
  CODE_FOR_vpshld_v4si = 10288,
  CODE_FOR_vpshld_v4si_mask = 10289,
  CODE_FOR_vpshld_v2di = 10290,
  CODE_FOR_vpshld_v2di_mask = 10291,
  CODE_FOR_vpshrdv_v32hi = 10292,
  CODE_FOR_vpshrdv_v16si = 10293,
  CODE_FOR_vpshrdv_v8di = 10294,
  CODE_FOR_vpshrdv_v16hi = 10295,
  CODE_FOR_vpshrdv_v8si = 10296,
  CODE_FOR_vpshrdv_v4di = 10297,
  CODE_FOR_vpshrdv_v8hi = 10298,
  CODE_FOR_vpshrdv_v4si = 10299,
  CODE_FOR_vpshrdv_v2di = 10300,
  CODE_FOR_vpshrdv_v32hi_mask = 10301,
  CODE_FOR_vpshrdv_v16si_mask = 10302,
  CODE_FOR_vpshrdv_v8di_mask = 10303,
  CODE_FOR_vpshrdv_v16hi_mask = 10304,
  CODE_FOR_vpshrdv_v8si_mask = 10305,
  CODE_FOR_vpshrdv_v4di_mask = 10306,
  CODE_FOR_vpshrdv_v8hi_mask = 10307,
  CODE_FOR_vpshrdv_v4si_mask = 10308,
  CODE_FOR_vpshrdv_v2di_mask = 10309,
  CODE_FOR_vpshrdv_v32hi_maskz_1 = 10310,
  CODE_FOR_vpshrdv_v16si_maskz_1 = 10311,
  CODE_FOR_vpshrdv_v8di_maskz_1 = 10312,
  CODE_FOR_vpshrdv_v16hi_maskz_1 = 10313,
  CODE_FOR_vpshrdv_v8si_maskz_1 = 10314,
  CODE_FOR_vpshrdv_v4di_maskz_1 = 10315,
  CODE_FOR_vpshrdv_v8hi_maskz_1 = 10316,
  CODE_FOR_vpshrdv_v4si_maskz_1 = 10317,
  CODE_FOR_vpshrdv_v2di_maskz_1 = 10318,
  CODE_FOR_vpshldv_v32hi = 10319,
  CODE_FOR_vpshldv_v16si = 10320,
  CODE_FOR_vpshldv_v8di = 10321,
  CODE_FOR_vpshldv_v16hi = 10322,
  CODE_FOR_vpshldv_v8si = 10323,
  CODE_FOR_vpshldv_v4di = 10324,
  CODE_FOR_vpshldv_v8hi = 10325,
  CODE_FOR_vpshldv_v4si = 10326,
  CODE_FOR_vpshldv_v2di = 10327,
  CODE_FOR_vpshldv_v32hi_mask = 10328,
  CODE_FOR_vpshldv_v16si_mask = 10329,
  CODE_FOR_vpshldv_v8di_mask = 10330,
  CODE_FOR_vpshldv_v16hi_mask = 10331,
  CODE_FOR_vpshldv_v8si_mask = 10332,
  CODE_FOR_vpshldv_v4di_mask = 10333,
  CODE_FOR_vpshldv_v8hi_mask = 10334,
  CODE_FOR_vpshldv_v4si_mask = 10335,
  CODE_FOR_vpshldv_v2di_mask = 10336,
  CODE_FOR_vpshldv_v32hi_maskz_1 = 10337,
  CODE_FOR_vpshldv_v16si_maskz_1 = 10338,
  CODE_FOR_vpshldv_v8di_maskz_1 = 10339,
  CODE_FOR_vpshldv_v16hi_maskz_1 = 10340,
  CODE_FOR_vpshldv_v8si_maskz_1 = 10341,
  CODE_FOR_vpshldv_v4di_maskz_1 = 10342,
  CODE_FOR_vpshldv_v8hi_maskz_1 = 10343,
  CODE_FOR_vpshldv_v4si_maskz_1 = 10344,
  CODE_FOR_vpshldv_v2di_maskz_1 = 10345,
  CODE_FOR_vpdpbusd_v16si = 10346,
  CODE_FOR_vpdpbusd_v8si = 10347,
  CODE_FOR_vpdpbusd_v4si = 10348,
  CODE_FOR_vpdpbusd_v16si_mask = 10349,
  CODE_FOR_vpdpbusd_v8si_mask = 10350,
  CODE_FOR_vpdpbusd_v4si_mask = 10351,
  CODE_FOR_vpdpbusd_v16si_maskz_1 = 10352,
  CODE_FOR_vpdpbusd_v8si_maskz_1 = 10353,
  CODE_FOR_vpdpbusd_v4si_maskz_1 = 10354,
  CODE_FOR_vpdpbusds_v16si = 10355,
  CODE_FOR_vpdpbusds_v8si = 10356,
  CODE_FOR_vpdpbusds_v4si = 10357,
  CODE_FOR_vpdpbusds_v16si_mask = 10358,
  CODE_FOR_vpdpbusds_v8si_mask = 10359,
  CODE_FOR_vpdpbusds_v4si_mask = 10360,
  CODE_FOR_vpdpbusds_v16si_maskz_1 = 10361,
  CODE_FOR_vpdpbusds_v8si_maskz_1 = 10362,
  CODE_FOR_vpdpbusds_v4si_maskz_1 = 10363,
  CODE_FOR_vpdpwssd_v16si = 10364,
  CODE_FOR_vpdpwssd_v8si = 10365,
  CODE_FOR_vpdpwssd_v4si = 10366,
  CODE_FOR_vpdpwssd_v16si_mask = 10367,
  CODE_FOR_vpdpwssd_v8si_mask = 10368,
  CODE_FOR_vpdpwssd_v4si_mask = 10369,
  CODE_FOR_vpdpwssd_v16si_maskz_1 = 10370,
  CODE_FOR_vpdpwssd_v8si_maskz_1 = 10371,
  CODE_FOR_vpdpwssd_v4si_maskz_1 = 10372,
  CODE_FOR_vpdpwssds_v16si = 10373,
  CODE_FOR_vpdpwssds_v8si = 10374,
  CODE_FOR_vpdpwssds_v4si = 10375,
  CODE_FOR_vpdpwssds_v16si_mask = 10376,
  CODE_FOR_vpdpwssds_v8si_mask = 10377,
  CODE_FOR_vpdpwssds_v4si_mask = 10378,
  CODE_FOR_vpdpwssds_v16si_maskz_1 = 10379,
  CODE_FOR_vpdpwssds_v8si_maskz_1 = 10380,
  CODE_FOR_vpdpwssds_v4si_maskz_1 = 10381,
  CODE_FOR_vaesdec_v32qi = 10382,
  CODE_FOR_vaesdec_v16qi = 10383,
  CODE_FOR_vaesdec_v64qi = 10384,
  CODE_FOR_vaesdeclast_v32qi = 10385,
  CODE_FOR_vaesdeclast_v16qi = 10386,
  CODE_FOR_vaesdeclast_v64qi = 10387,
  CODE_FOR_vaesenc_v32qi = 10388,
  CODE_FOR_vaesenc_v16qi = 10389,
  CODE_FOR_vaesenc_v64qi = 10390,
  CODE_FOR_vaesenclast_v32qi = 10391,
  CODE_FOR_vaesenclast_v16qi = 10392,
  CODE_FOR_vaesenclast_v64qi = 10393,
  CODE_FOR_vpclmulqdq_v8di = 10394,
  CODE_FOR_vpclmulqdq_v4di = 10395,
  CODE_FOR_vpclmulqdq_v2di = 10396,
  CODE_FOR_avx512vl_vpshufbitqmbv64qi = 10397,
  CODE_FOR_avx512vl_vpshufbitqmbv64qi_mask = 10398,
  CODE_FOR_avx512vl_vpshufbitqmbv16qi = 10399,
  CODE_FOR_avx512vl_vpshufbitqmbv16qi_mask = 10400,
  CODE_FOR_avx512vl_vpshufbitqmbv32qi = 10401,
  CODE_FOR_avx512vl_vpshufbitqmbv32qi_mask = 10402,
  CODE_FOR_avx512vp2intersect_2intersectv8di = 10405,
  CODE_FOR_avx512vp2intersect_2intersectv4di = 10406,
  CODE_FOR_avx512vp2intersect_2intersectv2di = 10407,
  CODE_FOR_avx512vp2intersect_2intersectv8si = 10408,
  CODE_FOR_avx512vp2intersect_2intersectv4si = 10409,
  CODE_FOR_avx512vp2intersect_2intersectv16si = 10410,
  CODE_FOR_avx512f_cvtne2ps2bf16_v32bf = 10411,
  CODE_FOR_avx512f_cvtne2ps2bf16_v32bf_mask = 10412,
  CODE_FOR_avx512f_cvtne2ps2bf16_v16bf = 10413,
  CODE_FOR_avx512f_cvtne2ps2bf16_v16bf_mask = 10414,
  CODE_FOR_avx512f_cvtne2ps2bf16_v8bf = 10415,
  CODE_FOR_avx512f_cvtne2ps2bf16_v8bf_mask = 10416,
  CODE_FOR_avx512f_cvtneps2bf16_v4sf_mask_1 = 10418,
  CODE_FOR_vcvtneps2bf16_v8sf = 10419,
  CODE_FOR_avx512f_cvtneps2bf16_v16sf = 10420,
  CODE_FOR_avx512f_cvtneps2bf16_v16sf_mask = 10421,
  CODE_FOR_avx512f_cvtneps2bf16_v8sf = 10422,
  CODE_FOR_avx512f_cvtneps2bf16_v8sf_mask = 10423,
  CODE_FOR_avx512f_dpbf16ps_v16sf = 10424,
  CODE_FOR_avx512f_dpbf16ps_v16sf_maskz_1 = 10425,
  CODE_FOR_avx512f_dpbf16ps_v8sf = 10426,
  CODE_FOR_avx512f_dpbf16ps_v8sf_maskz_1 = 10427,
  CODE_FOR_avx512f_dpbf16ps_v4sf = 10428,
  CODE_FOR_avx512f_dpbf16ps_v4sf_maskz_1 = 10429,
  CODE_FOR_avx512f_dpbf16ps_v16sf_mask = 10430,
  CODE_FOR_avx512f_dpbf16ps_v8sf_mask = 10431,
  CODE_FOR_avx512f_dpbf16ps_v4sf_mask = 10432,
  CODE_FOR_loadiwkey = 10433,
  CODE_FOR_aesdec128klu8 = 10436,
  CODE_FOR_aesdec256klu8 = 10437,
  CODE_FOR_aesenc128klu8 = 10438,
  CODE_FOR_aesenc256klu8 = 10439,
  CODE_FOR_vpdpbssd_v8si = 10444,
  CODE_FOR_vpdpbssds_v8si = 10445,
  CODE_FOR_vpdpbsud_v8si = 10446,
  CODE_FOR_vpdpbsuds_v8si = 10447,
  CODE_FOR_vpdpbuud_v8si = 10448,
  CODE_FOR_vpdpbuuds_v8si = 10449,
  CODE_FOR_vpdpbssd_v4si = 10450,
  CODE_FOR_vpdpbssds_v4si = 10451,
  CODE_FOR_vpdpbsud_v4si = 10452,
  CODE_FOR_vpdpbsuds_v4si = 10453,
  CODE_FOR_vpdpbuud_v4si = 10454,
  CODE_FOR_vpdpbuuds_v4si = 10455,
  CODE_FOR_vpdpbssd_v16si = 10456,
  CODE_FOR_vpdpbssds_v16si = 10457,
  CODE_FOR_vpdpbsud_v16si = 10458,
  CODE_FOR_vpdpbsuds_v16si = 10459,
  CODE_FOR_vpdpbuud_v16si = 10460,
  CODE_FOR_vpdpbuuds_v16si = 10461,
  CODE_FOR_vpdpbssd_v16si_mask = 10462,
  CODE_FOR_vpdpbssds_v16si_mask = 10463,
  CODE_FOR_vpdpbsud_v16si_mask = 10464,
  CODE_FOR_vpdpbsuds_v16si_mask = 10465,
  CODE_FOR_vpdpbuud_v16si_mask = 10466,
  CODE_FOR_vpdpbuuds_v16si_mask = 10467,
  CODE_FOR_vpdpbssd_v8si_mask = 10468,
  CODE_FOR_vpdpbssds_v8si_mask = 10469,
  CODE_FOR_vpdpbsud_v8si_mask = 10470,
  CODE_FOR_vpdpbsuds_v8si_mask = 10471,
  CODE_FOR_vpdpbuud_v8si_mask = 10472,
  CODE_FOR_vpdpbuuds_v8si_mask = 10473,
  CODE_FOR_vpdpbssd_v4si_mask = 10474,
  CODE_FOR_vpdpbssds_v4si_mask = 10475,
  CODE_FOR_vpdpbsud_v4si_mask = 10476,
  CODE_FOR_vpdpbsuds_v4si_mask = 10477,
  CODE_FOR_vpdpbuud_v4si_mask = 10478,
  CODE_FOR_vpdpbuuds_v4si_mask = 10479,
  CODE_FOR_vbcstnebf162ps_v8sf = 10498,
  CODE_FOR_vbcstnebf162ps_v4sf = 10499,
  CODE_FOR_vbcstnesh2ps_v8sf = 10500,
  CODE_FOR_vbcstnesh2ps_v4sf = 10501,
  CODE_FOR_vcvtneeph2ps_v8hf = 10502,
  CODE_FOR_vcvtneebf162ps_v8bf = 10503,
  CODE_FOR_vcvtneeph2ps_v16hf = 10504,
  CODE_FOR_vcvtneebf162ps_v16bf = 10505,
  CODE_FOR_vcvtneoph2ps_v8hf = 10506,
  CODE_FOR_vcvtneobf162ps_v8bf = 10507,
  CODE_FOR_vcvtneoph2ps_v16hf = 10508,
  CODE_FOR_vcvtneobf162ps_v16bf = 10509,
  CODE_FOR_avx10_2_cvt2ps2phx_v32hf = 10510,
  CODE_FOR_avx10_2_cvt2ps2phx_v32hf_round = 10511,
  CODE_FOR_avx10_2_cvt2ps2phx_v32hf_mask = 10512,
  CODE_FOR_avx10_2_cvt2ps2phx_v32hf_mask_round = 10513,
  CODE_FOR_avx10_2_cvt2ps2phx_v16hf = 10514,
   CODE_FOR_avx10_2_cvt2ps2phx_v16hf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvt2ps2phx_v16hf_mask = 10515,
   CODE_FOR_avx10_2_cvt2ps2phx_v16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvt2ps2phx_v8hf = 10516,
   CODE_FOR_avx10_2_cvt2ps2phx_v8hf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvt2ps2phx_v8hf_mask = 10517,
   CODE_FOR_avx10_2_cvt2ps2phx_v8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_vcvt2ph2bf8v32hf = 10518,
  CODE_FOR_vcvt2ph2bf8v32hf_mask = 10519,
  CODE_FOR_vcvt2ph2bf8sv32hf = 10520,
  CODE_FOR_vcvt2ph2bf8sv32hf_mask = 10521,
  CODE_FOR_vcvt2ph2hf8v32hf = 10522,
  CODE_FOR_vcvt2ph2hf8v32hf_mask = 10523,
  CODE_FOR_vcvt2ph2hf8sv32hf = 10524,
  CODE_FOR_vcvt2ph2hf8sv32hf_mask = 10525,
  CODE_FOR_vcvt2ph2bf8v16hf = 10526,
  CODE_FOR_vcvt2ph2bf8v16hf_mask = 10527,
  CODE_FOR_vcvt2ph2bf8sv16hf = 10528,
  CODE_FOR_vcvt2ph2bf8sv16hf_mask = 10529,
  CODE_FOR_vcvt2ph2hf8v16hf = 10530,
  CODE_FOR_vcvt2ph2hf8v16hf_mask = 10531,
  CODE_FOR_vcvt2ph2hf8sv16hf = 10532,
  CODE_FOR_vcvt2ph2hf8sv16hf_mask = 10533,
  CODE_FOR_vcvt2ph2bf8v8hf = 10534,
  CODE_FOR_vcvt2ph2bf8v8hf_mask = 10535,
  CODE_FOR_vcvt2ph2bf8sv8hf = 10536,
  CODE_FOR_vcvt2ph2bf8sv8hf_mask = 10537,
  CODE_FOR_vcvt2ph2hf8v8hf = 10538,
  CODE_FOR_vcvt2ph2hf8v8hf_mask = 10539,
  CODE_FOR_vcvt2ph2hf8sv8hf = 10540,
  CODE_FOR_vcvt2ph2hf8sv8hf_mask = 10541,
  CODE_FOR_vcvtbiasph2bf8v32hf = 10550,
  CODE_FOR_vcvtbiasph2bf8v32hf_mask = 10551,
  CODE_FOR_vcvtbiasph2bf8sv32hf = 10552,
  CODE_FOR_vcvtbiasph2bf8sv32hf_mask = 10553,
  CODE_FOR_vcvtbiasph2hf8v32hf = 10554,
  CODE_FOR_vcvtbiasph2hf8v32hf_mask = 10555,
  CODE_FOR_vcvtbiasph2hf8sv32hf = 10556,
  CODE_FOR_vcvtbiasph2hf8sv32hf_mask = 10557,
  CODE_FOR_vcvtbiasph2bf8v16hf = 10558,
  CODE_FOR_vcvtbiasph2bf8v16hf_mask = 10559,
  CODE_FOR_vcvtbiasph2bf8sv16hf = 10560,
  CODE_FOR_vcvtbiasph2bf8sv16hf_mask = 10561,
  CODE_FOR_vcvtbiasph2hf8v16hf = 10562,
  CODE_FOR_vcvtbiasph2hf8v16hf_mask = 10563,
  CODE_FOR_vcvtbiasph2hf8sv16hf = 10564,
  CODE_FOR_vcvtbiasph2hf8sv16hf_mask = 10565,
  CODE_FOR_vcvtph2bf8v16hf = 10574,
  CODE_FOR_vcvtph2bf8v16hf_mask = 10575,
  CODE_FOR_vcvtph2bf8sv16hf = 10576,
  CODE_FOR_vcvtph2bf8sv16hf_mask = 10577,
  CODE_FOR_vcvtph2hf8v16hf = 10578,
  CODE_FOR_vcvtph2hf8v16hf_mask = 10579,
  CODE_FOR_vcvtph2hf8sv16hf = 10580,
  CODE_FOR_vcvtph2hf8sv16hf_mask = 10581,
  CODE_FOR_vcvtph2bf8v32hf = 10582,
  CODE_FOR_vcvtph2bf8v32hf_mask = 10583,
  CODE_FOR_vcvtph2bf8sv32hf = 10584,
  CODE_FOR_vcvtph2bf8sv32hf_mask = 10585,
  CODE_FOR_vcvtph2hf8v32hf = 10586,
  CODE_FOR_vcvtph2hf8v32hf_mask = 10587,
  CODE_FOR_vcvtph2hf8sv32hf = 10588,
  CODE_FOR_vcvtph2hf8sv32hf_mask = 10589,
  CODE_FOR_vcvthf82phv32hf = 10590,
  CODE_FOR_vcvthf82phv32hf_mask = 10591,
  CODE_FOR_vcvthf82phv16hf = 10592,
  CODE_FOR_vcvthf82phv16hf_mask = 10593,
  CODE_FOR_vcvthf82phv8hf = 10594,
  CODE_FOR_vcvthf82phv8hf_mask = 10595,
  CODE_FOR_vpdpwusd_v8si = 10596,
  CODE_FOR_vpdpwusds_v8si = 10597,
  CODE_FOR_vpdpwsud_v8si = 10598,
  CODE_FOR_vpdpwsuds_v8si = 10599,
  CODE_FOR_vpdpwuud_v8si = 10600,
  CODE_FOR_vpdpwuuds_v8si = 10601,
  CODE_FOR_vpdpwusd_v4si = 10602,
  CODE_FOR_vpdpwusds_v4si = 10603,
  CODE_FOR_vpdpwsud_v4si = 10604,
  CODE_FOR_vpdpwsuds_v4si = 10605,
  CODE_FOR_vpdpwuud_v4si = 10606,
  CODE_FOR_vpdpwuuds_v4si = 10607,
  CODE_FOR_vpdpwusd_v16si = 10608,
  CODE_FOR_vpdpwusds_v16si = 10609,
  CODE_FOR_vpdpwsud_v16si = 10610,
  CODE_FOR_vpdpwsuds_v16si = 10611,
  CODE_FOR_vpdpwuud_v16si = 10612,
  CODE_FOR_vpdpwuuds_v16si = 10613,
  CODE_FOR_vpdpwusd_v16si_mask = 10614,
  CODE_FOR_vpdpwusds_v16si_mask = 10615,
  CODE_FOR_vpdpwsud_v16si_mask = 10616,
  CODE_FOR_vpdpwsuds_v16si_mask = 10617,
  CODE_FOR_vpdpwuud_v16si_mask = 10618,
  CODE_FOR_vpdpwuuds_v16si_mask = 10619,
  CODE_FOR_vpdpwusd_v8si_mask = 10620,
  CODE_FOR_vpdpwusds_v8si_mask = 10621,
  CODE_FOR_vpdpwsud_v8si_mask = 10622,
  CODE_FOR_vpdpwsuds_v8si_mask = 10623,
  CODE_FOR_vpdpwuud_v8si_mask = 10624,
  CODE_FOR_vpdpwuuds_v8si_mask = 10625,
  CODE_FOR_vpdpwusd_v4si_mask = 10626,
  CODE_FOR_vpdpwusds_v4si_mask = 10627,
  CODE_FOR_vpdpwsud_v4si_mask = 10628,
  CODE_FOR_vpdpwsuds_v4si_mask = 10629,
  CODE_FOR_vpdpwuud_v4si_mask = 10630,
  CODE_FOR_vpdpwuuds_v4si_mask = 10631,
  CODE_FOR_vdpphps_v16sf = 10650,
  CODE_FOR_vdpphps_v8sf = 10651,
  CODE_FOR_vdpphps_v4sf = 10652,
  CODE_FOR_vdpphps_v16sf_mask = 10653,
  CODE_FOR_vdpphps_v8sf_mask = 10654,
  CODE_FOR_vdpphps_v4sf_mask = 10655,
  CODE_FOR_vdpphps_v16sf_maskz_1 = 10656,
  CODE_FOR_vdpphps_v8sf_maskz_1 = 10657,
  CODE_FOR_vdpphps_v4sf_maskz_1 = 10658,
  CODE_FOR_avx10_2_scalefbf16_v32bf = 10659,
  CODE_FOR_avx10_2_scalefbf16_v32bf_mask = 10660,
  CODE_FOR_avx10_2_scalefbf16_v16bf = 10661,
  CODE_FOR_avx10_2_scalefbf16_v16bf_mask = 10662,
  CODE_FOR_avx10_2_scalefbf16_v8bf = 10663,
  CODE_FOR_avx10_2_scalefbf16_v8bf_mask = 10664,
  CODE_FOR_avx10_2_smaxbf16_v32bf = 10665,
  CODE_FOR_avx10_2_smaxbf16_v32bf_mask = 10666,
  CODE_FOR_avx10_2_sminbf16_v32bf = 10667,
  CODE_FOR_avx10_2_sminbf16_v32bf_mask = 10668,
  CODE_FOR_avx10_2_smaxbf16_v16bf = 10669,
  CODE_FOR_avx10_2_smaxbf16_v16bf_mask = 10670,
  CODE_FOR_avx10_2_sminbf16_v16bf = 10671,
  CODE_FOR_avx10_2_sminbf16_v16bf_mask = 10672,
  CODE_FOR_avx10_2_smaxbf16_v8bf = 10673,
  CODE_FOR_avx10_2_smaxbf16_v8bf_mask = 10674,
  CODE_FOR_avx10_2_sminbf16_v8bf = 10675,
  CODE_FOR_avx10_2_sminbf16_v8bf_mask = 10676,
  CODE_FOR_avx10_2_addbf16_v32bf = 10677,
  CODE_FOR_avx10_2_addbf16_v32bf_mask = 10678,
  CODE_FOR_avx10_2_subbf16_v32bf = 10679,
  CODE_FOR_avx10_2_subbf16_v32bf_mask = 10680,
  CODE_FOR_avx10_2_mulbf16_v32bf = 10681,
  CODE_FOR_avx10_2_mulbf16_v32bf_mask = 10682,
  CODE_FOR_avx10_2_divbf16_v32bf = 10683,
  CODE_FOR_avx10_2_divbf16_v32bf_mask = 10684,
  CODE_FOR_avx10_2_addbf16_v16bf = 10685,
  CODE_FOR_avx10_2_addbf16_v16bf_mask = 10686,
  CODE_FOR_avx10_2_subbf16_v16bf = 10687,
  CODE_FOR_avx10_2_subbf16_v16bf_mask = 10688,
  CODE_FOR_avx10_2_mulbf16_v16bf = 10689,
  CODE_FOR_avx10_2_mulbf16_v16bf_mask = 10690,
  CODE_FOR_avx10_2_divbf16_v16bf = 10691,
  CODE_FOR_avx10_2_divbf16_v16bf_mask = 10692,
  CODE_FOR_avx10_2_addbf16_v8bf = 10693,
  CODE_FOR_avx10_2_addbf16_v8bf_mask = 10694,
  CODE_FOR_avx10_2_subbf16_v8bf = 10695,
  CODE_FOR_avx10_2_subbf16_v8bf_mask = 10696,
  CODE_FOR_avx10_2_mulbf16_v8bf = 10697,
  CODE_FOR_avx10_2_mulbf16_v8bf_mask = 10698,
  CODE_FOR_avx10_2_divbf16_v8bf = 10699,
  CODE_FOR_avx10_2_divbf16_v8bf_mask = 10700,
  CODE_FOR_avx10_2_fmaddbf16_v32bf = 10701,
  CODE_FOR_avx10_2_fmaddbf16_v32bf_maskz_1 = 10702,
  CODE_FOR_avx10_2_fmaddbf16_v16bf = 10703,
  CODE_FOR_avx10_2_fmaddbf16_v16bf_maskz_1 = 10704,
  CODE_FOR_avx10_2_fmaddbf16_v8bf = 10705,
  CODE_FOR_avx10_2_fmaddbf16_v8bf_maskz_1 = 10706,
  CODE_FOR_avx10_2_fmaddbf16_v32bf_mask = 10707,
  CODE_FOR_avx10_2_fmaddbf16_v16bf_mask = 10708,
  CODE_FOR_avx10_2_fmaddbf16_v8bf_mask = 10709,
  CODE_FOR_avx10_2_fmaddbf16_v32bf_mask3 = 10710,
  CODE_FOR_avx10_2_fmaddbf16_v16bf_mask3 = 10711,
  CODE_FOR_avx10_2_fmaddbf16_v8bf_mask3 = 10712,
  CODE_FOR_avx10_2_fnmaddbf16_v32bf = 10713,
  CODE_FOR_avx10_2_fnmaddbf16_v32bf_maskz_1 = 10714,
  CODE_FOR_avx10_2_fnmaddbf16_v16bf = 10715,
  CODE_FOR_avx10_2_fnmaddbf16_v16bf_maskz_1 = 10716,
  CODE_FOR_avx10_2_fnmaddbf16_v8bf = 10717,
  CODE_FOR_avx10_2_fnmaddbf16_v8bf_maskz_1 = 10718,
  CODE_FOR_avx10_2_fnmaddbf16_v32bf_mask = 10719,
  CODE_FOR_avx10_2_fnmaddbf16_v16bf_mask = 10720,
  CODE_FOR_avx10_2_fnmaddbf16_v8bf_mask = 10721,
  CODE_FOR_avx10_2_fnmaddbf16_v32bf_mask3 = 10722,
  CODE_FOR_avx10_2_fnmaddbf16_v16bf_mask3 = 10723,
  CODE_FOR_avx10_2_fnmaddbf16_v8bf_mask3 = 10724,
  CODE_FOR_avx10_2_fmsubbf16_v32bf = 10725,
  CODE_FOR_avx10_2_fmsubbf16_v32bf_maskz_1 = 10726,
  CODE_FOR_avx10_2_fmsubbf16_v16bf = 10727,
  CODE_FOR_avx10_2_fmsubbf16_v16bf_maskz_1 = 10728,
  CODE_FOR_avx10_2_fmsubbf16_v8bf = 10729,
  CODE_FOR_avx10_2_fmsubbf16_v8bf_maskz_1 = 10730,
  CODE_FOR_avx10_2_fmsubbf16_v32bf_mask = 10731,
  CODE_FOR_avx10_2_fmsubbf16_v16bf_mask = 10732,
  CODE_FOR_avx10_2_fmsubbf16_v8bf_mask = 10733,
  CODE_FOR_avx10_2_fmsubbf16_v32bf_mask3 = 10734,
  CODE_FOR_avx10_2_fmsubbf16_v16bf_mask3 = 10735,
  CODE_FOR_avx10_2_fmsubbf16_v8bf_mask3 = 10736,
  CODE_FOR_avx10_2_fnmsubbf16_v32bf = 10737,
  CODE_FOR_avx10_2_fnmsubbf16_v32bf_maskz_1 = 10738,
  CODE_FOR_avx10_2_fnmsubbf16_v16bf = 10739,
  CODE_FOR_avx10_2_fnmsubbf16_v16bf_maskz_1 = 10740,
  CODE_FOR_avx10_2_fnmsubbf16_v8bf = 10741,
  CODE_FOR_avx10_2_fnmsubbf16_v8bf_maskz_1 = 10742,
  CODE_FOR_avx10_2_fnmsubbf16_v32bf_mask = 10743,
  CODE_FOR_avx10_2_fnmsubbf16_v16bf_mask = 10744,
  CODE_FOR_avx10_2_fnmsubbf16_v8bf_mask = 10745,
  CODE_FOR_avx10_2_fnmsubbf16_v32bf_mask3 = 10746,
  CODE_FOR_avx10_2_fnmsubbf16_v16bf_mask3 = 10747,
  CODE_FOR_avx10_2_fnmsubbf16_v8bf_mask3 = 10748,
  CODE_FOR_avx10_2_rsqrtbf16_v32bf = 10749,
  CODE_FOR_avx10_2_rsqrtbf16_v32bf_mask = 10750,
  CODE_FOR_avx10_2_rsqrtbf16_v16bf = 10751,
  CODE_FOR_avx10_2_rsqrtbf16_v16bf_mask = 10752,
  CODE_FOR_avx10_2_rsqrtbf16_v8bf = 10753,
  CODE_FOR_avx10_2_rsqrtbf16_v8bf_mask = 10754,
  CODE_FOR_avx10_2_sqrtbf16_v32bf = 10755,
  CODE_FOR_avx10_2_sqrtbf16_v32bf_mask = 10756,
  CODE_FOR_avx10_2_sqrtbf16_v16bf = 10757,
  CODE_FOR_avx10_2_sqrtbf16_v16bf_mask = 10758,
  CODE_FOR_avx10_2_sqrtbf16_v8bf = 10759,
  CODE_FOR_avx10_2_sqrtbf16_v8bf_mask = 10760,
  CODE_FOR_avx10_2_rcpbf16_v32bf = 10761,
  CODE_FOR_avx10_2_rcpbf16_v32bf_mask = 10762,
  CODE_FOR_avx10_2_rcpbf16_v16bf = 10763,
  CODE_FOR_avx10_2_rcpbf16_v16bf_mask = 10764,
  CODE_FOR_avx10_2_rcpbf16_v8bf = 10765,
  CODE_FOR_avx10_2_rcpbf16_v8bf_mask = 10766,
  CODE_FOR_avx10_2_getexpbf16_v32bf = 10767,
  CODE_FOR_avx10_2_getexpbf16_v32bf_mask = 10768,
  CODE_FOR_avx10_2_getexpbf16_v16bf = 10769,
  CODE_FOR_avx10_2_getexpbf16_v16bf_mask = 10770,
  CODE_FOR_avx10_2_getexpbf16_v8bf = 10771,
  CODE_FOR_avx10_2_getexpbf16_v8bf_mask = 10772,
  CODE_FOR_avx10_2_rndscalebf16_v32bf = 10773,
  CODE_FOR_avx10_2_rndscalebf16_v32bf_mask = 10774,
  CODE_FOR_avx10_2_reducebf16_v32bf = 10775,
  CODE_FOR_avx10_2_reducebf16_v32bf_mask = 10776,
  CODE_FOR_avx10_2_getmantbf16_v32bf = 10777,
  CODE_FOR_avx10_2_getmantbf16_v32bf_mask = 10778,
  CODE_FOR_avx10_2_rndscalebf16_v16bf = 10779,
  CODE_FOR_avx10_2_rndscalebf16_v16bf_mask = 10780,
  CODE_FOR_avx10_2_reducebf16_v16bf = 10781,
  CODE_FOR_avx10_2_reducebf16_v16bf_mask = 10782,
  CODE_FOR_avx10_2_getmantbf16_v16bf = 10783,
  CODE_FOR_avx10_2_getmantbf16_v16bf_mask = 10784,
  CODE_FOR_avx10_2_rndscalebf16_v8bf = 10785,
  CODE_FOR_avx10_2_rndscalebf16_v8bf_mask = 10786,
  CODE_FOR_avx10_2_reducebf16_v8bf = 10787,
  CODE_FOR_avx10_2_reducebf16_v8bf_mask = 10788,
  CODE_FOR_avx10_2_getmantbf16_v8bf = 10789,
  CODE_FOR_avx10_2_getmantbf16_v8bf_mask = 10790,
  CODE_FOR_avx10_2_fpclassbf16_v32bf = 10791,
  CODE_FOR_avx10_2_fpclassbf16_v32bf_mask = 10792,
  CODE_FOR_avx10_2_fpclassbf16_v16bf = 10793,
  CODE_FOR_avx10_2_fpclassbf16_v16bf_mask = 10794,
  CODE_FOR_avx10_2_fpclassbf16_v8bf = 10795,
  CODE_FOR_avx10_2_fpclassbf16_v8bf_mask = 10796,
  CODE_FOR_avx10_2_cmpbf16_v32bf = 10797,
  CODE_FOR_avx10_2_cmpbf16_v32bf_mask = 10798,
  CODE_FOR_avx10_2_cmpbf16_v16bf = 10799,
  CODE_FOR_avx10_2_cmpbf16_v16bf_mask = 10800,
  CODE_FOR_avx10_2_cmpbf16_v8bf = 10801,
  CODE_FOR_avx10_2_cmpbf16_v8bf_mask = 10802,
  CODE_FOR_avx10_2_cvtbf162ibsv32bf = 10803,
  CODE_FOR_avx10_2_cvtbf162ibsv32bf_mask = 10804,
  CODE_FOR_avx10_2_cvtbf162iubsv32bf = 10805,
  CODE_FOR_avx10_2_cvtbf162iubsv32bf_mask = 10806,
  CODE_FOR_avx10_2_cvttbf162ibsv32bf = 10807,
  CODE_FOR_avx10_2_cvttbf162ibsv32bf_mask = 10808,
  CODE_FOR_avx10_2_cvttbf162iubsv32bf = 10809,
  CODE_FOR_avx10_2_cvttbf162iubsv32bf_mask = 10810,
  CODE_FOR_avx10_2_cvtbf162ibsv16bf = 10811,
  CODE_FOR_avx10_2_cvtbf162ibsv16bf_mask = 10812,
  CODE_FOR_avx10_2_cvtbf162iubsv16bf = 10813,
  CODE_FOR_avx10_2_cvtbf162iubsv16bf_mask = 10814,
  CODE_FOR_avx10_2_cvttbf162ibsv16bf = 10815,
  CODE_FOR_avx10_2_cvttbf162ibsv16bf_mask = 10816,
  CODE_FOR_avx10_2_cvttbf162iubsv16bf = 10817,
  CODE_FOR_avx10_2_cvttbf162iubsv16bf_mask = 10818,
  CODE_FOR_avx10_2_cvtbf162ibsv8bf = 10819,
  CODE_FOR_avx10_2_cvtbf162ibsv8bf_mask = 10820,
  CODE_FOR_avx10_2_cvtbf162iubsv8bf = 10821,
  CODE_FOR_avx10_2_cvtbf162iubsv8bf_mask = 10822,
  CODE_FOR_avx10_2_cvttbf162ibsv8bf = 10823,
  CODE_FOR_avx10_2_cvttbf162ibsv8bf_mask = 10824,
  CODE_FOR_avx10_2_cvttbf162iubsv8bf = 10825,
  CODE_FOR_avx10_2_cvttbf162iubsv8bf_mask = 10826,
  CODE_FOR_avx10_2_cvtph2ibsv32hf = 10827,
  CODE_FOR_avx10_2_cvtph2ibsv32hf_round = 10828,
  CODE_FOR_avx10_2_cvtph2ibsv32hf_mask = 10829,
  CODE_FOR_avx10_2_cvtph2ibsv32hf_mask_round = 10830,
  CODE_FOR_avx10_2_cvtph2iubsv32hf = 10831,
  CODE_FOR_avx10_2_cvtph2iubsv32hf_round = 10832,
  CODE_FOR_avx10_2_cvtph2iubsv32hf_mask = 10833,
  CODE_FOR_avx10_2_cvtph2iubsv32hf_mask_round = 10834,
  CODE_FOR_avx10_2_cvtph2ibsv16hf = 10835,
   CODE_FOR_avx10_2_cvtph2ibsv16hf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtph2ibsv16hf_mask = 10836,
   CODE_FOR_avx10_2_cvtph2ibsv16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtph2iubsv16hf = 10837,
   CODE_FOR_avx10_2_cvtph2iubsv16hf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtph2iubsv16hf_mask = 10838,
   CODE_FOR_avx10_2_cvtph2iubsv16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtph2ibsv8hf = 10839,
   CODE_FOR_avx10_2_cvtph2ibsv8hf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtph2ibsv8hf_mask = 10840,
   CODE_FOR_avx10_2_cvtph2ibsv8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtph2iubsv8hf = 10841,
   CODE_FOR_avx10_2_cvtph2iubsv8hf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtph2iubsv8hf_mask = 10842,
   CODE_FOR_avx10_2_cvtph2iubsv8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttph2ibsv32hf = 10843,
  CODE_FOR_avx10_2_cvttph2ibsv32hf_round = 10844,
  CODE_FOR_avx10_2_cvttph2ibsv32hf_mask = 10845,
  CODE_FOR_avx10_2_cvttph2ibsv32hf_mask_round = 10846,
  CODE_FOR_avx10_2_cvttph2iubsv32hf = 10847,
  CODE_FOR_avx10_2_cvttph2iubsv32hf_round = 10848,
  CODE_FOR_avx10_2_cvttph2iubsv32hf_mask = 10849,
  CODE_FOR_avx10_2_cvttph2iubsv32hf_mask_round = 10850,
  CODE_FOR_avx10_2_cvttph2ibsv16hf = 10851,
   CODE_FOR_avx10_2_cvttph2ibsv16hf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttph2ibsv16hf_mask = 10852,
   CODE_FOR_avx10_2_cvttph2ibsv16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttph2iubsv16hf = 10853,
   CODE_FOR_avx10_2_cvttph2iubsv16hf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttph2iubsv16hf_mask = 10854,
   CODE_FOR_avx10_2_cvttph2iubsv16hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttph2ibsv8hf = 10855,
   CODE_FOR_avx10_2_cvttph2ibsv8hf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttph2ibsv8hf_mask = 10856,
   CODE_FOR_avx10_2_cvttph2ibsv8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttph2iubsv8hf = 10857,
   CODE_FOR_avx10_2_cvttph2iubsv8hf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttph2iubsv8hf_mask = 10858,
   CODE_FOR_avx10_2_cvttph2iubsv8hf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtps2ibsv16sf = 10859,
  CODE_FOR_avx10_2_cvtps2ibsv16sf_round = 10860,
  CODE_FOR_avx10_2_cvtps2ibsv16sf_mask = 10861,
  CODE_FOR_avx10_2_cvtps2ibsv16sf_mask_round = 10862,
  CODE_FOR_avx10_2_cvtps2iubsv16sf = 10863,
  CODE_FOR_avx10_2_cvtps2iubsv16sf_round = 10864,
  CODE_FOR_avx10_2_cvtps2iubsv16sf_mask = 10865,
  CODE_FOR_avx10_2_cvtps2iubsv16sf_mask_round = 10866,
  CODE_FOR_avx10_2_cvtps2ibsv8sf = 10867,
   CODE_FOR_avx10_2_cvtps2ibsv8sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtps2ibsv8sf_mask = 10868,
   CODE_FOR_avx10_2_cvtps2ibsv8sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtps2iubsv8sf = 10869,
   CODE_FOR_avx10_2_cvtps2iubsv8sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtps2iubsv8sf_mask = 10870,
   CODE_FOR_avx10_2_cvtps2iubsv8sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtps2ibsv4sf = 10871,
   CODE_FOR_avx10_2_cvtps2ibsv4sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtps2ibsv4sf_mask = 10872,
   CODE_FOR_avx10_2_cvtps2ibsv4sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtps2iubsv4sf = 10873,
   CODE_FOR_avx10_2_cvtps2iubsv4sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvtps2iubsv4sf_mask = 10874,
   CODE_FOR_avx10_2_cvtps2iubsv4sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttps2ibsv16sf = 10875,
  CODE_FOR_avx10_2_cvttps2ibsv16sf_round = 10876,
  CODE_FOR_avx10_2_cvttps2ibsv16sf_mask = 10877,
  CODE_FOR_avx10_2_cvttps2ibsv16sf_mask_round = 10878,
  CODE_FOR_avx10_2_cvttps2iubsv16sf = 10879,
  CODE_FOR_avx10_2_cvttps2iubsv16sf_round = 10880,
  CODE_FOR_avx10_2_cvttps2iubsv16sf_mask = 10881,
  CODE_FOR_avx10_2_cvttps2iubsv16sf_mask_round = 10882,
  CODE_FOR_avx10_2_cvttps2ibsv8sf = 10883,
   CODE_FOR_avx10_2_cvttps2ibsv8sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttps2ibsv8sf_mask = 10884,
   CODE_FOR_avx10_2_cvttps2ibsv8sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttps2iubsv8sf = 10885,
   CODE_FOR_avx10_2_cvttps2iubsv8sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttps2iubsv8sf_mask = 10886,
   CODE_FOR_avx10_2_cvttps2iubsv8sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttps2ibsv4sf = 10887,
   CODE_FOR_avx10_2_cvttps2ibsv4sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttps2ibsv4sf_mask = 10888,
   CODE_FOR_avx10_2_cvttps2ibsv4sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttps2iubsv4sf = 10889,
   CODE_FOR_avx10_2_cvttps2iubsv4sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_cvttps2iubsv4sf_mask = 10890,
   CODE_FOR_avx10_2_cvttps2iubsv4sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2dqsv16sf = 10891,
  CODE_FOR_avx10_2_vcvttps2dqsv16sf_round = 10892,
  CODE_FOR_avx10_2_vcvttps2dqsv16sf_mask = 10893,
  CODE_FOR_avx10_2_vcvttps2dqsv16sf_mask_round = 10894,
  CODE_FOR_avx10_2_vcvttps2udqsv16sf = 10895,
  CODE_FOR_avx10_2_vcvttps2udqsv16sf_round = 10896,
  CODE_FOR_avx10_2_vcvttps2udqsv16sf_mask = 10897,
  CODE_FOR_avx10_2_vcvttps2udqsv16sf_mask_round = 10898,
  CODE_FOR_avx10_2_vcvttps2dqsv8sf = 10899,
   CODE_FOR_avx10_2_vcvttps2dqsv8sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2dqsv8sf_mask = 10900,
   CODE_FOR_avx10_2_vcvttps2dqsv8sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2udqsv8sf = 10901,
   CODE_FOR_avx10_2_vcvttps2udqsv8sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2udqsv8sf_mask = 10902,
   CODE_FOR_avx10_2_vcvttps2udqsv8sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2dqsv4sf = 10903,
   CODE_FOR_avx10_2_vcvttps2dqsv4sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2dqsv4sf_mask = 10904,
   CODE_FOR_avx10_2_vcvttps2dqsv4sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2udqsv4sf = 10905,
   CODE_FOR_avx10_2_vcvttps2udqsv4sf_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2udqsv4sf_mask = 10906,
   CODE_FOR_avx10_2_vcvttps2udqsv4sf_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2dqsv8df = 10907,
  CODE_FOR_avx10_2_vcvttpd2dqsv8df_round = 10908,
  CODE_FOR_avx10_2_vcvttpd2dqsv8df_mask = 10909,
  CODE_FOR_avx10_2_vcvttpd2dqsv8df_mask_round = 10910,
  CODE_FOR_avx10_2_vcvttpd2udqsv8df = 10911,
  CODE_FOR_avx10_2_vcvttpd2udqsv8df_round = 10912,
  CODE_FOR_avx10_2_vcvttpd2udqsv8df_mask = 10913,
  CODE_FOR_avx10_2_vcvttpd2udqsv8df_mask_round = 10914,
  CODE_FOR_avx10_2_vcvttpd2dqsv4df = 10915,
   CODE_FOR_avx10_2_vcvttpd2dqsv4df_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2dqsv4df_mask = 10916,
   CODE_FOR_avx10_2_vcvttpd2dqsv4df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2udqsv4df = 10917,
   CODE_FOR_avx10_2_vcvttpd2udqsv4df_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2udqsv4df_mask = 10918,
   CODE_FOR_avx10_2_vcvttpd2udqsv4df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2dqsv2df = 10919,
   CODE_FOR_avx10_2_vcvttpd2dqsv2df_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2dqsv2df_mask = 10920,
   CODE_FOR_avx10_2_vcvttpd2dqsv2df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2udqsv2df = 10921,
   CODE_FOR_avx10_2_vcvttpd2udqsv2df_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2udqsv2df_mask = 10922,
   CODE_FOR_avx10_2_vcvttpd2udqsv2df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2qqsv8df = 10923,
  CODE_FOR_avx10_2_vcvttpd2qqsv8df_round = 10924,
  CODE_FOR_avx10_2_vcvttpd2qqsv8df_mask = 10925,
  CODE_FOR_avx10_2_vcvttpd2qqsv8df_mask_round = 10926,
  CODE_FOR_avx10_2_vcvttpd2uqqsv8df = 10927,
  CODE_FOR_avx10_2_vcvttpd2uqqsv8df_round = 10928,
  CODE_FOR_avx10_2_vcvttpd2uqqsv8df_mask = 10929,
  CODE_FOR_avx10_2_vcvttpd2uqqsv8df_mask_round = 10930,
  CODE_FOR_avx10_2_vcvttpd2qqsv4df = 10931,
   CODE_FOR_avx10_2_vcvttpd2qqsv4df_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2qqsv4df_mask = 10932,
   CODE_FOR_avx10_2_vcvttpd2qqsv4df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2uqqsv4df = 10933,
   CODE_FOR_avx10_2_vcvttpd2uqqsv4df_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2uqqsv4df_mask = 10934,
   CODE_FOR_avx10_2_vcvttpd2uqqsv4df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2qqsv2df = 10935,
   CODE_FOR_avx10_2_vcvttpd2qqsv2df_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2qqsv2df_mask = 10936,
   CODE_FOR_avx10_2_vcvttpd2qqsv2df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2uqqsv2df = 10937,
   CODE_FOR_avx10_2_vcvttpd2uqqsv2df_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttpd2uqqsv2df_mask = 10938,
   CODE_FOR_avx10_2_vcvttpd2uqqsv2df_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2qqsv8di = 10939,
  CODE_FOR_avx10_2_vcvttps2qqsv8di_round = 10940,
  CODE_FOR_avx10_2_vcvttps2qqsv8di_mask = 10941,
  CODE_FOR_avx10_2_vcvttps2qqsv8di_mask_round = 10942,
  CODE_FOR_avx10_2_vcvttps2uqqsv8di = 10943,
  CODE_FOR_avx10_2_vcvttps2uqqsv8di_round = 10944,
  CODE_FOR_avx10_2_vcvttps2uqqsv8di_mask = 10945,
  CODE_FOR_avx10_2_vcvttps2uqqsv8di_mask_round = 10946,
  CODE_FOR_avx10_2_vcvttps2qqsv4di = 10947,
   CODE_FOR_avx10_2_vcvttps2qqsv4di_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2qqsv4di_mask = 10948,
   CODE_FOR_avx10_2_vcvttps2qqsv4di_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2uqqsv4di = 10949,
   CODE_FOR_avx10_2_vcvttps2uqqsv4di_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2uqqsv4di_mask = 10950,
   CODE_FOR_avx10_2_vcvttps2uqqsv4di_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2qqsv2di = 10951,
   CODE_FOR_avx10_2_vcvttps2qqsv2di_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2qqsv2di_mask = 10952,
   CODE_FOR_avx10_2_vcvttps2qqsv2di_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2uqqsv2di = 10953,
   CODE_FOR_avx10_2_vcvttps2uqqsv2di_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttps2uqqsv2di_mask = 10954,
   CODE_FOR_avx10_2_vcvttps2uqqsv2di_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx10_2_vcvttsd2sissi = 10955,
  CODE_FOR_avx10_2_vcvttsd2sissi_round = 10956,
  CODE_FOR_avx10_2_vcvttsd2usissi = 10957,
  CODE_FOR_avx10_2_vcvttsd2usissi_round = 10958,
  CODE_FOR_avx10_2_vcvttsd2sisdi = 10959,
  CODE_FOR_avx10_2_vcvttsd2sisdi_round = 10960,
  CODE_FOR_avx10_2_vcvttsd2usisdi = 10961,
  CODE_FOR_avx10_2_vcvttsd2usisdi_round = 10962,
  CODE_FOR_avx10_2_vcvttss2sissi = 10963,
  CODE_FOR_avx10_2_vcvttss2sissi_round = 10964,
  CODE_FOR_avx10_2_vcvttss2usissi = 10965,
  CODE_FOR_avx10_2_vcvttss2usissi_round = 10966,
  CODE_FOR_avx10_2_vcvttss2sisdi = 10967,
  CODE_FOR_avx10_2_vcvttss2sisdi_round = 10968,
  CODE_FOR_avx10_2_vcvttss2usisdi = 10969,
  CODE_FOR_avx10_2_vcvttss2usisdi_round = 10970,
  CODE_FOR_avx10_2_minmaxbf16_v32bf = 10971,
  CODE_FOR_avx10_2_minmaxbf16_v32bf_mask = 10972,
  CODE_FOR_avx10_2_minmaxbf16_v16bf = 10973,
  CODE_FOR_avx10_2_minmaxbf16_v16bf_mask = 10974,
  CODE_FOR_avx10_2_minmaxbf16_v8bf = 10975,
  CODE_FOR_avx10_2_minmaxbf16_v8bf_mask = 10976,
  CODE_FOR_avx10_2_minmaxpv32hf = 10977,
  CODE_FOR_avx10_2_minmaxpv32hf_round = 10978,
  CODE_FOR_avx10_2_minmaxpv32hf_mask = 10979,
  CODE_FOR_avx10_2_minmaxpv32hf_mask_round = 10980,
  CODE_FOR_avx10_2_minmaxpv16hf = 10981,
  CODE_FOR_avx10_2_minmaxpv16hf_round = 10982,
  CODE_FOR_avx10_2_minmaxpv16hf_mask = 10983,
  CODE_FOR_avx10_2_minmaxpv16hf_mask_round = 10984,
  CODE_FOR_avx10_2_minmaxpv8hf = 10985,
  CODE_FOR_avx10_2_minmaxpv8hf_round = 10986,
  CODE_FOR_avx10_2_minmaxpv8hf_mask = 10987,
  CODE_FOR_avx10_2_minmaxpv8hf_mask_round = 10988,
  CODE_FOR_avx10_2_minmaxpv16sf = 10989,
  CODE_FOR_avx10_2_minmaxpv16sf_round = 10990,
  CODE_FOR_avx10_2_minmaxpv16sf_mask = 10991,
  CODE_FOR_avx10_2_minmaxpv16sf_mask_round = 10992,
  CODE_FOR_avx10_2_minmaxpv8sf = 10993,
  CODE_FOR_avx10_2_minmaxpv8sf_round = 10994,
  CODE_FOR_avx10_2_minmaxpv8sf_mask = 10995,
  CODE_FOR_avx10_2_minmaxpv8sf_mask_round = 10996,
  CODE_FOR_avx10_2_minmaxpv4sf = 10997,
  CODE_FOR_avx10_2_minmaxpv4sf_round = 10998,
  CODE_FOR_avx10_2_minmaxpv4sf_mask = 10999,
  CODE_FOR_avx10_2_minmaxpv4sf_mask_round = 11000,
  CODE_FOR_avx10_2_minmaxpv8df = 11001,
  CODE_FOR_avx10_2_minmaxpv8df_round = 11002,
  CODE_FOR_avx10_2_minmaxpv8df_mask = 11003,
  CODE_FOR_avx10_2_minmaxpv8df_mask_round = 11004,
  CODE_FOR_avx10_2_minmaxpv4df = 11005,
  CODE_FOR_avx10_2_minmaxpv4df_round = 11006,
  CODE_FOR_avx10_2_minmaxpv4df_mask = 11007,
  CODE_FOR_avx10_2_minmaxpv4df_mask_round = 11008,
  CODE_FOR_avx10_2_minmaxpv2df = 11009,
  CODE_FOR_avx10_2_minmaxpv2df_round = 11010,
  CODE_FOR_avx10_2_minmaxpv2df_mask = 11011,
  CODE_FOR_avx10_2_minmaxpv2df_mask_round = 11012,
  CODE_FOR_avx10_2_minmaxsv8hf = 11013,
  CODE_FOR_avx10_2_minmaxsv8hf_mask = 11014,
  CODE_FOR_avx10_2_minmaxsv8hf_round = 11015,
  CODE_FOR_avx10_2_minmaxsv8hf_mask_round = 11016,
  CODE_FOR_avx10_2_minmaxsv4sf = 11017,
  CODE_FOR_avx10_2_minmaxsv4sf_mask = 11018,
  CODE_FOR_avx10_2_minmaxsv4sf_round = 11019,
  CODE_FOR_avx10_2_minmaxsv4sf_mask_round = 11020,
  CODE_FOR_avx10_2_minmaxsv2df = 11021,
  CODE_FOR_avx10_2_minmaxsv2df_mask = 11022,
  CODE_FOR_avx10_2_minmaxsv2df_round = 11023,
  CODE_FOR_avx10_2_minmaxsv2df_mask_round = 11024,
  CODE_FOR_avx10_2_vmovrsbv64qi = 11025,
  CODE_FOR_avx10_2_vmovrsbv64qi_mask = 11026,
  CODE_FOR_avx10_2_vmovrsbv32qi = 11027,
  CODE_FOR_avx10_2_vmovrsbv32qi_mask = 11028,
  CODE_FOR_avx10_2_vmovrsbv16qi = 11029,
  CODE_FOR_avx10_2_vmovrsbv16qi_mask = 11030,
  CODE_FOR_avx10_2_vmovrswv32hi = 11031,
  CODE_FOR_avx10_2_vmovrswv32hi_mask = 11032,
  CODE_FOR_avx10_2_vmovrswv16hi = 11033,
  CODE_FOR_avx10_2_vmovrswv16hi_mask = 11034,
  CODE_FOR_avx10_2_vmovrswv8hi = 11035,
  CODE_FOR_avx10_2_vmovrswv8hi_mask = 11036,
  CODE_FOR_avx10_2_vmovrsdv16si = 11037,
  CODE_FOR_avx10_2_vmovrsdv16si_mask = 11038,
  CODE_FOR_avx10_2_vmovrsdv8si = 11039,
  CODE_FOR_avx10_2_vmovrsdv8si_mask = 11040,
  CODE_FOR_avx10_2_vmovrsdv4si = 11041,
  CODE_FOR_avx10_2_vmovrsdv4si_mask = 11042,
  CODE_FOR_avx10_2_vmovrsqv8di = 11043,
  CODE_FOR_avx10_2_vmovrsqv8di_mask = 11044,
  CODE_FOR_avx10_2_vmovrsqv4di = 11045,
  CODE_FOR_avx10_2_vmovrsqv4di_mask = 11046,
  CODE_FOR_avx10_2_vmovrsqv2di = 11047,
  CODE_FOR_avx10_2_vmovrsqv2di_mask = 11048,
  CODE_FOR_avx512bmm_vbmacor16x16x16_v32hi = 11049,
  CODE_FOR_avx512bmm_vbmacor16x16x16_v16hi = 11050,
  CODE_FOR_avx512bmm_vbmacxor16x16x16_v32hi = 11051,
  CODE_FOR_avx512bmm_vbmacxor16x16x16_v16hi = 11052,
  CODE_FOR_avx512bmm_vbitrevb_v64qi_mask = 11053,
  CODE_FOR_avx512bmm_vbitrevb_v16qi_mask = 11054,
  CODE_FOR_avx512bmm_vbitrevb_v32qi_mask = 11055,
  CODE_FOR_avx512bmm_vbitrevb_v64qi = 11056,
  CODE_FOR_avx512bmm_vbitrevb_v16qi = 11057,
  CODE_FOR_avx512bmm_vbitrevb_v32qi = 11058,
  CODE_FOR_mfence_sse2 = 11061,
  CODE_FOR_mfence_nosse = 11062,
  CODE_FOR_atomic_loaddi_fpu = 11063,
  CODE_FOR_atomic_storeqi_1 = 11064,
  CODE_FOR_atomic_storehi_1 = 11065,
  CODE_FOR_atomic_storesi_1 = 11066,
  CODE_FOR_atomic_storedi_1 = 11067,
  CODE_FOR_atomic_storedi_fpu = 11068,
  CODE_FOR_loaddi_via_fpu = 11069,
  CODE_FOR_storedi_via_fpu = 11070,
  CODE_FOR_loaddi_via_sse = 11071,
  CODE_FOR_storedi_via_sse = 11072,
  CODE_FOR_atomic_compare_and_swapdi_doubleword = 11073,
  CODE_FOR_atomic_compare_and_swapti_doubleword = 11074,
  CODE_FOR_atomic_compare_and_swapqi_1 = 11075,
  CODE_FOR_atomic_compare_and_swaphi_1 = 11076,
  CODE_FOR_atomic_compare_and_swapsi_1 = 11077,
  CODE_FOR_atomic_compare_and_swapdi_1 = 11078,
  CODE_FOR_atomic_fetch_addqi = 11079,
  CODE_FOR_atomic_fetch_addhi = 11080,
  CODE_FOR_atomic_fetch_addsi = 11081,
  CODE_FOR_atomic_fetch_adddi = 11082,
  CODE_FOR_atomic_exchangeqi = 11087,
  CODE_FOR_atomic_exchangehi = 11088,
  CODE_FOR_atomic_exchangesi = 11089,
  CODE_FOR_atomic_exchangedi = 11090,
  CODE_FOR_rao_aandsi = 11091,
  CODE_FOR_rao_aorsi = 11092,
  CODE_FOR_rao_axorsi = 11093,
  CODE_FOR_rao_aaddsi = 11094,
  CODE_FOR_rao_aanddi = 11095,
  CODE_FOR_rao_aordi = 11096,
  CODE_FOR_rao_axordi = 11097,
  CODE_FOR_rao_aadddi = 11098,
  CODE_FOR_atomic_addqi = 11099,
  CODE_FOR_atomic_addhi = 11100,
  CODE_FOR_atomic_addsi = 11101,
  CODE_FOR_atomic_adddi = 11102,
  CODE_FOR_atomic_subqi = 11103,
  CODE_FOR_atomic_subhi = 11104,
  CODE_FOR_atomic_subsi = 11105,
  CODE_FOR_atomic_subdi = 11106,
  CODE_FOR_atomic_andqi = 11107,
  CODE_FOR_atomic_orqi = 11108,
  CODE_FOR_atomic_xorqi = 11109,
  CODE_FOR_atomic_andhi = 11110,
  CODE_FOR_atomic_orhi = 11111,
  CODE_FOR_atomic_xorhi = 11112,
  CODE_FOR_atomic_andsi = 11113,
  CODE_FOR_atomic_orsi = 11114,
  CODE_FOR_atomic_xorsi = 11115,
  CODE_FOR_atomic_anddi = 11116,
  CODE_FOR_atomic_ordi = 11117,
  CODE_FOR_atomic_xordi = 11118,
  CODE_FOR_atomic_bit_test_and_sethi_1 = 11119,
  CODE_FOR_atomic_bit_test_and_setsi_1 = 11120,
  CODE_FOR_atomic_bit_test_and_setdi_1 = 11121,
  CODE_FOR_atomic_bit_test_and_complementhi_1 = 11122,
  CODE_FOR_atomic_bit_test_and_complementsi_1 = 11123,
  CODE_FOR_atomic_bit_test_and_complementdi_1 = 11124,
  CODE_FOR_atomic_bit_test_and_resethi_1 = 11125,
  CODE_FOR_atomic_bit_test_and_resetsi_1 = 11126,
  CODE_FOR_atomic_bit_test_and_resetdi_1 = 11127,
  CODE_FOR_atomic_add_fetch_cmp_0qi_1 = 11128,
  CODE_FOR_atomic_add_fetch_cmp_0hi_1 = 11129,
  CODE_FOR_atomic_add_fetch_cmp_0si_1 = 11130,
  CODE_FOR_atomic_add_fetch_cmp_0di_1 = 11131,
  CODE_FOR_atomic_sub_fetch_cmp_0qi_1 = 11132,
  CODE_FOR_atomic_sub_fetch_cmp_0hi_1 = 11133,
  CODE_FOR_atomic_sub_fetch_cmp_0si_1 = 11134,
  CODE_FOR_atomic_sub_fetch_cmp_0di_1 = 11135,
  CODE_FOR_atomic_and_fetch_cmp_0qi_1 = 11136,
  CODE_FOR_atomic_or_fetch_cmp_0qi_1 = 11137,
  CODE_FOR_atomic_xor_fetch_cmp_0qi_1 = 11138,
  CODE_FOR_atomic_and_fetch_cmp_0hi_1 = 11139,
  CODE_FOR_atomic_or_fetch_cmp_0hi_1 = 11140,
  CODE_FOR_atomic_xor_fetch_cmp_0hi_1 = 11141,
  CODE_FOR_atomic_and_fetch_cmp_0si_1 = 11142,
  CODE_FOR_atomic_or_fetch_cmp_0si_1 = 11143,
  CODE_FOR_atomic_xor_fetch_cmp_0si_1 = 11144,
  CODE_FOR_atomic_and_fetch_cmp_0di_1 = 11145,
  CODE_FOR_atomic_or_fetch_cmp_0di_1 = 11146,
  CODE_FOR_atomic_xor_fetch_cmp_0di_1 = 11147,
  CODE_FOR_cmpccxadd_si = 11148,
  CODE_FOR_cmpccxadd_di = 11149,
  CODE_FOR_cbranchqi4 = 11150,
  CODE_FOR_cbranchhi4 = 11151,
  CODE_FOR_cbranchsi4 = 11152,
  CODE_FOR_cbranchdi4 = 11153,
  CODE_FOR_cbranchti4 = 11154,
  CODE_FOR_cbranchoi4 = 11155,
  CODE_FOR_cbranchxi4 = 11156,
  CODE_FOR_cstoreqi4 = 11157,
  CODE_FOR_cstorehi4 = 11158,
  CODE_FOR_cstoresi4 = 11159,
  CODE_FOR_cstoredi4 = 11160,
  CODE_FOR_cstoreti4 = 11161,
  CODE_FOR_cmpqi_1 = 11162,
  CODE_FOR_cmphi_1 = 11163,
  CODE_FOR_cmpsi_1 = 11164,
  CODE_FOR_cmpdi_1 = 11165,
  CODE_FOR_cmpqi_ext_3 = 11166,
  CODE_FOR_cbranchxf4 = 11167,
  CODE_FOR_cstorexf4 = 11168,
  CODE_FOR_cbranchhf4 = 11169,
  CODE_FOR_cbranchsf4 = 11170,
  CODE_FOR_cbranchdf4 = 11171,
  CODE_FOR_cbranchbf4 = 11172,
  CODE_FOR_cstorehf4 = 11173,
  CODE_FOR_cstorebf4 = 11174,
  CODE_FOR_cstoresf4 = 11175,
  CODE_FOR_cstoredf4 = 11176,
  CODE_FOR_cbranchcc4 = 11177,
  CODE_FOR_cstoreccgc4 = 11178,
  CODE_FOR_cstoreccgoc4 = 11179,
  CODE_FOR_cstoreccno4 = 11180,
  CODE_FOR_cstoreccgz4 = 11181,
  CODE_FOR_cstorecca4 = 11182,
  CODE_FOR_cstoreccc4 = 11183,
  CODE_FOR_cstorecco4 = 11184,
  CODE_FOR_cstoreccp4 = 11185,
  CODE_FOR_cstoreccs4 = 11186,
  CODE_FOR_cstoreccz4 = 11187,
  CODE_FOR_cstorecc4 = 11188,
  CODE_FOR_reload_noff_store = 11189,
  CODE_FOR_reload_noff_load = 11190,
  CODE_FOR_movxi = 11191,
  CODE_FOR_movoi = 11192,
  CODE_FOR_movti = 11193,
  CODE_FOR_movcdi = 11194,
  CODE_FOR_movqi = 11195,
  CODE_FOR_movhi = 11196,
  CODE_FOR_movsi = 11197,
  CODE_FOR_movdi = 11198,
  CODE_FOR_movstrictqi = 11199,
  CODE_FOR_movstricthi = 11200,
  CODE_FOR_extvhi = 11201,
  CODE_FOR_extvsi = 11202,
  CODE_FOR_extzvhi = 11203,
  CODE_FOR_extzvsi = 11204,
  CODE_FOR_extzvdi = 11205,
  CODE_FOR_insvhi = 11206,
  CODE_FOR_insvsi = 11207,
  CODE_FOR_insvdi = 11208,
  CODE_FOR_movtf = 11209,
  CODE_FOR_movhf = 11210,
  CODE_FOR_movsf = 11211,
  CODE_FOR_movdf = 11212,
  CODE_FOR_movxf = 11213,
  CODE_FOR_movbf = 11214,
  CODE_FOR_zero_extendsidi2 = 11215,
  CODE_FOR_zero_extendqisi2 = 11216,
  CODE_FOR_zero_extendhisi2 = 11217,
  CODE_FOR_zero_extendqihi2 = 11218,
  CODE_FOR_extendsidi2 = 11219,
  CODE_FOR_extendsfdf2 = 11220,
  CODE_FOR_extendhfsf2 = 11221,
  CODE_FOR_extendhfdf2 = 11222,
  CODE_FOR_extendbfsf2 = 11223,
  CODE_FOR_extendsfxf2 = 11224,
  CODE_FOR_extenddfxf2 = 11225,
  CODE_FOR_truncsfhf2 = 11226,
  CODE_FOR_truncdfhf2 = 11227,
  CODE_FOR_fix_truncxfdi2 = 11228,
  CODE_FOR_fix_truncsfdi2 = 11229,
  CODE_FOR_fix_truncdfdi2 = 11230,
  CODE_FOR_fix_truncxfsi2 = 11231,
  CODE_FOR_fix_truncsfsi2 = 11232,
  CODE_FOR_fix_truncdfsi2 = 11233,
  CODE_FOR_fix_truncsfhi2 = 11234,
  CODE_FOR_fix_truncdfhi2 = 11235,
  CODE_FOR_fix_truncxfhi2 = 11236,
  CODE_FOR_fixuns_truncsfsi2 = 11237,
  CODE_FOR_fixuns_truncdfsi2 = 11238,
  CODE_FOR_fixuns_trunchfhi2 = 11239,
  CODE_FOR_fixuns_truncsfhi2 = 11240,
  CODE_FOR_fixuns_truncdfhi2 = 11241,
  CODE_FOR_floatsisf2 = 11242,
  CODE_FOR_floatdisf2 = 11243,
  CODE_FOR_floatsidf2 = 11244,
  CODE_FOR_floatdidf2 = 11245,
  CODE_FOR_floatunsqisf2 = 11246,
  CODE_FOR_floatunshisf2 = 11247,
  CODE_FOR_floatunsqidf2 = 11248,
  CODE_FOR_floatunshidf2 = 11249,
  CODE_FOR_floatunssisf2 = 11250,
  CODE_FOR_floatunssidf2 = 11251,
  CODE_FOR_floatunssixf2 = 11252,
  CODE_FOR_floatunsdisf2 = 11253,
  CODE_FOR_floatunsdidf2 = 11254,
  CODE_FOR_addqi3 = 11255,
  CODE_FOR_addhi3 = 11256,
  CODE_FOR_addsi3 = 11257,
  CODE_FOR_adddi3 = 11258,
  CODE_FOR_addti3 = 11259,
  CODE_FOR_addqi_ext_1 = 11260,
  CODE_FOR_addvqi4 = 11261,
  CODE_FOR_addvhi4 = 11262,
  CODE_FOR_addvsi4 = 11263,
  CODE_FOR_addvdi4 = 11264,
  CODE_FOR_addvti4 = 11265,
  CODE_FOR_uaddvqi4 = 11266,
  CODE_FOR_uaddvhi4 = 11267,
  CODE_FOR_uaddvsi4 = 11268,
  CODE_FOR_uaddvdi4 = 11269,
  CODE_FOR_uaddvti4 = 11270,
  CODE_FOR_subqi3 = 11271,
  CODE_FOR_subhi3 = 11272,
  CODE_FOR_subsi3 = 11273,
  CODE_FOR_subdi3 = 11274,
  CODE_FOR_subti3 = 11275,
  CODE_FOR_subvqi4 = 11276,
  CODE_FOR_subvhi4 = 11277,
  CODE_FOR_subvsi4 = 11278,
  CODE_FOR_subvdi4 = 11279,
  CODE_FOR_subvti4 = 11280,
  CODE_FOR_usubvqi4 = 11281,
  CODE_FOR_usubvhi4 = 11282,
  CODE_FOR_usubvsi4 = 11283,
  CODE_FOR_usubvdi4 = 11284,
  CODE_FOR_subqi_3 = 11285,
  CODE_FOR_subhi_3 = 11286,
  CODE_FOR_subsi_3 = 11287,
  CODE_FOR_subdi_3 = 11288,
  CODE_FOR_addcarrysi_0 = 11289,
  CODE_FOR_addcarrydi_0 = 11290,
  CODE_FOR_subborrowsi_0 = 11291,
  CODE_FOR_subborrowdi_0 = 11292,
  CODE_FOR_uaddcsi5 = 11293,
  CODE_FOR_uaddcdi5 = 11294,
  CODE_FOR_usubcsi5 = 11295,
  CODE_FOR_usubcdi5 = 11296,
  CODE_FOR_addqi3_cconly_overflow = 11297,
  CODE_FOR_usaddqi3 = 11298,
  CODE_FOR_usaddhi3 = 11299,
  CODE_FOR_usaddsi3 = 11300,
  CODE_FOR_usadddi3 = 11301,
  CODE_FOR_ussubqi3 = 11302,
  CODE_FOR_ussubhi3 = 11303,
  CODE_FOR_ussubsi3 = 11304,
  CODE_FOR_ussubdi3 = 11305,
  CODE_FOR_ustruncdiqi2 = 11306,
  CODE_FOR_ustruncdihi2 = 11307,
  CODE_FOR_ustruncdisi2 = 11308,
  CODE_FOR_ustruncsiqi2 = 11309,
  CODE_FOR_ustruncsihi2 = 11310,
  CODE_FOR_ustrunchiqi2 = 11311,
  CODE_FOR_addxf3 = 11312,
  CODE_FOR_subxf3 = 11313,
  CODE_FOR_addhf3 = 11314,
  CODE_FOR_subhf3 = 11315,
  CODE_FOR_addsf3 = 11316,
  CODE_FOR_subsf3 = 11317,
  CODE_FOR_adddf3 = 11318,
  CODE_FOR_subdf3 = 11319,
  CODE_FOR_mulhi3 = 11320,
  CODE_FOR_mulsi3 = 11321,
  CODE_FOR_muldi3 = 11322,
  CODE_FOR_mulqi3 = 11323,
  CODE_FOR_mulvhi4 = 11324,
  CODE_FOR_mulvsi4 = 11325,
  CODE_FOR_mulvdi4 = 11326,
  CODE_FOR_umulvhi4 = 11327,
  CODE_FOR_umulvsi4 = 11328,
  CODE_FOR_umulvdi4 = 11329,
  CODE_FOR_mulvqi4 = 11330,
  CODE_FOR_umulvqi4 = 11331,
  CODE_FOR_mulsidi3 = 11332,
  CODE_FOR_umulsidi3 = 11333,
  CODE_FOR_mulditi3 = 11334,
  CODE_FOR_umulditi3 = 11335,
  CODE_FOR_mulqihi3 = 11336,
  CODE_FOR_umulqihi3 = 11337,
  CODE_FOR_mulxf3 = 11338,
  CODE_FOR_mulhf3 = 11339,
  CODE_FOR_mulsf3 = 11340,
  CODE_FOR_muldf3 = 11341,
  CODE_FOR_divxf3 = 11342,
  CODE_FOR_divhf3 = 11343,
  CODE_FOR_divsf3 = 11344,
  CODE_FOR_divdf3 = 11345,
  CODE_FOR_divmodhi4 = 11346,
  CODE_FOR_udivmodhi4 = 11347,
  CODE_FOR_divmodsi4 = 11348,
  CODE_FOR_udivmodsi4 = 11349,
  CODE_FOR_divmoddi4 = 11350,
  CODE_FOR_udivmoddi4 = 11351,
  CODE_FOR_divmodqi4 = 11352,
  CODE_FOR_udivmodqi4 = 11353,
  CODE_FOR_testsi_ccno_1 = 11354,
  CODE_FOR_testdi_ccno_1 = 11355,
  CODE_FOR_testqi_ccz_1 = 11356,
  CODE_FOR_testqi_ext_1_ccno = 11357,
  CODE_FOR_andqi3 = 11358,
  CODE_FOR_andhi3 = 11359,
  CODE_FOR_andsi3 = 11360,
  CODE_FOR_anddi3 = 11361,
  CODE_FOR_andti3 = 11362,
  CODE_FOR_andqi_ext_1 = 11363,
  CODE_FOR_iorqi3 = 11364,
  CODE_FOR_xorqi3 = 11365,
  CODE_FOR_iorhi3 = 11366,
  CODE_FOR_xorhi3 = 11367,
  CODE_FOR_iorsi3 = 11368,
  CODE_FOR_xorsi3 = 11369,
  CODE_FOR_iordi3 = 11370,
  CODE_FOR_xordi3 = 11371,
  CODE_FOR_iorti3 = 11372,
  CODE_FOR_xorti3 = 11373,
  CODE_FOR_xorqi_ext_1_cc = 11374,
  CODE_FOR_negqi2 = 11375,
  CODE_FOR_neghi2 = 11376,
  CODE_FOR_negsi2 = 11377,
  CODE_FOR_negdi2 = 11378,
  CODE_FOR_negti2 = 11379,
  CODE_FOR_x86_negsi_ccc = 11380,
  CODE_FOR_x86_negdi_ccc = 11381,
  CODE_FOR_negvqi3 = 11382,
  CODE_FOR_negvhi3 = 11383,
  CODE_FOR_negvsi3 = 11384,
  CODE_FOR_negvdi3 = 11385,
  CODE_FOR_absqi2 = 11386,
  CODE_FOR_abshi2 = 11387,
  CODE_FOR_abssi2 = 11388,
  CODE_FOR_absdi2 = 11389,
  CODE_FOR_absti2 = 11390,
  CODE_FOR_abstf2 = 11391,
  CODE_FOR_negtf2 = 11392,
  CODE_FOR_abshf2 = 11393,
  CODE_FOR_neghf2 = 11394,
  CODE_FOR_abssf2 = 11395,
  CODE_FOR_negsf2 = 11396,
  CODE_FOR_absdf2 = 11397,
  CODE_FOR_negdf2 = 11398,
  CODE_FOR_absxf2 = 11399,
  CODE_FOR_negxf2 = 11400,
  CODE_FOR_copysignhf3 = 11401,
  CODE_FOR_copysignsf3 = 11402,
  CODE_FOR_copysigndf3 = 11403,
  CODE_FOR_copysigntf3 = 11404,
  CODE_FOR_xorsignhf3 = 11405,
  CODE_FOR_xorsignsf3 = 11406,
  CODE_FOR_xorsigndf3 = 11407,
  CODE_FOR_one_cmplqi2 = 11408,
  CODE_FOR_one_cmplhi2 = 11409,
  CODE_FOR_one_cmplsi2 = 11410,
  CODE_FOR_one_cmpldi2 = 11411,
  CODE_FOR_one_cmplti2 = 11412,
  CODE_FOR_ashlqi3 = 11413,
  CODE_FOR_ashlhi3 = 11414,
  CODE_FOR_ashlsi3 = 11415,
  CODE_FOR_ashldi3 = 11416,
  CODE_FOR_ashlti3 = 11417,
  CODE_FOR_x86_shiftsi_adj_1 = 11418,
  CODE_FOR_x86_shiftdi_adj_1 = 11419,
  CODE_FOR_x86_shiftsi_adj_2 = 11420,
  CODE_FOR_x86_shiftdi_adj_2 = 11421,
  CODE_FOR_lshrqi3 = 11422,
  CODE_FOR_ashrqi3 = 11423,
  CODE_FOR_lshrhi3 = 11424,
  CODE_FOR_ashrhi3 = 11425,
  CODE_FOR_lshrsi3 = 11426,
  CODE_FOR_ashrsi3 = 11427,
  CODE_FOR_lshrdi3 = 11428,
  CODE_FOR_ashrdi3 = 11429,
  CODE_FOR_lshrti3 = 11430,
  CODE_FOR_ashrti3 = 11431,
  CODE_FOR_x86_shiftsi_adj_3 = 11432,
  CODE_FOR_x86_shiftdi_adj_3 = 11433,
  CODE_FOR_rotlti3 = 11434,
  CODE_FOR_rotrti3 = 11435,
  CODE_FOR_rotldi3 = 11436,
  CODE_FOR_rotrdi3 = 11437,
  CODE_FOR_rotlqi3 = 11438,
  CODE_FOR_rotrqi3 = 11439,
  CODE_FOR_rotlhi3 = 11440,
  CODE_FOR_rotrhi3 = 11441,
  CODE_FOR_rotlsi3 = 11442,
  CODE_FOR_rotrsi3 = 11443,
  CODE_FOR_setcc_si_slp = 11444,
  CODE_FOR_indirect_jump = 11445,
  CODE_FOR_tablejump = 11446,
  CODE_FOR_call = 11447,
  CODE_FOR_sibcall = 11448,
  CODE_FOR_call_pop = 11449,
  CODE_FOR_call_value = 11450,
  CODE_FOR_sibcall_value = 11451,
  CODE_FOR_call_value_pop = 11452,
  CODE_FOR_untyped_call = 11453,
  CODE_FOR_memory_blockage = 11454,
  CODE_FOR_return = 11455,
  CODE_FOR_simple_return = 11456,
  CODE_FOR_simple_return_indirect_internal = 11457,
  CODE_FOR_prologue = 11458,
  CODE_FOR_set_got = 11459,
  CODE_FOR_set_got_labelled = 11460,
  CODE_FOR_epilogue = 11461,
  CODE_FOR_sibcall_epilogue = 11462,
  CODE_FOR_eh_return = 11463,
  CODE_FOR_leave_si = 11464,
  CODE_FOR_leave_di = 11465,
  CODE_FOR_split_stack_prologue = 11466,
  CODE_FOR_split_stack_space_check = 11467,
  CODE_FOR_ffssi2 = 11468,
  CODE_FOR_ffsdi2 = 11469,
  CODE_FOR_clzsi2 = 11470,
  CODE_FOR_clzdi2 = 11471,
  CODE_FOR_bmi2_bzhi_si3 = 11472,
  CODE_FOR_bmi2_bzhi_di3 = 11473,
  CODE_FOR_bswapdi2 = 11474,
  CODE_FOR_bswapsi2 = 11475,
  CODE_FOR_bswaphi2 = 11476,
  CODE_FOR_paritydi2 = 11477,
  CODE_FOR_paritysi2 = 11478,
  CODE_FOR_parityhi2 = 11479,
  CODE_FOR_parityqi2 = 11480,
  CODE_FOR_tls_global_dynamic_32 = 11481,
  CODE_FOR_tls_global_dynamic_64_si = 11482,
  CODE_FOR_tls_global_dynamic_64_di = 11483,
  CODE_FOR_tls_local_dynamic_base_32 = 11484,
  CODE_FOR_tls_local_dynamic_base_64_si = 11485,
  CODE_FOR_tls_local_dynamic_base_64_di = 11486,
  CODE_FOR_get_thread_pointersi = 11487,
  CODE_FOR_get_thread_pointerdi = 11488,
  CODE_FOR_tls_dynamic_gnu2_32 = 11489,
  CODE_FOR_tls_dynamic_gnu2_64_si = 11490,
  CODE_FOR_tls_dynamic_gnu2_64_di = 11491,
  CODE_FOR_rsqrtsf2 = 11492,
  CODE_FOR_sqrtsf2 = 11493,
  CODE_FOR_sqrtdf2 = 11494,
  CODE_FOR_hypotsf3 = 11495,
  CODE_FOR_hypotdf3 = 11496,
  CODE_FOR_fmodxf3 = 11497,
  CODE_FOR_fmodsf3 = 11498,
  CODE_FOR_fmoddf3 = 11499,
  CODE_FOR_remainderxf3 = 11500,
  CODE_FOR_remaindersf3 = 11501,
  CODE_FOR_remainderdf3 = 11502,
  CODE_FOR_sinsf2 = 11503,
  CODE_FOR_cossf2 = 11504,
  CODE_FOR_sindf2 = 11505,
  CODE_FOR_cosdf2 = 11506,
  CODE_FOR_sincossf3 = 11507,
  CODE_FOR_sincosdf3 = 11508,
  CODE_FOR_tanxf2 = 11509,
  CODE_FOR_tansf2 = 11510,
  CODE_FOR_tandf2 = 11511,
  CODE_FOR_atan2sf3 = 11512,
  CODE_FOR_atan2df3 = 11513,
  CODE_FOR_atanxf2 = 11514,
  CODE_FOR_atansf2 = 11515,
  CODE_FOR_atandf2 = 11516,
  CODE_FOR_asinxf2 = 11517,
  CODE_FOR_asinsf2 = 11518,
  CODE_FOR_asindf2 = 11519,
  CODE_FOR_acosxf2 = 11520,
  CODE_FOR_acossf2 = 11521,
  CODE_FOR_acosdf2 = 11522,
  CODE_FOR_sinhxf2 = 11523,
  CODE_FOR_sinhsf2 = 11524,
  CODE_FOR_sinhdf2 = 11525,
  CODE_FOR_coshxf2 = 11526,
  CODE_FOR_coshsf2 = 11527,
  CODE_FOR_coshdf2 = 11528,
  CODE_FOR_tanhxf2 = 11529,
  CODE_FOR_tanhsf2 = 11530,
  CODE_FOR_tanhdf2 = 11531,
  CODE_FOR_asinhxf2 = 11532,
  CODE_FOR_asinhsf2 = 11533,
  CODE_FOR_asinhdf2 = 11534,
  CODE_FOR_acoshxf2 = 11535,
  CODE_FOR_acoshsf2 = 11536,
  CODE_FOR_acoshdf2 = 11537,
  CODE_FOR_atanhxf2 = 11538,
  CODE_FOR_atanhsf2 = 11539,
  CODE_FOR_atanhdf2 = 11540,
  CODE_FOR_logxf2 = 11541,
  CODE_FOR_logsf2 = 11542,
  CODE_FOR_logdf2 = 11543,
  CODE_FOR_log10xf2 = 11544,
  CODE_FOR_log10sf2 = 11545,
  CODE_FOR_log10df2 = 11546,
  CODE_FOR_log2xf2 = 11547,
  CODE_FOR_log2sf2 = 11548,
  CODE_FOR_log2df2 = 11549,
  CODE_FOR_log1pxf2 = 11550,
  CODE_FOR_log1psf2 = 11551,
  CODE_FOR_log1pdf2 = 11552,
  CODE_FOR_logbxf2 = 11553,
  CODE_FOR_logbsf2 = 11554,
  CODE_FOR_logbdf2 = 11555,
  CODE_FOR_ilogbxf2 = 11556,
  CODE_FOR_ilogbsf2 = 11557,
  CODE_FOR_ilogbdf2 = 11558,
  CODE_FOR_expNcorexf3 = 11559,
  CODE_FOR_expxf2 = 11560,
  CODE_FOR_expsf2 = 11561,
  CODE_FOR_expdf2 = 11562,
  CODE_FOR_exp10xf2 = 11563,
  CODE_FOR_exp10sf2 = 11564,
  CODE_FOR_exp10df2 = 11565,
  CODE_FOR_exp2xf2 = 11566,
  CODE_FOR_exp2sf2 = 11567,
  CODE_FOR_exp2df2 = 11568,
  CODE_FOR_expm1xf2 = 11569,
  CODE_FOR_expm1sf2 = 11570,
  CODE_FOR_expm1df2 = 11571,
  CODE_FOR_ldexpxf3 = 11572,
  CODE_FOR_ldexpsf3 = 11573,
  CODE_FOR_ldexpdf3 = 11574,
  CODE_FOR_scalbxf3 = 11575,
  CODE_FOR_scalbsf3 = 11576,
  CODE_FOR_scalbdf3 = 11577,
  CODE_FOR_significandxf2 = 11578,
  CODE_FOR_significandsf2 = 11579,
  CODE_FOR_significanddf2 = 11580,
  CODE_FOR_rinthf2 = 11581,
  CODE_FOR_rintsf2 = 11582,
  CODE_FOR_rintdf2 = 11583,
  CODE_FOR_nearbyintxf2 = 11584,
  CODE_FOR_nearbyinthf2 = 11585,
  CODE_FOR_nearbyintsf2 = 11586,
  CODE_FOR_nearbyintdf2 = 11587,
  CODE_FOR_roundhf2 = 11588,
  CODE_FOR_roundsf2 = 11589,
  CODE_FOR_rounddf2 = 11590,
  CODE_FOR_roundxf2 = 11591,
  CODE_FOR_lroundhfhi2 = 11592,
  CODE_FOR_lroundhfsi2 = 11593,
  CODE_FOR_lroundhfdi2 = 11594,
  CODE_FOR_lrinthfsi2 = 11595,
  CODE_FOR_lrinthfdi2 = 11596,
  CODE_FOR_lrintsfsi2 = 11597,
  CODE_FOR_lrintsfdi2 = 11598,
  CODE_FOR_lrintdfsi2 = 11599,
  CODE_FOR_lrintdfdi2 = 11600,
  CODE_FOR_lroundsfhi2 = 11601,
  CODE_FOR_lrounddfhi2 = 11602,
  CODE_FOR_lroundxfhi2 = 11603,
  CODE_FOR_lroundsfsi2 = 11604,
  CODE_FOR_lrounddfsi2 = 11605,
  CODE_FOR_lroundxfsi2 = 11606,
  CODE_FOR_lroundsfdi2 = 11607,
  CODE_FOR_lrounddfdi2 = 11608,
  CODE_FOR_lroundxfdi2 = 11609,
  CODE_FOR_roundevenxf2 = 11610,
  CODE_FOR_floorxf2 = 11611,
  CODE_FOR_ceilxf2 = 11612,
  CODE_FOR_btruncxf2 = 11613,
  CODE_FOR_roundevenhf2 = 11614,
  CODE_FOR_floorhf2 = 11615,
  CODE_FOR_ceilhf2 = 11616,
  CODE_FOR_btrunchf2 = 11617,
  CODE_FOR_roundevensf2 = 11618,
  CODE_FOR_floorsf2 = 11619,
  CODE_FOR_ceilsf2 = 11620,
  CODE_FOR_btruncsf2 = 11621,
  CODE_FOR_roundevendf2 = 11622,
  CODE_FOR_floordf2 = 11623,
  CODE_FOR_ceildf2 = 11624,
  CODE_FOR_btruncdf2 = 11625,
  CODE_FOR_lfloorxfhi2 = 11626,
  CODE_FOR_lceilxfhi2 = 11627,
  CODE_FOR_lfloorxfsi2 = 11628,
  CODE_FOR_lceilxfsi2 = 11629,
  CODE_FOR_lfloorxfdi2 = 11630,
  CODE_FOR_lceilxfdi2 = 11631,
  CODE_FOR_lfloorhfsi2 = 11632,
  CODE_FOR_lceilhfsi2 = 11633,
  CODE_FOR_lfloorhfdi2 = 11634,
  CODE_FOR_lceilhfdi2 = 11635,
  CODE_FOR_lfloorsfsi2 = 11636,
  CODE_FOR_lceilsfsi2 = 11637,
  CODE_FOR_lfloorsfdi2 = 11638,
  CODE_FOR_lceilsfdi2 = 11639,
  CODE_FOR_lfloordfsi2 = 11640,
  CODE_FOR_lceildfsi2 = 11641,
  CODE_FOR_lfloordfdi2 = 11642,
  CODE_FOR_lceildfdi2 = 11643,
  CODE_FOR_signbittf2 = 11644,
  CODE_FOR_signbitxf2 = 11645,
  CODE_FOR_signbitdf2 = 11646,
  CODE_FOR_signbitsf2 = 11647,
  CODE_FOR_movmemsi = 11648,
  CODE_FOR_movmemdi = 11649,
  CODE_FOR_cpymemsi = 11650,
  CODE_FOR_cpymemdi = 11651,
  CODE_FOR_strmov = 11652,
  CODE_FOR_strmov_singleop = 11653,
  CODE_FOR_rep_mov = 11654,
  CODE_FOR_setmemsi = 11655,
  CODE_FOR_setmemdi = 11656,
  CODE_FOR_strset = 11657,
  CODE_FOR_strset_singleop = 11658,
  CODE_FOR_rep_stos = 11659,
  CODE_FOR_cmpmemsi = 11660,
  CODE_FOR_cmpstrnsi = 11661,
  CODE_FOR_cmpintqi = 11662,
  CODE_FOR_cmpstrnqi_nz_1 = 11663,
  CODE_FOR_cmpstrnqi_1 = 11664,
  CODE_FOR_strlensi = 11665,
  CODE_FOR_strlendi = 11666,
  CODE_FOR_strlenqi_1 = 11667,
  CODE_FOR_movqicc = 11668,
  CODE_FOR_movhicc = 11669,
  CODE_FOR_movsicc = 11670,
  CODE_FOR_movdicc = 11671,
  CODE_FOR_x86_movsicc_0_m1 = 11672,
  CODE_FOR_x86_movdicc_0_m1 = 11673,
  CODE_FOR_x86_movqicc_0_m1_neg = 11674,
  CODE_FOR_x86_movhicc_0_m1_neg = 11675,
  CODE_FOR_x86_movsicc_0_m1_neg = 11676,
  CODE_FOR_x86_movdicc_0_m1_neg = 11677,
  CODE_FOR_movhfcc = 11678,
  CODE_FOR_movsfcc = 11679,
  CODE_FOR_movdfcc = 11680,
  CODE_FOR_movxfcc = 11681,
  CODE_FOR_addqicc = 11682,
  CODE_FOR_addhicc = 11683,
  CODE_FOR_addsicc = 11684,
  CODE_FOR_adddicc = 11685,
  CODE_FOR_smaxqi3 = 11686,
  CODE_FOR_sminqi3 = 11687,
  CODE_FOR_umaxqi3 = 11688,
  CODE_FOR_uminqi3 = 11689,
  CODE_FOR_smaxhi3 = 11690,
  CODE_FOR_sminhi3 = 11691,
  CODE_FOR_umaxhi3 = 11692,
  CODE_FOR_uminhi3 = 11693,
  CODE_FOR_smaxsi3 = 11694,
  CODE_FOR_sminsi3 = 11695,
  CODE_FOR_umaxsi3 = 11696,
  CODE_FOR_uminsi3 = 11697,
  CODE_FOR_smaxdi3 = 11698,
  CODE_FOR_smindi3 = 11699,
  CODE_FOR_umaxdi3 = 11700,
  CODE_FOR_umindi3 = 11701,
  CODE_FOR_smaxti3 = 11702,
  CODE_FOR_sminti3 = 11703,
  CODE_FOR_umaxti3 = 11704,
  CODE_FOR_uminti3 = 11705,
  CODE_FOR_allocate_stack = 11706,
  CODE_FOR_probe_stack = 11707,
  CODE_FOR_builtin_setjmp_receiver = 11708,
  CODE_FOR_save_stack_nonlocal = 11709,
  CODE_FOR_restore_stack_nonlocal = 11710,
  CODE_FOR_stack_protect_set = 11711,
  CODE_FOR_stack_protect_test = 11712,
  CODE_FOR_prefetch = 11713,
  CODE_FOR_crc_revqisi4 = 11714,
  CODE_FOR_crc_revhisi4 = 11715,
  CODE_FOR_crc_revsisi4 = 11716,
  CODE_FOR_pause = 11717,
  CODE_FOR_xbegin = 11718,
  CODE_FOR_xtest = 11719,
  CODE_FOR_rdpkru = 11720,
  CODE_FOR_wrpkru = 11721,
  CODE_FOR_spaceshipsf4 = 11722,
  CODE_FOR_spaceshipdf4 = 11723,
  CODE_FOR_spaceshipxf4 = 11724,
  CODE_FOR_spaceshipqi4 = 11725,
  CODE_FOR_spaceshiphi4 = 11726,
  CODE_FOR_spaceshipsi4 = 11727,
  CODE_FOR_spaceshipdi4 = 11728,
  CODE_FOR_issignalingxf2 = 11729,
  CODE_FOR_movv8qi = 11730,
  CODE_FOR_movv4hi = 11731,
  CODE_FOR_movv2si = 11732,
  CODE_FOR_movv1di = 11733,
  CODE_FOR_movv2sf = 11734,
  CODE_FOR_movv4hf = 11735,
  CODE_FOR_movv4bf = 11736,
  CODE_FOR_movmisalignv8qi = 11737,
  CODE_FOR_movmisalignv4hi = 11738,
  CODE_FOR_movmisalignv2si = 11739,
  CODE_FOR_movmisalignv1di = 11740,
  CODE_FOR_movmisalignv2sf = 11741,
  CODE_FOR_movmisalignv4hf = 11742,
  CODE_FOR_movmisalignv4bf = 11743,
  CODE_FOR_movv4qi = 11744,
  CODE_FOR_movv2hi = 11745,
  CODE_FOR_movv1si = 11746,
  CODE_FOR_movv2hf = 11747,
  CODE_FOR_movv2bf = 11748,
  CODE_FOR_movmisalignv4qi = 11749,
  CODE_FOR_movmisalignv2hi = 11750,
  CODE_FOR_movmisalignv1si = 11751,
  CODE_FOR_movmisalignv2hf = 11752,
  CODE_FOR_movmisalignv2bf = 11753,
  CODE_FOR_movv2qi = 11754,
  CODE_FOR_movmisalignv2qi = 11755,
  CODE_FOR_movq_v2sf_to_sse = 11756,
  CODE_FOR_movq_v2si_to_sse = 11757,
  CODE_FOR_movq_v4hf_to_sse = 11758,
  CODE_FOR_movq_v4hi_to_sse = 11759,
  CODE_FOR_absv2sf2 = 11760,
  CODE_FOR_negv2sf2 = 11761,
  CODE_FOR_addv2sf3 = 11762,
  CODE_FOR_subv2sf3 = 11763,
  CODE_FOR_mulv2sf3 = 11764,
  CODE_FOR_mmx_addv2sf3 = 11765,
  CODE_FOR_mmx_subv2sf3 = 11766,
  CODE_FOR_mmx_subrv2sf3 = 11767,
  CODE_FOR_mmx_mulv2sf3 = 11768,
  CODE_FOR_divv2sf3 = 11769,
  CODE_FOR_smaxv2sf3 = 11770,
  CODE_FOR_sminv2sf3 = 11771,
  CODE_FOR_mmx_smaxv2sf3 = 11772,
  CODE_FOR_mmx_sminv2sf3 = 11773,
  CODE_FOR_sqrtv2sf2 = 11774,
  CODE_FOR_mmx_haddv2sf3 = 11775,
  CODE_FOR_mmx_haddsubv2sf3 = 11776,
  CODE_FOR_vec_addsubv2sf3 = 11777,
  CODE_FOR_vec_fmaddsubv2sf4 = 11778,
  CODE_FOR_vec_fmsubaddv2sf4 = 11779,
  CODE_FOR_mmx_eqv2sf3 = 11780,
  CODE_FOR_vec_cmpv2sfv2si = 11781,
  CODE_FOR_copysignv2sf3 = 11782,
  CODE_FOR_xorsignv2sf3 = 11783,
  CODE_FOR_signbitv2sf2 = 11784,
  CODE_FOR_fmav2sf4 = 11785,
  CODE_FOR_fmsv2sf4 = 11786,
  CODE_FOR_fnmav2sf4 = 11787,
  CODE_FOR_fnmsv2sf4 = 11788,
  CODE_FOR_fix_truncv2sfv2si2 = 11789,
  CODE_FOR_fixuns_truncv2sfv2si2 = 11790,
  CODE_FOR_floatv2siv2sf2 = 11791,
  CODE_FOR_floatunsv2siv2sf2 = 11792,
  CODE_FOR_vec_setv2sf = 11793,
  CODE_FOR_vec_extractv2sfsf = 11794,
  CODE_FOR_vec_initv2sfsf = 11795,
  CODE_FOR_nearbyintv2sf2 = 11796,
  CODE_FOR_rintv2sf2 = 11797,
  CODE_FOR_lrintv2sfv2si2 = 11798,
  CODE_FOR_ceilv2sf2 = 11799,
  CODE_FOR_lceilv2sfv2si2 = 11800,
  CODE_FOR_floorv2sf2 = 11801,
  CODE_FOR_lfloorv2sfv2si2 = 11802,
  CODE_FOR_btruncv2sf2 = 11803,
  CODE_FOR_roundv2sf2 = 11804,
  CODE_FOR_lroundv2sfv2si2 = 11805,
  CODE_FOR_divv4hf3 = 11806,
  CODE_FOR_movd_v2hf_to_sse = 11807,
  CODE_FOR_movd_v2bf_to_sse = 11808,
  CODE_FOR_movd_v2hi_to_sse = 11809,
  CODE_FOR_movd_v2hf_to_sse_reg = 11810,
  CODE_FOR_movd_v2bf_to_sse_reg = 11811,
  CODE_FOR_movd_v2hi_to_sse_reg = 11812,
  CODE_FOR_addv2hf3 = 11813,
  CODE_FOR_subv2hf3 = 11814,
  CODE_FOR_mulv2hf3 = 11815,
  CODE_FOR_addv4hf3 = 11816,
  CODE_FOR_subv4hf3 = 11817,
  CODE_FOR_mulv4hf3 = 11818,
  CODE_FOR_addv2bf3 = 11819,
  CODE_FOR_subv2bf3 = 11820,
  CODE_FOR_mulv2bf3 = 11821,
  CODE_FOR_divv2bf3 = 11822,
  CODE_FOR_addv4bf3 = 11823,
  CODE_FOR_subv4bf3 = 11824,
  CODE_FOR_mulv4bf3 = 11825,
  CODE_FOR_divv4bf3 = 11826,
  CODE_FOR_divv2hf3 = 11827,
  CODE_FOR_smaxv2hf3 = 11828,
  CODE_FOR_sminv2hf3 = 11829,
  CODE_FOR_smaxv4hf3 = 11830,
  CODE_FOR_sminv4hf3 = 11831,
  CODE_FOR_smaxv2bf3 = 11832,
  CODE_FOR_sminv2bf3 = 11833,
  CODE_FOR_smaxv4bf3 = 11834,
  CODE_FOR_sminv4bf3 = 11835,
  CODE_FOR_sqrtv2hf2 = 11836,
  CODE_FOR_sqrtv4hf2 = 11837,
  CODE_FOR_sqrtv2bf2 = 11838,
  CODE_FOR_sqrtv4bf2 = 11839,
  CODE_FOR_absv2bf2 = 11840,
  CODE_FOR_negv2bf2 = 11841,
  CODE_FOR_absv4bf2 = 11842,
  CODE_FOR_negv4bf2 = 11843,
  CODE_FOR_absv2hf2 = 11844,
  CODE_FOR_negv2hf2 = 11845,
  CODE_FOR_absv4hf2 = 11846,
  CODE_FOR_negv4hf2 = 11847,
  CODE_FOR_vec_cmpv4hfqi = 11848,
  CODE_FOR_vcond_mask_v4hfv4hi = 11849,
  CODE_FOR_vcond_mask_v4bfv4hi = 11850,
  CODE_FOR_vcond_mask_v4hfqi = 11851,
  CODE_FOR_vcond_mask_v4bfqi = 11852,
  CODE_FOR_vcond_mask_v4hiqi = 11853,
  CODE_FOR_vec_cmpv2hfqi = 11854,
  CODE_FOR_vcond_mask_v2hfv2hi = 11855,
  CODE_FOR_vcond_mask_v2bfv2hi = 11856,
  CODE_FOR_vcond_mask_v2hfqi = 11857,
  CODE_FOR_vcond_mask_v2bfqi = 11858,
  CODE_FOR_vcond_mask_v2hiqi = 11859,
  CODE_FOR_vec_cmpv2bfqi = 11860,
  CODE_FOR_vec_cmpv4bfqi = 11861,
  CODE_FOR_btruncv2hf2 = 11862,
  CODE_FOR_btruncv4hf2 = 11863,
  CODE_FOR_nearbyintv2hf2 = 11864,
  CODE_FOR_nearbyintv4hf2 = 11865,
  CODE_FOR_rintv2hf2 = 11866,
  CODE_FOR_rintv4hf2 = 11867,
  CODE_FOR_lrintv2hfv2hi2 = 11868,
  CODE_FOR_lrintv4hfv4hi2 = 11869,
  CODE_FOR_floorv2hf2 = 11870,
  CODE_FOR_floorv4hf2 = 11871,
  CODE_FOR_lfloorv2hfv2hi2 = 11872,
  CODE_FOR_lfloorv4hfv4hi2 = 11873,
  CODE_FOR_ceilv2hf2 = 11874,
  CODE_FOR_ceilv4hf2 = 11875,
  CODE_FOR_lceilv2hfv2hi2 = 11876,
  CODE_FOR_lceilv4hfv4hi2 = 11877,
  CODE_FOR_roundv2hf2 = 11878,
  CODE_FOR_roundv4hf2 = 11879,
  CODE_FOR_lroundv2hfv2hi2 = 11880,
  CODE_FOR_lroundv4hfv4hi2 = 11881,
  CODE_FOR_copysignv2bf3 = 11882,
  CODE_FOR_copysignv4bf3 = 11883,
  CODE_FOR_copysignv2hf3 = 11884,
  CODE_FOR_copysignv4hf3 = 11885,
  CODE_FOR_xorsignv2bf3 = 11886,
  CODE_FOR_xorsignv4bf3 = 11887,
  CODE_FOR_xorsignv2hf3 = 11888,
  CODE_FOR_xorsignv4hf3 = 11889,
  CODE_FOR_signbitv2bf2 = 11890,
  CODE_FOR_signbitv4bf2 = 11891,
  CODE_FOR_signbitv2hf2 = 11892,
  CODE_FOR_signbitv4hf2 = 11893,
  CODE_FOR_fmav2hf4 = 11894,
  CODE_FOR_fmav4hf4 = 11895,
  CODE_FOR_fmsv2hf4 = 11896,
  CODE_FOR_fmsv4hf4 = 11897,
  CODE_FOR_fnmav2hf4 = 11898,
  CODE_FOR_fnmav4hf4 = 11899,
  CODE_FOR_fnmsv2hf4 = 11900,
  CODE_FOR_fnmsv4hf4 = 11901,
  CODE_FOR_vec_fmaddsubv4hf4 = 11902,
  CODE_FOR_vec_fmsubaddv4hf4 = 11903,
  CODE_FOR_fmav2bf4 = 11904,
  CODE_FOR_fmav4bf4 = 11905,
  CODE_FOR_fmsv2bf4 = 11906,
  CODE_FOR_fmsv4bf4 = 11907,
  CODE_FOR_fnmav2bf4 = 11908,
  CODE_FOR_fnmav4bf4 = 11909,
  CODE_FOR_fnmsv2bf4 = 11910,
  CODE_FOR_fnmsv4bf4 = 11911,
  CODE_FOR_cmlav4hf4 = 11912,
  CODE_FOR_cmla_conjv4hf4 = 11913,
  CODE_FOR_cmulv4hf3 = 11914,
  CODE_FOR_cmul_conjv4hf3 = 11915,
  CODE_FOR_fix_truncv2hfv2hi2 = 11916,
  CODE_FOR_fixuns_truncv2hfv2hi2 = 11917,
  CODE_FOR_fix_truncv4hfv4hi2 = 11918,
  CODE_FOR_fixuns_truncv4hfv4hi2 = 11919,
  CODE_FOR_fix_truncv2hfv2si2 = 11920,
  CODE_FOR_fixuns_truncv2hfv2si2 = 11921,
  CODE_FOR_floatv2hiv2hf2 = 11922,
  CODE_FOR_floatunsv2hiv2hf2 = 11923,
  CODE_FOR_floatv4hiv4hf2 = 11924,
  CODE_FOR_floatunsv4hiv4hf2 = 11925,
  CODE_FOR_floatv2siv2hf2 = 11926,
  CODE_FOR_floatunsv2siv2hf2 = 11927,
  CODE_FOR_extendv2hfv2sf2 = 11928,
  CODE_FOR_truncv2sfv2hf2 = 11929,
  CODE_FOR_truncv2sfv2bf2 = 11930,
  CODE_FOR_extendv2bfv2sf2 = 11931,
  CODE_FOR_negv8qi2 = 11932,
  CODE_FOR_negv4hi2 = 11933,
  CODE_FOR_negv2si2 = 11934,
  CODE_FOR_negv4qi2 = 11935,
  CODE_FOR_negv2hi2 = 11936,
  CODE_FOR_mmx_addv8qi3 = 11937,
  CODE_FOR_mmx_subv8qi3 = 11938,
  CODE_FOR_mmx_addv4hi3 = 11939,
  CODE_FOR_mmx_subv4hi3 = 11940,
  CODE_FOR_mmx_addv2si3 = 11941,
  CODE_FOR_mmx_subv2si3 = 11942,
  CODE_FOR_mmx_addv1di3 = 11943,
  CODE_FOR_mmx_subv1di3 = 11944,
  CODE_FOR_addv8qi3 = 11945,
  CODE_FOR_subv8qi3 = 11946,
  CODE_FOR_addv4hi3 = 11947,
  CODE_FOR_subv4hi3 = 11948,
  CODE_FOR_addv2si3 = 11949,
  CODE_FOR_subv2si3 = 11950,
  CODE_FOR_mmx_ssaddv8qi3 = 11951,
  CODE_FOR_mmx_usaddv8qi3 = 11952,
  CODE_FOR_mmx_sssubv8qi3 = 11953,
  CODE_FOR_mmx_ussubv8qi3 = 11954,
  CODE_FOR_mmx_ssaddv4hi3 = 11955,
  CODE_FOR_mmx_usaddv4hi3 = 11956,
  CODE_FOR_mmx_sssubv4hi3 = 11957,
  CODE_FOR_mmx_ussubv4hi3 = 11958,
  CODE_FOR_ssaddv8qi3 = 11959,
  CODE_FOR_usaddv8qi3 = 11960,
  CODE_FOR_sssubv8qi3 = 11961,
  CODE_FOR_ussubv8qi3 = 11962,
  CODE_FOR_ssaddv4hi3 = 11963,
  CODE_FOR_usaddv4hi3 = 11964,
  CODE_FOR_sssubv4hi3 = 11965,
  CODE_FOR_ussubv4hi3 = 11966,
  CODE_FOR_mmx_mulv4hi3 = 11967,
  CODE_FOR_mulv4hi3 = 11968,
  CODE_FOR_mulv8qi3 = 11969,
  CODE_FOR_mulv4qi3 = 11970,
  CODE_FOR_mmx_smulv4hi3_highpart = 11971,
  CODE_FOR_mmx_umulv4hi3_highpart = 11972,
  CODE_FOR_smulv4hi3_highpart = 11973,
  CODE_FOR_umulv4hi3_highpart = 11974,
  CODE_FOR_mmx_pmaddwd = 11975,
  CODE_FOR_mmx_pmulhrwv4hi3 = 11976,
  CODE_FOR_sse2_umulv1siv1di3 = 11977,
  CODE_FOR_mmx_smaxv4hi3 = 11978,
  CODE_FOR_mmx_sminv4hi3 = 11979,
  CODE_FOR_smaxv4hi3 = 11980,
  CODE_FOR_sminv4hi3 = 11981,
  CODE_FOR_mmx_umaxv8qi3 = 11982,
  CODE_FOR_mmx_uminv8qi3 = 11983,
  CODE_FOR_umaxv8qi3 = 11984,
  CODE_FOR_uminv8qi3 = 11985,
  CODE_FOR_absv8qi2 = 11986,
  CODE_FOR_absv4hi2 = 11987,
  CODE_FOR_absv2si2 = 11988,
  CODE_FOR_ashrv4hi3 = 11989,
  CODE_FOR_ashrv2si3 = 11990,
  CODE_FOR_ashlv4hi3 = 11991,
  CODE_FOR_lshrv4hi3 = 11992,
  CODE_FOR_ashlv2si3 = 11993,
  CODE_FOR_lshrv2si3 = 11994,
  CODE_FOR_ashlv8qi3 = 11995,
  CODE_FOR_lshrv8qi3 = 11996,
  CODE_FOR_ashrv8qi3 = 11997,
  CODE_FOR_ashlv4qi3 = 11998,
  CODE_FOR_lshrv4qi3 = 11999,
  CODE_FOR_ashrv4qi3 = 12000,
  CODE_FOR_vashlv8qi3 = 12001,
  CODE_FOR_vlshrv8qi3 = 12002,
  CODE_FOR_vashrv8qi3 = 12003,
  CODE_FOR_vashlv4qi3 = 12004,
  CODE_FOR_vlshrv4qi3 = 12005,
  CODE_FOR_vashrv4qi3 = 12006,
  CODE_FOR_vec_shl_v2sf = 12007,
  CODE_FOR_vec_shl_v2si = 12008,
  CODE_FOR_vec_shl_v4hf = 12009,
  CODE_FOR_vec_shl_v4bf = 12010,
  CODE_FOR_vec_shl_v4hi = 12011,
  CODE_FOR_vec_shl_v8qi = 12012,
  CODE_FOR_vec_shl_v2hf = 12013,
  CODE_FOR_vec_shl_v2bf = 12014,
  CODE_FOR_vec_shl_v2hi = 12015,
  CODE_FOR_vec_shl_v4qi = 12016,
  CODE_FOR_vec_shr_v2sf = 12017,
  CODE_FOR_vec_shr_v2si = 12018,
  CODE_FOR_vec_shr_v4hf = 12019,
  CODE_FOR_vec_shr_v4bf = 12020,
  CODE_FOR_vec_shr_v4hi = 12021,
  CODE_FOR_vec_shr_v8qi = 12022,
  CODE_FOR_vec_shr_v2hf = 12023,
  CODE_FOR_vec_shr_v2bf = 12024,
  CODE_FOR_vec_shr_v2hi = 12025,
  CODE_FOR_vec_shr_v4qi = 12026,
  CODE_FOR_mmx_eqv8qi3 = 12027,
  CODE_FOR_mmx_eqv4hi3 = 12028,
  CODE_FOR_mmx_eqv2si3 = 12029,
  CODE_FOR_vec_cmpv8qiv8qi = 12030,
  CODE_FOR_vec_cmpv4hiv4hi = 12031,
  CODE_FOR_vec_cmpv2siv2si = 12032,
  CODE_FOR_vec_cmpv4qiv4qi = 12033,
  CODE_FOR_vec_cmpv2qiv2qi = 12034,
  CODE_FOR_vec_cmpv2hiv2hi = 12035,
  CODE_FOR_vec_cmpuv8qiv8qi = 12036,
  CODE_FOR_vec_cmpuv4hiv4hi = 12037,
  CODE_FOR_vec_cmpuv2siv2si = 12038,
  CODE_FOR_vec_cmpuv4qiv4qi = 12039,
  CODE_FOR_vec_cmpuv2qiv2qi = 12040,
  CODE_FOR_vec_cmpuv2hiv2hi = 12041,
  CODE_FOR_vcond_mask_v8qiv8qi = 12042,
  CODE_FOR_vcond_mask_v4hiv4hi = 12043,
  CODE_FOR_vcond_mask_v2siv2si = 12044,
  CODE_FOR_vcond_mask_v2sfv2si = 12045,
  CODE_FOR_vcond_mask_v4qiv4qi = 12046,
  CODE_FOR_vcond_mask_v2qiv2qi = 12047,
  CODE_FOR_vcond_mask_v2hiv2hi = 12048,
  CODE_FOR_one_cmplv8qi2 = 12049,
  CODE_FOR_one_cmplv4hi2 = 12050,
  CODE_FOR_one_cmplv2si2 = 12051,
  CODE_FOR_andnv8qi3 = 12052,
  CODE_FOR_andnv4hi3 = 12053,
  CODE_FOR_andnv2si3 = 12054,
  CODE_FOR_mmx_andv8qi3 = 12055,
  CODE_FOR_mmx_iorv8qi3 = 12056,
  CODE_FOR_mmx_xorv8qi3 = 12057,
  CODE_FOR_mmx_andv4hi3 = 12058,
  CODE_FOR_mmx_iorv4hi3 = 12059,
  CODE_FOR_mmx_xorv4hi3 = 12060,
  CODE_FOR_mmx_andv2si3 = 12061,
  CODE_FOR_mmx_iorv2si3 = 12062,
  CODE_FOR_mmx_xorv2si3 = 12063,
  CODE_FOR_andv8qi3 = 12064,
  CODE_FOR_iorv8qi3 = 12065,
  CODE_FOR_xorv8qi3 = 12066,
  CODE_FOR_andv4hi3 = 12067,
  CODE_FOR_iorv4hi3 = 12068,
  CODE_FOR_xorv4hi3 = 12069,
  CODE_FOR_andv2si3 = 12070,
  CODE_FOR_iorv2si3 = 12071,
  CODE_FOR_xorv2si3 = 12072,
  CODE_FOR_andv4qi3 = 12073,
  CODE_FOR_iorv4qi3 = 12074,
  CODE_FOR_xorv4qi3 = 12075,
  CODE_FOR_andv2qi3 = 12076,
  CODE_FOR_iorv2qi3 = 12077,
  CODE_FOR_xorv2qi3 = 12078,
  CODE_FOR_andv2hi3 = 12079,
  CODE_FOR_iorv2hi3 = 12080,
  CODE_FOR_xorv2hi3 = 12081,
  CODE_FOR_extendv4qiv4hi2 = 12082,
  CODE_FOR_zero_extendv4qiv4hi2 = 12083,
  CODE_FOR_extendv2hiv2si2 = 12084,
  CODE_FOR_zero_extendv2hiv2si2 = 12085,
  CODE_FOR_extendv2qiv2si2 = 12086,
  CODE_FOR_zero_extendv2qiv2si2 = 12087,
  CODE_FOR_extendv2qiv2hi2 = 12088,
  CODE_FOR_zero_extendv2qiv2hi2 = 12089,
  CODE_FOR_truncv4hiv4qi2 = 12090,
  CODE_FOR_truncv2hiv2qi2 = 12091,
  CODE_FOR_truncv2siv2qi2 = 12092,
  CODE_FOR_truncv2siv2hi2 = 12093,
  CODE_FOR_vec_pack_trunc_v4hi = 12094,
  CODE_FOR_vec_pack_trunc_v2si = 12095,
  CODE_FOR_vec_pack_trunc_v2hi = 12096,
  CODE_FOR_vec_unpacks_lo_v8qi = 12097,
  CODE_FOR_vec_unpacks_lo_v4hi = 12098,
  CODE_FOR_vec_unpacks_hi_v8qi = 12099,
  CODE_FOR_vec_unpacks_hi_v4hi = 12100,
  CODE_FOR_vec_unpacku_lo_v8qi = 12101,
  CODE_FOR_vec_unpacku_lo_v4hi = 12102,
  CODE_FOR_vec_unpacku_hi_v8qi = 12103,
  CODE_FOR_vec_unpacku_hi_v4hi = 12104,
  CODE_FOR_vec_unpacks_lo_v4qi = 12105,
  CODE_FOR_vec_unpacks_hi_v4qi = 12106,
  CODE_FOR_vec_unpacku_lo_v4qi = 12107,
  CODE_FOR_vec_unpacku_hi_v4qi = 12108,
  CODE_FOR_mmx_pshufw = 12109,
  CODE_FOR_vec_setv2si = 12110,
  CODE_FOR_vec_extractv2sisi = 12111,
  CODE_FOR_vec_initv2sisi = 12112,
  CODE_FOR_vec_setv4hf = 12113,
  CODE_FOR_vec_setv4bf = 12114,
  CODE_FOR_vec_setv4hi = 12115,
  CODE_FOR_vec_extractv4hfhf = 12116,
  CODE_FOR_vec_extractv4bfbf = 12117,
  CODE_FOR_vec_extractv4hihi = 12118,
  CODE_FOR_vec_initv4hihi = 12119,
  CODE_FOR_vec_initv4hfhf = 12120,
  CODE_FOR_vec_initv4bfbf = 12121,
  CODE_FOR_vec_setv8qi = 12122,
  CODE_FOR_vec_extractv8qiqi = 12123,
  CODE_FOR_vec_initv8qiqi = 12124,
  CODE_FOR_vec_setv2hf = 12125,
  CODE_FOR_vec_setv2bf = 12126,
  CODE_FOR_vec_setv2hi = 12127,
  CODE_FOR_vec_extractv2hfhf = 12128,
  CODE_FOR_vec_extractv2bfbf = 12129,
  CODE_FOR_vec_extractv2hihi = 12130,
  CODE_FOR_vec_setv4qi = 12131,
  CODE_FOR_vec_extractv4qiqi = 12132,
  CODE_FOR_vec_initv2hfhf = 12133,
  CODE_FOR_vec_initv2bfbf = 12134,
  CODE_FOR_vec_initv2hihi = 12135,
  CODE_FOR_vec_initv4qiqi = 12136,
  CODE_FOR_mmx_uavgv8qi3 = 12137,
  CODE_FOR_mmx_uavgv4hi3 = 12138,
  CODE_FOR_uavgv8qi3_ceil = 12139,
  CODE_FOR_uavgv4hi3_ceil = 12140,
  CODE_FOR_mmx_psadbw = 12141,
  CODE_FOR_reduc_and_scal_v8qi = 12142,
  CODE_FOR_reduc_ior_scal_v8qi = 12143,
  CODE_FOR_reduc_xor_scal_v8qi = 12144,
  CODE_FOR_reduc_and_scal_v4hi = 12145,
  CODE_FOR_reduc_ior_scal_v4hi = 12146,
  CODE_FOR_reduc_xor_scal_v4hi = 12147,
  CODE_FOR_reduc_and_scal_v4qi = 12148,
  CODE_FOR_reduc_ior_scal_v4qi = 12149,
  CODE_FOR_reduc_xor_scal_v4qi = 12150,
  CODE_FOR_reduc_plus_scal_v8qi = 12151,
  CODE_FOR_reduc_plus_scal_v4hi = 12152,
  CODE_FOR_reduc_smax_scal_v4hi = 12153,
  CODE_FOR_reduc_smin_scal_v4hi = 12154,
  CODE_FOR_reduc_smax_scal_v4qi = 12155,
  CODE_FOR_reduc_smin_scal_v4qi = 12156,
  CODE_FOR_reduc_umax_scal_v4hi = 12157,
  CODE_FOR_reduc_umin_scal_v4hi = 12158,
  CODE_FOR_reduc_umax_scal_v4qi = 12159,
  CODE_FOR_reduc_umin_scal_v4qi = 12160,
  CODE_FOR_reduc_plus_scal_v4qi = 12161,
  CODE_FOR_usadv8qi = 12162,
  CODE_FOR_usdot_prodv2siv8qi = 12163,
  CODE_FOR_sdot_prodv2siv8qi = 12164,
  CODE_FOR_udot_prodv2siv8qi = 12165,
  CODE_FOR_usdot_prodv2siv4hi = 12166,
  CODE_FOR_udot_prodv2siv4hi = 12167,
  CODE_FOR_sdot_prodv2siv4hi = 12168,
  CODE_FOR_mmx_maskmovq = 12169,
  CODE_FOR_mmx_emms = 12170,
  CODE_FOR_mmx_femms = 12171,
  CODE_FOR_movv64qi = 12172,
  CODE_FOR_movv32qi = 12173,
  CODE_FOR_movv16qi = 12174,
  CODE_FOR_movv32hi = 12175,
  CODE_FOR_movv16hi = 12176,
  CODE_FOR_movv8hi = 12177,
  CODE_FOR_movv16si = 12178,
  CODE_FOR_movv8si = 12179,
  CODE_FOR_movv4si = 12180,
  CODE_FOR_movv8di = 12181,
  CODE_FOR_movv4di = 12182,
  CODE_FOR_movv2di = 12183,
  CODE_FOR_movv4ti = 12184,
  CODE_FOR_movv2ti = 12185,
  CODE_FOR_movv1ti = 12186,
  CODE_FOR_movv32hf = 12187,
  CODE_FOR_movv16hf = 12188,
  CODE_FOR_movv8hf = 12189,
  CODE_FOR_movv32bf = 12190,
  CODE_FOR_movv16bf = 12191,
  CODE_FOR_movv8bf = 12192,
  CODE_FOR_movv16sf = 12193,
  CODE_FOR_movv8sf = 12194,
  CODE_FOR_movv4sf = 12195,
  CODE_FOR_movv8df = 12196,
  CODE_FOR_movv4df = 12197,
  CODE_FOR_movv2df = 12198,
  CODE_FOR_avx512f_loadv16si_mask = 12199,
  CODE_FOR_avx512vl_loadv8si_mask = 12200,
  CODE_FOR_avx512vl_loadv4si_mask = 12201,
  CODE_FOR_avx512f_loadv8di_mask = 12202,
  CODE_FOR_avx512vl_loadv4di_mask = 12203,
  CODE_FOR_avx512vl_loadv2di_mask = 12204,
  CODE_FOR_avx512f_loadv16sf_mask = 12205,
  CODE_FOR_avx512vl_loadv8sf_mask = 12206,
  CODE_FOR_avx512vl_loadv4sf_mask = 12207,
  CODE_FOR_avx512f_loadv8df_mask = 12208,
  CODE_FOR_avx512vl_loadv4df_mask = 12209,
  CODE_FOR_avx512vl_loadv2df_mask = 12210,
  CODE_FOR_avx512bw_loadv64qi_mask = 12211,
  CODE_FOR_avx512vl_loadv16qi_mask = 12212,
  CODE_FOR_avx512vl_loadv32qi_mask = 12213,
  CODE_FOR_avx512bw_loadv32hi_mask = 12214,
  CODE_FOR_avx512vl_loadv16hi_mask = 12215,
  CODE_FOR_avx512vl_loadv8hi_mask = 12216,
  CODE_FOR_avx512f_loadhf_mask = 12217,
  CODE_FOR_avx512f_loadsf_mask = 12218,
  CODE_FOR_avx512f_loaddf_mask = 12219,
  CODE_FOR_sse2_movq128 = 12220,
  CODE_FOR_movmisalignv64qi = 12221,
  CODE_FOR_movmisalignv32qi = 12222,
  CODE_FOR_movmisalignv16qi = 12223,
  CODE_FOR_movmisalignv32hi = 12224,
  CODE_FOR_movmisalignv16hi = 12225,
  CODE_FOR_movmisalignv8hi = 12226,
  CODE_FOR_movmisalignv16si = 12227,
  CODE_FOR_movmisalignv8si = 12228,
  CODE_FOR_movmisalignv4si = 12229,
  CODE_FOR_movmisalignv8di = 12230,
  CODE_FOR_movmisalignv4di = 12231,
  CODE_FOR_movmisalignv2di = 12232,
  CODE_FOR_movmisalignv4ti = 12233,
  CODE_FOR_movmisalignv2ti = 12234,
  CODE_FOR_movmisalignv1ti = 12235,
  CODE_FOR_movmisalignv32hf = 12236,
  CODE_FOR_movmisalignv16hf = 12237,
  CODE_FOR_movmisalignv8hf = 12238,
  CODE_FOR_movmisalignv32bf = 12239,
  CODE_FOR_movmisalignv16bf = 12240,
  CODE_FOR_movmisalignv8bf = 12241,
  CODE_FOR_movmisalignv16sf = 12242,
  CODE_FOR_movmisalignv8sf = 12243,
  CODE_FOR_movmisalignv4sf = 12244,
  CODE_FOR_movmisalignv8df = 12245,
  CODE_FOR_movmisalignv4df = 12246,
  CODE_FOR_movmisalignv2df = 12247,
  CODE_FOR_storentdi = 12248,
  CODE_FOR_storentsi = 12249,
  CODE_FOR_storentsf = 12250,
  CODE_FOR_storentdf = 12251,
  CODE_FOR_storentv8di = 12252,
  CODE_FOR_storentv4di = 12253,
  CODE_FOR_storentv2di = 12254,
  CODE_FOR_storentv16sf = 12255,
  CODE_FOR_storentv8sf = 12256,
  CODE_FOR_storentv4sf = 12257,
  CODE_FOR_storentv8df = 12258,
  CODE_FOR_storentv4df = 12259,
  CODE_FOR_storentv2df = 12260,
  CODE_FOR_kmovb = 12261,
  CODE_FOR_kmovw = 12262,
  CODE_FOR_kmovd = 12263,
  CODE_FOR_kmovq = 12264,
  CODE_FOR_kortestqi = 12265,
  CODE_FOR_kortesthi = 12266,
  CODE_FOR_kortestsi = 12267,
  CODE_FOR_kortestdi = 12268,
  CODE_FOR_absv32bf2 = 12269,
  CODE_FOR_negv32bf2 = 12270,
  CODE_FOR_absv16bf2 = 12271,
  CODE_FOR_negv16bf2 = 12272,
  CODE_FOR_absv8bf2 = 12273,
  CODE_FOR_negv8bf2 = 12274,
  CODE_FOR_absv32hf2 = 12275,
  CODE_FOR_negv32hf2 = 12276,
  CODE_FOR_absv16hf2 = 12277,
  CODE_FOR_negv16hf2 = 12278,
  CODE_FOR_absv8hf2 = 12279,
  CODE_FOR_negv8hf2 = 12280,
  CODE_FOR_absv16sf2 = 12281,
  CODE_FOR_negv16sf2 = 12282,
  CODE_FOR_absv8sf2 = 12283,
  CODE_FOR_negv8sf2 = 12284,
  CODE_FOR_absv4sf2 = 12285,
  CODE_FOR_negv4sf2 = 12286,
  CODE_FOR_absv8df2 = 12287,
  CODE_FOR_negv8df2 = 12288,
  CODE_FOR_absv4df2 = 12289,
  CODE_FOR_negv4df2 = 12290,
  CODE_FOR_absv2df2 = 12291,
  CODE_FOR_negv2df2 = 12292,
  CODE_FOR_cond_addv32hf = 12293,
  CODE_FOR_cond_subv32hf = 12294,
  CODE_FOR_cond_addv16hf = 12295,
  CODE_FOR_cond_subv16hf = 12296,
  CODE_FOR_cond_addv8hf = 12297,
  CODE_FOR_cond_subv8hf = 12298,
  CODE_FOR_cond_addv16sf = 12299,
  CODE_FOR_cond_subv16sf = 12300,
  CODE_FOR_cond_addv8sf = 12301,
  CODE_FOR_cond_subv8sf = 12302,
  CODE_FOR_cond_addv4sf = 12303,
  CODE_FOR_cond_subv4sf = 12304,
  CODE_FOR_cond_addv8df = 12305,
  CODE_FOR_cond_subv8df = 12306,
  CODE_FOR_cond_addv4df = 12307,
  CODE_FOR_cond_subv4df = 12308,
  CODE_FOR_cond_addv2df = 12309,
  CODE_FOR_cond_subv2df = 12310,
  CODE_FOR_addv32hf3 = 12311,
  CODE_FOR_addv32hf3_round = 12312,
  CODE_FOR_addv32hf3_mask = 12313,
  CODE_FOR_addv32hf3_mask_round = 12314,
  CODE_FOR_subv32hf3 = 12315,
  CODE_FOR_subv32hf3_round = 12316,
  CODE_FOR_subv32hf3_mask = 12317,
  CODE_FOR_subv32hf3_mask_round = 12318,
  CODE_FOR_addv16hf3 = 12319,
   CODE_FOR_addv16hf3_round = CODE_FOR_nothing,
  CODE_FOR_addv16hf3_mask = 12320,
   CODE_FOR_addv16hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_subv16hf3 = 12321,
   CODE_FOR_subv16hf3_round = CODE_FOR_nothing,
  CODE_FOR_subv16hf3_mask = 12322,
   CODE_FOR_subv16hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_addv8hf3 = 12323,
   CODE_FOR_addv8hf3_round = CODE_FOR_nothing,
  CODE_FOR_addv8hf3_mask = 12324,
   CODE_FOR_addv8hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_subv8hf3 = 12325,
   CODE_FOR_subv8hf3_round = CODE_FOR_nothing,
  CODE_FOR_subv8hf3_mask = 12326,
   CODE_FOR_subv8hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_addv16sf3 = 12327,
  CODE_FOR_addv16sf3_round = 12328,
  CODE_FOR_addv16sf3_mask = 12329,
  CODE_FOR_addv16sf3_mask_round = 12330,
  CODE_FOR_subv16sf3 = 12331,
  CODE_FOR_subv16sf3_round = 12332,
  CODE_FOR_subv16sf3_mask = 12333,
  CODE_FOR_subv16sf3_mask_round = 12334,
  CODE_FOR_addv8sf3 = 12335,
   CODE_FOR_addv8sf3_round = CODE_FOR_nothing,
  CODE_FOR_addv8sf3_mask = 12336,
   CODE_FOR_addv8sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_subv8sf3 = 12337,
   CODE_FOR_subv8sf3_round = CODE_FOR_nothing,
  CODE_FOR_subv8sf3_mask = 12338,
   CODE_FOR_subv8sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_addv4sf3 = 12339,
   CODE_FOR_addv4sf3_round = CODE_FOR_nothing,
  CODE_FOR_addv4sf3_mask = 12340,
   CODE_FOR_addv4sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_subv4sf3 = 12341,
   CODE_FOR_subv4sf3_round = CODE_FOR_nothing,
  CODE_FOR_subv4sf3_mask = 12342,
   CODE_FOR_subv4sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_addv8df3 = 12343,
  CODE_FOR_addv8df3_round = 12344,
  CODE_FOR_addv8df3_mask = 12345,
  CODE_FOR_addv8df3_mask_round = 12346,
  CODE_FOR_subv8df3 = 12347,
  CODE_FOR_subv8df3_round = 12348,
  CODE_FOR_subv8df3_mask = 12349,
  CODE_FOR_subv8df3_mask_round = 12350,
  CODE_FOR_addv4df3 = 12351,
   CODE_FOR_addv4df3_round = CODE_FOR_nothing,
  CODE_FOR_addv4df3_mask = 12352,
   CODE_FOR_addv4df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_subv4df3 = 12353,
   CODE_FOR_subv4df3_round = CODE_FOR_nothing,
  CODE_FOR_subv4df3_mask = 12354,
   CODE_FOR_subv4df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_addv2df3 = 12355,
   CODE_FOR_addv2df3_round = CODE_FOR_nothing,
  CODE_FOR_addv2df3_mask = 12356,
   CODE_FOR_addv2df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_subv2df3 = 12357,
   CODE_FOR_subv2df3_round = CODE_FOR_nothing,
  CODE_FOR_subv2df3_mask = 12358,
   CODE_FOR_subv2df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_addv32bf3 = 12359,
  CODE_FOR_addv32bf3_mask = 12360,
  CODE_FOR_subv32bf3 = 12361,
  CODE_FOR_subv32bf3_mask = 12362,
  CODE_FOR_addv16bf3 = 12363,
  CODE_FOR_addv16bf3_mask = 12364,
  CODE_FOR_subv16bf3 = 12365,
  CODE_FOR_subv16bf3_mask = 12366,
  CODE_FOR_addv8bf3 = 12367,
  CODE_FOR_addv8bf3_mask = 12368,
  CODE_FOR_subv8bf3 = 12369,
  CODE_FOR_subv8bf3_mask = 12370,
  CODE_FOR_cond_mulv32hf = 12371,
  CODE_FOR_cond_mulv16hf = 12372,
  CODE_FOR_cond_mulv8hf = 12373,
  CODE_FOR_cond_mulv16sf = 12374,
  CODE_FOR_cond_mulv8sf = 12375,
  CODE_FOR_cond_mulv4sf = 12376,
  CODE_FOR_cond_mulv8df = 12377,
  CODE_FOR_cond_mulv4df = 12378,
  CODE_FOR_cond_mulv2df = 12379,
  CODE_FOR_mulv32hf3 = 12380,
  CODE_FOR_mulv32hf3_round = 12381,
  CODE_FOR_mulv32hf3_mask = 12382,
  CODE_FOR_mulv32hf3_mask_round = 12383,
  CODE_FOR_mulv16hf3 = 12384,
   CODE_FOR_mulv16hf3_round = CODE_FOR_nothing,
  CODE_FOR_mulv16hf3_mask = 12385,
   CODE_FOR_mulv16hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_mulv8hf3 = 12386,
   CODE_FOR_mulv8hf3_round = CODE_FOR_nothing,
  CODE_FOR_mulv8hf3_mask = 12387,
   CODE_FOR_mulv8hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_mulv16sf3 = 12388,
  CODE_FOR_mulv16sf3_round = 12389,
  CODE_FOR_mulv16sf3_mask = 12390,
  CODE_FOR_mulv16sf3_mask_round = 12391,
  CODE_FOR_mulv8sf3 = 12392,
   CODE_FOR_mulv8sf3_round = CODE_FOR_nothing,
  CODE_FOR_mulv8sf3_mask = 12393,
   CODE_FOR_mulv8sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_mulv4sf3 = 12394,
   CODE_FOR_mulv4sf3_round = CODE_FOR_nothing,
  CODE_FOR_mulv4sf3_mask = 12395,
   CODE_FOR_mulv4sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_mulv8df3 = 12396,
  CODE_FOR_mulv8df3_round = 12397,
  CODE_FOR_mulv8df3_mask = 12398,
  CODE_FOR_mulv8df3_mask_round = 12399,
  CODE_FOR_mulv4df3 = 12400,
   CODE_FOR_mulv4df3_round = CODE_FOR_nothing,
  CODE_FOR_mulv4df3_mask = 12401,
   CODE_FOR_mulv4df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_mulv2df3 = 12402,
   CODE_FOR_mulv2df3_round = CODE_FOR_nothing,
  CODE_FOR_mulv2df3_mask = 12403,
   CODE_FOR_mulv2df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_mulv32bf3 = 12404,
  CODE_FOR_mulv32bf3_mask = 12405,
  CODE_FOR_mulv16bf3 = 12406,
  CODE_FOR_mulv16bf3_mask = 12407,
  CODE_FOR_mulv8bf3 = 12408,
  CODE_FOR_mulv8bf3_mask = 12409,
  CODE_FOR_divv8df3 = 12410,
  CODE_FOR_divv4df3 = 12411,
  CODE_FOR_divv2df3 = 12412,
  CODE_FOR_divv32hf3 = 12413,
  CODE_FOR_divv16hf3 = 12414,
  CODE_FOR_divv8hf3 = 12415,
  CODE_FOR_divv16sf3 = 12416,
  CODE_FOR_divv8sf3 = 12417,
  CODE_FOR_divv4sf3 = 12418,
  CODE_FOR_divv32bf3 = 12419,
  CODE_FOR_divv16bf3 = 12420,
  CODE_FOR_divv8bf3 = 12421,
  CODE_FOR_cond_divv32hf = 12422,
  CODE_FOR_cond_divv16hf = 12423,
  CODE_FOR_cond_divv8hf = 12424,
  CODE_FOR_cond_divv16sf = 12425,
  CODE_FOR_cond_divv8sf = 12426,
  CODE_FOR_cond_divv4sf = 12427,
  CODE_FOR_cond_divv8df = 12428,
  CODE_FOR_cond_divv4df = 12429,
  CODE_FOR_cond_divv2df = 12430,
  CODE_FOR_sqrtv32bf2 = 12431,
  CODE_FOR_sqrtv16bf2 = 12432,
  CODE_FOR_sqrtv8bf2 = 12433,
  CODE_FOR_sqrtv32hf2 = 12434,
  CODE_FOR_sqrtv16hf2 = 12435,
  CODE_FOR_sqrtv8hf2 = 12436,
  CODE_FOR_sqrtv8df2 = 12437,
  CODE_FOR_sqrtv4df2 = 12438,
  CODE_FOR_sqrtv2df2 = 12439,
  CODE_FOR_sqrtv16sf2 = 12440,
  CODE_FOR_sqrtv8sf2 = 12441,
  CODE_FOR_sqrtv4sf2 = 12442,
  CODE_FOR_rsqrtv8sf2 = 12443,
  CODE_FOR_rsqrtv4sf2 = 12444,
  CODE_FOR_rsqrtv32hf2 = 12445,
  CODE_FOR_rsqrtv16hf2 = 12446,
  CODE_FOR_rsqrtv8hf2 = 12447,
  CODE_FOR_cond_smaxv32hf = 12448,
  CODE_FOR_cond_sminv32hf = 12449,
  CODE_FOR_cond_smaxv16hf = 12450,
  CODE_FOR_cond_sminv16hf = 12451,
  CODE_FOR_cond_smaxv8hf = 12452,
  CODE_FOR_cond_sminv8hf = 12453,
  CODE_FOR_cond_smaxv16sf = 12454,
  CODE_FOR_cond_sminv16sf = 12455,
  CODE_FOR_cond_smaxv8sf = 12456,
  CODE_FOR_cond_sminv8sf = 12457,
  CODE_FOR_cond_smaxv4sf = 12458,
  CODE_FOR_cond_sminv4sf = 12459,
  CODE_FOR_cond_smaxv8df = 12460,
  CODE_FOR_cond_sminv8df = 12461,
  CODE_FOR_cond_smaxv4df = 12462,
  CODE_FOR_cond_sminv4df = 12463,
  CODE_FOR_cond_smaxv2df = 12464,
  CODE_FOR_cond_sminv2df = 12465,
  CODE_FOR_smaxv32hf3 = 12466,
  CODE_FOR_smaxv32hf3_round = 12467,
  CODE_FOR_smaxv32hf3_mask = 12468,
  CODE_FOR_smaxv32hf3_mask_round = 12469,
  CODE_FOR_sminv32hf3 = 12470,
  CODE_FOR_sminv32hf3_round = 12471,
  CODE_FOR_sminv32hf3_mask = 12472,
  CODE_FOR_sminv32hf3_mask_round = 12473,
  CODE_FOR_smaxv16hf3 = 12474,
   CODE_FOR_smaxv16hf3_round = CODE_FOR_nothing,
  CODE_FOR_smaxv16hf3_mask = 12475,
   CODE_FOR_smaxv16hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_sminv16hf3 = 12476,
   CODE_FOR_sminv16hf3_round = CODE_FOR_nothing,
  CODE_FOR_sminv16hf3_mask = 12477,
   CODE_FOR_sminv16hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_smaxv8hf3 = 12478,
   CODE_FOR_smaxv8hf3_round = CODE_FOR_nothing,
  CODE_FOR_smaxv8hf3_mask = 12479,
   CODE_FOR_smaxv8hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_sminv8hf3 = 12480,
   CODE_FOR_sminv8hf3_round = CODE_FOR_nothing,
  CODE_FOR_sminv8hf3_mask = 12481,
   CODE_FOR_sminv8hf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_smaxv16sf3 = 12482,
  CODE_FOR_smaxv16sf3_round = 12483,
  CODE_FOR_smaxv16sf3_mask = 12484,
  CODE_FOR_smaxv16sf3_mask_round = 12485,
  CODE_FOR_sminv16sf3 = 12486,
  CODE_FOR_sminv16sf3_round = 12487,
  CODE_FOR_sminv16sf3_mask = 12488,
  CODE_FOR_sminv16sf3_mask_round = 12489,
  CODE_FOR_smaxv8sf3 = 12490,
   CODE_FOR_smaxv8sf3_round = CODE_FOR_nothing,
  CODE_FOR_smaxv8sf3_mask = 12491,
   CODE_FOR_smaxv8sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_sminv8sf3 = 12492,
   CODE_FOR_sminv8sf3_round = CODE_FOR_nothing,
  CODE_FOR_sminv8sf3_mask = 12493,
   CODE_FOR_sminv8sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_smaxv4sf3 = 12494,
   CODE_FOR_smaxv4sf3_round = CODE_FOR_nothing,
  CODE_FOR_smaxv4sf3_mask = 12495,
   CODE_FOR_smaxv4sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_sminv4sf3 = 12496,
   CODE_FOR_sminv4sf3_round = CODE_FOR_nothing,
  CODE_FOR_sminv4sf3_mask = 12497,
   CODE_FOR_sminv4sf3_mask_round = CODE_FOR_nothing,
  CODE_FOR_smaxv8df3 = 12498,
  CODE_FOR_smaxv8df3_round = 12499,
  CODE_FOR_smaxv8df3_mask = 12500,
  CODE_FOR_smaxv8df3_mask_round = 12501,
  CODE_FOR_sminv8df3 = 12502,
  CODE_FOR_sminv8df3_round = 12503,
  CODE_FOR_sminv8df3_mask = 12504,
  CODE_FOR_sminv8df3_mask_round = 12505,
  CODE_FOR_smaxv4df3 = 12506,
   CODE_FOR_smaxv4df3_round = CODE_FOR_nothing,
  CODE_FOR_smaxv4df3_mask = 12507,
   CODE_FOR_smaxv4df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_sminv4df3 = 12508,
   CODE_FOR_sminv4df3_round = CODE_FOR_nothing,
  CODE_FOR_sminv4df3_mask = 12509,
   CODE_FOR_sminv4df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_smaxv2df3 = 12510,
   CODE_FOR_smaxv2df3_round = CODE_FOR_nothing,
  CODE_FOR_smaxv2df3_mask = 12511,
   CODE_FOR_smaxv2df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_sminv2df3 = 12512,
   CODE_FOR_sminv2df3_round = CODE_FOR_nothing,
  CODE_FOR_sminv2df3_mask = 12513,
   CODE_FOR_sminv2df3_mask_round = CODE_FOR_nothing,
  CODE_FOR_avx512fp16_vmsmaxv8hf3 = 12514,
  CODE_FOR_avx512fp16_vmsmaxv8hf3_mask = 12515,
  CODE_FOR_avx512fp16_vmsmaxv8hf3_round = 12516,
  CODE_FOR_avx512fp16_vmsmaxv8hf3_mask_round = 12517,
  CODE_FOR_avx512fp16_vmsminv8hf3 = 12518,
  CODE_FOR_avx512fp16_vmsminv8hf3_mask = 12519,
  CODE_FOR_avx512fp16_vmsminv8hf3_round = 12520,
  CODE_FOR_avx512fp16_vmsminv8hf3_mask_round = 12521,
  CODE_FOR_sse_vmsmaxv4sf3 = 12522,
  CODE_FOR_sse_vmsmaxv4sf3_mask = 12523,
  CODE_FOR_sse_vmsmaxv4sf3_round = 12524,
  CODE_FOR_sse_vmsmaxv4sf3_mask_round = 12525,
  CODE_FOR_sse_vmsminv4sf3 = 12526,
  CODE_FOR_sse_vmsminv4sf3_mask = 12527,
  CODE_FOR_sse_vmsminv4sf3_round = 12528,
  CODE_FOR_sse_vmsminv4sf3_mask_round = 12529,
  CODE_FOR_sse2_vmsmaxv2df3 = 12530,
  CODE_FOR_sse2_vmsmaxv2df3_mask = 12531,
  CODE_FOR_sse2_vmsmaxv2df3_round = 12532,
  CODE_FOR_sse2_vmsmaxv2df3_mask_round = 12533,
  CODE_FOR_sse2_vmsminv2df3 = 12534,
  CODE_FOR_sse2_vmsminv2df3_mask = 12535,
  CODE_FOR_sse2_vmsminv2df3_round = 12536,
  CODE_FOR_sse2_vmsminv2df3_mask_round = 12537,
  CODE_FOR_sse3_haddv2df3 = 12538,
  CODE_FOR_reduc_plus_scal_v2df = 12539,
  CODE_FOR_reduc_plus_scal_v4sf = 12540,
  CODE_FOR_reduc_plus_scal_v8hf = 12541,
  CODE_FOR_reduc_plus_scal_v8hi = 12542,
  CODE_FOR_reduc_plus_scal_v4si = 12543,
  CODE_FOR_reduc_plus_scal_v2di = 12544,
  CODE_FOR_reduc_plus_scal_v16qi = 12545,
  CODE_FOR_reduc_plus_scal_v4df = 12546,
  CODE_FOR_reduc_plus_scal_v8sf = 12547,
  CODE_FOR_reduc_plus_scal_v16hf = 12548,
  CODE_FOR_reduc_plus_scal_v8df = 12549,
  CODE_FOR_reduc_plus_scal_v16sf = 12550,
  CODE_FOR_reduc_plus_scal_v32hf = 12551,
  CODE_FOR_reduc_plus_scal_v32qi = 12552,
  CODE_FOR_reduc_plus_scal_v16hi = 12553,
  CODE_FOR_reduc_plus_scal_v8si = 12554,
  CODE_FOR_reduc_plus_scal_v4di = 12555,
  CODE_FOR_reduc_plus_scal_v64qi = 12556,
  CODE_FOR_reduc_plus_scal_v32hi = 12557,
  CODE_FOR_reduc_plus_scal_v16si = 12558,
  CODE_FOR_reduc_plus_scal_v8di = 12559,
  CODE_FOR_reduc_smax_scal_v8hf = 12560,
  CODE_FOR_reduc_smin_scal_v8hf = 12561,
  CODE_FOR_reduc_smax_scal_v4sf = 12562,
  CODE_FOR_reduc_smin_scal_v4sf = 12563,
  CODE_FOR_reduc_smax_scal_v2df = 12564,
  CODE_FOR_reduc_smin_scal_v2df = 12565,
  CODE_FOR_reduc_smax_scal_v4si = 12566,
  CODE_FOR_reduc_smin_scal_v4si = 12567,
  CODE_FOR_reduc_smax_scal_v8hi = 12568,
  CODE_FOR_reduc_smin_scal_v8hi = 12569,
  CODE_FOR_reduc_smax_scal_v16qi = 12570,
  CODE_FOR_reduc_smin_scal_v16qi = 12571,
  CODE_FOR_reduc_smax_scal_v2di = 12572,
  CODE_FOR_reduc_smin_scal_v2di = 12573,
  CODE_FOR_reduc_smax_scal_v32qi = 12574,
  CODE_FOR_reduc_smin_scal_v32qi = 12575,
  CODE_FOR_reduc_smax_scal_v16hi = 12576,
  CODE_FOR_reduc_smin_scal_v16hi = 12577,
  CODE_FOR_reduc_smax_scal_v16hf = 12578,
  CODE_FOR_reduc_smin_scal_v16hf = 12579,
  CODE_FOR_reduc_smax_scal_v8si = 12580,
  CODE_FOR_reduc_smin_scal_v8si = 12581,
  CODE_FOR_reduc_smax_scal_v4di = 12582,
  CODE_FOR_reduc_smin_scal_v4di = 12583,
  CODE_FOR_reduc_smax_scal_v8sf = 12584,
  CODE_FOR_reduc_smin_scal_v8sf = 12585,
  CODE_FOR_reduc_smax_scal_v4df = 12586,
  CODE_FOR_reduc_smin_scal_v4df = 12587,
  CODE_FOR_reduc_smax_scal_v64qi = 12588,
  CODE_FOR_reduc_smin_scal_v64qi = 12589,
  CODE_FOR_reduc_smax_scal_v32hf = 12590,
  CODE_FOR_reduc_smin_scal_v32hf = 12591,
  CODE_FOR_reduc_smax_scal_v32hi = 12592,
  CODE_FOR_reduc_smin_scal_v32hi = 12593,
  CODE_FOR_reduc_smax_scal_v16si = 12594,
  CODE_FOR_reduc_smin_scal_v16si = 12595,
  CODE_FOR_reduc_smax_scal_v8di = 12596,
  CODE_FOR_reduc_smin_scal_v8di = 12597,
  CODE_FOR_reduc_smax_scal_v16sf = 12598,
  CODE_FOR_reduc_smin_scal_v16sf = 12599,
  CODE_FOR_reduc_smax_scal_v8df = 12600,
  CODE_FOR_reduc_smin_scal_v8df = 12601,
  CODE_FOR_reduc_umax_scal_v16si = 12602,
  CODE_FOR_reduc_umin_scal_v16si = 12603,
  CODE_FOR_reduc_umax_scal_v8di = 12604,
  CODE_FOR_reduc_umin_scal_v8di = 12605,
  CODE_FOR_reduc_umax_scal_v32hi = 12606,
  CODE_FOR_reduc_umin_scal_v32hi = 12607,
  CODE_FOR_reduc_umax_scal_v64qi = 12608,
  CODE_FOR_reduc_umin_scal_v64qi = 12609,
  CODE_FOR_reduc_umax_scal_v32qi = 12610,
  CODE_FOR_reduc_umin_scal_v32qi = 12611,
  CODE_FOR_reduc_umax_scal_v16hi = 12612,
  CODE_FOR_reduc_umin_scal_v16hi = 12613,
  CODE_FOR_reduc_umax_scal_v8si = 12614,
  CODE_FOR_reduc_umin_scal_v8si = 12615,
  CODE_FOR_reduc_umax_scal_v4di = 12616,
  CODE_FOR_reduc_umin_scal_v4di = 12617,
  CODE_FOR_reduc_umin_scal_v8hi = 12618,
  CODE_FOR_reduc_sbool_and_scal_qi = 12619,
  CODE_FOR_reduc_sbool_and_scal_hi = 12620,
  CODE_FOR_reduc_sbool_and_scal_si = 12621,
  CODE_FOR_reduc_sbool_and_scal_di = 12622,
  CODE_FOR_reduc_sbool_ior_scal_qi = 12623,
  CODE_FOR_reduc_sbool_ior_scal_hi = 12624,
  CODE_FOR_reduc_sbool_ior_scal_si = 12625,
  CODE_FOR_reduc_sbool_ior_scal_di = 12626,
  CODE_FOR_reduc_sbool_xor_scal_qi = 12627,
  CODE_FOR_reduc_sbool_xor_scal_hi = 12628,
  CODE_FOR_reduc_sbool_xor_scal_si = 12629,
  CODE_FOR_reduc_sbool_xor_scal_di = 12630,
  CODE_FOR_reduc_sbool_and_scal_v32qi = 12631,
  CODE_FOR_reduc_sbool_and_scal_v16qi = 12632,
  CODE_FOR_reduc_sbool_and_scal_v16hi = 12633,
  CODE_FOR_reduc_sbool_and_scal_v8hi = 12634,
  CODE_FOR_reduc_sbool_and_scal_v8si = 12635,
  CODE_FOR_reduc_sbool_and_scal_v4si = 12636,
  CODE_FOR_reduc_sbool_and_scal_v4di = 12637,
  CODE_FOR_reduc_sbool_and_scal_v2di = 12638,
  CODE_FOR_reduc_sbool_ior_scal_v32qi = 12639,
  CODE_FOR_reduc_sbool_ior_scal_v16qi = 12640,
  CODE_FOR_reduc_sbool_ior_scal_v16hi = 12641,
  CODE_FOR_reduc_sbool_ior_scal_v8hi = 12642,
  CODE_FOR_reduc_sbool_ior_scal_v8si = 12643,
  CODE_FOR_reduc_sbool_ior_scal_v4si = 12644,
  CODE_FOR_reduc_sbool_ior_scal_v4di = 12645,
  CODE_FOR_reduc_sbool_ior_scal_v2di = 12646,
  CODE_FOR_reduc_sbool_xor_scal_v32qi = 12647,
  CODE_FOR_reduc_sbool_xor_scal_v16qi = 12648,
  CODE_FOR_reduc_sbool_xor_scal_v4si = 12649,
  CODE_FOR_reduc_sbool_xor_scal_v2di = 12650,
  CODE_FOR_reduc_sbool_xor_scal_v8si = 12651,
  CODE_FOR_reduc_sbool_xor_scal_v4di = 12652,
  CODE_FOR_reduc_and_scal_v16qi = 12653,
  CODE_FOR_reduc_ior_scal_v16qi = 12654,
  CODE_FOR_reduc_xor_scal_v16qi = 12655,
  CODE_FOR_reduc_and_scal_v8hi = 12656,
  CODE_FOR_reduc_ior_scal_v8hi = 12657,
  CODE_FOR_reduc_xor_scal_v8hi = 12658,
  CODE_FOR_reduc_and_scal_v4si = 12659,
  CODE_FOR_reduc_ior_scal_v4si = 12660,
  CODE_FOR_reduc_xor_scal_v4si = 12661,
  CODE_FOR_reduc_and_scal_v2di = 12662,
  CODE_FOR_reduc_ior_scal_v2di = 12663,
  CODE_FOR_reduc_xor_scal_v2di = 12664,
  CODE_FOR_reduc_and_scal_v32qi = 12665,
  CODE_FOR_reduc_ior_scal_v32qi = 12666,
  CODE_FOR_reduc_xor_scal_v32qi = 12667,
  CODE_FOR_reduc_and_scal_v16hi = 12668,
  CODE_FOR_reduc_ior_scal_v16hi = 12669,
  CODE_FOR_reduc_xor_scal_v16hi = 12670,
  CODE_FOR_reduc_and_scal_v8si = 12671,
  CODE_FOR_reduc_ior_scal_v8si = 12672,
  CODE_FOR_reduc_xor_scal_v8si = 12673,
  CODE_FOR_reduc_and_scal_v4di = 12674,
  CODE_FOR_reduc_ior_scal_v4di = 12675,
  CODE_FOR_reduc_xor_scal_v4di = 12676,
  CODE_FOR_reduc_and_scal_v64qi = 12677,
  CODE_FOR_reduc_ior_scal_v64qi = 12678,
  CODE_FOR_reduc_xor_scal_v64qi = 12679,
  CODE_FOR_reduc_and_scal_v32hi = 12680,
  CODE_FOR_reduc_ior_scal_v32hi = 12681,
  CODE_FOR_reduc_xor_scal_v32hi = 12682,
  CODE_FOR_reduc_and_scal_v16si = 12683,
  CODE_FOR_reduc_ior_scal_v16si = 12684,
  CODE_FOR_reduc_xor_scal_v16si = 12685,
  CODE_FOR_reduc_and_scal_v8di = 12686,
  CODE_FOR_reduc_ior_scal_v8di = 12687,
  CODE_FOR_reduc_xor_scal_v8di = 12688,
  CODE_FOR_vec_cmpv16sihi = 12689,
  CODE_FOR_vec_cmpv8siqi = 12690,
  CODE_FOR_vec_cmpv4siqi = 12691,
  CODE_FOR_vec_cmpv8diqi = 12692,
  CODE_FOR_vec_cmpv4diqi = 12693,
  CODE_FOR_vec_cmpv2diqi = 12694,
  CODE_FOR_vec_cmpv32hfsi = 12695,
  CODE_FOR_vec_cmpv16hfhi = 12696,
  CODE_FOR_vec_cmpv8hfqi = 12697,
  CODE_FOR_vec_cmpv16sfhi = 12698,
  CODE_FOR_vec_cmpv8sfqi = 12699,
  CODE_FOR_vec_cmpv4sfqi = 12700,
  CODE_FOR_vec_cmpv8dfqi = 12701,
  CODE_FOR_vec_cmpv4dfqi = 12702,
  CODE_FOR_vec_cmpv2dfqi = 12703,
  CODE_FOR_vec_cmpv64qidi = 12704,
  CODE_FOR_vec_cmpv16qihi = 12705,
  CODE_FOR_vec_cmpv32qisi = 12706,
  CODE_FOR_vec_cmpv32hisi = 12707,
  CODE_FOR_vec_cmpv16hihi = 12708,
  CODE_FOR_vec_cmpv8hiqi = 12709,
  CODE_FOR_vec_cmpv32bfsi = 12710,
  CODE_FOR_vec_cmpv16bfhi = 12711,
  CODE_FOR_vec_cmpv8bfqi = 12712,
  CODE_FOR_vec_cmpv32qiv32qi = 12713,
  CODE_FOR_vec_cmpv16hiv16hi = 12714,
  CODE_FOR_vec_cmpv8siv8si = 12715,
  CODE_FOR_vec_cmpv4div4di = 12716,
  CODE_FOR_vec_cmpv16qiv16qi = 12717,
  CODE_FOR_vec_cmpv8hiv8hi = 12718,
  CODE_FOR_vec_cmpv4siv4si = 12719,
  CODE_FOR_vec_cmpv2div2di = 12720,
  CODE_FOR_vec_cmpv8sfv8si = 12721,
  CODE_FOR_vec_cmpv4dfv4di = 12722,
  CODE_FOR_vec_cmpv4sfv4si = 12723,
  CODE_FOR_vec_cmpv2dfv2di = 12724,
  CODE_FOR_vec_cmpuv16sihi = 12725,
  CODE_FOR_vec_cmpuv8siqi = 12726,
  CODE_FOR_vec_cmpuv4siqi = 12727,
  CODE_FOR_vec_cmpuv8diqi = 12728,
  CODE_FOR_vec_cmpuv4diqi = 12729,
  CODE_FOR_vec_cmpuv2diqi = 12730,
  CODE_FOR_vec_cmpuv64qidi = 12731,
  CODE_FOR_vec_cmpuv16qihi = 12732,
  CODE_FOR_vec_cmpuv32qisi = 12733,
  CODE_FOR_vec_cmpuv32hisi = 12734,
  CODE_FOR_vec_cmpuv16hihi = 12735,
  CODE_FOR_vec_cmpuv8hiqi = 12736,
  CODE_FOR_vec_cmpuv32qiv32qi = 12737,
  CODE_FOR_vec_cmpuv16hiv16hi = 12738,
  CODE_FOR_vec_cmpuv8siv8si = 12739,
  CODE_FOR_vec_cmpuv4div4di = 12740,
  CODE_FOR_vec_cmpuv16qiv16qi = 12741,
  CODE_FOR_vec_cmpuv8hiv8hi = 12742,
  CODE_FOR_vec_cmpuv4siv4si = 12743,
  CODE_FOR_vec_cmpuv2div2di = 12744,
  CODE_FOR_vec_cmpeqv2div2di = 12745,
  CODE_FOR_vec_cmpeqv1tiv1ti = 12746,
  CODE_FOR_vcond_mask_v16sihi = 12747,
  CODE_FOR_vcond_mask_v8siqi = 12748,
  CODE_FOR_vcond_mask_v4siqi = 12749,
  CODE_FOR_vcond_mask_v8diqi = 12750,
  CODE_FOR_vcond_mask_v4diqi = 12751,
  CODE_FOR_vcond_mask_v2diqi = 12752,
  CODE_FOR_vcond_mask_v16sfhi = 12753,
  CODE_FOR_vcond_mask_v8sfqi = 12754,
  CODE_FOR_vcond_mask_v4sfqi = 12755,
  CODE_FOR_vcond_mask_v8dfqi = 12756,
  CODE_FOR_vcond_mask_v4dfqi = 12757,
  CODE_FOR_vcond_mask_v2dfqi = 12758,
  CODE_FOR_vcond_mask_v64qidi = 12759,
  CODE_FOR_vcond_mask_v16qihi = 12760,
  CODE_FOR_vcond_mask_v32qisi = 12761,
  CODE_FOR_vcond_mask_v32hisi = 12762,
  CODE_FOR_vcond_mask_v16hihi = 12763,
  CODE_FOR_vcond_mask_v8hiqi = 12764,
  CODE_FOR_vcond_mask_v32hfsi = 12765,
  CODE_FOR_vcond_mask_v16hfhi = 12766,
  CODE_FOR_vcond_mask_v8hfqi = 12767,
  CODE_FOR_vcond_mask_v32bfsi = 12768,
  CODE_FOR_vcond_mask_v16bfhi = 12769,
  CODE_FOR_vcond_mask_v8bfqi = 12770,
  CODE_FOR_vcond_mask_v32qiv32qi = 12771,
  CODE_FOR_vcond_mask_v16hiv16hi = 12772,
  CODE_FOR_vcond_mask_v8siv8si = 12773,
  CODE_FOR_vcond_mask_v4div4di = 12774,
  CODE_FOR_vcond_mask_v16qiv16qi = 12775,
  CODE_FOR_vcond_mask_v8hiv8hi = 12776,
  CODE_FOR_vcond_mask_v4siv4si = 12777,
  CODE_FOR_vcond_mask_v2div2di = 12778,
  CODE_FOR_vcond_mask_v1tiv1ti = 12779,
  CODE_FOR_vcond_mask_v8sfv8si = 12780,
  CODE_FOR_vcond_mask_v4dfv4di = 12781,
  CODE_FOR_vcond_mask_v4sfv4si = 12782,
  CODE_FOR_vcond_mask_v2dfv2di = 12783,
  CODE_FOR_vcond_mask_qiqi = 12784,
  CODE_FOR_vcond_mask_hihi = 12785,
  CODE_FOR_vcond_mask_sisi = 12786,
  CODE_FOR_vcond_mask_didi = 12787,
  CODE_FOR_andv16bf3 = 12788,
   CODE_FOR_andv16bf3_mask = CODE_FOR_nothing,
  CODE_FOR_iorv16bf3 = 12789,
   CODE_FOR_iorv16bf3_mask = CODE_FOR_nothing,
  CODE_FOR_xorv16bf3 = 12790,
   CODE_FOR_xorv16bf3_mask = CODE_FOR_nothing,
  CODE_FOR_andv8bf3 = 12791,
   CODE_FOR_andv8bf3_mask = CODE_FOR_nothing,
  CODE_FOR_iorv8bf3 = 12792,
   CODE_FOR_iorv8bf3_mask = CODE_FOR_nothing,
  CODE_FOR_xorv8bf3 = 12793,
   CODE_FOR_xorv8bf3_mask = CODE_FOR_nothing,
  CODE_FOR_andv16hf3 = 12794,
   CODE_FOR_andv16hf3_mask = CODE_FOR_nothing,
  CODE_FOR_iorv16hf3 = 12795,
   CODE_FOR_iorv16hf3_mask = CODE_FOR_nothing,
  CODE_FOR_xorv16hf3 = 12796,
   CODE_FOR_xorv16hf3_mask = CODE_FOR_nothing,
  CODE_FOR_andv8hf3 = 12797,
   CODE_FOR_andv8hf3_mask = CODE_FOR_nothing,
  CODE_FOR_iorv8hf3 = 12798,
   CODE_FOR_iorv8hf3_mask = CODE_FOR_nothing,
  CODE_FOR_xorv8hf3 = 12799,
   CODE_FOR_xorv8hf3_mask = CODE_FOR_nothing,
  CODE_FOR_andv8sf3 = 12800,
  CODE_FOR_andv8sf3_mask = 12801,
  CODE_FOR_iorv8sf3 = 12802,
  CODE_FOR_iorv8sf3_mask = 12803,
  CODE_FOR_xorv8sf3 = 12804,
  CODE_FOR_xorv8sf3_mask = 12805,
  CODE_FOR_andv4sf3 = 12806,
  CODE_FOR_andv4sf3_mask = 12807,
  CODE_FOR_iorv4sf3 = 12808,
  CODE_FOR_iorv4sf3_mask = 12809,
  CODE_FOR_xorv4sf3 = 12810,
  CODE_FOR_xorv4sf3_mask = 12811,
  CODE_FOR_andv4df3 = 12812,
  CODE_FOR_andv4df3_mask = 12813,
  CODE_FOR_iorv4df3 = 12814,
  CODE_FOR_iorv4df3_mask = 12815,
  CODE_FOR_xorv4df3 = 12816,
  CODE_FOR_xorv4df3_mask = 12817,
  CODE_FOR_andv2df3 = 12818,
  CODE_FOR_andv2df3_mask = 12819,
  CODE_FOR_iorv2df3 = 12820,
  CODE_FOR_iorv2df3_mask = 12821,
  CODE_FOR_xorv2df3 = 12822,
  CODE_FOR_xorv2df3_mask = 12823,
  CODE_FOR_andv32bf3 = 12824,
   CODE_FOR_andv32bf3_mask = CODE_FOR_nothing,
  CODE_FOR_iorv32bf3 = 12825,
   CODE_FOR_iorv32bf3_mask = CODE_FOR_nothing,
  CODE_FOR_xorv32bf3 = 12826,
   CODE_FOR_xorv32bf3_mask = CODE_FOR_nothing,
  CODE_FOR_andv32hf3 = 12827,
   CODE_FOR_andv32hf3_mask = CODE_FOR_nothing,
  CODE_FOR_iorv32hf3 = 12828,
   CODE_FOR_iorv32hf3_mask = CODE_FOR_nothing,
  CODE_FOR_xorv32hf3 = 12829,
   CODE_FOR_xorv32hf3_mask = CODE_FOR_nothing,
  CODE_FOR_andv16sf3 = 12830,
  CODE_FOR_andv16sf3_mask = 12831,
  CODE_FOR_iorv16sf3 = 12832,
  CODE_FOR_iorv16sf3_mask = 12833,
  CODE_FOR_xorv16sf3 = 12834,
  CODE_FOR_xorv16sf3_mask = 12835,
  CODE_FOR_andv8df3 = 12836,
  CODE_FOR_andv8df3_mask = 12837,
  CODE_FOR_iorv8df3 = 12838,
  CODE_FOR_iorv8df3_mask = 12839,
  CODE_FOR_xorv8df3 = 12840,
  CODE_FOR_xorv8df3_mask = 12841,
  CODE_FOR_copysignv32bf3 = 12842,
  CODE_FOR_copysignv16bf3 = 12843,
  CODE_FOR_copysignv8bf3 = 12844,
  CODE_FOR_copysignv32hf3 = 12845,
  CODE_FOR_copysignv16hf3 = 12846,
  CODE_FOR_copysignv8hf3 = 12847,
  CODE_FOR_copysignv16sf3 = 12848,
  CODE_FOR_copysignv8sf3 = 12849,
  CODE_FOR_copysignv4sf3 = 12850,
  CODE_FOR_copysignv8df3 = 12851,
  CODE_FOR_copysignv4df3 = 12852,
  CODE_FOR_copysignv2df3 = 12853,
  CODE_FOR_xorsignv32bf3 = 12854,
  CODE_FOR_xorsignv16bf3 = 12855,
  CODE_FOR_xorsignv8bf3 = 12856,
  CODE_FOR_xorsignv32hf3 = 12857,
  CODE_FOR_xorsignv16hf3 = 12858,
  CODE_FOR_xorsignv8hf3 = 12859,
  CODE_FOR_xorsignv16sf3 = 12860,
  CODE_FOR_xorsignv8sf3 = 12861,
  CODE_FOR_xorsignv4sf3 = 12862,
  CODE_FOR_xorsignv8df3 = 12863,
  CODE_FOR_xorsignv4df3 = 12864,
  CODE_FOR_xorsignv2df3 = 12865,
  CODE_FOR_signbitv16sf2 = 12866,
  CODE_FOR_signbitv8sf2 = 12867,
  CODE_FOR_signbitv4sf2 = 12868,
  CODE_FOR_andtf3 = 12869,
  CODE_FOR_iortf3 = 12870,
  CODE_FOR_xortf3 = 12871,
  CODE_FOR_fmasf4 = 12872,
  CODE_FOR_fmadf4 = 12873,
  CODE_FOR_fmav4sf4 = 12874,
  CODE_FOR_fmav2df4 = 12875,
  CODE_FOR_fmav8sf4 = 12876,
  CODE_FOR_fmav4df4 = 12877,
  CODE_FOR_fmav16sf4 = 12878,
  CODE_FOR_fmav8df4 = 12879,
  CODE_FOR_fmahf4 = 12880,
  CODE_FOR_fmav8hf4 = 12881,
  CODE_FOR_fmav16hf4 = 12882,
  CODE_FOR_fmav32hf4 = 12883,
  CODE_FOR_fmav8bf4 = 12884,
  CODE_FOR_fmav16bf4 = 12885,
  CODE_FOR_fmav32bf4 = 12886,
  CODE_FOR_fmssf4 = 12887,
  CODE_FOR_fmsdf4 = 12888,
  CODE_FOR_fmsv4sf4 = 12889,
  CODE_FOR_fmsv2df4 = 12890,
  CODE_FOR_fmsv8sf4 = 12891,
  CODE_FOR_fmsv4df4 = 12892,
  CODE_FOR_fmsv16sf4 = 12893,
  CODE_FOR_fmsv8df4 = 12894,
  CODE_FOR_fmshf4 = 12895,
  CODE_FOR_fmsv8hf4 = 12896,
  CODE_FOR_fmsv16hf4 = 12897,
  CODE_FOR_fmsv32hf4 = 12898,
  CODE_FOR_fmsv8bf4 = 12899,
  CODE_FOR_fmsv16bf4 = 12900,
  CODE_FOR_fmsv32bf4 = 12901,
  CODE_FOR_fnmasf4 = 12902,
  CODE_FOR_fnmadf4 = 12903,
  CODE_FOR_fnmav4sf4 = 12904,
  CODE_FOR_fnmav2df4 = 12905,
  CODE_FOR_fnmav8sf4 = 12906,
  CODE_FOR_fnmav4df4 = 12907,
  CODE_FOR_fnmav16sf4 = 12908,
  CODE_FOR_fnmav8df4 = 12909,
  CODE_FOR_fnmahf4 = 12910,
  CODE_FOR_fnmav8hf4 = 12911,
  CODE_FOR_fnmav16hf4 = 12912,
  CODE_FOR_fnmav32hf4 = 12913,
  CODE_FOR_fnmav8bf4 = 12914,
  CODE_FOR_fnmav16bf4 = 12915,
  CODE_FOR_fnmav32bf4 = 12916,
  CODE_FOR_fnmssf4 = 12917,
  CODE_FOR_fnmsdf4 = 12918,
  CODE_FOR_fnmsv4sf4 = 12919,
  CODE_FOR_fnmsv2df4 = 12920,
  CODE_FOR_fnmsv8sf4 = 12921,
  CODE_FOR_fnmsv4df4 = 12922,
  CODE_FOR_fnmsv16sf4 = 12923,
  CODE_FOR_fnmsv8df4 = 12924,
  CODE_FOR_fnmshf4 = 12925,
  CODE_FOR_fnmsv8hf4 = 12926,
  CODE_FOR_fnmsv16hf4 = 12927,
  CODE_FOR_fnmsv32hf4 = 12928,
  CODE_FOR_fnmsv8bf4 = 12929,
  CODE_FOR_fnmsv16bf4 = 12930,
  CODE_FOR_fnmsv32bf4 = 12931,
  CODE_FOR_fma4i_fmadd_sf = 12932,
  CODE_FOR_fma4i_fmadd_df = 12933,
  CODE_FOR_fma4i_fmadd_v4sf = 12934,
  CODE_FOR_fma4i_fmadd_v2df = 12935,
  CODE_FOR_fma4i_fmadd_v8sf = 12936,
  CODE_FOR_fma4i_fmadd_v4df = 12937,
  CODE_FOR_fma4i_fmadd_v16sf = 12938,
  CODE_FOR_fma4i_fmadd_v8df = 12939,
  CODE_FOR_fma4i_fmsub_sf = 12940,
  CODE_FOR_fma4i_fmsub_df = 12941,
  CODE_FOR_fma4i_fmsub_v4sf = 12942,
  CODE_FOR_fma4i_fmsub_v2df = 12943,
  CODE_FOR_fma4i_fmsub_v8sf = 12944,
  CODE_FOR_fma4i_fmsub_v4df = 12945,
  CODE_FOR_fma4i_fmsub_v16sf = 12946,
  CODE_FOR_fma4i_fmsub_v8df = 12947,
  CODE_FOR_fma4i_fnmadd_sf = 12948,
  CODE_FOR_fma4i_fnmadd_df = 12949,
  CODE_FOR_fma4i_fnmadd_v4sf = 12950,
  CODE_FOR_fma4i_fnmadd_v2df = 12951,
  CODE_FOR_fma4i_fnmadd_v8sf = 12952,
  CODE_FOR_fma4i_fnmadd_v4df = 12953,
  CODE_FOR_fma4i_fnmadd_v16sf = 12954,
  CODE_FOR_fma4i_fnmadd_v8df = 12955,
  CODE_FOR_fma4i_fnmsub_sf = 12956,
  CODE_FOR_fma4i_fnmsub_df = 12957,
  CODE_FOR_fma4i_fnmsub_v4sf = 12958,
  CODE_FOR_fma4i_fnmsub_v2df = 12959,
  CODE_FOR_fma4i_fnmsub_v8sf = 12960,
  CODE_FOR_fma4i_fnmsub_v4df = 12961,
  CODE_FOR_fma4i_fnmsub_v16sf = 12962,
  CODE_FOR_fma4i_fnmsub_v8df = 12963,
  CODE_FOR_avx512bw_fmadd_v32hf_maskz = 12964,
  CODE_FOR_avx512bw_fmadd_v32hf_maskz_round = 12965,
  CODE_FOR_avx512vl_fmadd_v16hf_maskz = 12966,
  CODE_FOR_avx512vl_fmadd_v16hf_maskz_round = 12967,
  CODE_FOR_avx512fp16_fmadd_v8hf_maskz = 12968,
  CODE_FOR_avx512fp16_fmadd_v8hf_maskz_round = 12969,
  CODE_FOR_avx512f_fmadd_v16sf_maskz = 12970,
  CODE_FOR_avx512f_fmadd_v16sf_maskz_round = 12971,
  CODE_FOR_avx512vl_fmadd_v8sf_maskz = 12972,
  CODE_FOR_avx512vl_fmadd_v8sf_maskz_round = 12973,
  CODE_FOR_avx512vl_fmadd_v4sf_maskz = 12974,
  CODE_FOR_avx512vl_fmadd_v4sf_maskz_round = 12975,
  CODE_FOR_avx512f_fmadd_v8df_maskz = 12976,
  CODE_FOR_avx512f_fmadd_v8df_maskz_round = 12977,
  CODE_FOR_avx512vl_fmadd_v4df_maskz = 12978,
  CODE_FOR_avx512vl_fmadd_v4df_maskz_round = 12979,
  CODE_FOR_avx512vl_fmadd_v2df_maskz = 12980,
  CODE_FOR_avx512vl_fmadd_v2df_maskz_round = 12981,
  CODE_FOR_cond_fmav32hf = 12982,
  CODE_FOR_cond_fmav16hf = 12983,
  CODE_FOR_cond_fmav8hf = 12984,
  CODE_FOR_cond_fmav16sf = 12985,
  CODE_FOR_cond_fmav8sf = 12986,
  CODE_FOR_cond_fmav4sf = 12987,
  CODE_FOR_cond_fmav8df = 12988,
  CODE_FOR_cond_fmav4df = 12989,
  CODE_FOR_cond_fmav2df = 12990,
  CODE_FOR_avx512bw_fmsub_v32hf_maskz = 12991,
  CODE_FOR_avx512bw_fmsub_v32hf_maskz_round = 12992,
  CODE_FOR_avx512vl_fmsub_v16hf_maskz = 12993,
  CODE_FOR_avx512vl_fmsub_v16hf_maskz_round = 12994,
  CODE_FOR_avx512fp16_fmsub_v8hf_maskz = 12995,
  CODE_FOR_avx512fp16_fmsub_v8hf_maskz_round = 12996,
  CODE_FOR_avx512f_fmsub_v16sf_maskz = 12997,
  CODE_FOR_avx512f_fmsub_v16sf_maskz_round = 12998,
  CODE_FOR_avx512vl_fmsub_v8sf_maskz = 12999,
  CODE_FOR_avx512vl_fmsub_v8sf_maskz_round = 13000,
  CODE_FOR_avx512vl_fmsub_v4sf_maskz = 13001,
  CODE_FOR_avx512vl_fmsub_v4sf_maskz_round = 13002,
  CODE_FOR_avx512f_fmsub_v8df_maskz = 13003,
  CODE_FOR_avx512f_fmsub_v8df_maskz_round = 13004,
  CODE_FOR_avx512vl_fmsub_v4df_maskz = 13005,
  CODE_FOR_avx512vl_fmsub_v4df_maskz_round = 13006,
  CODE_FOR_avx512vl_fmsub_v2df_maskz = 13007,
  CODE_FOR_avx512vl_fmsub_v2df_maskz_round = 13008,
  CODE_FOR_cond_fmsv32hf = 13009,
  CODE_FOR_cond_fmsv16hf = 13010,
  CODE_FOR_cond_fmsv8hf = 13011,
  CODE_FOR_cond_fmsv16sf = 13012,
  CODE_FOR_cond_fmsv8sf = 13013,
  CODE_FOR_cond_fmsv4sf = 13014,
  CODE_FOR_cond_fmsv8df = 13015,
  CODE_FOR_cond_fmsv4df = 13016,
  CODE_FOR_cond_fmsv2df = 13017,
  CODE_FOR_avx512bw_fnmadd_v32hf_maskz = 13018,
  CODE_FOR_avx512bw_fnmadd_v32hf_maskz_round = 13019,
  CODE_FOR_avx512vl_fnmadd_v16hf_maskz = 13020,
  CODE_FOR_avx512vl_fnmadd_v16hf_maskz_round = 13021,
  CODE_FOR_avx512fp16_fnmadd_v8hf_maskz = 13022,
  CODE_FOR_avx512fp16_fnmadd_v8hf_maskz_round = 13023,
  CODE_FOR_avx512f_fnmadd_v16sf_maskz = 13024,
  CODE_FOR_avx512f_fnmadd_v16sf_maskz_round = 13025,
  CODE_FOR_avx512vl_fnmadd_v8sf_maskz = 13026,
  CODE_FOR_avx512vl_fnmadd_v8sf_maskz_round = 13027,
  CODE_FOR_avx512vl_fnmadd_v4sf_maskz = 13028,
  CODE_FOR_avx512vl_fnmadd_v4sf_maskz_round = 13029,
  CODE_FOR_avx512f_fnmadd_v8df_maskz = 13030,
  CODE_FOR_avx512f_fnmadd_v8df_maskz_round = 13031,
  CODE_FOR_avx512vl_fnmadd_v4df_maskz = 13032,
  CODE_FOR_avx512vl_fnmadd_v4df_maskz_round = 13033,
  CODE_FOR_avx512vl_fnmadd_v2df_maskz = 13034,
  CODE_FOR_avx512vl_fnmadd_v2df_maskz_round = 13035,
  CODE_FOR_cond_fnmav32hf = 13036,
  CODE_FOR_cond_fnmav16hf = 13037,
  CODE_FOR_cond_fnmav8hf = 13038,
  CODE_FOR_cond_fnmav16sf = 13039,
  CODE_FOR_cond_fnmav8sf = 13040,
  CODE_FOR_cond_fnmav4sf = 13041,
  CODE_FOR_cond_fnmav8df = 13042,
  CODE_FOR_cond_fnmav4df = 13043,
  CODE_FOR_cond_fnmav2df = 13044,
  CODE_FOR_avx512bw_fnmsub_v32hf_maskz = 13045,
  CODE_FOR_avx512bw_fnmsub_v32hf_maskz_round = 13046,
  CODE_FOR_avx512vl_fnmsub_v16hf_maskz = 13047,
  CODE_FOR_avx512vl_fnmsub_v16hf_maskz_round = 13048,
  CODE_FOR_avx512fp16_fnmsub_v8hf_maskz = 13049,
  CODE_FOR_avx512fp16_fnmsub_v8hf_maskz_round = 13050,
  CODE_FOR_avx512f_fnmsub_v16sf_maskz = 13051,
  CODE_FOR_avx512f_fnmsub_v16sf_maskz_round = 13052,
  CODE_FOR_avx512vl_fnmsub_v8sf_maskz = 13053,
  CODE_FOR_avx512vl_fnmsub_v8sf_maskz_round = 13054,
  CODE_FOR_avx512vl_fnmsub_v4sf_maskz = 13055,
  CODE_FOR_avx512vl_fnmsub_v4sf_maskz_round = 13056,
  CODE_FOR_avx512f_fnmsub_v8df_maskz = 13057,
  CODE_FOR_avx512f_fnmsub_v8df_maskz_round = 13058,
  CODE_FOR_avx512vl_fnmsub_v4df_maskz = 13059,
  CODE_FOR_avx512vl_fnmsub_v4df_maskz_round = 13060,
  CODE_FOR_avx512vl_fnmsub_v2df_maskz = 13061,
  CODE_FOR_avx512vl_fnmsub_v2df_maskz_round = 13062,
  CODE_FOR_cond_fnmsv32hf = 13063,
  CODE_FOR_cond_fnmsv16hf = 13064,
  CODE_FOR_cond_fnmsv8hf = 13065,
  CODE_FOR_cond_fnmsv16sf = 13066,
  CODE_FOR_cond_fnmsv8sf = 13067,
  CODE_FOR_cond_fnmsv4sf = 13068,
  CODE_FOR_cond_fnmsv8df = 13069,
  CODE_FOR_cond_fnmsv4df = 13070,
  CODE_FOR_cond_fnmsv2df = 13071,
  CODE_FOR_vec_fmaddsubv32hf4 = 13072,
  CODE_FOR_vec_fmaddsubv16hf4 = 13073,
  CODE_FOR_vec_fmaddsubv8hf4 = 13074,
  CODE_FOR_vec_fmaddsubv16sf4 = 13075,
  CODE_FOR_vec_fmaddsubv8sf4 = 13076,
  CODE_FOR_vec_fmaddsubv4sf4 = 13077,
  CODE_FOR_vec_fmaddsubv8df4 = 13078,
  CODE_FOR_vec_fmaddsubv4df4 = 13079,
  CODE_FOR_vec_fmaddsubv2df4 = 13080,
  CODE_FOR_vec_fmsubaddv32hf4 = 13081,
  CODE_FOR_vec_fmsubaddv16hf4 = 13082,
  CODE_FOR_vec_fmsubaddv8hf4 = 13083,
  CODE_FOR_vec_fmsubaddv16sf4 = 13084,
  CODE_FOR_vec_fmsubaddv8sf4 = 13085,
  CODE_FOR_vec_fmsubaddv4sf4 = 13086,
  CODE_FOR_vec_fmsubaddv8df4 = 13087,
  CODE_FOR_vec_fmsubaddv4df4 = 13088,
  CODE_FOR_vec_fmsubaddv2df4 = 13089,
  CODE_FOR_fmaddsub_v16sf = 13090,
  CODE_FOR_fmaddsub_v8sf = 13091,
  CODE_FOR_fmaddsub_v4sf = 13092,
  CODE_FOR_fmaddsub_v8df = 13093,
  CODE_FOR_fmaddsub_v4df = 13094,
  CODE_FOR_fmaddsub_v2df = 13095,
  CODE_FOR_avx512bw_fmaddsub_v32hf_maskz = 13096,
  CODE_FOR_avx512bw_fmaddsub_v32hf_maskz_round = 13097,
  CODE_FOR_avx512vl_fmaddsub_v16hf_maskz = 13098,
  CODE_FOR_avx512vl_fmaddsub_v16hf_maskz_round = 13099,
  CODE_FOR_avx512fp16_fmaddsub_v8hf_maskz = 13100,
  CODE_FOR_avx512fp16_fmaddsub_v8hf_maskz_round = 13101,
  CODE_FOR_avx512f_fmaddsub_v16sf_maskz = 13102,
  CODE_FOR_avx512f_fmaddsub_v16sf_maskz_round = 13103,
  CODE_FOR_avx512vl_fmaddsub_v8sf_maskz = 13104,
  CODE_FOR_avx512vl_fmaddsub_v8sf_maskz_round = 13105,
  CODE_FOR_avx512vl_fmaddsub_v4sf_maskz = 13106,
  CODE_FOR_avx512vl_fmaddsub_v4sf_maskz_round = 13107,
  CODE_FOR_avx512f_fmaddsub_v8df_maskz = 13108,
  CODE_FOR_avx512f_fmaddsub_v8df_maskz_round = 13109,
  CODE_FOR_avx512vl_fmaddsub_v4df_maskz = 13110,
  CODE_FOR_avx512vl_fmaddsub_v4df_maskz_round = 13111,
  CODE_FOR_avx512vl_fmaddsub_v2df_maskz = 13112,
  CODE_FOR_avx512vl_fmaddsub_v2df_maskz_round = 13113,
  CODE_FOR_avx512bw_fmsubadd_v32hf_maskz = 13114,
  CODE_FOR_avx512bw_fmsubadd_v32hf_maskz_round = 13115,
  CODE_FOR_avx512vl_fmsubadd_v16hf_maskz = 13116,
  CODE_FOR_avx512vl_fmsubadd_v16hf_maskz_round = 13117,
  CODE_FOR_avx512fp16_fmsubadd_v8hf_maskz = 13118,
  CODE_FOR_avx512fp16_fmsubadd_v8hf_maskz_round = 13119,
  CODE_FOR_avx512f_fmsubadd_v16sf_maskz = 13120,
  CODE_FOR_avx512f_fmsubadd_v16sf_maskz_round = 13121,
  CODE_FOR_avx512vl_fmsubadd_v8sf_maskz = 13122,
  CODE_FOR_avx512vl_fmsubadd_v8sf_maskz_round = 13123,
  CODE_FOR_avx512vl_fmsubadd_v4sf_maskz = 13124,
  CODE_FOR_avx512vl_fmsubadd_v4sf_maskz_round = 13125,
  CODE_FOR_avx512f_fmsubadd_v8df_maskz = 13126,
  CODE_FOR_avx512f_fmsubadd_v8df_maskz_round = 13127,
  CODE_FOR_avx512vl_fmsubadd_v4df_maskz = 13128,
  CODE_FOR_avx512vl_fmsubadd_v4df_maskz_round = 13129,
  CODE_FOR_avx512vl_fmsubadd_v2df_maskz = 13130,
  CODE_FOR_avx512vl_fmsubadd_v2df_maskz_round = 13131,
  CODE_FOR_fmai_vmfmadd_v8hf = 13132,
  CODE_FOR_fmai_vmfmadd_v8hf_round = 13133,
  CODE_FOR_fmai_vmfmadd_v4sf = 13134,
  CODE_FOR_fmai_vmfmadd_v4sf_round = 13135,
  CODE_FOR_fmai_vmfmadd_v2df = 13136,
  CODE_FOR_fmai_vmfmadd_v2df_round = 13137,
  CODE_FOR_fmai_vmfmsub_v8hf = 13138,
  CODE_FOR_fmai_vmfmsub_v8hf_round = 13139,
  CODE_FOR_fmai_vmfmsub_v4sf = 13140,
  CODE_FOR_fmai_vmfmsub_v4sf_round = 13141,
  CODE_FOR_fmai_vmfmsub_v2df = 13142,
  CODE_FOR_fmai_vmfmsub_v2df_round = 13143,
  CODE_FOR_fmai_vmfnmadd_v8hf = 13144,
  CODE_FOR_fmai_vmfnmadd_v8hf_round = 13145,
  CODE_FOR_fmai_vmfnmadd_v4sf = 13146,
  CODE_FOR_fmai_vmfnmadd_v4sf_round = 13147,
  CODE_FOR_fmai_vmfnmadd_v2df = 13148,
  CODE_FOR_fmai_vmfnmadd_v2df_round = 13149,
  CODE_FOR_fmai_vmfnmsub_v8hf = 13150,
  CODE_FOR_fmai_vmfnmsub_v8hf_round = 13151,
  CODE_FOR_fmai_vmfnmsub_v4sf = 13152,
  CODE_FOR_fmai_vmfnmsub_v4sf_round = 13153,
  CODE_FOR_fmai_vmfnmsub_v2df = 13154,
  CODE_FOR_fmai_vmfnmsub_v2df_round = 13155,
  CODE_FOR_avx512f_vmfmadd_v8hf_maskz = 13156,
  CODE_FOR_avx512f_vmfmadd_v8hf_maskz_round = 13157,
  CODE_FOR_avx512f_vmfmadd_v4sf_maskz = 13158,
  CODE_FOR_avx512f_vmfmadd_v4sf_maskz_round = 13159,
  CODE_FOR_avx512f_vmfmadd_v2df_maskz = 13160,
  CODE_FOR_avx512f_vmfmadd_v2df_maskz_round = 13161,
  CODE_FOR_avx512f_vmfnmadd_v8hf_maskz = 13162,
  CODE_FOR_avx512f_vmfnmadd_v8hf_maskz_round = 13163,
  CODE_FOR_avx512f_vmfnmadd_v4sf_maskz = 13164,
  CODE_FOR_avx512f_vmfnmadd_v4sf_maskz_round = 13165,
  CODE_FOR_avx512f_vmfnmadd_v2df_maskz = 13166,
  CODE_FOR_avx512f_vmfnmadd_v2df_maskz_round = 13167,
  CODE_FOR_fma4i_vmfmadd_v4sf = 13168,
  CODE_FOR_fma4i_vmfmadd_v2df = 13169,
  CODE_FOR_avx512bw_fmaddc_v32hf_mask1 = 13170,
  CODE_FOR_avx512bw_fmaddc_v32hf_mask1_round = 13171,
  CODE_FOR_avx512vl_fmaddc_v16hf_mask1 = 13172,
  CODE_FOR_avx512vl_fmaddc_v16hf_mask1_round = 13173,
  CODE_FOR_avx512fp16_fmaddc_v8hf_mask1 = 13174,
  CODE_FOR_avx512fp16_fmaddc_v8hf_mask1_round = 13175,
  CODE_FOR_avx512bw_fmaddc_v32hf_maskz = 13176,
  CODE_FOR_avx512bw_fmaddc_v32hf_maskz_round = 13177,
  CODE_FOR_avx512vl_fmaddc_v16hf_maskz = 13178,
  CODE_FOR_avx512vl_fmaddc_v16hf_maskz_round = 13179,
  CODE_FOR_avx512fp16_fmaddc_v8hf_maskz = 13180,
  CODE_FOR_avx512fp16_fmaddc_v8hf_maskz_round = 13181,
  CODE_FOR_avx512bw_fcmaddc_v32hf_mask1 = 13182,
  CODE_FOR_avx512bw_fcmaddc_v32hf_mask1_round = 13183,
  CODE_FOR_avx512vl_fcmaddc_v16hf_mask1 = 13184,
  CODE_FOR_avx512vl_fcmaddc_v16hf_mask1_round = 13185,
  CODE_FOR_avx512fp16_fcmaddc_v8hf_mask1 = 13186,
  CODE_FOR_avx512fp16_fcmaddc_v8hf_mask1_round = 13187,
  CODE_FOR_avx512bw_fcmaddc_v32hf_maskz = 13188,
  CODE_FOR_avx512bw_fcmaddc_v32hf_maskz_round = 13189,
  CODE_FOR_avx512vl_fcmaddc_v16hf_maskz = 13190,
  CODE_FOR_avx512vl_fcmaddc_v16hf_maskz_round = 13191,
  CODE_FOR_avx512fp16_fcmaddc_v8hf_maskz = 13192,
  CODE_FOR_avx512fp16_fcmaddc_v8hf_maskz_round = 13193,
  CODE_FOR_cmlav32hf4 = 13194,
  CODE_FOR_cmla_conjv32hf4 = 13195,
  CODE_FOR_cmlav16hf4 = 13196,
  CODE_FOR_cmla_conjv16hf4 = 13197,
  CODE_FOR_cmlav8hf4 = 13198,
  CODE_FOR_cmla_conjv8hf4 = 13199,
  CODE_FOR_cmulv32hf3 = 13200,
  CODE_FOR_cmul_conjv32hf3 = 13201,
  CODE_FOR_cmulv16hf3 = 13202,
  CODE_FOR_cmul_conjv16hf3 = 13203,
  CODE_FOR_cmulv8hf3 = 13204,
  CODE_FOR_cmul_conjv8hf3 = 13205,
  CODE_FOR_avx512fp16_fmaddcsh_v8hf_maskz = 13206,
  CODE_FOR_avx512fp16_fmaddcsh_v8hf_maskz_round = 13207,
  CODE_FOR_avx512fp16_fmaddcsh_v8hf_mask1 = 13208,
  CODE_FOR_avx512fp16_fmaddcsh_v8hf_mask1_round = 13209,
  CODE_FOR_avx512fp16_fcmaddcsh_v8hf_maskz = 13210,
  CODE_FOR_avx512fp16_fcmaddcsh_v8hf_maskz_round = 13211,
  CODE_FOR_avx512fp16_fcmaddcsh_v8hf_mask1 = 13212,
  CODE_FOR_avx512fp16_fcmaddcsh_v8hf_mask1_round = 13213,
  CODE_FOR_avx512fp16_fcmaddcsh_v8hf_mask3 = 13214,
  CODE_FOR_avx512fp16_fcmaddcsh_v8hf_mask3_round = 13215,
  CODE_FOR_avx512fp16_fmaddcsh_v8hf_mask3 = 13216,
  CODE_FOR_avx512fp16_fmaddcsh_v8hf_mask3_round = 13217,
  CODE_FOR_vec_unpacks_lo_v32hf = 13218,
  CODE_FOR_vec_unpacks_lo_v16hf = 13219,
  CODE_FOR_vec_unpacks_lo_v8hf = 13220,
  CODE_FOR_vec_unpacks_hi_v32hf = 13221,
  CODE_FOR_vec_unpacks_hi_v16hf = 13222,
  CODE_FOR_vec_unpacks_hi_v8hf = 13223,
  CODE_FOR_lrintv32hfv32hi2 = 13224,
  CODE_FOR_lrintv16hfv16hi2 = 13225,
  CODE_FOR_lrintv8hfv8hi2 = 13226,
  CODE_FOR_floatv8hiv8hf2 = 13227,
  CODE_FOR_floatunsv8hiv8hf2 = 13228,
  CODE_FOR_floatv16hiv16hf2 = 13229,
  CODE_FOR_floatunsv16hiv16hf2 = 13230,
  CODE_FOR_floatv32hiv32hf2 = 13231,
  CODE_FOR_floatunsv32hiv32hf2 = 13232,
  CODE_FOR_floatv8siv8hf2 = 13233,
  CODE_FOR_floatunsv8siv8hf2 = 13234,
  CODE_FOR_floatv16siv16hf2 = 13235,
  CODE_FOR_floatunsv16siv16hf2 = 13236,
  CODE_FOR_floatv8div8hf2 = 13237,
  CODE_FOR_floatunsv8div8hf2 = 13238,
  CODE_FOR_floatv4siv4hf2 = 13239,
  CODE_FOR_floatunsv4siv4hf2 = 13240,
  CODE_FOR_floatv4div4hf2 = 13241,
  CODE_FOR_floatunsv4div4hf2 = 13242,
  CODE_FOR_avx512fp16_floatv4siv4hf2 = 13243,
  CODE_FOR_avx512fp16_floatunsv4siv4hf2 = 13244,
  CODE_FOR_avx512fp16_floatv4div4hf2 = 13245,
  CODE_FOR_avx512fp16_floatunsv4div4hf2 = 13246,
  CODE_FOR_avx512fp16_vcvtdq2ph_v4si_mask = 13247,
  CODE_FOR_avx512fp16_vcvtudq2ph_v4si_mask = 13248,
  CODE_FOR_avx512fp16_vcvtqq2ph_v4di_mask = 13249,
  CODE_FOR_avx512fp16_vcvtuqq2ph_v4di_mask = 13250,
  CODE_FOR_floatv2div2hf2 = 13251,
  CODE_FOR_floatunsv2div2hf2 = 13252,
  CODE_FOR_avx512fp16_floatv2div2hf2 = 13253,
  CODE_FOR_avx512fp16_floatunsv2div2hf2 = 13254,
  CODE_FOR_avx512fp16_vcvtqq2ph_v2di_mask = 13255,
  CODE_FOR_avx512fp16_vcvtuqq2ph_v2di_mask = 13256,
  CODE_FOR_fix_truncv8hfv8hi2 = 13257,
  CODE_FOR_fixuns_truncv8hfv8hi2 = 13258,
  CODE_FOR_fix_truncv16hfv16hi2 = 13259,
  CODE_FOR_fixuns_truncv16hfv16hi2 = 13260,
  CODE_FOR_fix_truncv32hfv32hi2 = 13261,
  CODE_FOR_fixuns_truncv32hfv32hi2 = 13262,
  CODE_FOR_fix_truncv8hfv8si2 = 13263,
  CODE_FOR_fixuns_truncv8hfv8si2 = 13264,
  CODE_FOR_fix_truncv16hfv16si2 = 13265,
  CODE_FOR_fixuns_truncv16hfv16si2 = 13266,
  CODE_FOR_fix_truncv8hfv8di2 = 13267,
  CODE_FOR_fixuns_truncv8hfv8di2 = 13268,
  CODE_FOR_fix_truncv4hfv4si2 = 13269,
  CODE_FOR_fixuns_truncv4hfv4si2 = 13270,
  CODE_FOR_fix_truncv4hfv4di2 = 13271,
  CODE_FOR_fixuns_truncv4hfv4di2 = 13272,
  CODE_FOR_fix_truncv2hfv2di2 = 13273,
  CODE_FOR_fixuns_truncv2hfv2di2 = 13274,
  CODE_FOR_extendv8hfv8df2 = 13275,
  CODE_FOR_extendv16hfv16sf2 = 13276,
  CODE_FOR_extendv8hfv8sf2 = 13277,
  CODE_FOR_extendv4hfv4df2 = 13278,
  CODE_FOR_extendv4hfv4sf2 = 13279,
  CODE_FOR_extendv2hfv2df2 = 13280,
  CODE_FOR_truncv8dfv8hf2 = 13281,
  CODE_FOR_truncv16sfv16hf2 = 13282,
  CODE_FOR_truncv8sfv8hf2 = 13283,
  CODE_FOR_truncv4dfv4hf2 = 13284,
  CODE_FOR_truncv4sfv4hf2 = 13285,
  CODE_FOR_avx512fp16_truncv4dfv4hf2 = 13286,
  CODE_FOR_avx512fp16_truncv4sfv4hf2 = 13287,
  CODE_FOR_avx512fp16_vcvtpd2ph_v4df_mask = 13288,
  CODE_FOR_avx512fp16_vcvtps2ph_v4sf_mask = 13289,
  CODE_FOR_truncv2dfv2hf2 = 13290,
  CODE_FOR_avx512fp16_truncv2dfv2hf2 = 13291,
  CODE_FOR_avx512fp16_vcvtpd2ph_v2df_mask = 13292,
  CODE_FOR_floatunsv16siv16sf2 = 13293,
  CODE_FOR_floatunsv8siv8sf2 = 13294,
  CODE_FOR_floatunsv4siv4sf2 = 13295,
  CODE_FOR_fixuns_truncv8sfv8si2 = 13296,
  CODE_FOR_fixuns_truncv4sfv4si2 = 13297,
  CODE_FOR_floatv2siv2df2 = 13298,
  CODE_FOR_fix_truncv2dfv2si2 = 13299,
  CODE_FOR_avx512dq_floatv2div2sf2 = 13300,
  CODE_FOR_avx512dq_floatunsv2div2sf2 = 13301,
  CODE_FOR_floatv2div2sf2 = 13302,
  CODE_FOR_floatunsv2div2sf2 = 13303,
  CODE_FOR_vec_packs_float_v8di = 13304,
  CODE_FOR_vec_packu_float_v8di = 13305,
  CODE_FOR_vec_packs_float_v4di = 13306,
  CODE_FOR_vec_packu_float_v4di = 13307,
  CODE_FOR_vec_packs_float_v2di = 13308,
  CODE_FOR_vec_packu_float_v2di = 13309,
  CODE_FOR_vec_packs_float_v16si = 13310,
  CODE_FOR_vec_packu_float_v16si = 13311,
  CODE_FOR_vec_packs_float_v8si = 13312,
  CODE_FOR_vec_packu_float_v8si = 13313,
  CODE_FOR_vec_packs_float_v4si = 13314,
  CODE_FOR_vec_packu_float_v4si = 13315,
  CODE_FOR_floatv2div2sf2_mask = 13316,
  CODE_FOR_floatunsv2div2sf2_mask = 13317,
  CODE_FOR_avx_cvtpd2dq256_2 = 13318,
  CODE_FOR_fix_truncv2sfv2di2 = 13319,
  CODE_FOR_fixuns_truncv2sfv2di2 = 13320,
  CODE_FOR_vec_unpack_sfix_trunc_lo_v16sf = 13321,
  CODE_FOR_vec_unpack_ufix_trunc_lo_v16sf = 13322,
  CODE_FOR_vec_unpack_sfix_trunc_lo_v8sf = 13323,
  CODE_FOR_vec_unpack_ufix_trunc_lo_v8sf = 13324,
  CODE_FOR_vec_unpack_sfix_trunc_lo_v4sf = 13325,
  CODE_FOR_vec_unpack_ufix_trunc_lo_v4sf = 13326,
  CODE_FOR_vec_unpack_sfix_trunc_hi_v16sf = 13327,
  CODE_FOR_vec_unpack_ufix_trunc_hi_v16sf = 13328,
  CODE_FOR_vec_unpack_sfix_trunc_hi_v8sf = 13329,
  CODE_FOR_vec_unpack_ufix_trunc_hi_v8sf = 13330,
  CODE_FOR_vec_unpack_sfix_trunc_hi_v4sf = 13331,
  CODE_FOR_vec_unpack_ufix_trunc_hi_v4sf = 13332,
  CODE_FOR_vec_unpack_sfix_trunc_lo_v32hf = 13333,
  CODE_FOR_vec_unpack_ufix_trunc_lo_v32hf = 13334,
  CODE_FOR_vec_unpack_sfix_trunc_lo_v16hf = 13335,
  CODE_FOR_vec_unpack_ufix_trunc_lo_v16hf = 13336,
  CODE_FOR_vec_unpack_sfix_trunc_lo_v8hf = 13337,
  CODE_FOR_vec_unpack_ufix_trunc_lo_v8hf = 13338,
  CODE_FOR_vec_unpack_sfix_trunc_hi_v32hf = 13339,
  CODE_FOR_vec_unpack_ufix_trunc_hi_v32hf = 13340,
  CODE_FOR_vec_unpack_sfix_trunc_hi_v16hf = 13341,
  CODE_FOR_vec_unpack_ufix_trunc_hi_v16hf = 13342,
  CODE_FOR_vec_unpack_sfix_trunc_hi_v8hf = 13343,
  CODE_FOR_vec_unpack_ufix_trunc_hi_v8hf = 13344,
  CODE_FOR_avx_cvttpd2dq256_2 = 13345,
  CODE_FOR_sse2_cvtpd2ps = 13346,
  CODE_FOR_sse2_cvtpd2ps_mask = 13347,
  CODE_FOR_truncv8dfv8sf2 = 13348,
  CODE_FOR_truncv4dfv4sf2 = 13349,
  CODE_FOR_extendv8sfv8df2 = 13350,
  CODE_FOR_extendv4sfv4df2 = 13351,
  CODE_FOR_avx512bw_cvtmask2bv64qi = 13352,
  CODE_FOR_avx512vl_cvtmask2bv16qi = 13353,
  CODE_FOR_avx512vl_cvtmask2bv32qi = 13354,
  CODE_FOR_avx512bw_cvtmask2wv32hi = 13355,
  CODE_FOR_avx512vl_cvtmask2wv16hi = 13356,
  CODE_FOR_avx512vl_cvtmask2wv8hi = 13357,
  CODE_FOR_avx512f_cvtmask2dv16si = 13358,
  CODE_FOR_avx512vl_cvtmask2dv8si = 13359,
  CODE_FOR_avx512vl_cvtmask2dv4si = 13360,
  CODE_FOR_avx512f_cvtmask2qv8di = 13361,
  CODE_FOR_avx512vl_cvtmask2qv4di = 13362,
  CODE_FOR_avx512vl_cvtmask2qv2di = 13363,
  CODE_FOR_extendv2sfv2df2 = 13364,
  CODE_FOR_vec_unpacks_hi_v4sf = 13365,
  CODE_FOR_vec_unpacks_hi_v8sf = 13366,
  CODE_FOR_vec_unpacks_hi_v16sf = 13367,
  CODE_FOR_vec_unpacks_lo_v4sf = 13368,
  CODE_FOR_vec_unpacks_lo_v8sf = 13369,
  CODE_FOR_vec_unpacks_float_hi_v32hi = 13370,
  CODE_FOR_vec_unpacks_float_hi_v16hi = 13371,
  CODE_FOR_vec_unpacks_float_hi_v8hi = 13372,
  CODE_FOR_vec_unpacks_float_lo_v32hi = 13373,
  CODE_FOR_vec_unpacks_float_lo_v16hi = 13374,
  CODE_FOR_vec_unpacks_float_lo_v8hi = 13375,
  CODE_FOR_vec_unpacku_float_hi_v32hi = 13376,
  CODE_FOR_vec_unpacku_float_hi_v16hi = 13377,
  CODE_FOR_vec_unpacku_float_hi_v8hi = 13378,
  CODE_FOR_vec_unpacku_float_lo_v32hi = 13379,
  CODE_FOR_vec_unpacku_float_lo_v16hi = 13380,
  CODE_FOR_vec_unpacku_float_lo_v8hi = 13381,
  CODE_FOR_vec_unpacks_float_hi_v4si = 13382,
  CODE_FOR_vec_unpacks_float_lo_v4si = 13383,
  CODE_FOR_vec_unpacks_float_hi_v8si = 13384,
  CODE_FOR_vec_unpacks_float_lo_v8si = 13385,
  CODE_FOR_vec_unpacks_float_hi_v16si = 13386,
  CODE_FOR_vec_unpacks_float_lo_v16si = 13387,
  CODE_FOR_vec_unpacku_float_hi_v4si = 13388,
  CODE_FOR_vec_unpacku_float_lo_v4si = 13389,
  CODE_FOR_vec_unpacku_float_hi_v8si = 13390,
  CODE_FOR_vec_unpacku_float_hi_v16si = 13391,
  CODE_FOR_vec_unpacku_float_lo_v8si = 13392,
  CODE_FOR_vec_unpacku_float_lo_v16si = 13393,
  CODE_FOR_vec_pack_trunc_v8df = 13394,
  CODE_FOR_vec_pack_trunc_v4df = 13395,
  CODE_FOR_vec_pack_trunc_v16sf = 13396,
  CODE_FOR_vec_pack_trunc_v8sf = 13397,
  CODE_FOR_vec_pack_trunc_v4sf = 13398,
  CODE_FOR_vec_pack_trunc_v2df = 13399,
  CODE_FOR_vec_pack_sfix_trunc_v8df = 13400,
  CODE_FOR_vec_pack_sfix_trunc_v4df = 13401,
  CODE_FOR_vec_pack_sfix_trunc_v2df = 13402,
  CODE_FOR_vec_pack_ufix_trunc_v8df = 13403,
  CODE_FOR_vec_pack_ufix_trunc_v4df = 13404,
  CODE_FOR_vec_pack_ufix_trunc_v2df = 13405,
  CODE_FOR_avx512f_vec_pack_sfix_v8df = 13406,
  CODE_FOR_vec_pack_sfix_v4df = 13407,
  CODE_FOR_vec_pack_sfix_v2df = 13408,
  CODE_FOR_sse_movhlps_exp = 13409,
  CODE_FOR_sse_movlhps_exp = 13410,
  CODE_FOR_vec_interleave_highv8sf = 13411,
  CODE_FOR_vec_interleave_lowv8sf = 13412,
  CODE_FOR_avx_shufps256 = 13413,
  CODE_FOR_avx_shufps256_mask = 13414,
  CODE_FOR_sse_shufps = 13415,
  CODE_FOR_sse_shufps_mask = 13416,
  CODE_FOR_sse_loadhps_exp = 13417,
  CODE_FOR_sse_loadlps_exp = 13418,
  CODE_FOR_vec_setv16qi = 13419,
  CODE_FOR_vec_setv8hi = 13420,
  CODE_FOR_vec_setv8hf = 13421,
  CODE_FOR_vec_setv8bf = 13422,
  CODE_FOR_vec_setv4si = 13423,
  CODE_FOR_vec_setv2di = 13424,
  CODE_FOR_vec_setv4sf = 13425,
  CODE_FOR_vec_setv2df = 13426,
  CODE_FOR_vec_setv32qi = 13427,
  CODE_FOR_vec_setv16hi = 13428,
  CODE_FOR_vec_setv16hf = 13429,
  CODE_FOR_vec_setv16bf = 13430,
  CODE_FOR_vec_setv8si = 13431,
  CODE_FOR_vec_setv4di = 13432,
  CODE_FOR_vec_setv8sf = 13433,
  CODE_FOR_vec_setv4df = 13434,
  CODE_FOR_vec_setv64qi = 13435,
  CODE_FOR_vec_setv32hi = 13436,
  CODE_FOR_vec_setv32hf = 13437,
  CODE_FOR_vec_setv32bf = 13438,
  CODE_FOR_vec_setv16si = 13439,
  CODE_FOR_vec_setv8di = 13440,
  CODE_FOR_vec_setv16sf = 13441,
  CODE_FOR_vec_setv8df = 13442,
  CODE_FOR_avx512dq_vextractf64x2_mask = 13443,
  CODE_FOR_avx512dq_vextracti64x2_mask = 13444,
  CODE_FOR_avx512f_vextractf32x4_mask = 13445,
  CODE_FOR_avx512f_vextracti32x4_mask = 13446,
  CODE_FOR_avx512dq_vextractf32x8_mask = 13447,
  CODE_FOR_avx512dq_vextracti32x8_mask = 13448,
  CODE_FOR_avx512f_vextractf64x4_mask = 13449,
  CODE_FOR_avx512f_vextracti64x4_mask = 13450,
  CODE_FOR_avx512vl_vextractf128v8si = 13451,
  CODE_FOR_avx512vl_vextractf128v8sf = 13452,
  CODE_FOR_avx512vl_vextractf128v4di = 13453,
  CODE_FOR_avx512vl_vextractf128v4df = 13454,
  CODE_FOR_avx_vextractf128v32qi = 13455,
  CODE_FOR_avx_vextractf128v16hi = 13456,
  CODE_FOR_avx_vextractf128v8si = 13457,
  CODE_FOR_avx_vextractf128v4di = 13458,
  CODE_FOR_avx_vextractf128v8sf = 13459,
  CODE_FOR_avx_vextractf128v4df = 13460,
  CODE_FOR_avx_vextractf128v16hf = 13461,
  CODE_FOR_avx_vextractf128v16bf = 13462,
  CODE_FOR_vec_extractv64qiqi = 13463,
  CODE_FOR_vec_extractv32qiqi = 13464,
  CODE_FOR_vec_extractv16qiqi = 13465,
  CODE_FOR_vec_extractv32hihi = 13466,
  CODE_FOR_vec_extractv16hihi = 13467,
  CODE_FOR_vec_extractv8hihi = 13468,
  CODE_FOR_vec_extractv16sisi = 13469,
  CODE_FOR_vec_extractv8sisi = 13470,
  CODE_FOR_vec_extractv4sisi = 13471,
  CODE_FOR_vec_extractv8didi = 13472,
  CODE_FOR_vec_extractv4didi = 13473,
  CODE_FOR_vec_extractv2didi = 13474,
  CODE_FOR_vec_extractv32hfhf = 13475,
  CODE_FOR_vec_extractv16hfhf = 13476,
  CODE_FOR_vec_extractv8hfhf = 13477,
  CODE_FOR_vec_extractv32bfbf = 13478,
  CODE_FOR_vec_extractv16bfbf = 13479,
  CODE_FOR_vec_extractv8bfbf = 13480,
  CODE_FOR_vec_extractv16sfsf = 13481,
  CODE_FOR_vec_extractv8sfsf = 13482,
  CODE_FOR_vec_extractv4sfsf = 13483,
  CODE_FOR_vec_extractv8dfdf = 13484,
  CODE_FOR_vec_extractv4dfdf = 13485,
  CODE_FOR_vec_extractv2dfdf = 13486,
  CODE_FOR_vec_extractv4titi = 13487,
  CODE_FOR_vec_extractv2titi = 13488,
  CODE_FOR_vec_extractv32qiv16qi = 13489,
  CODE_FOR_vec_extractv16hiv8hi = 13490,
  CODE_FOR_vec_extractv16hfv8hf = 13491,
  CODE_FOR_vec_extractv16bfv8bf = 13492,
  CODE_FOR_vec_extractv8siv4si = 13493,
  CODE_FOR_vec_extractv4div2di = 13494,
  CODE_FOR_vec_extractv8sfv4sf = 13495,
  CODE_FOR_vec_extractv4dfv2df = 13496,
  CODE_FOR_vec_extractv64qiv32qi = 13497,
  CODE_FOR_vec_extractv32hiv16hi = 13498,
  CODE_FOR_vec_extractv32hfv16hf = 13499,
  CODE_FOR_vec_extractv32bfv16bf = 13500,
  CODE_FOR_vec_extractv16siv8si = 13501,
  CODE_FOR_vec_extractv8div4di = 13502,
  CODE_FOR_vec_extractv16sfv8sf = 13503,
  CODE_FOR_vec_extractv8dfv4df = 13504,
  CODE_FOR_vec_interleave_highv4df = 13505,
  CODE_FOR_vec_interleave_highv2df = 13506,
  CODE_FOR_vec_interleave_lowv4df = 13507,
  CODE_FOR_vec_interleave_lowv2df = 13508,
  CODE_FOR_avx512f_vternlogv16si_maskz = 13509,
  CODE_FOR_avx512vl_vternlogv8si_maskz = 13510,
  CODE_FOR_avx512vl_vternlogv4si_maskz = 13511,
  CODE_FOR_avx512f_vternlogv8di_maskz = 13512,
  CODE_FOR_avx512vl_vternlogv4di_maskz = 13513,
  CODE_FOR_avx512vl_vternlogv2di_maskz = 13514,
  CODE_FOR_avx512f_vternlogv16si_mask = 13515,
  CODE_FOR_avx512vl_vternlogv8si_mask = 13516,
  CODE_FOR_avx512vl_vternlogv4si_mask = 13517,
  CODE_FOR_avx512f_vternlogv8di_mask = 13518,
  CODE_FOR_avx512vl_vternlogv4di_mask = 13519,
  CODE_FOR_avx512vl_vternlogv2di_mask = 13520,
  CODE_FOR_avx512f_shufps512_mask = 13521,
  CODE_FOR_avx512f_fixupimmv16sf_maskz = 13522,
  CODE_FOR_avx512f_fixupimmv16sf_maskz_round = 13523,
  CODE_FOR_avx512vl_fixupimmv8sf_maskz = 13524,
  CODE_FOR_avx512vl_fixupimmv8sf_maskz_round = 13525,
  CODE_FOR_avx512vl_fixupimmv4sf_maskz = 13526,
  CODE_FOR_avx512vl_fixupimmv4sf_maskz_round = 13527,
  CODE_FOR_avx512f_fixupimmv8df_maskz = 13528,
  CODE_FOR_avx512f_fixupimmv8df_maskz_round = 13529,
  CODE_FOR_avx512vl_fixupimmv4df_maskz = 13530,
  CODE_FOR_avx512vl_fixupimmv4df_maskz_round = 13531,
  CODE_FOR_avx512vl_fixupimmv2df_maskz = 13532,
  CODE_FOR_avx512vl_fixupimmv2df_maskz_round = 13533,
  CODE_FOR_avx512f_sfixupimmv4sf_maskz = 13534,
  CODE_FOR_avx512f_sfixupimmv4sf_maskz_round = 13535,
  CODE_FOR_avx512f_sfixupimmv2df_maskz = 13536,
  CODE_FOR_avx512f_sfixupimmv2df_maskz_round = 13537,
  CODE_FOR_avx512f_shufpd512_mask = 13538,
  CODE_FOR_avx_shufpd256 = 13539,
  CODE_FOR_avx_shufpd256_mask = 13540,
  CODE_FOR_sse2_shufpd = 13541,
  CODE_FOR_sse2_shufpd_mask = 13542,
  CODE_FOR_sse2_loadhpd_exp = 13543,
  CODE_FOR_sse2_loadlpd_exp = 13544,
  CODE_FOR_truncv16siv16qi2 = 13545,
  CODE_FOR_truncv16siv16hi2 = 13546,
  CODE_FOR_truncv8div8si2 = 13547,
  CODE_FOR_truncv8div8hi2 = 13548,
  CODE_FOR_avx512f_ss_truncatev16siv16qi2_mask_store = 13549,
  CODE_FOR_avx512f_truncatev16siv16qi2_mask_store = 13550,
  CODE_FOR_avx512f_us_truncatev16siv16qi2_mask_store = 13551,
  CODE_FOR_avx512f_ss_truncatev16siv16hi2_mask_store = 13552,
  CODE_FOR_avx512f_truncatev16siv16hi2_mask_store = 13553,
  CODE_FOR_avx512f_us_truncatev16siv16hi2_mask_store = 13554,
  CODE_FOR_avx512f_ss_truncatev8div8si2_mask_store = 13555,
  CODE_FOR_avx512f_truncatev8div8si2_mask_store = 13556,
  CODE_FOR_avx512f_us_truncatev8div8si2_mask_store = 13557,
  CODE_FOR_avx512f_ss_truncatev8div8hi2_mask_store = 13558,
  CODE_FOR_avx512f_truncatev8div8hi2_mask_store = 13559,
  CODE_FOR_avx512f_us_truncatev8div8hi2_mask_store = 13560,
  CODE_FOR_truncv32hiv32qi2 = 13561,
  CODE_FOR_avx512bw_ss_truncatev32hiv32qi2_mask_store = 13562,
  CODE_FOR_avx512bw_truncatev32hiv32qi2_mask_store = 13563,
  CODE_FOR_avx512bw_us_truncatev32hiv32qi2_mask_store = 13564,
  CODE_FOR_truncv4div4si2 = 13565,
  CODE_FOR_truncv8siv8hi2 = 13566,
  CODE_FOR_truncv16hiv16qi2 = 13567,
  CODE_FOR_avx512vl_ss_truncatev4div4si2_mask_store = 13568,
  CODE_FOR_avx512vl_truncatev4div4si2_mask_store = 13569,
  CODE_FOR_avx512vl_us_truncatev4div4si2_mask_store = 13570,
  CODE_FOR_avx512vl_ss_truncatev8siv8hi2_mask_store = 13571,
  CODE_FOR_avx512vl_truncatev8siv8hi2_mask_store = 13572,
  CODE_FOR_avx512vl_us_truncatev8siv8hi2_mask_store = 13573,
  CODE_FOR_avx512vl_ss_truncatev16hiv16qi2_mask_store = 13574,
  CODE_FOR_avx512vl_truncatev16hiv16qi2_mask_store = 13575,
  CODE_FOR_avx512vl_us_truncatev16hiv16qi2_mask_store = 13576,
  CODE_FOR_truncv4div4qi2 = 13577,
  CODE_FOR_truncv2div2qi2 = 13578,
  CODE_FOR_truncv8siv8qi2 = 13579,
  CODE_FOR_truncv4siv4qi2 = 13580,
  CODE_FOR_truncv8hiv8qi2 = 13581,
  CODE_FOR_avx512vl_ss_truncatev2div2qi2_mask_store_2 = 13582,
  CODE_FOR_avx512vl_truncatev2div2qi2_mask_store_2 = 13583,
  CODE_FOR_avx512vl_us_truncatev2div2qi2_mask_store_2 = 13584,
  CODE_FOR_avx512vl_ss_truncatev4siv4qi2_mask_store_2 = 13585,
  CODE_FOR_avx512vl_truncatev4siv4qi2_mask_store_2 = 13586,
  CODE_FOR_avx512vl_us_truncatev4siv4qi2_mask_store_2 = 13587,
  CODE_FOR_avx512vl_ss_truncatev4div4qi2_mask_store_2 = 13588,
  CODE_FOR_avx512vl_truncatev4div4qi2_mask_store_2 = 13589,
  CODE_FOR_avx512vl_us_truncatev4div4qi2_mask_store_2 = 13590,
  CODE_FOR_avx512vl_ss_truncatev8hiv8qi2_mask_store_2 = 13591,
  CODE_FOR_avx512vl_truncatev8hiv8qi2_mask_store_2 = 13592,
  CODE_FOR_avx512vl_us_truncatev8hiv8qi2_mask_store_2 = 13593,
  CODE_FOR_avx512vl_ss_truncatev8siv8qi2_mask_store_2 = 13594,
  CODE_FOR_avx512vl_truncatev8siv8qi2_mask_store_2 = 13595,
  CODE_FOR_avx512vl_us_truncatev8siv8qi2_mask_store_2 = 13596,
  CODE_FOR_truncv4div4hi2 = 13597,
  CODE_FOR_truncv2div2hi2 = 13598,
  CODE_FOR_truncv4siv4hi2 = 13599,
  CODE_FOR_avx512vl_ss_truncatev4siv4hi2_mask_store_2 = 13600,
  CODE_FOR_avx512vl_truncatev4siv4hi2_mask_store_2 = 13601,
  CODE_FOR_avx512vl_us_truncatev4siv4hi2_mask_store_2 = 13602,
  CODE_FOR_avx512vl_ss_truncatev4div4hi2_mask_store_2 = 13603,
  CODE_FOR_avx512vl_truncatev4div4hi2_mask_store_2 = 13604,
  CODE_FOR_avx512vl_us_truncatev4div4hi2_mask_store_2 = 13605,
  CODE_FOR_avx512vl_ss_truncatev2div2hi2_mask_store_2 = 13606,
  CODE_FOR_avx512vl_truncatev2div2hi2_mask_store_2 = 13607,
  CODE_FOR_avx512vl_us_truncatev2div2hi2_mask_store_2 = 13608,
  CODE_FOR_truncv2div2si2 = 13609,
  CODE_FOR_avx512vl_ss_truncatev2div2si2_mask_store_2 = 13610,
  CODE_FOR_avx512vl_truncatev2div2si2_mask_store_2 = 13611,
  CODE_FOR_avx512vl_us_truncatev2div2si2_mask_store_2 = 13612,
  CODE_FOR_truncv8div8qi2 = 13613,
  CODE_FOR_avx512f_ss_truncatev8div16qi2_mask_store_2 = 13614,
  CODE_FOR_avx512f_truncatev8div16qi2_mask_store_2 = 13615,
  CODE_FOR_avx512f_us_truncatev8div16qi2_mask_store_2 = 13616,
  CODE_FOR_negv64qi2 = 13617,
  CODE_FOR_negv32qi2 = 13618,
  CODE_FOR_negv16qi2 = 13619,
  CODE_FOR_negv32hi2 = 13620,
  CODE_FOR_negv16hi2 = 13621,
  CODE_FOR_negv8hi2 = 13622,
  CODE_FOR_negv16si2 = 13623,
  CODE_FOR_negv8si2 = 13624,
  CODE_FOR_negv4si2 = 13625,
  CODE_FOR_negv8di2 = 13626,
  CODE_FOR_negv4di2 = 13627,
  CODE_FOR_negv2di2 = 13628,
  CODE_FOR_addv64qi3 = 13629,
  CODE_FOR_subv64qi3 = 13630,
  CODE_FOR_addv32qi3 = 13631,
  CODE_FOR_subv32qi3 = 13632,
  CODE_FOR_addv16qi3 = 13633,
  CODE_FOR_subv16qi3 = 13634,
  CODE_FOR_addv32hi3 = 13635,
  CODE_FOR_subv32hi3 = 13636,
  CODE_FOR_addv16hi3 = 13637,
  CODE_FOR_subv16hi3 = 13638,
  CODE_FOR_addv8hi3 = 13639,
  CODE_FOR_subv8hi3 = 13640,
  CODE_FOR_addv16si3 = 13641,
  CODE_FOR_subv16si3 = 13642,
  CODE_FOR_addv8si3 = 13643,
  CODE_FOR_subv8si3 = 13644,
  CODE_FOR_addv4si3 = 13645,
  CODE_FOR_subv4si3 = 13646,
  CODE_FOR_addv8di3 = 13647,
  CODE_FOR_subv8di3 = 13648,
  CODE_FOR_addv4di3 = 13649,
  CODE_FOR_subv4di3 = 13650,
  CODE_FOR_addv2di3 = 13651,
  CODE_FOR_subv2di3 = 13652,
  CODE_FOR_cond_addv64qi = 13653,
  CODE_FOR_cond_subv64qi = 13654,
  CODE_FOR_cond_addv32qi = 13655,
  CODE_FOR_cond_subv32qi = 13656,
  CODE_FOR_cond_addv16qi = 13657,
  CODE_FOR_cond_subv16qi = 13658,
  CODE_FOR_cond_addv32hi = 13659,
  CODE_FOR_cond_subv32hi = 13660,
  CODE_FOR_cond_addv16hi = 13661,
  CODE_FOR_cond_subv16hi = 13662,
  CODE_FOR_cond_addv8hi = 13663,
  CODE_FOR_cond_subv8hi = 13664,
  CODE_FOR_cond_addv16si = 13665,
  CODE_FOR_cond_subv16si = 13666,
  CODE_FOR_cond_addv8si = 13667,
  CODE_FOR_cond_subv8si = 13668,
  CODE_FOR_cond_addv4si = 13669,
  CODE_FOR_cond_subv4si = 13670,
  CODE_FOR_cond_addv8di = 13671,
  CODE_FOR_cond_subv8di = 13672,
  CODE_FOR_cond_addv4di = 13673,
  CODE_FOR_cond_subv4di = 13674,
  CODE_FOR_cond_addv2di = 13675,
  CODE_FOR_cond_subv2di = 13676,
  CODE_FOR_addv16si3_mask = 13677,
  CODE_FOR_subv16si3_mask = 13678,
  CODE_FOR_addv8si3_mask = 13679,
  CODE_FOR_subv8si3_mask = 13680,
  CODE_FOR_addv4si3_mask = 13681,
  CODE_FOR_subv4si3_mask = 13682,
  CODE_FOR_addv8di3_mask = 13683,
  CODE_FOR_subv8di3_mask = 13684,
  CODE_FOR_addv4di3_mask = 13685,
  CODE_FOR_subv4di3_mask = 13686,
  CODE_FOR_addv2di3_mask = 13687,
  CODE_FOR_subv2di3_mask = 13688,
  CODE_FOR_addv64qi3_mask = 13689,
  CODE_FOR_subv64qi3_mask = 13690,
  CODE_FOR_addv16qi3_mask = 13691,
  CODE_FOR_subv16qi3_mask = 13692,
  CODE_FOR_addv32qi3_mask = 13693,
  CODE_FOR_subv32qi3_mask = 13694,
  CODE_FOR_addv32hi3_mask = 13695,
  CODE_FOR_subv32hi3_mask = 13696,
  CODE_FOR_addv16hi3_mask = 13697,
  CODE_FOR_subv16hi3_mask = 13698,
  CODE_FOR_addv8hi3_mask = 13699,
  CODE_FOR_subv8hi3_mask = 13700,
  CODE_FOR_ssaddv64qi3 = 13701,
  CODE_FOR_ssaddv64qi3_mask = 13702,
  CODE_FOR_usaddv64qi3 = 13703,
  CODE_FOR_usaddv64qi3_mask = 13704,
  CODE_FOR_sssubv64qi3 = 13705,
  CODE_FOR_sssubv64qi3_mask = 13706,
  CODE_FOR_ussubv64qi3 = 13707,
  CODE_FOR_ussubv64qi3_mask = 13708,
  CODE_FOR_ssaddv32qi3 = 13709,
  CODE_FOR_ssaddv32qi3_mask = 13710,
  CODE_FOR_usaddv32qi3 = 13711,
  CODE_FOR_usaddv32qi3_mask = 13712,
  CODE_FOR_sssubv32qi3 = 13713,
  CODE_FOR_sssubv32qi3_mask = 13714,
  CODE_FOR_ussubv32qi3 = 13715,
  CODE_FOR_ussubv32qi3_mask = 13716,
  CODE_FOR_ssaddv16qi3 = 13717,
  CODE_FOR_ssaddv16qi3_mask = 13718,
  CODE_FOR_usaddv16qi3 = 13719,
  CODE_FOR_usaddv16qi3_mask = 13720,
  CODE_FOR_sssubv16qi3 = 13721,
  CODE_FOR_sssubv16qi3_mask = 13722,
  CODE_FOR_ussubv16qi3 = 13723,
  CODE_FOR_ussubv16qi3_mask = 13724,
  CODE_FOR_ssaddv32hi3 = 13725,
  CODE_FOR_ssaddv32hi3_mask = 13726,
  CODE_FOR_usaddv32hi3 = 13727,
  CODE_FOR_usaddv32hi3_mask = 13728,
  CODE_FOR_sssubv32hi3 = 13729,
  CODE_FOR_sssubv32hi3_mask = 13730,
  CODE_FOR_ussubv32hi3 = 13731,
  CODE_FOR_ussubv32hi3_mask = 13732,
  CODE_FOR_ssaddv16hi3 = 13733,
  CODE_FOR_ssaddv16hi3_mask = 13734,
  CODE_FOR_usaddv16hi3 = 13735,
  CODE_FOR_usaddv16hi3_mask = 13736,
  CODE_FOR_sssubv16hi3 = 13737,
  CODE_FOR_sssubv16hi3_mask = 13738,
  CODE_FOR_ussubv16hi3 = 13739,
  CODE_FOR_ussubv16hi3_mask = 13740,
  CODE_FOR_ssaddv8hi3 = 13741,
  CODE_FOR_ssaddv8hi3_mask = 13742,
  CODE_FOR_usaddv8hi3 = 13743,
  CODE_FOR_usaddv8hi3_mask = 13744,
  CODE_FOR_sssubv8hi3 = 13745,
  CODE_FOR_sssubv8hi3_mask = 13746,
  CODE_FOR_ussubv8hi3 = 13747,
  CODE_FOR_ussubv8hi3_mask = 13748,
  CODE_FOR_mulv64qi3 = 13749,
  CODE_FOR_mulv32qi3 = 13750,
  CODE_FOR_mulv16qi3 = 13751,
  CODE_FOR_cond_mulv8hi = 13752,
  CODE_FOR_cond_mulv16hi = 13753,
  CODE_FOR_cond_mulv32hi = 13754,
  CODE_FOR_mulv32hi3 = 13755,
  CODE_FOR_mulv32hi3_mask = 13756,
  CODE_FOR_mulv16hi3 = 13757,
  CODE_FOR_mulv16hi3_mask = 13758,
  CODE_FOR_mulv8hi3 = 13759,
  CODE_FOR_mulv8hi3_mask = 13760,
  CODE_FOR_smulv32hi3_highpart = 13761,
  CODE_FOR_smulv32hi3_highpart_mask = 13762,
  CODE_FOR_umulv32hi3_highpart = 13763,
  CODE_FOR_umulv32hi3_highpart_mask = 13764,
  CODE_FOR_smulv16hi3_highpart = 13765,
  CODE_FOR_smulv16hi3_highpart_mask = 13766,
  CODE_FOR_umulv16hi3_highpart = 13767,
  CODE_FOR_umulv16hi3_highpart_mask = 13768,
  CODE_FOR_smulv8hi3_highpart = 13769,
  CODE_FOR_smulv8hi3_highpart_mask = 13770,
  CODE_FOR_umulv8hi3_highpart = 13771,
  CODE_FOR_umulv8hi3_highpart_mask = 13772,
  CODE_FOR_vec_widen_umult_even_v16si = 13773,
  CODE_FOR_vec_widen_umult_even_v16si_mask = 13774,
  CODE_FOR_vec_widen_umult_even_v8si = 13775,
  CODE_FOR_vec_widen_umult_even_v8si_mask = 13776,
  CODE_FOR_vec_widen_umult_even_v4si = 13777,
  CODE_FOR_vec_widen_umult_even_v4si_mask = 13778,
  CODE_FOR_vec_widen_smult_even_v16si = 13779,
  CODE_FOR_vec_widen_smult_even_v16si_mask = 13780,
  CODE_FOR_vec_widen_smult_even_v8si = 13781,
  CODE_FOR_vec_widen_smult_even_v8si_mask = 13782,
  CODE_FOR_sse4_1_mulv2siv2di3 = 13783,
  CODE_FOR_sse4_1_mulv2siv2di3_mask = 13784,
  CODE_FOR_avx2_pmaddwd = 13785,
  CODE_FOR_sse2_pmaddwd = 13786,
  CODE_FOR_cond_mulv8di = 13787,
  CODE_FOR_cond_mulv4di = 13788,
  CODE_FOR_cond_mulv2di = 13789,
  CODE_FOR_avx512dq_mulv8di3 = 13790,
  CODE_FOR_avx512dq_mulv8di3_mask = 13791,
  CODE_FOR_avx512dq_mulv4di3 = 13792,
  CODE_FOR_avx512dq_mulv4di3_mask = 13793,
  CODE_FOR_avx512dq_mulv2di3 = 13794,
  CODE_FOR_avx512dq_mulv2di3_mask = 13795,
  CODE_FOR_cond_mulv16si = 13796,
  CODE_FOR_cond_mulv8si = 13797,
  CODE_FOR_cond_mulv4si = 13798,
  CODE_FOR_mulv16si3 = 13799,
  CODE_FOR_mulv16si3_mask = 13800,
  CODE_FOR_mulv8si3 = 13801,
  CODE_FOR_mulv8si3_mask = 13802,
  CODE_FOR_mulv4si3 = 13803,
  CODE_FOR_mulv4si3_mask = 13804,
  CODE_FOR_mulv8di3 = 13805,
  CODE_FOR_mulv4di3 = 13806,
  CODE_FOR_mulv2di3 = 13807,
  CODE_FOR_vec_widen_smult_hi_v32qi = 13808,
  CODE_FOR_vec_widen_umult_hi_v32qi = 13809,
  CODE_FOR_vec_widen_smult_hi_v16qi = 13810,
  CODE_FOR_vec_widen_umult_hi_v16qi = 13811,
  CODE_FOR_vec_widen_smult_hi_v16hi = 13812,
  CODE_FOR_vec_widen_umult_hi_v16hi = 13813,
  CODE_FOR_vec_widen_smult_hi_v8hi = 13814,
  CODE_FOR_vec_widen_umult_hi_v8hi = 13815,
  CODE_FOR_vec_widen_smult_hi_v8si = 13816,
  CODE_FOR_vec_widen_umult_hi_v8si = 13817,
  CODE_FOR_vec_widen_smult_hi_v4si = 13818,
  CODE_FOR_vec_widen_umult_hi_v4si = 13819,
  CODE_FOR_vec_widen_smult_lo_v32qi = 13820,
  CODE_FOR_vec_widen_umult_lo_v32qi = 13821,
  CODE_FOR_vec_widen_smult_lo_v16qi = 13822,
  CODE_FOR_vec_widen_umult_lo_v16qi = 13823,
  CODE_FOR_vec_widen_smult_lo_v16hi = 13824,
  CODE_FOR_vec_widen_umult_lo_v16hi = 13825,
  CODE_FOR_vec_widen_smult_lo_v8hi = 13826,
  CODE_FOR_vec_widen_umult_lo_v8hi = 13827,
  CODE_FOR_vec_widen_smult_lo_v8si = 13828,
  CODE_FOR_vec_widen_umult_lo_v8si = 13829,
  CODE_FOR_vec_widen_smult_lo_v4si = 13830,
  CODE_FOR_vec_widen_umult_lo_v4si = 13831,
  CODE_FOR_vec_widen_smult_even_v4si = 13832,
  CODE_FOR_vec_widen_smult_odd_v16si = 13833,
  CODE_FOR_vec_widen_umult_odd_v16si = 13834,
  CODE_FOR_vec_widen_smult_odd_v8si = 13835,
  CODE_FOR_vec_widen_umult_odd_v8si = 13836,
  CODE_FOR_vec_widen_smult_odd_v4si = 13837,
  CODE_FOR_vec_widen_umult_odd_v4si = 13838,
  CODE_FOR_sdot_prodv16siv32hi = 13839,
  CODE_FOR_sdot_prodv8siv16hi = 13840,
  CODE_FOR_sdot_prodv4siv8hi = 13841,
  CODE_FOR_sdot_prodv2div4si = 13842,
  CODE_FOR_uavgv64qi3_ceil = 13843,
  CODE_FOR_uavgv32qi3_ceil = 13844,
  CODE_FOR_uavgv16qi3_ceil = 13845,
  CODE_FOR_uavgv32hi3_ceil = 13846,
  CODE_FOR_uavgv16hi3_ceil = 13847,
  CODE_FOR_uavgv8hi3_ceil = 13848,
  CODE_FOR_usadv16qi = 13849,
  CODE_FOR_usadv32qi = 13850,
  CODE_FOR_usadv64qi = 13851,
  CODE_FOR_ashrv32hi3 = 13852,
  CODE_FOR_ashrv16si3 = 13853,
  CODE_FOR_ashrv8di3 = 13854,
  CODE_FOR_ashrv4di3 = 13855,
  CODE_FOR_vec_shl_v16qi = 13856,
  CODE_FOR_vec_shl_v8hi = 13857,
  CODE_FOR_vec_shl_v8hf = 13858,
  CODE_FOR_vec_shl_v8bf = 13859,
  CODE_FOR_vec_shl_v4si = 13860,
  CODE_FOR_vec_shl_v2di = 13861,
  CODE_FOR_vec_shl_v4sf = 13862,
  CODE_FOR_vec_shl_v2df = 13863,
  CODE_FOR_vec_shr_v16qi = 13864,
  CODE_FOR_vec_shr_v8hi = 13865,
  CODE_FOR_vec_shr_v8hf = 13866,
  CODE_FOR_vec_shr_v8bf = 13867,
  CODE_FOR_vec_shr_v4si = 13868,
  CODE_FOR_vec_shr_v2di = 13869,
  CODE_FOR_vec_shr_v4sf = 13870,
  CODE_FOR_vec_shr_v2df = 13871,
  CODE_FOR_ashlv1ti3 = 13872,
  CODE_FOR_lshrv1ti3 = 13873,
  CODE_FOR_ashrv1ti3 = 13874,
  CODE_FOR_rotlv1ti3 = 13875,
  CODE_FOR_rotrv1ti3 = 13876,
  CODE_FOR_smaxv32qi3 = 13877,
  CODE_FOR_sminv32qi3 = 13878,
  CODE_FOR_umaxv32qi3 = 13879,
  CODE_FOR_uminv32qi3 = 13880,
  CODE_FOR_smaxv16hi3 = 13881,
  CODE_FOR_sminv16hi3 = 13882,
  CODE_FOR_umaxv16hi3 = 13883,
  CODE_FOR_uminv16hi3 = 13884,
  CODE_FOR_smaxv8si3 = 13885,
  CODE_FOR_sminv8si3 = 13886,
  CODE_FOR_umaxv8si3 = 13887,
  CODE_FOR_uminv8si3 = 13888,
  CODE_FOR_smaxv64qi3 = 13889,
  CODE_FOR_sminv64qi3 = 13890,
  CODE_FOR_umaxv64qi3 = 13891,
  CODE_FOR_uminv64qi3 = 13892,
  CODE_FOR_smaxv32hi3 = 13893,
  CODE_FOR_sminv32hi3 = 13894,
  CODE_FOR_umaxv32hi3 = 13895,
  CODE_FOR_uminv32hi3 = 13896,
  CODE_FOR_smaxv16si3 = 13897,
  CODE_FOR_sminv16si3 = 13898,
  CODE_FOR_umaxv16si3 = 13899,
  CODE_FOR_uminv16si3 = 13900,
  CODE_FOR_cond_smaxv64qi = 13901,
  CODE_FOR_cond_sminv64qi = 13902,
  CODE_FOR_cond_umaxv64qi = 13903,
  CODE_FOR_cond_uminv64qi = 13904,
  CODE_FOR_cond_smaxv32qi = 13905,
  CODE_FOR_cond_sminv32qi = 13906,
  CODE_FOR_cond_umaxv32qi = 13907,
  CODE_FOR_cond_uminv32qi = 13908,
  CODE_FOR_cond_smaxv16qi = 13909,
  CODE_FOR_cond_sminv16qi = 13910,
  CODE_FOR_cond_umaxv16qi = 13911,
  CODE_FOR_cond_uminv16qi = 13912,
  CODE_FOR_cond_smaxv32hi = 13913,
  CODE_FOR_cond_sminv32hi = 13914,
  CODE_FOR_cond_umaxv32hi = 13915,
  CODE_FOR_cond_uminv32hi = 13916,
  CODE_FOR_cond_smaxv16hi = 13917,
  CODE_FOR_cond_sminv16hi = 13918,
  CODE_FOR_cond_umaxv16hi = 13919,
  CODE_FOR_cond_uminv16hi = 13920,
  CODE_FOR_cond_smaxv8hi = 13921,
  CODE_FOR_cond_sminv8hi = 13922,
  CODE_FOR_cond_umaxv8hi = 13923,
  CODE_FOR_cond_uminv8hi = 13924,
  CODE_FOR_cond_smaxv16si = 13925,
  CODE_FOR_cond_sminv16si = 13926,
  CODE_FOR_cond_umaxv16si = 13927,
  CODE_FOR_cond_uminv16si = 13928,
  CODE_FOR_cond_smaxv8si = 13929,
  CODE_FOR_cond_sminv8si = 13930,
  CODE_FOR_cond_umaxv8si = 13931,
  CODE_FOR_cond_uminv8si = 13932,
  CODE_FOR_cond_smaxv4si = 13933,
  CODE_FOR_cond_sminv4si = 13934,
  CODE_FOR_cond_umaxv4si = 13935,
  CODE_FOR_cond_uminv4si = 13936,
  CODE_FOR_cond_smaxv8di = 13937,
  CODE_FOR_cond_sminv8di = 13938,
  CODE_FOR_cond_umaxv8di = 13939,
  CODE_FOR_cond_uminv8di = 13940,
  CODE_FOR_cond_smaxv4di = 13941,
  CODE_FOR_cond_sminv4di = 13942,
  CODE_FOR_cond_umaxv4di = 13943,
  CODE_FOR_cond_uminv4di = 13944,
  CODE_FOR_cond_smaxv2di = 13945,
  CODE_FOR_cond_sminv2di = 13946,
  CODE_FOR_cond_umaxv2di = 13947,
  CODE_FOR_cond_uminv2di = 13948,
  CODE_FOR_smaxv64qi3_mask = 13949,
  CODE_FOR_sminv64qi3_mask = 13950,
  CODE_FOR_umaxv64qi3_mask = 13951,
  CODE_FOR_uminv64qi3_mask = 13952,
  CODE_FOR_smaxv32qi3_mask = 13953,
  CODE_FOR_sminv32qi3_mask = 13954,
  CODE_FOR_umaxv32qi3_mask = 13955,
  CODE_FOR_uminv32qi3_mask = 13956,
  CODE_FOR_smaxv16qi3_mask = 13957,
  CODE_FOR_sminv16qi3_mask = 13958,
  CODE_FOR_umaxv16qi3_mask = 13959,
  CODE_FOR_uminv16qi3_mask = 13960,
  CODE_FOR_smaxv32hi3_mask = 13961,
  CODE_FOR_sminv32hi3_mask = 13962,
  CODE_FOR_umaxv32hi3_mask = 13963,
  CODE_FOR_uminv32hi3_mask = 13964,
  CODE_FOR_smaxv16hi3_mask = 13965,
  CODE_FOR_sminv16hi3_mask = 13966,
  CODE_FOR_umaxv16hi3_mask = 13967,
  CODE_FOR_uminv16hi3_mask = 13968,
  CODE_FOR_smaxv8hi3_mask = 13969,
  CODE_FOR_sminv8hi3_mask = 13970,
  CODE_FOR_umaxv8hi3_mask = 13971,
  CODE_FOR_uminv8hi3_mask = 13972,
  CODE_FOR_smaxv16si3_mask = 13973,
  CODE_FOR_sminv16si3_mask = 13974,
  CODE_FOR_umaxv16si3_mask = 13975,
  CODE_FOR_uminv16si3_mask = 13976,
  CODE_FOR_smaxv8si3_mask = 13977,
  CODE_FOR_sminv8si3_mask = 13978,
  CODE_FOR_umaxv8si3_mask = 13979,
  CODE_FOR_uminv8si3_mask = 13980,
  CODE_FOR_smaxv4si3_mask = 13981,
  CODE_FOR_sminv4si3_mask = 13982,
  CODE_FOR_umaxv4si3_mask = 13983,
  CODE_FOR_uminv4si3_mask = 13984,
  CODE_FOR_smaxv8di3_mask = 13985,
  CODE_FOR_sminv8di3_mask = 13986,
  CODE_FOR_umaxv8di3_mask = 13987,
  CODE_FOR_uminv8di3_mask = 13988,
  CODE_FOR_smaxv4di3_mask = 13989,
  CODE_FOR_sminv4di3_mask = 13990,
  CODE_FOR_umaxv4di3_mask = 13991,
  CODE_FOR_uminv4di3_mask = 13992,
  CODE_FOR_smaxv2di3_mask = 13993,
  CODE_FOR_sminv2di3_mask = 13994,
  CODE_FOR_umaxv2di3_mask = 13995,
  CODE_FOR_uminv2di3_mask = 13996,
  CODE_FOR_smaxv8di3 = 13997,
  CODE_FOR_sminv8di3 = 13998,
  CODE_FOR_umaxv8di3 = 13999,
  CODE_FOR_uminv8di3 = 14000,
  CODE_FOR_smaxv4di3 = 14001,
  CODE_FOR_sminv4di3 = 14002,
  CODE_FOR_umaxv4di3 = 14003,
  CODE_FOR_uminv4di3 = 14004,
  CODE_FOR_smaxv2di3 = 14005,
  CODE_FOR_sminv2di3 = 14006,
  CODE_FOR_umaxv2di3 = 14007,
  CODE_FOR_uminv2di3 = 14008,
  CODE_FOR_smaxv16qi3 = 14009,
  CODE_FOR_sminv16qi3 = 14010,
  CODE_FOR_smaxv8hi3 = 14011,
  CODE_FOR_sminv8hi3 = 14012,
  CODE_FOR_smaxv4si3 = 14013,
  CODE_FOR_sminv4si3 = 14014,
  CODE_FOR_umaxv16qi3 = 14015,
  CODE_FOR_uminv16qi3 = 14016,
  CODE_FOR_umaxv8hi3 = 14017,
  CODE_FOR_uminv8hi3 = 14018,
  CODE_FOR_umaxv4si3 = 14019,
  CODE_FOR_uminv4si3 = 14020,
  CODE_FOR_avx512bw_eqv64qi3 = 14021,
  CODE_FOR_avx512bw_eqv64qi3_mask = 14022,
  CODE_FOR_avx512vl_eqv16qi3 = 14023,
  CODE_FOR_avx512vl_eqv16qi3_mask = 14024,
  CODE_FOR_avx512vl_eqv32qi3 = 14025,
  CODE_FOR_avx512vl_eqv32qi3_mask = 14026,
  CODE_FOR_avx512bw_eqv32hi3 = 14027,
  CODE_FOR_avx512bw_eqv32hi3_mask = 14028,
  CODE_FOR_avx512vl_eqv16hi3 = 14029,
  CODE_FOR_avx512vl_eqv16hi3_mask = 14030,
  CODE_FOR_avx512vl_eqv8hi3 = 14031,
  CODE_FOR_avx512vl_eqv8hi3_mask = 14032,
  CODE_FOR_avx512f_eqv16si3 = 14033,
  CODE_FOR_avx512f_eqv16si3_mask = 14034,
  CODE_FOR_avx512vl_eqv8si3 = 14035,
  CODE_FOR_avx512vl_eqv8si3_mask = 14036,
  CODE_FOR_avx512vl_eqv4si3 = 14037,
  CODE_FOR_avx512vl_eqv4si3_mask = 14038,
  CODE_FOR_avx512f_eqv8di3 = 14039,
  CODE_FOR_avx512f_eqv8di3_mask = 14040,
  CODE_FOR_avx512vl_eqv4di3 = 14041,
  CODE_FOR_avx512vl_eqv4di3_mask = 14042,
  CODE_FOR_avx512vl_eqv2di3 = 14043,
  CODE_FOR_avx512vl_eqv2di3_mask = 14044,
  CODE_FOR_avx512f_gtv16si3 = 14045,
  CODE_FOR_avx512f_gtv16si3_mask = 14046,
  CODE_FOR_avx512vl_gtv8si3 = 14047,
  CODE_FOR_avx512vl_gtv8si3_mask = 14048,
  CODE_FOR_avx512vl_gtv4si3 = 14049,
  CODE_FOR_avx512vl_gtv4si3_mask = 14050,
  CODE_FOR_avx512f_gtv8di3 = 14051,
  CODE_FOR_avx512f_gtv8di3_mask = 14052,
  CODE_FOR_avx512vl_gtv4di3 = 14053,
  CODE_FOR_avx512vl_gtv4di3_mask = 14054,
  CODE_FOR_avx512vl_gtv2di3 = 14055,
  CODE_FOR_avx512vl_gtv2di3_mask = 14056,
  CODE_FOR_avx512bw_gtv64qi3 = 14057,
  CODE_FOR_avx512bw_gtv64qi3_mask = 14058,
  CODE_FOR_avx512vl_gtv16qi3 = 14059,
  CODE_FOR_avx512vl_gtv16qi3_mask = 14060,
  CODE_FOR_avx512vl_gtv32qi3 = 14061,
  CODE_FOR_avx512vl_gtv32qi3_mask = 14062,
  CODE_FOR_avx512bw_gtv32hi3 = 14063,
  CODE_FOR_avx512bw_gtv32hi3_mask = 14064,
  CODE_FOR_avx512vl_gtv16hi3 = 14065,
  CODE_FOR_avx512vl_gtv16hi3_mask = 14066,
  CODE_FOR_avx512vl_gtv8hi3 = 14067,
  CODE_FOR_avx512vl_gtv8hi3_mask = 14068,
  CODE_FOR_vec_permv16qi = 14069,
  CODE_FOR_vec_permv8hi = 14070,
  CODE_FOR_vec_permv4si = 14071,
  CODE_FOR_vec_permv2di = 14072,
  CODE_FOR_vec_permv4sf = 14073,
  CODE_FOR_vec_permv2df = 14074,
  CODE_FOR_vec_permv8hf = 14075,
  CODE_FOR_vec_permv32qi = 14076,
  CODE_FOR_vec_permv16hi = 14077,
  CODE_FOR_vec_permv8si = 14078,
  CODE_FOR_vec_permv4di = 14079,
  CODE_FOR_vec_permv8sf = 14080,
  CODE_FOR_vec_permv4df = 14081,
  CODE_FOR_vec_permv16hf = 14082,
  CODE_FOR_vec_permv16sf = 14083,
  CODE_FOR_vec_permv8df = 14084,
  CODE_FOR_vec_permv16si = 14085,
  CODE_FOR_vec_permv8di = 14086,
  CODE_FOR_vec_permv32hi = 14087,
  CODE_FOR_vec_permv64qi = 14088,
  CODE_FOR_vec_permv32hf = 14089,
  CODE_FOR_one_cmplv16si2 = 14090,
  CODE_FOR_one_cmplv8di2 = 14091,
  CODE_FOR_one_cmplv64qi2 = 14092,
  CODE_FOR_one_cmplv32qi2 = 14093,
  CODE_FOR_one_cmplv16qi2 = 14094,
  CODE_FOR_one_cmplv32hi2 = 14095,
  CODE_FOR_one_cmplv16hi2 = 14096,
  CODE_FOR_one_cmplv8hi2 = 14097,
  CODE_FOR_one_cmplv8si2 = 14098,
  CODE_FOR_one_cmplv4si2 = 14099,
  CODE_FOR_one_cmplv4di2 = 14100,
  CODE_FOR_one_cmplv2di2 = 14101,
  CODE_FOR_avx512bw_andnotv64qi3 = 14102,
  CODE_FOR_avx2_andnotv32qi3 = 14103,
  CODE_FOR_sse2_andnotv16qi3 = 14104,
  CODE_FOR_avx512bw_andnotv32hi3 = 14105,
  CODE_FOR_avx2_andnotv16hi3 = 14106,
  CODE_FOR_sse2_andnotv8hi3 = 14107,
  CODE_FOR_avx512f_andnotv16si3 = 14108,
  CODE_FOR_avx2_andnotv8si3 = 14109,
  CODE_FOR_sse2_andnotv4si3 = 14110,
  CODE_FOR_avx512f_andnotv8di3 = 14111,
  CODE_FOR_avx2_andnotv4di3 = 14112,
  CODE_FOR_sse2_andnotv2di3 = 14113,
  CODE_FOR_andnv16si3 = 14114,
  CODE_FOR_andnv8di3 = 14115,
  CODE_FOR_andnv64qi3 = 14116,
  CODE_FOR_andnv32qi3 = 14117,
  CODE_FOR_andnv16qi3 = 14118,
  CODE_FOR_andnv32hi3 = 14119,
  CODE_FOR_andnv16hi3 = 14120,
  CODE_FOR_andnv8hi3 = 14121,
  CODE_FOR_andnv8si3 = 14122,
  CODE_FOR_andnv4si3 = 14123,
  CODE_FOR_andnv4di3 = 14124,
  CODE_FOR_andnv2di3 = 14125,
  CODE_FOR_avx512f_andnotv16si3_mask = 14126,
  CODE_FOR_avx2_andnotv8si3_mask = 14127,
  CODE_FOR_sse2_andnotv4si3_mask = 14128,
  CODE_FOR_avx512f_andnotv8di3_mask = 14129,
  CODE_FOR_avx2_andnotv4di3_mask = 14130,
  CODE_FOR_sse2_andnotv2di3_mask = 14131,
  CODE_FOR_andv16si3 = 14132,
  CODE_FOR_iorv16si3 = 14133,
  CODE_FOR_xorv16si3 = 14134,
  CODE_FOR_andv8di3 = 14135,
  CODE_FOR_iorv8di3 = 14136,
  CODE_FOR_xorv8di3 = 14137,
  CODE_FOR_andv64qi3 = 14138,
  CODE_FOR_iorv64qi3 = 14139,
  CODE_FOR_xorv64qi3 = 14140,
  CODE_FOR_andv32qi3 = 14141,
  CODE_FOR_iorv32qi3 = 14142,
  CODE_FOR_xorv32qi3 = 14143,
  CODE_FOR_andv16qi3 = 14144,
  CODE_FOR_iorv16qi3 = 14145,
  CODE_FOR_xorv16qi3 = 14146,
  CODE_FOR_andv32hi3 = 14147,
  CODE_FOR_iorv32hi3 = 14148,
  CODE_FOR_xorv32hi3 = 14149,
  CODE_FOR_andv16hi3 = 14150,
  CODE_FOR_iorv16hi3 = 14151,
  CODE_FOR_xorv16hi3 = 14152,
  CODE_FOR_andv8hi3 = 14153,
  CODE_FOR_iorv8hi3 = 14154,
  CODE_FOR_xorv8hi3 = 14155,
  CODE_FOR_andv8si3 = 14156,
  CODE_FOR_iorv8si3 = 14157,
  CODE_FOR_xorv8si3 = 14158,
  CODE_FOR_andv4si3 = 14159,
  CODE_FOR_iorv4si3 = 14160,
  CODE_FOR_xorv4si3 = 14161,
  CODE_FOR_andv4di3 = 14162,
  CODE_FOR_iorv4di3 = 14163,
  CODE_FOR_xorv4di3 = 14164,
  CODE_FOR_andv2di3 = 14165,
  CODE_FOR_iorv2di3 = 14166,
  CODE_FOR_xorv2di3 = 14167,
  CODE_FOR_cond_andv16si = 14168,
  CODE_FOR_cond_iorv16si = 14169,
  CODE_FOR_cond_xorv16si = 14170,
  CODE_FOR_cond_andv8si = 14171,
  CODE_FOR_cond_iorv8si = 14172,
  CODE_FOR_cond_xorv8si = 14173,
  CODE_FOR_cond_andv4si = 14174,
  CODE_FOR_cond_iorv4si = 14175,
  CODE_FOR_cond_xorv4si = 14176,
  CODE_FOR_cond_andv8di = 14177,
  CODE_FOR_cond_iorv8di = 14178,
  CODE_FOR_cond_xorv8di = 14179,
  CODE_FOR_cond_andv4di = 14180,
  CODE_FOR_cond_iorv4di = 14181,
  CODE_FOR_cond_xorv4di = 14182,
  CODE_FOR_cond_andv2di = 14183,
  CODE_FOR_cond_iorv2di = 14184,
  CODE_FOR_cond_xorv2di = 14185,
  CODE_FOR_andv16si3_mask = 14186,
  CODE_FOR_iorv16si3_mask = 14187,
  CODE_FOR_xorv16si3_mask = 14188,
  CODE_FOR_andv8si3_mask = 14189,
  CODE_FOR_iorv8si3_mask = 14190,
  CODE_FOR_xorv8si3_mask = 14191,
  CODE_FOR_andv4si3_mask = 14192,
  CODE_FOR_iorv4si3_mask = 14193,
  CODE_FOR_xorv4si3_mask = 14194,
  CODE_FOR_andv8di3_mask = 14195,
  CODE_FOR_iorv8di3_mask = 14196,
  CODE_FOR_xorv8di3_mask = 14197,
  CODE_FOR_andv4di3_mask = 14198,
  CODE_FOR_iorv4di3_mask = 14199,
  CODE_FOR_xorv4di3_mask = 14200,
  CODE_FOR_andv2di3_mask = 14201,
  CODE_FOR_iorv2di3_mask = 14202,
  CODE_FOR_xorv2di3_mask = 14203,
  CODE_FOR_one_cmplv1ti2 = 14204,
  CODE_FOR_vec_pack_trunc_v32hi = 14205,
  CODE_FOR_vec_pack_trunc_v16hi = 14206,
  CODE_FOR_vec_pack_trunc_v8hi = 14207,
  CODE_FOR_vec_pack_trunc_v16si = 14208,
  CODE_FOR_vec_pack_trunc_v8si = 14209,
  CODE_FOR_vec_pack_trunc_v4si = 14210,
  CODE_FOR_vec_pack_trunc_v8di = 14211,
  CODE_FOR_vec_pack_trunc_v4di = 14212,
  CODE_FOR_vec_pack_trunc_v2di = 14213,
  CODE_FOR_vec_pack_trunc_qi = 14214,
  CODE_FOR_vec_pack_trunc_hi = 14215,
  CODE_FOR_vec_pack_trunc_si = 14216,
  CODE_FOR_vec_pack_sbool_trunc_qi = 14217,
  CODE_FOR_vec_interleave_highv32qi = 14218,
  CODE_FOR_vec_interleave_highv16hi = 14219,
  CODE_FOR_vec_interleave_highv8si = 14220,
  CODE_FOR_vec_interleave_highv4di = 14221,
  CODE_FOR_vec_interleave_lowv32qi = 14222,
  CODE_FOR_vec_interleave_lowv16hi = 14223,
  CODE_FOR_vec_interleave_lowv8si = 14224,
  CODE_FOR_vec_interleave_lowv4di = 14225,
  CODE_FOR_avx512dq_vinsertf64x2_mask = 14226,
  CODE_FOR_avx512dq_vinserti64x2_mask = 14227,
  CODE_FOR_avx512f_vinsertf32x4_mask = 14228,
  CODE_FOR_avx512f_vinserti32x4_mask = 14229,
  CODE_FOR_avx512dq_vinsertf32x8_mask = 14230,
  CODE_FOR_avx512dq_vinserti32x8_mask = 14231,
  CODE_FOR_avx512f_vinsertf64x4_mask = 14232,
  CODE_FOR_avx512f_vinserti64x4_mask = 14233,
  CODE_FOR_avx512dq_shuf_i64x2_mask = 14234,
  CODE_FOR_avx512dq_shuf_f64x2_mask = 14235,
  CODE_FOR_avx512f_shuf_f64x2_mask = 14236,
  CODE_FOR_avx512f_shuf_i64x2_mask = 14237,
  CODE_FOR_avx512vl_shuf_i32x4_mask = 14238,
  CODE_FOR_avx512vl_shuf_f32x4_mask = 14239,
  CODE_FOR_avx512f_shuf_f32x4_mask = 14240,
  CODE_FOR_avx512f_shuf_i32x4_mask = 14241,
  CODE_FOR_avx512f_pshufdv3_mask = 14242,
  CODE_FOR_avx512vl_pshufdv3_mask = 14243,
  CODE_FOR_avx2_pshufdv3 = 14244,
  CODE_FOR_avx512vl_pshufd_mask = 14245,
  CODE_FOR_sse2_pshufd = 14246,
  CODE_FOR_avx512vl_pshuflwv3_mask = 14247,
  CODE_FOR_avx2_pshuflwv3 = 14248,
  CODE_FOR_avx512vl_pshuflw_mask = 14249,
  CODE_FOR_sse2_pshuflw = 14250,
  CODE_FOR_avx2_pshufhwv3 = 14251,
  CODE_FOR_avx512vl_pshufhwv3_mask = 14252,
  CODE_FOR_avx512vl_pshufhw_mask = 14253,
  CODE_FOR_sse2_pshufhw = 14254,
  CODE_FOR_sse2_loadd = 14255,
  CODE_FOR_vec_unpacks_lo_v64qi = 14256,
  CODE_FOR_vec_unpacks_lo_v32qi = 14257,
  CODE_FOR_vec_unpacks_lo_v16qi = 14258,
  CODE_FOR_vec_unpacks_lo_v32hi = 14259,
  CODE_FOR_vec_unpacks_lo_v16hi = 14260,
  CODE_FOR_vec_unpacks_lo_v8hi = 14261,
  CODE_FOR_vec_unpacks_lo_v16si = 14262,
  CODE_FOR_vec_unpacks_lo_v8si = 14263,
  CODE_FOR_vec_unpacks_lo_v4si = 14264,
  CODE_FOR_vec_unpacks_hi_v64qi = 14265,
  CODE_FOR_vec_unpacks_hi_v32qi = 14266,
  CODE_FOR_vec_unpacks_hi_v16qi = 14267,
  CODE_FOR_vec_unpacks_hi_v32hi = 14268,
  CODE_FOR_vec_unpacks_hi_v16hi = 14269,
  CODE_FOR_vec_unpacks_hi_v8hi = 14270,
  CODE_FOR_vec_unpacks_hi_v16si = 14271,
  CODE_FOR_vec_unpacks_hi_v8si = 14272,
  CODE_FOR_vec_unpacks_hi_v4si = 14273,
  CODE_FOR_vec_unpacku_lo_v64qi = 14274,
  CODE_FOR_vec_unpacku_lo_v32qi = 14275,
  CODE_FOR_vec_unpacku_lo_v16qi = 14276,
  CODE_FOR_vec_unpacku_lo_v32hi = 14277,
  CODE_FOR_vec_unpacku_lo_v16hi = 14278,
  CODE_FOR_vec_unpacku_lo_v8hi = 14279,
  CODE_FOR_vec_unpacku_lo_v16si = 14280,
  CODE_FOR_vec_unpacku_lo_v8si = 14281,
  CODE_FOR_vec_unpacku_lo_v4si = 14282,
  CODE_FOR_vec_unpacks_sbool_lo_qi = 14283,
  CODE_FOR_vec_unpacks_lo_hi = 14284,
  CODE_FOR_vec_unpacks_lo_si = 14285,
  CODE_FOR_vec_unpacks_lo_di = 14286,
  CODE_FOR_vec_unpacku_hi_v64qi = 14287,
  CODE_FOR_vec_unpacku_hi_v32qi = 14288,
  CODE_FOR_vec_unpacku_hi_v16qi = 14289,
  CODE_FOR_vec_unpacku_hi_v32hi = 14290,
  CODE_FOR_vec_unpacku_hi_v16hi = 14291,
  CODE_FOR_vec_unpacku_hi_v8hi = 14292,
  CODE_FOR_vec_unpacku_hi_v16si = 14293,
  CODE_FOR_vec_unpacku_hi_v8si = 14294,
  CODE_FOR_vec_unpacku_hi_v4si = 14295,
  CODE_FOR_vec_unpacks_sbool_hi_qi = 14296,
  CODE_FOR_vec_unpacks_hi_hi = 14297,
  CODE_FOR_vec_unpacks_hi_si = 14298,
  CODE_FOR_vec_unpacks_hi_di = 14299,
  CODE_FOR_avx512bw_uavgv64qi3 = 14300,
  CODE_FOR_avx512bw_uavgv64qi3_mask = 14301,
  CODE_FOR_avx2_uavgv32qi3 = 14302,
  CODE_FOR_avx2_uavgv32qi3_mask = 14303,
  CODE_FOR_sse2_uavgv16qi3 = 14304,
  CODE_FOR_sse2_uavgv16qi3_mask = 14305,
  CODE_FOR_avx512bw_uavgv32hi3 = 14306,
  CODE_FOR_avx512bw_uavgv32hi3_mask = 14307,
  CODE_FOR_avx2_uavgv16hi3 = 14308,
  CODE_FOR_avx2_uavgv16hi3_mask = 14309,
  CODE_FOR_sse2_uavgv8hi3 = 14310,
  CODE_FOR_sse2_uavgv8hi3_mask = 14311,
  CODE_FOR_avx512f_psadbw = 14312,
  CODE_FOR_avx2_psadbw = 14313,
  CODE_FOR_sse2_psadbw = 14314,
  CODE_FOR_sse2_maskmovdqu = 14315,
  CODE_FOR_ssse3_pmulhrswv8hi3_mask = 14316,
  CODE_FOR_avx2_pmulhrswv16hi3_mask = 14317,
  CODE_FOR_ssse3_pmulhrswv8hi3 = 14318,
  CODE_FOR_avx2_pmulhrswv16hi3 = 14319,
  CODE_FOR_smulhrsv32hi3 = 14320,
  CODE_FOR_smulhrsv16hi3 = 14321,
  CODE_FOR_smulhrsv8hi3 = 14322,
  CODE_FOR_smulhrsv4hi3 = 14323,
  CODE_FOR_ssse3_pmulhrswv4hi3 = 14324,
  CODE_FOR_smulhrsv2hi3 = 14325,
  CODE_FOR_ssse3_pshufbv8qi3 = 14326,
  CODE_FOR_absv64qi2 = 14327,
  CODE_FOR_absv32qi2 = 14328,
  CODE_FOR_absv16qi2 = 14329,
  CODE_FOR_absv32hi2 = 14330,
  CODE_FOR_absv16hi2 = 14331,
  CODE_FOR_absv8hi2 = 14332,
  CODE_FOR_absv16si2 = 14333,
  CODE_FOR_absv8si2 = 14334,
  CODE_FOR_absv4si2 = 14335,
  CODE_FOR_absv8di2 = 14336,
  CODE_FOR_absv4di2 = 14337,
  CODE_FOR_absv2di2 = 14338,
  CODE_FOR_avx2_pblendw = 14339,
  CODE_FOR_avx2_pblendph = 14340,
  CODE_FOR_avx2_pblendbf = 14341,
  CODE_FOR_avx2_pblendw_1 = 14342,
  CODE_FOR_avx2_pblendph_1 = 14343,
  CODE_FOR_avx2_pblendbf_1 = 14344,
  CODE_FOR_extendv16qiv16hi2 = 14345,
  CODE_FOR_zero_extendv16qiv16hi2 = 14346,
  CODE_FOR_extendv32qiv32hi2 = 14347,
  CODE_FOR_zero_extendv32qiv32hi2 = 14348,
  CODE_FOR_extendv8qiv8hi2 = 14349,
  CODE_FOR_zero_extendv8qiv8hi2 = 14350,
  CODE_FOR_extendv16qiv16si2 = 14351,
  CODE_FOR_zero_extendv16qiv16si2 = 14352,
  CODE_FOR_extendv8qiv8si2 = 14353,
  CODE_FOR_zero_extendv8qiv8si2 = 14354,
  CODE_FOR_extendv4qiv4si2 = 14355,
  CODE_FOR_zero_extendv4qiv4si2 = 14356,
  CODE_FOR_extendv16hiv16si2 = 14357,
  CODE_FOR_zero_extendv16hiv16si2 = 14358,
  CODE_FOR_extendv8hiv8si2 = 14359,
  CODE_FOR_zero_extendv8hiv8si2 = 14360,
  CODE_FOR_extendv4hiv4si2 = 14361,
  CODE_FOR_zero_extendv4hiv4si2 = 14362,
  CODE_FOR_extendv8qiv8di2 = 14363,
  CODE_FOR_zero_extendv8qiv8di2 = 14364,
  CODE_FOR_extendv4qiv4di2 = 14365,
  CODE_FOR_zero_extendv4qiv4di2 = 14366,
  CODE_FOR_extendv2qiv2di2 = 14367,
  CODE_FOR_zero_extendv2qiv2di2 = 14368,
  CODE_FOR_extendv8hiv8di2 = 14369,
  CODE_FOR_zero_extendv8hiv8di2 = 14370,
  CODE_FOR_extendv4hiv4di2 = 14371,
  CODE_FOR_zero_extendv4hiv4di2 = 14372,
  CODE_FOR_extendv2hiv2di2 = 14373,
  CODE_FOR_zero_extendv2hiv2di2 = 14374,
  CODE_FOR_extendv8siv8di2 = 14375,
  CODE_FOR_zero_extendv8siv8di2 = 14376,
  CODE_FOR_extendv4siv4di2 = 14377,
  CODE_FOR_zero_extendv4siv4di2 = 14378,
  CODE_FOR_extendv2siv2di2 = 14379,
  CODE_FOR_zero_extendv2siv2di2 = 14380,
  CODE_FOR_sse4_1_ptestzv16qi = 14381,
  CODE_FOR_sse4_1_ptestzv8hi = 14382,
  CODE_FOR_sse4_1_ptestzv4si = 14383,
  CODE_FOR_sse4_1_ptestzv2di = 14384,
  CODE_FOR_sse4_1_ptestzv1ti = 14385,
  CODE_FOR_sse4_1_ptestzv4sf = 14386,
  CODE_FOR_sse4_1_ptestzv2df = 14387,
  CODE_FOR_avx_ptestzv32qi = 14388,
  CODE_FOR_avx_ptestzv16hi = 14389,
  CODE_FOR_avx_ptestzv8si = 14390,
  CODE_FOR_avx_ptestzv4di = 14391,
  CODE_FOR_avx_ptestzv2ti = 14392,
  CODE_FOR_avx_ptestzv8sf = 14393,
  CODE_FOR_avx_ptestzv4df = 14394,
  CODE_FOR_sse4_1_ptestcv16qi = 14395,
  CODE_FOR_sse4_1_ptestcv8hi = 14396,
  CODE_FOR_sse4_1_ptestcv4si = 14397,
  CODE_FOR_sse4_1_ptestcv2di = 14398,
  CODE_FOR_sse4_1_ptestcv1ti = 14399,
  CODE_FOR_sse4_1_ptestcv4sf = 14400,
  CODE_FOR_sse4_1_ptestcv2df = 14401,
  CODE_FOR_avx_ptestcv32qi = 14402,
  CODE_FOR_avx_ptestcv16hi = 14403,
  CODE_FOR_avx_ptestcv8si = 14404,
  CODE_FOR_avx_ptestcv4di = 14405,
  CODE_FOR_avx_ptestcv2ti = 14406,
  CODE_FOR_avx_ptestcv8sf = 14407,
  CODE_FOR_avx_ptestcv4df = 14408,
  CODE_FOR_sse4_1_ptestv16qi = 14409,
  CODE_FOR_sse4_1_ptestv8hi = 14410,
  CODE_FOR_sse4_1_ptestv4si = 14411,
  CODE_FOR_sse4_1_ptestv2di = 14412,
  CODE_FOR_sse4_1_ptestv1ti = 14413,
  CODE_FOR_sse4_1_ptestv4sf = 14414,
  CODE_FOR_sse4_1_ptestv2df = 14415,
  CODE_FOR_avx_ptestv32qi = 14416,
  CODE_FOR_avx_ptestv16hi = 14417,
  CODE_FOR_avx_ptestv8si = 14418,
  CODE_FOR_avx_ptestv4di = 14419,
  CODE_FOR_avx_ptestv2ti = 14420,
  CODE_FOR_avx_ptestv8sf = 14421,
  CODE_FOR_avx_ptestv4df = 14422,
  CODE_FOR_nearbyintv32hf2 = 14423,
  CODE_FOR_nearbyintv16hf2 = 14424,
  CODE_FOR_nearbyintv8hf2 = 14425,
  CODE_FOR_nearbyintv16sf2 = 14426,
  CODE_FOR_nearbyintv8sf2 = 14427,
  CODE_FOR_nearbyintv4sf2 = 14428,
  CODE_FOR_nearbyintv8df2 = 14429,
  CODE_FOR_nearbyintv4df2 = 14430,
  CODE_FOR_nearbyintv2df2 = 14431,
  CODE_FOR_rintv32hf2 = 14432,
  CODE_FOR_rintv16hf2 = 14433,
  CODE_FOR_rintv8hf2 = 14434,
  CODE_FOR_rintv16sf2 = 14435,
  CODE_FOR_rintv8sf2 = 14436,
  CODE_FOR_rintv4sf2 = 14437,
  CODE_FOR_rintv8df2 = 14438,
  CODE_FOR_rintv4df2 = 14439,
  CODE_FOR_rintv2df2 = 14440,
  CODE_FOR_lrintv16sfv16si2 = 14441,
  CODE_FOR_lrintv8sfv8si2 = 14442,
  CODE_FOR_lrintv4sfv4si2 = 14443,
  CODE_FOR_lrintv8dfv8di2 = 14444,
  CODE_FOR_lrintv4dfv4di2 = 14445,
  CODE_FOR_lrintv2dfv2di2 = 14446,
  CODE_FOR_avx_roundps_sfix256 = 14447,
  CODE_FOR_sse4_1_roundps_sfix = 14448,
  CODE_FOR_avx512f_roundps512 = 14449,
  CODE_FOR_avx512f_roundpd512 = 14450,
  CODE_FOR_avx512f_roundps512_sfix = 14451,
  CODE_FOR_avx512f_roundpd_vec_pack_sfix512 = 14452,
  CODE_FOR_avx_roundpd_vec_pack_sfix256 = 14453,
  CODE_FOR_sse4_1_roundpd_vec_pack_sfix = 14454,
  CODE_FOR_floorv32hf2 = 14455,
  CODE_FOR_floorv16hf2 = 14456,
  CODE_FOR_floorv8hf2 = 14457,
  CODE_FOR_floorv16sf2 = 14458,
  CODE_FOR_floorv8sf2 = 14459,
  CODE_FOR_floorv4sf2 = 14460,
  CODE_FOR_floorv8df2 = 14461,
  CODE_FOR_floorv4df2 = 14462,
  CODE_FOR_floorv2df2 = 14463,
  CODE_FOR_lfloorv32hfv32hi2 = 14464,
  CODE_FOR_lfloorv16hfv16hi2 = 14465,
  CODE_FOR_lfloorv8hfv8hi2 = 14466,
  CODE_FOR_lfloorv16sfv16si2 = 14467,
  CODE_FOR_lfloorv8sfv8si2 = 14468,
  CODE_FOR_lfloorv4sfv4si2 = 14469,
  CODE_FOR_lfloorv8dfv8di2 = 14470,
  CODE_FOR_lfloorv4dfv4di2 = 14471,
  CODE_FOR_lfloorv2dfv2di2 = 14472,
  CODE_FOR_ceilv32hf2 = 14473,
  CODE_FOR_ceilv16hf2 = 14474,
  CODE_FOR_ceilv8hf2 = 14475,
  CODE_FOR_ceilv16sf2 = 14476,
  CODE_FOR_ceilv8sf2 = 14477,
  CODE_FOR_ceilv4sf2 = 14478,
  CODE_FOR_ceilv8df2 = 14479,
  CODE_FOR_ceilv4df2 = 14480,
  CODE_FOR_ceilv2df2 = 14481,
  CODE_FOR_lceilv32hfv32hi2 = 14482,
  CODE_FOR_lceilv16hfv16hi2 = 14483,
  CODE_FOR_lceilv8hfv8hi2 = 14484,
  CODE_FOR_lceilv16sfv16si2 = 14485,
  CODE_FOR_lceilv8sfv8si2 = 14486,
  CODE_FOR_lceilv4sfv4si2 = 14487,
  CODE_FOR_lceilv8dfv8di2 = 14488,
  CODE_FOR_lceilv4dfv4di2 = 14489,
  CODE_FOR_lceilv2dfv2di2 = 14490,
  CODE_FOR_btruncv32hf2 = 14491,
  CODE_FOR_btruncv16hf2 = 14492,
  CODE_FOR_btruncv8hf2 = 14493,
  CODE_FOR_btruncv16sf2 = 14494,
  CODE_FOR_btruncv8sf2 = 14495,
  CODE_FOR_btruncv4sf2 = 14496,
  CODE_FOR_btruncv8df2 = 14497,
  CODE_FOR_btruncv4df2 = 14498,
  CODE_FOR_btruncv2df2 = 14499,
  CODE_FOR_roundv32hf2 = 14500,
  CODE_FOR_roundv16hf2 = 14501,
  CODE_FOR_roundv8hf2 = 14502,
  CODE_FOR_roundv16sf2 = 14503,
  CODE_FOR_roundv8sf2 = 14504,
  CODE_FOR_roundv4sf2 = 14505,
  CODE_FOR_roundv8df2 = 14506,
  CODE_FOR_roundv4df2 = 14507,
  CODE_FOR_roundv2df2 = 14508,
  CODE_FOR_lroundv32hfv32hi2 = 14509,
  CODE_FOR_lroundv16hfv16hi2 = 14510,
  CODE_FOR_lroundv8hfv8hi2 = 14511,
  CODE_FOR_lroundv16sfv16si2 = 14512,
  CODE_FOR_lroundv8sfv8si2 = 14513,
  CODE_FOR_lroundv4sfv4si2 = 14514,
  CODE_FOR_lroundv8dfv8di2 = 14515,
  CODE_FOR_lroundv4dfv4di2 = 14516,
  CODE_FOR_lroundv2dfv2di2 = 14517,
  CODE_FOR_roundv16sf2_sfix = 14518,
  CODE_FOR_roundv8sf2_sfix = 14519,
  CODE_FOR_roundv4sf2_sfix = 14520,
  CODE_FOR_roundv8df2_vec_pack_sfix = 14521,
  CODE_FOR_roundv4df2_vec_pack_sfix = 14522,
  CODE_FOR_roundv2df2_vec_pack_sfix = 14523,
  CODE_FOR_rotlv8hi3 = 14524,
  CODE_FOR_rotlv4si3 = 14525,
  CODE_FOR_rotlv2di3 = 14526,
  CODE_FOR_rotrv8hi3 = 14527,
  CODE_FOR_rotrv4si3 = 14528,
  CODE_FOR_rotrv2di3 = 14529,
  CODE_FOR_vrotrv16qi3 = 14530,
  CODE_FOR_vrotrv8hi3 = 14531,
  CODE_FOR_vrotrv4si3 = 14532,
  CODE_FOR_vrotrv2di3 = 14533,
  CODE_FOR_vrotlv16qi3 = 14534,
  CODE_FOR_vrotlv8hi3 = 14535,
  CODE_FOR_vrotlv4si3 = 14536,
  CODE_FOR_vrotlv2di3 = 14537,
  CODE_FOR_vlshrv16qi3 = 14538,
  CODE_FOR_vlshrv8hi3 = 14539,
  CODE_FOR_vlshrv4si3 = 14540,
  CODE_FOR_vlshrv2di3 = 14541,
  CODE_FOR_vashlv64qi3 = 14542,
  CODE_FOR_vlshrv64qi3 = 14543,
  CODE_FOR_vashrv64qi3 = 14544,
  CODE_FOR_vashlv32qi3 = 14545,
  CODE_FOR_vlshrv32qi3 = 14546,
  CODE_FOR_vashrv32qi3 = 14547,
  CODE_FOR_vashlv32hi3 = 14548,
  CODE_FOR_vlshrv32hi3 = 14549,
  CODE_FOR_vashrv32hi3 = 14550,
  CODE_FOR_vashlv16hi3 = 14551,
  CODE_FOR_vlshrv16hi3 = 14552,
  CODE_FOR_vashrv16hi3 = 14553,
  CODE_FOR_vlshrv16si3 = 14554,
  CODE_FOR_vlshrv8di3 = 14555,
  CODE_FOR_vlshrv8si3 = 14556,
  CODE_FOR_vlshrv4di3 = 14557,
  CODE_FOR_vashrv8di3 = 14558,
  CODE_FOR_vashrv4di3 = 14559,
  CODE_FOR_vashrv16qi3 = 14560,
  CODE_FOR_vashrv8hi3 = 14561,
  CODE_FOR_vashrv2di3 = 14562,
  CODE_FOR_vashrv4si3 = 14563,
  CODE_FOR_vashrv16si3 = 14564,
  CODE_FOR_vashrv8si3 = 14565,
  CODE_FOR_vashlv16qi3 = 14566,
  CODE_FOR_vashlv8hi3 = 14567,
  CODE_FOR_vashlv4si3 = 14568,
  CODE_FOR_vashlv2di3 = 14569,
  CODE_FOR_vashlv16si3 = 14570,
  CODE_FOR_vashlv8di3 = 14571,
  CODE_FOR_vashlv8si3 = 14572,
  CODE_FOR_vashlv4di3 = 14573,
  CODE_FOR_ashlv64qi3 = 14574,
  CODE_FOR_lshrv64qi3 = 14575,
  CODE_FOR_ashrv64qi3 = 14576,
  CODE_FOR_ashlv32qi3 = 14577,
  CODE_FOR_lshrv32qi3 = 14578,
  CODE_FOR_ashrv32qi3 = 14579,
  CODE_FOR_ashlv16qi3 = 14580,
  CODE_FOR_lshrv16qi3 = 14581,
  CODE_FOR_ashrv16qi3 = 14582,
  CODE_FOR_rotlv64qi3 = 14583,
  CODE_FOR_rotrv64qi3 = 14584,
  CODE_FOR_rotlv32qi3 = 14585,
  CODE_FOR_rotrv32qi3 = 14586,
  CODE_FOR_rotlv16qi3 = 14587,
  CODE_FOR_rotrv16qi3 = 14588,
  CODE_FOR_ashrv2di3 = 14589,
  CODE_FOR_xop_vmfrczv4sf2 = 14590,
  CODE_FOR_xop_vmfrczv2df2 = 14591,
  CODE_FOR_avx_vzeroall = 14592,
  CODE_FOR_avx_vzeroupper = 14593,
  CODE_FOR_avx512f_vpermilv8df = 14594,
  CODE_FOR_avx512f_vpermilv8df_mask = 14595,
  CODE_FOR_avx_vpermilv4df = 14596,
  CODE_FOR_avx_vpermilv4df_mask = 14597,
  CODE_FOR_avx_vpermilv2df = 14598,
  CODE_FOR_avx_vpermilv2df_mask = 14599,
  CODE_FOR_avx512f_vpermilv16sf = 14600,
  CODE_FOR_avx512f_vpermilv16sf_mask = 14601,
  CODE_FOR_avx_vpermilv8sf = 14602,
  CODE_FOR_avx_vpermilv8sf_mask = 14603,
  CODE_FOR_avx_vpermilv4sf = 14604,
  CODE_FOR_avx_vpermilv4sf_mask = 14605,
  CODE_FOR_avx2_permv4di = 14606,
  CODE_FOR_avx2_permv4df = 14607,
  CODE_FOR_avx512vl_permv4di_mask = 14608,
  CODE_FOR_avx512vl_permv4df_mask = 14609,
  CODE_FOR_avx512f_permv8df = 14610,
  CODE_FOR_avx512f_permv8di = 14611,
  CODE_FOR_avx512f_permv8df_mask = 14612,
  CODE_FOR_avx512f_permv8di_mask = 14613,
  CODE_FOR_avx512f_vpermi2varv16si3_mask = 14614,
  CODE_FOR_avx512f_vpermi2varv16sf3_mask = 14615,
  CODE_FOR_avx512f_vpermi2varv8di3_mask = 14616,
  CODE_FOR_avx512f_vpermi2varv8df3_mask = 14617,
  CODE_FOR_avx512vl_vpermi2varv8si3_mask = 14618,
  CODE_FOR_avx512vl_vpermi2varv8sf3_mask = 14619,
  CODE_FOR_avx512vl_vpermi2varv4di3_mask = 14620,
  CODE_FOR_avx512vl_vpermi2varv4df3_mask = 14621,
  CODE_FOR_avx512vl_vpermi2varv4si3_mask = 14622,
  CODE_FOR_avx512vl_vpermi2varv4sf3_mask = 14623,
  CODE_FOR_avx512vl_vpermi2varv2di3_mask = 14624,
  CODE_FOR_avx512vl_vpermi2varv2df3_mask = 14625,
  CODE_FOR_avx512bw_vpermi2varv32hi3_mask = 14626,
  CODE_FOR_avx512vl_vpermi2varv16hi3_mask = 14627,
  CODE_FOR_avx512vl_vpermi2varv8hi3_mask = 14628,
  CODE_FOR_avx512bw_vpermi2varv64qi3_mask = 14629,
  CODE_FOR_avx512vl_vpermi2varv32qi3_mask = 14630,
  CODE_FOR_avx512vl_vpermi2varv16qi3_mask = 14631,
  CODE_FOR_avx512f_vpermt2varv16si3_maskz = 14632,
  CODE_FOR_avx512f_vpermt2varv16sf3_maskz = 14633,
  CODE_FOR_avx512f_vpermt2varv8di3_maskz = 14634,
  CODE_FOR_avx512f_vpermt2varv8df3_maskz = 14635,
  CODE_FOR_avx512vl_vpermt2varv8si3_maskz = 14636,
  CODE_FOR_avx512vl_vpermt2varv8sf3_maskz = 14637,
  CODE_FOR_avx512vl_vpermt2varv4di3_maskz = 14638,
  CODE_FOR_avx512vl_vpermt2varv4df3_maskz = 14639,
  CODE_FOR_avx512vl_vpermt2varv4si3_maskz = 14640,
  CODE_FOR_avx512vl_vpermt2varv4sf3_maskz = 14641,
  CODE_FOR_avx512vl_vpermt2varv2di3_maskz = 14642,
  CODE_FOR_avx512vl_vpermt2varv2df3_maskz = 14643,
  CODE_FOR_avx512bw_vpermt2varv32hi3_maskz = 14644,
  CODE_FOR_avx512vl_vpermt2varv16hi3_maskz = 14645,
  CODE_FOR_avx512vl_vpermt2varv8hi3_maskz = 14646,
  CODE_FOR_avx512bw_vpermt2varv64qi3_maskz = 14647,
  CODE_FOR_avx512vl_vpermt2varv32qi3_maskz = 14648,
  CODE_FOR_avx512vl_vpermt2varv16qi3_maskz = 14649,
  CODE_FOR_avx_vperm2f128v8si3 = 14650,
  CODE_FOR_avx_vperm2f128v8sf3 = 14651,
  CODE_FOR_avx_vperm2f128v4df3 = 14652,
  CODE_FOR_avx512vl_vinsertv8si = 14653,
  CODE_FOR_avx512vl_vinsertv8sf = 14654,
  CODE_FOR_avx512vl_vinsertv4di = 14655,
  CODE_FOR_avx512vl_vinsertv4df = 14656,
  CODE_FOR_avx_vinsertf128v32qi = 14657,
  CODE_FOR_avx_vinsertf128v16hi = 14658,
  CODE_FOR_avx_vinsertf128v8si = 14659,
  CODE_FOR_avx_vinsertf128v4di = 14660,
  CODE_FOR_avx_vinsertf128v8sf = 14661,
  CODE_FOR_avx_vinsertf128v4df = 14662,
  CODE_FOR_avx_vinsertf128v16hf = 14663,
  CODE_FOR_avx_vinsertf128v16bf = 14664,
  CODE_FOR_maskloadv4sfv4si_1 = 14665,
  CODE_FOR_maskloadv2dfv2di_1 = 14666,
  CODE_FOR_maskloadv4div4di_1 = 14667,
  CODE_FOR_maskloadv2div2di_1 = 14668,
  CODE_FOR_maskloadv8sfv8si_1 = 14669,
  CODE_FOR_maskloadv4dfv4di_1 = 14670,
  CODE_FOR_maskloadv8siv8si_1 = 14671,
  CODE_FOR_maskloadv4siv4si_1 = 14672,
  CODE_FOR_maskloadv4sfv4si = 14673,
  CODE_FOR_maskloadv2dfv2di = 14674,
  CODE_FOR_maskloadv4div4di = 14675,
  CODE_FOR_maskloadv2div2di = 14676,
  CODE_FOR_maskloadv8sfv8si = 14677,
  CODE_FOR_maskloadv4dfv4di = 14678,
  CODE_FOR_maskloadv8siv8si = 14679,
  CODE_FOR_maskloadv4siv4si = 14680,
  CODE_FOR_maskloadv16sihi = 14681,
  CODE_FOR_maskloadv8siqi = 14682,
  CODE_FOR_maskloadv4siqi = 14683,
  CODE_FOR_maskloadv8diqi = 14684,
  CODE_FOR_maskloadv4diqi = 14685,
  CODE_FOR_maskloadv2diqi = 14686,
  CODE_FOR_maskloadv16sfhi = 14687,
  CODE_FOR_maskloadv8sfqi = 14688,
  CODE_FOR_maskloadv4sfqi = 14689,
  CODE_FOR_maskloadv8dfqi = 14690,
  CODE_FOR_maskloadv4dfqi = 14691,
  CODE_FOR_maskloadv2dfqi = 14692,
  CODE_FOR_maskloadv64qidi = 14693,
  CODE_FOR_maskloadv16qihi = 14694,
  CODE_FOR_maskloadv32qisi = 14695,
  CODE_FOR_maskloadv32hisi = 14696,
  CODE_FOR_maskloadv16hihi = 14697,
  CODE_FOR_maskloadv8hiqi = 14698,
  CODE_FOR_maskloadv32hfsi = 14699,
  CODE_FOR_maskloadv16hfhi = 14700,
  CODE_FOR_maskloadv8hfqi = 14701,
  CODE_FOR_maskloadv32bfsi = 14702,
  CODE_FOR_maskloadv16bfhi = 14703,
  CODE_FOR_maskloadv8bfqi = 14704,
  CODE_FOR_maskstorev4sfv4si = 14705,
  CODE_FOR_maskstorev2dfv2di = 14706,
  CODE_FOR_maskstorev4div4di = 14707,
  CODE_FOR_maskstorev2div2di = 14708,
  CODE_FOR_maskstorev8sfv8si = 14709,
  CODE_FOR_maskstorev4dfv4di = 14710,
  CODE_FOR_maskstorev8siv8si = 14711,
  CODE_FOR_maskstorev4siv4si = 14712,
  CODE_FOR_maskstorev16sihi = 14713,
  CODE_FOR_maskstorev8siqi = 14714,
  CODE_FOR_maskstorev4siqi = 14715,
  CODE_FOR_maskstorev8diqi = 14716,
  CODE_FOR_maskstorev4diqi = 14717,
  CODE_FOR_maskstorev2diqi = 14718,
  CODE_FOR_maskstorev16sfhi = 14719,
  CODE_FOR_maskstorev8sfqi = 14720,
  CODE_FOR_maskstorev4sfqi = 14721,
  CODE_FOR_maskstorev8dfqi = 14722,
  CODE_FOR_maskstorev4dfqi = 14723,
  CODE_FOR_maskstorev2dfqi = 14724,
  CODE_FOR_maskstorev64qidi = 14725,
  CODE_FOR_maskstorev16qihi = 14726,
  CODE_FOR_maskstorev32qisi = 14727,
  CODE_FOR_maskstorev32hisi = 14728,
  CODE_FOR_maskstorev16hihi = 14729,
  CODE_FOR_maskstorev8hiqi = 14730,
  CODE_FOR_maskstorev32hfsi = 14731,
  CODE_FOR_maskstorev16hfhi = 14732,
  CODE_FOR_maskstorev8hfqi = 14733,
  CODE_FOR_maskstorev32bfsi = 14734,
  CODE_FOR_maskstorev16bfhi = 14735,
  CODE_FOR_maskstorev8bfqi = 14736,
  CODE_FOR_cbranchv64qi4 = 14737,
  CODE_FOR_cbranchv32qi4 = 14738,
  CODE_FOR_cbranchv16qi4 = 14739,
  CODE_FOR_cbranchv32hi4 = 14740,
  CODE_FOR_cbranchv16hi4 = 14741,
  CODE_FOR_cbranchv8hi4 = 14742,
  CODE_FOR_cbranchv16si4 = 14743,
  CODE_FOR_cbranchv8si4 = 14744,
  CODE_FOR_cbranchv4si4 = 14745,
  CODE_FOR_cbranchv8di4 = 14746,
  CODE_FOR_cbranchv4di4 = 14747,
  CODE_FOR_cbranchv2di4 = 14748,
  CODE_FOR_vec_initv64qiqi = 14749,
  CODE_FOR_vec_initv32qiqi = 14750,
  CODE_FOR_vec_initv16qiqi = 14751,
  CODE_FOR_vec_initv32hihi = 14752,
  CODE_FOR_vec_initv16hihi = 14753,
  CODE_FOR_vec_initv8hihi = 14754,
  CODE_FOR_vec_initv16sisi = 14755,
  CODE_FOR_vec_initv8sisi = 14756,
  CODE_FOR_vec_initv4sisi = 14757,
  CODE_FOR_vec_initv8didi = 14758,
  CODE_FOR_vec_initv4didi = 14759,
  CODE_FOR_vec_initv2didi = 14760,
  CODE_FOR_vec_initv32hfhf = 14761,
  CODE_FOR_vec_initv16hfhf = 14762,
  CODE_FOR_vec_initv8hfhf = 14763,
  CODE_FOR_vec_initv32bfbf = 14764,
  CODE_FOR_vec_initv16bfbf = 14765,
  CODE_FOR_vec_initv8bfbf = 14766,
  CODE_FOR_vec_initv16sfsf = 14767,
  CODE_FOR_vec_initv8sfsf = 14768,
  CODE_FOR_vec_initv4sfsf = 14769,
  CODE_FOR_vec_initv8dfdf = 14770,
  CODE_FOR_vec_initv4dfdf = 14771,
  CODE_FOR_vec_initv2dfdf = 14772,
  CODE_FOR_vec_initv4titi = 14773,
  CODE_FOR_vec_initv2titi = 14774,
  CODE_FOR_vec_initv64qiv32qi = 14775,
  CODE_FOR_vec_initv32qiv16qi = 14776,
  CODE_FOR_vec_initv16qiv8qi = 14777,
  CODE_FOR_vec_initv32hiv16hi = 14778,
  CODE_FOR_vec_initv16hiv8hi = 14779,
  CODE_FOR_vec_initv8hiv4hi = 14780,
  CODE_FOR_vec_initv16siv8si = 14781,
  CODE_FOR_vec_initv8siv4si = 14782,
  CODE_FOR_vec_initv4siv2si = 14783,
  CODE_FOR_vec_initv8div4di = 14784,
  CODE_FOR_vec_initv4div2di = 14785,
  CODE_FOR_vec_initv32hfv16hf = 14786,
  CODE_FOR_vec_initv16hfv8hf = 14787,
  CODE_FOR_vec_initv8hfv4hf = 14788,
  CODE_FOR_vec_initv32bfv16bf = 14789,
  CODE_FOR_vec_initv16bfv8bf = 14790,
  CODE_FOR_vec_initv8bfv4bf = 14791,
  CODE_FOR_vec_initv16sfv8sf = 14792,
  CODE_FOR_vec_initv8sfv4sf = 14793,
  CODE_FOR_vec_initv4sfv2sf = 14794,
  CODE_FOR_vec_initv8dfv4df = 14795,
  CODE_FOR_vec_initv4dfv2df = 14796,
  CODE_FOR_vec_initv4tiv2ti = 14797,
  CODE_FOR_cond_ashlv32hi = 14798,
  CODE_FOR_cond_lshrv32hi = 14799,
  CODE_FOR_cond_ashrv32hi = 14800,
  CODE_FOR_cond_ashlv16hi = 14801,
  CODE_FOR_cond_lshrv16hi = 14802,
  CODE_FOR_cond_ashrv16hi = 14803,
  CODE_FOR_cond_ashlv8hi = 14804,
  CODE_FOR_cond_lshrv8hi = 14805,
  CODE_FOR_cond_ashrv8hi = 14806,
  CODE_FOR_cond_ashlv16si = 14807,
  CODE_FOR_cond_lshrv16si = 14808,
  CODE_FOR_cond_ashrv16si = 14809,
  CODE_FOR_cond_ashlv8si = 14810,
  CODE_FOR_cond_lshrv8si = 14811,
  CODE_FOR_cond_ashrv8si = 14812,
  CODE_FOR_cond_ashlv4si = 14813,
  CODE_FOR_cond_lshrv4si = 14814,
  CODE_FOR_cond_ashrv4si = 14815,
  CODE_FOR_cond_ashlv8di = 14816,
  CODE_FOR_cond_lshrv8di = 14817,
  CODE_FOR_cond_ashrv8di = 14818,
  CODE_FOR_cond_ashlv4di = 14819,
  CODE_FOR_cond_lshrv4di = 14820,
  CODE_FOR_cond_ashrv4di = 14821,
  CODE_FOR_cond_ashlv2di = 14822,
  CODE_FOR_cond_lshrv2di = 14823,
  CODE_FOR_cond_ashrv2di = 14824,
  CODE_FOR_vcvtps2ph_mask = 14825,
  CODE_FOR_vcvtps2ph = 14826,
  CODE_FOR_avx512f_vcvtps2ph512_mask_sae = 14827,
  CODE_FOR_avx2_gathersiv2di = 14828,
  CODE_FOR_avx2_gathersiv2df = 14829,
  CODE_FOR_avx2_gathersiv4di = 14830,
  CODE_FOR_avx2_gathersiv4df = 14831,
  CODE_FOR_avx2_gathersiv4si = 14832,
  CODE_FOR_avx2_gathersiv4sf = 14833,
  CODE_FOR_avx2_gathersiv8si = 14834,
  CODE_FOR_avx2_gathersiv8sf = 14835,
  CODE_FOR_avx2_gatherdiv2di = 14836,
  CODE_FOR_avx2_gatherdiv2df = 14837,
  CODE_FOR_avx2_gatherdiv4di = 14838,
  CODE_FOR_avx2_gatherdiv4df = 14839,
  CODE_FOR_avx2_gatherdiv4si = 14840,
  CODE_FOR_avx2_gatherdiv4sf = 14841,
  CODE_FOR_avx2_gatherdiv8si = 14842,
  CODE_FOR_avx2_gatherdiv8sf = 14843,
  CODE_FOR_avx512f_gathersiv16si = 14844,
  CODE_FOR_avx512f_gathersiv16sf = 14845,
  CODE_FOR_avx512f_gathersiv8di = 14846,
  CODE_FOR_avx512f_gathersiv8df = 14847,
  CODE_FOR_avx512vl_gathersiv8si = 14848,
  CODE_FOR_avx512vl_gathersiv8sf = 14849,
  CODE_FOR_avx512vl_gathersiv4di = 14850,
  CODE_FOR_avx512vl_gathersiv4df = 14851,
  CODE_FOR_avx512vl_gathersiv4si = 14852,
  CODE_FOR_avx512vl_gathersiv4sf = 14853,
  CODE_FOR_avx512vl_gathersiv2di = 14854,
  CODE_FOR_avx512vl_gathersiv2df = 14855,
  CODE_FOR_avx512f_gatherdiv16si = 14856,
  CODE_FOR_avx512f_gatherdiv16sf = 14857,
  CODE_FOR_avx512f_gatherdiv8di = 14858,
  CODE_FOR_avx512f_gatherdiv8df = 14859,
  CODE_FOR_avx512vl_gatherdiv8si = 14860,
  CODE_FOR_avx512vl_gatherdiv8sf = 14861,
  CODE_FOR_avx512vl_gatherdiv4di = 14862,
  CODE_FOR_avx512vl_gatherdiv4df = 14863,
  CODE_FOR_avx512vl_gatherdiv4si = 14864,
  CODE_FOR_avx512vl_gatherdiv4sf = 14865,
  CODE_FOR_avx512vl_gatherdiv2di = 14866,
  CODE_FOR_avx512vl_gatherdiv2df = 14867,
  CODE_FOR_avx512f_scattersiv16si = 14868,
  CODE_FOR_avx512f_scattersiv16sf = 14869,
  CODE_FOR_avx512f_scattersiv8di = 14870,
  CODE_FOR_avx512f_scattersiv8df = 14871,
  CODE_FOR_avx512vl_scattersiv8si = 14872,
  CODE_FOR_avx512vl_scattersiv8sf = 14873,
  CODE_FOR_avx512vl_scattersiv4di = 14874,
  CODE_FOR_avx512vl_scattersiv4df = 14875,
  CODE_FOR_avx512vl_scattersiv4si = 14876,
  CODE_FOR_avx512vl_scattersiv4sf = 14877,
  CODE_FOR_avx512vl_scattersiv2di = 14878,
  CODE_FOR_avx512vl_scattersiv2df = 14879,
  CODE_FOR_avx512f_scatterdiv16si = 14880,
  CODE_FOR_avx512f_scatterdiv16sf = 14881,
  CODE_FOR_avx512f_scatterdiv8di = 14882,
  CODE_FOR_avx512f_scatterdiv8df = 14883,
  CODE_FOR_avx512vl_scatterdiv8si = 14884,
  CODE_FOR_avx512vl_scatterdiv8sf = 14885,
  CODE_FOR_avx512vl_scatterdiv4di = 14886,
  CODE_FOR_avx512vl_scatterdiv4df = 14887,
  CODE_FOR_avx512vl_scatterdiv4si = 14888,
  CODE_FOR_avx512vl_scatterdiv4sf = 14889,
  CODE_FOR_avx512vl_scatterdiv2di = 14890,
  CODE_FOR_avx512vl_scatterdiv2df = 14891,
  CODE_FOR_avx512f_expandv16si_maskz = 14892,
  CODE_FOR_avx512f_expandv16sf_maskz = 14893,
  CODE_FOR_avx512f_expandv8di_maskz = 14894,
  CODE_FOR_avx512f_expandv8df_maskz = 14895,
  CODE_FOR_avx512vl_expandv8si_maskz = 14896,
  CODE_FOR_avx512vl_expandv8sf_maskz = 14897,
  CODE_FOR_avx512vl_expandv4di_maskz = 14898,
  CODE_FOR_avx512vl_expandv4df_maskz = 14899,
  CODE_FOR_avx512vl_expandv4si_maskz = 14900,
  CODE_FOR_avx512vl_expandv4sf_maskz = 14901,
  CODE_FOR_avx512vl_expandv2di_maskz = 14902,
  CODE_FOR_avx512vl_expandv2df_maskz = 14903,
  CODE_FOR_expandv64qi_maskz = 14904,
  CODE_FOR_expandv16qi_maskz = 14905,
  CODE_FOR_expandv32qi_maskz = 14906,
  CODE_FOR_expandv32hi_maskz = 14907,
  CODE_FOR_expandv16hi_maskz = 14908,
  CODE_FOR_expandv8hi_maskz = 14909,
  CODE_FOR_vpmadd52huqv8di_maskz = 14910,
  CODE_FOR_vpmadd52huqv4di_maskz = 14911,
  CODE_FOR_vpmadd52huqv2di_maskz = 14912,
  CODE_FOR_vpmadd52luqv8di_maskz = 14913,
  CODE_FOR_vpmadd52luqv4di_maskz = 14914,
  CODE_FOR_vpmadd52luqv2di_maskz = 14915,
  CODE_FOR_popcountv16si2 = 14916,
  CODE_FOR_popcountv8si2 = 14917,
  CODE_FOR_popcountv4si2 = 14918,
  CODE_FOR_popcountv8di2 = 14919,
  CODE_FOR_popcountv4di2 = 14920,
  CODE_FOR_popcountv2di2 = 14921,
  CODE_FOR_popcountv64qi2 = 14922,
  CODE_FOR_popcountv16qi2 = 14923,
  CODE_FOR_popcountv32qi2 = 14924,
  CODE_FOR_popcountv32hi2 = 14925,
  CODE_FOR_popcountv16hi2 = 14926,
  CODE_FOR_popcountv8hi2 = 14927,
  CODE_FOR_vpshrdv_v32hi_maskz = 14928,
  CODE_FOR_vpshrdv_v16si_maskz = 14929,
  CODE_FOR_vpshrdv_v8di_maskz = 14930,
  CODE_FOR_vpshrdv_v16hi_maskz = 14931,
  CODE_FOR_vpshrdv_v8si_maskz = 14932,
  CODE_FOR_vpshrdv_v4di_maskz = 14933,
  CODE_FOR_vpshrdv_v8hi_maskz = 14934,
  CODE_FOR_vpshrdv_v4si_maskz = 14935,
  CODE_FOR_vpshrdv_v2di_maskz = 14936,
  CODE_FOR_vpshldv_v32hi_maskz = 14937,
  CODE_FOR_vpshldv_v16si_maskz = 14938,
  CODE_FOR_vpshldv_v8di_maskz = 14939,
  CODE_FOR_vpshldv_v16hi_maskz = 14940,
  CODE_FOR_vpshldv_v8si_maskz = 14941,
  CODE_FOR_vpshldv_v4di_maskz = 14942,
  CODE_FOR_vpshldv_v8hi_maskz = 14943,
  CODE_FOR_vpshldv_v4si_maskz = 14944,
  CODE_FOR_vpshldv_v2di_maskz = 14945,
  CODE_FOR_usdot_prodv16siv64qi = 14946,
  CODE_FOR_usdot_prodv8siv32qi = 14947,
  CODE_FOR_usdot_prodv4siv16qi = 14948,
  CODE_FOR_vpdpbusd_v16si_maskz = 14949,
  CODE_FOR_vpdpbusd_v8si_maskz = 14950,
  CODE_FOR_vpdpbusd_v4si_maskz = 14951,
  CODE_FOR_vpdpbusds_v16si_maskz = 14952,
  CODE_FOR_vpdpbusds_v8si_maskz = 14953,
  CODE_FOR_vpdpbusds_v4si_maskz = 14954,
  CODE_FOR_vpdpwssd_v16si_maskz = 14955,
  CODE_FOR_vpdpwssd_v8si_maskz = 14956,
  CODE_FOR_vpdpwssd_v4si_maskz = 14957,
  CODE_FOR_vpdpwssds_v16si_maskz = 14958,
  CODE_FOR_vpdpwssds_v8si_maskz = 14959,
  CODE_FOR_vpdpwssds_v4si_maskz = 14960,
  CODE_FOR_movp2qi = 14961,
  CODE_FOR_movp2hi = 14962,
  CODE_FOR_avx512f_cvtne2ps2bf16_v32bf_maskz = 14963,
  CODE_FOR_avx512f_cvtne2ps2bf16_v16bf_maskz = 14964,
  CODE_FOR_avx512f_cvtne2ps2bf16_v8bf_maskz = 14965,
  CODE_FOR_truncv4sfv4bf2 = 14966,
  CODE_FOR_vcvtneps2bf16_v4sf = 14967,
  CODE_FOR_avx512f_cvtneps2bf16_v4sf_maskz = 14968,
  CODE_FOR_avx512f_cvtneps2bf16_v4sf_mask = 14969,
  CODE_FOR_avx512f_cvtneps2bf16_v16sf_maskz = 14970,
  CODE_FOR_avx512f_cvtneps2bf16_v8sf_maskz = 14971,
  CODE_FOR_truncv8sfv8bf2 = 14972,
  CODE_FOR_truncv16sfv16bf2 = 14973,
  CODE_FOR_extendv16bfv16sf2 = 14974,
  CODE_FOR_extendv8bfv8sf2 = 14975,
  CODE_FOR_extendv4bfv4sf2 = 14976,
  CODE_FOR_avx512f_dpbf16ps_v16sf_maskz = 14977,
  CODE_FOR_avx512f_dpbf16ps_v8sf_maskz = 14978,
  CODE_FOR_avx512f_dpbf16ps_v4sf_maskz = 14979,
  CODE_FOR_encodekey128u32 = 14980,
  CODE_FOR_encodekey256u32 = 14981,
  CODE_FOR_aesdecwide128klu8 = 14982,
  CODE_FOR_aesdecwide256klu8 = 14983,
  CODE_FOR_aesencwide128klu8 = 14984,
  CODE_FOR_aesencwide256klu8 = 14985,
  CODE_FOR_vec_duplicatev64qi = 14986,
  CODE_FOR_vec_duplicatev32qi = 14987,
  CODE_FOR_vec_duplicatev16qi = 14988,
  CODE_FOR_vec_duplicatev32hi = 14989,
  CODE_FOR_vec_duplicatev16hi = 14990,
  CODE_FOR_vec_duplicatev8hi = 14991,
  CODE_FOR_vec_duplicatev16si = 14992,
  CODE_FOR_vec_duplicatev8si = 14993,
  CODE_FOR_vec_duplicatev4si = 14994,
  CODE_FOR_vec_duplicatev8di = 14995,
  CODE_FOR_vec_duplicatev4di = 14996,
  CODE_FOR_vec_duplicatev2di = 14997,
  CODE_FOR_sdot_prodv16siv64qi = 14998,
  CODE_FOR_sdot_prodv8siv32qi = 14999,
  CODE_FOR_sdot_prodv4siv16qi = 15000,
  CODE_FOR_udot_prodv16siv64qi = 15001,
  CODE_FOR_udot_prodv8siv32qi = 15002,
  CODE_FOR_udot_prodv4siv16qi = 15003,
  CODE_FOR_vpdpbssd_v16si_maskz = 15004,
  CODE_FOR_vpdpbssds_v16si_maskz = 15005,
  CODE_FOR_vpdpbsud_v16si_maskz = 15006,
  CODE_FOR_vpdpbsuds_v16si_maskz = 15007,
  CODE_FOR_vpdpbuud_v16si_maskz = 15008,
  CODE_FOR_vpdpbuuds_v16si_maskz = 15009,
  CODE_FOR_vpdpbssd_v8si_maskz = 15010,
  CODE_FOR_vpdpbssds_v8si_maskz = 15011,
  CODE_FOR_vpdpbsud_v8si_maskz = 15012,
  CODE_FOR_vpdpbsuds_v8si_maskz = 15013,
  CODE_FOR_vpdpbuud_v8si_maskz = 15014,
  CODE_FOR_vpdpbuuds_v8si_maskz = 15015,
  CODE_FOR_vpdpbssd_v4si_maskz = 15016,
  CODE_FOR_vpdpbssds_v4si_maskz = 15017,
  CODE_FOR_vpdpbsud_v4si_maskz = 15018,
  CODE_FOR_vpdpbsuds_v4si_maskz = 15019,
  CODE_FOR_vpdpbuud_v4si_maskz = 15020,
  CODE_FOR_vpdpbuuds_v4si_maskz = 15021,
  CODE_FOR_vcvtbiasph2bf8v8hf = 15022,
  CODE_FOR_vcvtbiasph2bf8sv8hf = 15023,
  CODE_FOR_vcvtbiasph2hf8v8hf = 15024,
  CODE_FOR_vcvtbiasph2hf8sv8hf = 15025,
  CODE_FOR_vcvtbiasph2bf8v8hf_mask = 15026,
  CODE_FOR_vcvtbiasph2bf8sv8hf_mask = 15027,
  CODE_FOR_vcvtbiasph2hf8v8hf_mask = 15028,
  CODE_FOR_vcvtbiasph2hf8sv8hf_mask = 15029,
  CODE_FOR_vcvtph2bf8v8hf = 15030,
  CODE_FOR_vcvtph2bf8sv8hf = 15031,
  CODE_FOR_vcvtph2hf8v8hf = 15032,
  CODE_FOR_vcvtph2hf8sv8hf = 15033,
  CODE_FOR_vcvtph2bf8v8hf_mask = 15034,
  CODE_FOR_vcvtph2bf8sv8hf_mask = 15035,
  CODE_FOR_vcvtph2hf8v8hf_mask = 15036,
  CODE_FOR_vcvtph2hf8sv8hf_mask = 15037,
  CODE_FOR_usdot_prodv16siv32hi = 15038,
  CODE_FOR_usdot_prodv8siv16hi = 15039,
  CODE_FOR_usdot_prodv4siv8hi = 15040,
  CODE_FOR_udot_prodv16siv32hi = 15041,
  CODE_FOR_udot_prodv8siv16hi = 15042,
  CODE_FOR_udot_prodv4siv8hi = 15043,
  CODE_FOR_vpdpwusd_v16si_maskz = 15044,
  CODE_FOR_vpdpwusds_v16si_maskz = 15045,
  CODE_FOR_vpdpwsud_v16si_maskz = 15046,
  CODE_FOR_vpdpwsuds_v16si_maskz = 15047,
  CODE_FOR_vpdpwuud_v16si_maskz = 15048,
  CODE_FOR_vpdpwuuds_v16si_maskz = 15049,
  CODE_FOR_vpdpwusd_v8si_maskz = 15050,
  CODE_FOR_vpdpwusds_v8si_maskz = 15051,
  CODE_FOR_vpdpwsud_v8si_maskz = 15052,
  CODE_FOR_vpdpwsuds_v8si_maskz = 15053,
  CODE_FOR_vpdpwuud_v8si_maskz = 15054,
  CODE_FOR_vpdpwuuds_v8si_maskz = 15055,
  CODE_FOR_vpdpwusd_v4si_maskz = 15056,
  CODE_FOR_vpdpwusds_v4si_maskz = 15057,
  CODE_FOR_vpdpwsud_v4si_maskz = 15058,
  CODE_FOR_vpdpwsuds_v4si_maskz = 15059,
  CODE_FOR_vpdpwuud_v4si_maskz = 15060,
  CODE_FOR_vpdpwuuds_v4si_maskz = 15061,
  CODE_FOR_vdpphps_v16sf_maskz = 15062,
  CODE_FOR_vdpphps_v8sf_maskz = 15063,
  CODE_FOR_vdpphps_v4sf_maskz = 15064,
  CODE_FOR_smaxv32bf3 = 15065,
  CODE_FOR_sminv32bf3 = 15066,
  CODE_FOR_smaxv16bf3 = 15067,
  CODE_FOR_sminv16bf3 = 15068,
  CODE_FOR_smaxv8bf3 = 15069,
  CODE_FOR_sminv8bf3 = 15070,
  CODE_FOR_avx10_2_fmaddbf16_v32bf_maskz = 15071,
  CODE_FOR_avx10_2_fmaddbf16_v16bf_maskz = 15072,
  CODE_FOR_avx10_2_fmaddbf16_v8bf_maskz = 15073,
  CODE_FOR_avx10_2_fnmaddbf16_v32bf_maskz = 15074,
  CODE_FOR_avx10_2_fnmaddbf16_v16bf_maskz = 15075,
  CODE_FOR_avx10_2_fnmaddbf16_v8bf_maskz = 15076,
  CODE_FOR_avx10_2_fmsubbf16_v32bf_maskz = 15077,
  CODE_FOR_avx10_2_fmsubbf16_v16bf_maskz = 15078,
  CODE_FOR_avx10_2_fmsubbf16_v8bf_maskz = 15079,
  CODE_FOR_avx10_2_fnmsubbf16_v32bf_maskz = 15080,
  CODE_FOR_avx10_2_fnmsubbf16_v16bf_maskz = 15081,
  CODE_FOR_avx10_2_fnmsubbf16_v8bf_maskz = 15082,
  CODE_FOR_sse2_lfence = 15083,
  CODE_FOR_sse_sfence = 15084,
  CODE_FOR_sse2_mfence = 15085,
  CODE_FOR_mem_thread_fence = 15086,
  CODE_FOR_atomic_loadqi = 15087,
  CODE_FOR_atomic_loadhi = 15088,
  CODE_FOR_atomic_loadsi = 15089,
  CODE_FOR_atomic_loaddi = 15090,
  CODE_FOR_atomic_storeqi = 15091,
  CODE_FOR_atomic_storehi = 15092,
  CODE_FOR_atomic_storesi = 15093,
  CODE_FOR_atomic_storedi = 15094,
  CODE_FOR_atomic_compare_and_swapqi = 15095,
  CODE_FOR_atomic_compare_and_swaphi = 15096,
  CODE_FOR_atomic_compare_and_swapsi = 15097,
  CODE_FOR_atomic_compare_and_swapdi = 15098,
  CODE_FOR_atomic_compare_and_swapti = 15099,
  CODE_FOR_atomic_fetch_andqi = 15100,
  CODE_FOR_atomic_fetch_orqi = 15101,
  CODE_FOR_atomic_fetch_xorqi = 15102,
  CODE_FOR_atomic_fetch_andhi = 15103,
  CODE_FOR_atomic_fetch_orhi = 15104,
  CODE_FOR_atomic_fetch_xorhi = 15105,
  CODE_FOR_atomic_fetch_andsi = 15106,
  CODE_FOR_atomic_fetch_orsi = 15107,
  CODE_FOR_atomic_fetch_xorsi = 15108,
  CODE_FOR_atomic_and_fetchqi = 15109,
  CODE_FOR_atomic_or_fetchqi = 15110,
  CODE_FOR_atomic_xor_fetchqi = 15111,
  CODE_FOR_atomic_and_fetchhi = 15112,
  CODE_FOR_atomic_or_fetchhi = 15113,
  CODE_FOR_atomic_xor_fetchhi = 15114,
  CODE_FOR_atomic_and_fetchsi = 15115,
  CODE_FOR_atomic_or_fetchsi = 15116,
  CODE_FOR_atomic_xor_fetchsi = 15117,
  CODE_FOR_atomic_fetch_nandqi = 15118,
  CODE_FOR_atomic_fetch_nandhi = 15119,
  CODE_FOR_atomic_fetch_nandsi = 15120,
  CODE_FOR_atomic_nand_fetchqi = 15121,
  CODE_FOR_atomic_nand_fetchhi = 15122,
  CODE_FOR_atomic_nand_fetchsi = 15123,
  CODE_FOR_atomic_fetch_anddi = 15124,
  CODE_FOR_atomic_fetch_ordi = 15125,
  CODE_FOR_atomic_fetch_xordi = 15126,
  CODE_FOR_atomic_fetch_andti = 15127,
  CODE_FOR_atomic_fetch_orti = 15128,
  CODE_FOR_atomic_fetch_xorti = 15129,
  CODE_FOR_atomic_and_fetchdi = 15130,
  CODE_FOR_atomic_or_fetchdi = 15131,
  CODE_FOR_atomic_xor_fetchdi = 15132,
  CODE_FOR_atomic_and_fetchti = 15133,
  CODE_FOR_atomic_or_fetchti = 15134,
  CODE_FOR_atomic_xor_fetchti = 15135,
  CODE_FOR_atomic_fetch_nanddi = 15136,
  CODE_FOR_atomic_fetch_nandti = 15137,
  CODE_FOR_atomic_nand_fetchdi = 15138,
  CODE_FOR_atomic_nand_fetchti = 15139,
  CODE_FOR_atomic_bit_test_and_sethi = 15140,
  CODE_FOR_atomic_bit_test_and_setsi = 15141,
  CODE_FOR_atomic_bit_test_and_setdi = 15142,
  CODE_FOR_atomic_bit_test_and_complementhi = 15143,
  CODE_FOR_atomic_bit_test_and_complementsi = 15144,
  CODE_FOR_atomic_bit_test_and_complementdi = 15145,
  CODE_FOR_atomic_bit_test_and_resethi = 15146,
  CODE_FOR_atomic_bit_test_and_resetsi = 15147,
  CODE_FOR_atomic_bit_test_and_resetdi = 15148,
  CODE_FOR_atomic_add_fetch_cmp_0qi = 15149,
  CODE_FOR_atomic_sub_fetch_cmp_0qi = 15150,
  CODE_FOR_atomic_add_fetch_cmp_0hi = 15151,
  CODE_FOR_atomic_sub_fetch_cmp_0hi = 15152,
  CODE_FOR_atomic_add_fetch_cmp_0si = 15153,
  CODE_FOR_atomic_sub_fetch_cmp_0si = 15154,
  CODE_FOR_atomic_add_fetch_cmp_0di = 15155,
  CODE_FOR_atomic_sub_fetch_cmp_0di = 15156,
  CODE_FOR_atomic_and_fetch_cmp_0qi = 15157,
  CODE_FOR_atomic_or_fetch_cmp_0qi = 15158,
  CODE_FOR_atomic_xor_fetch_cmp_0qi = 15159,
  CODE_FOR_atomic_and_fetch_cmp_0hi = 15160,
  CODE_FOR_atomic_or_fetch_cmp_0hi = 15161,
  CODE_FOR_atomic_xor_fetch_cmp_0hi = 15162,
  CODE_FOR_atomic_and_fetch_cmp_0si = 15163,
  CODE_FOR_atomic_or_fetch_cmp_0si = 15164,
  CODE_FOR_atomic_xor_fetch_cmp_0si = 15165,
  CODE_FOR_atomic_and_fetch_cmp_0di = 15166,
  CODE_FOR_atomic_or_fetch_cmp_0di = 15167,
  CODE_FOR_atomic_xor_fetch_cmp_0di = 15168
};

const unsigned int NUM_INSN_CODES = 15169;
#endif /* GCC_INSN_CODES_H */
